@@ -1,7 +1,7 @@
 <?php
-/* 
+/*
 ** ZABBIX
-** Copyright (C) 2000-2005 SIA Zabbix
+** Copyright (C) 2000-2009 SIA Zabbix
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -19,15 +19,14 @@
 **/
 ?>
 <?php
-	require_once 'include/config.inc.php';
-	require_once 'include/graphs.inc.php';
-	require_once 'include/classes/chart.inc.php';
-	
-	$page['file']	= 'chart3.php';
-	$page['title']	= 'S_CHART';
-	$page['type']	= PAGE_TYPE_IMAGE;
+require_once('include/config.inc.php');
+require_once('include/graphs.inc.php');
 
-include_once 'include/page_header.php';
+$page['file']	= 'chart3.php';
+$page['title']	= 'S_CHART';
+$page['type']	= PAGE_TYPE_IMAGE;
+
+include_once('include/page_header.php');
 
 ?>
 <?php
@@ -36,15 +35,22 @@ include_once 'include/page_header.php';
 		'period'=>	array(T_ZBX_INT, O_OPT,	P_NZERO,	BETWEEN(ZBX_MIN_PERIOD,ZBX_MAX_PERIOD),	null),
 		'from'=>	array(T_ZBX_INT, O_OPT,	P_NZERO,	null,			null),
 		'stime'=>	array(T_ZBX_INT, O_OPT,	P_NZERO,	null,			null),
-		'border'=>	array(T_ZBX_INT, O_OPT,	P_NZERO,	IN('0,1'),		null),
+
 		'name'=>	array(T_ZBX_STR, O_OPT,	NULL,		null,			null),
 		'width'=>	array(T_ZBX_INT, O_OPT,	NULL,		BETWEEN(0,65535),	null),
 		'height'=>	array(T_ZBX_INT, O_OPT,	NULL,		BETWEEN(0,65535),	null),
-		'yaxistype'=>	array(T_ZBX_INT, O_OPT,	NULL,		IN('0,1,2'),		null),
+
+		'ymin_type'=>	array(T_ZBX_INT, O_OPT,	NULL,		IN('0,1,2'),		null),
+		'ymax_type'=>	array(T_ZBX_INT, O_OPT,	NULL,		IN('0,1,2'),		null),
+
+		'ymin_itemid'=>	array(T_ZBX_INT, O_OPT,	NULL,		DB_ID,	null),
+		'ymax_itemid'=>	array(T_ZBX_INT, O_OPT,	NULL,		DB_ID,	null),
+
 		'graphtype'=>	array(T_ZBX_INT, O_OPT,	NULL,		IN('0,1'),		null),
+
 		'yaxismin'=>	array(T_ZBX_DBL, O_OPT,	NULL,		BETWEEN(-65535,65535),	null),
 		'yaxismax'=>	array(T_ZBX_DBL, O_OPT,	NULL,		null,	null),
-		'yaxismax'=>	array(T_ZBX_DBL, O_OPT,	NULL,		null,	null),
+
 		'percent_left'=>	array(T_ZBX_DBL, O_OPT,	 NULL,	BETWEEN(0,100),	null),
 		'percent_right'=>	array(T_ZBX_DBL, O_OPT,	 NULL,	BETWEEN(0,100),	null),
 
@@ -55,7 +61,7 @@ include_once 'include/page_header.php';
 ?>
 <?php
 	$available_hosts = get_accessible_hosts_by_user($USER_DETAILS, PERM_READ_ONLY, PERM_RES_IDS_ARRAY, get_current_nodeid(true));
-	
+
 	$items = get_request('items', array());
 	asort_by_key($items, 'sortorder');
 
@@ -67,53 +73,65 @@ include_once 'include/page_header.php';
 			access_deny();
 		}
 	}
-	
-	$graph = new Chart(get_request('graphtype'	,GRAPH_TYPE_NORMAL));
+
+	$effectiveperiod = navigation_bar_calc();
+
+	$graph = new CChart(get_request('graphtype'	,GRAPH_TYPE_NORMAL));
 
 	$chart_header = '';
-	if(id2nodeid($host['hostid']) != get_current_nodeid()){
-		$chart_header = get_node_name_by_elid($host['hostid'],true);
+	if(isset($host)){
+		if(id2nodeid($host['hostid']) != get_current_nodeid()){
+			$chart_header = get_node_name_by_elid($host['hostid'],true, ': ');
+		}
+		$chart_header.= $host['host'].':';
 	}
-	$chart_header.= $host['host'].':'.get_request('name','');
-	
+	$chart_header.=get_request('name','');
+
 	$graph->setHeader($chart_header);
 
 	unset($host);
 
-	if(isset($_REQUEST['period']))		$graph->SetPeriod($_REQUEST['period']);
-	if(isset($_REQUEST['from']))		$graph->SetFrom($_REQUEST['from']);
-	if(isset($_REQUEST['stime']))		$graph->SetSTime($_REQUEST['stime']);
-	if(isset($_REQUEST['border']))		$graph->SetBorder(0);
+	navigation_bar_calc();
 
-	$graph->SetWidth(get_request('width',		900));
-	$graph->SetHeight(get_request('height',		200));
+//SDI($_REQUEST['stime']);
+	$graph->setPeriod($_REQUEST['period']);
+	$graph->setSTime($_REQUEST['stime']);
+
+	$graph->setWidth(get_request('width',		900));
+	$graph->setHeight(get_request('height',		200));
+
+	$graph->showWorkPeriod(get_request('showworkperiod'	,1));
+	$graph->showTriggers(get_request('showtriggers'		,1));
+
+	$graph->setYMinAxisType(get_request('ymin_type'		,GRAPH_YAXIS_TYPE_CALCULATED));
+	$graph->setYMaxAxisType(get_request('ymax_type'		,GRAPH_YAXIS_TYPE_CALCULATED));
+
+	$graph->setYAxisMin(get_request('yaxismin'		,0.00));
+	$graph->setYAxisMax(get_request('yaxismax'		,100.00));
+
+	$graph->setYMinItemId(get_request('ymin_itemid'		,0));
+	$graph->setYMaxItemId(get_request('ymax_itemid'		,0));
 
-	$graph->ShowWorkPeriod(get_request('showworkperiod'	,1));
-	$graph->ShowTriggers(get_request('showtriggers'		,1));
-	$graph->SetYAxisType(get_request('yaxistype'		,GRAPH_YAXIS_TYPE_CALCULATED));
-	$graph->SetYAxisMin(get_request('yaxismin'		,0.00));
-	$graph->SetYAxisMax(get_request('yaxismax'		,100.00));
 	$graph->setLeftPercentage(get_request('percent_left',0));
 	$graph->setRightPercentage(get_request('percent_right',0));
 
-
-	foreach($items as $id => $gitem){
-		$graph->AddItem(
+	foreach($items as $gnum => $gitem){
+		$graph->addItem(
 			$gitem['itemid'],
-			$gitem['yaxisside'],
-			$gitem['calc_fnc'],
-			$gitem['color'],
-			$gitem['drawtype'],
-			$gitem['type'],
-			$gitem['periods_cnt']
+			isset($gitem['yaxisside'])?$gitem['yaxisside']:null,
+			isset($gitem['calc_fnc'])?$gitem['calc_fnc']:null,
+			isset($gitem['color'])?$gitem['color']:null,
+			isset($gitem['drawtype'])?$gitem['drawtype']:null,
+			isset($gitem['type'])?$gitem['type']:null,
+			isset($gitem['periods_cnt'])?$gitem['periods_cnt']:null
 			);
 
 		unset($items[$id]);
 	}
-	$graph->Draw();
+	$graph->draw();
 ?>
 <?php
 
-include_once 'include/page_footer.php';
+include_once('include/page_footer.php');
 
 ?>
