@@ -1,5 +1,5 @@
 <?php
-/* 
+/*
 ** ZABBIX
 ** Copyright (C) 2000-2005 SIA Zabbix
 **
@@ -19,31 +19,32 @@
 **/
 ?>
 <?php
-	require_once "include/config.inc.php";
-	require_once "include/hosts.inc.php";
-	require_once "include/httptest.inc.php";
-	require_once "include/forms.inc.php";
+	require_once('include/config.inc.php');
+	require_once('include/hosts.inc.php');
+	require_once('include/httptest.inc.php');
+	require_once('include/forms.inc.php');
 
-	$page["title"] = "S_STATUS_OF_WEB_MONITORING";
-	$page["file"] = "httpmon.php";
+	$page['title'] = "S_STATUS_OF_WEB_MONITORING";
+	$page['file'] = 'httpmon.php';
 	$page['hist_arg'] = array('open','groupid','hostid');
-	
+
 	define('ZBX_PAGE_DO_REFRESH', 1);
 
-include_once "include/page_header.php";
+include_once('include/page_header.php');
 
 ?>
 <?php
 
 //		VAR			TYPE	OPTIONAL FLAGS	VALIDATION	EXCEPTION
 	$fields=array(
-		"applications"=>	array(T_ZBX_INT, O_OPT,	null,	DB_ID,		null),
-		"applicationid"=>	array(T_ZBX_INT, O_OPT,	null,	DB_ID,		null),
-		"close"=>		array(T_ZBX_INT, O_OPT,	null,	IN("1"),	null),
-		"open"=>		array(T_ZBX_INT, O_OPT,	null,	IN("1"),	null),
+		'applications'=>	array(T_ZBX_INT, O_OPT,	null,	DB_ID,		null),
+		'applicationid'=>	array(T_ZBX_INT, O_OPT,	null,	DB_ID,		null),
+		'close'=>		array(T_ZBX_INT, O_OPT,	null,	IN('1'),	null),
+		'open'=>		array(T_ZBX_INT, O_OPT,	null,	IN('1'),	null),
+		'fullscreen'=>	array(T_ZBX_INT, O_OPT,	P_SYS,	IN('0,1'),	NULL),
 
-		"groupid"=>	array(T_ZBX_INT, O_OPT,	 P_SYS,	DB_ID,	null),
-		"hostid"=>	array(T_ZBX_INT, O_OPT,  P_SYS,	DB_ID,	null),
+		'groupid'=>	array(T_ZBX_INT, O_OPT,	 P_SYS,	DB_ID,	null),
+		'hostid'=>	array(T_ZBX_INT, O_OPT,  P_SYS,	DB_ID,	null),
 //ajax
 		'favobj'=>		array(T_ZBX_STR, O_OPT, P_ACT,	NULL,			'isset({favid})'),
 		'favid'=>		array(T_ZBX_STR, O_OPT, P_ACT,  NOT_EMPTY,		NULL),
@@ -58,7 +59,7 @@ include_once "include/page_header.php";
 		if('hat' == $_REQUEST['favobj']){
 			update_profile('web.httpmon.hats.'.$_REQUEST['favid'].'.state',$_REQUEST['state'], PROFILE_TYPE_INT);
 		}
-	}	
+	}
 
 	if((PAGE_TYPE_JS == $page['type']) || (PAGE_TYPE_HTML_BLOCK == $page['type'])){
 		exit();
@@ -67,8 +68,8 @@ include_once "include/page_header.php";
 	validate_sort_and_sortorder('wt.name',ZBX_SORT_DOWN);
 
 	$options = array('allow_all_hosts','monitored_hosts','with_monitored_httptests');
-	if(!$ZBX_WITH_SUBNODES)	array_push($options,'only_current_node');
-	
+	if(!$ZBX_WITH_ALL_NODES)	array_push($options,'only_current_node');
+
 //SDI($_REQUEST['groupid'].' : '.$_REQUEST['hostid']);
 	$params = array();
 	foreach($options as  $option) $params[$option] = 1;
@@ -79,7 +80,7 @@ include_once "include/page_header.php";
 //SDI($_REQUEST['groupid'].' : '.$_REQUEST['hostid']);
 ?>
 <?php
-	$_REQUEST['applications'] = get_request('applications',get_profile('web.httpmon.applications',array(),PROFILE_TYPE_ARRAY_ID));
+	$_REQUEST['applications'] = get_request('applications',get_profile('web.httpmon.applications',array()));
 
 	if(isset($_REQUEST['open'])){
 		if(!isset($_REQUEST['applicationid'])){
@@ -89,8 +90,8 @@ include_once "include/page_header.php";
 		else if(!uint_in_array($_REQUEST['applicationid'],$_REQUEST['applications'])){
 			array_push($_REQUEST['applications'],$_REQUEST['applicationid']);
 		}
-		
-	} 
+
+	}
 	else if(isset($_REQUEST['close'])){
 		if(!isset($_REQUEST['applicationid'])){
 			$_REQUEST['applications'] = array();
@@ -109,11 +110,22 @@ include_once "include/page_header.php";
 ?>
 <?php
 
-	$p_elements = array();
-	
+	$httpmon_wdgt = new CWidget();
+
 // Table HEADER
-	$form = new CForm();
-	$form->setMethod('get');
+	$url = 'httpmon.php?fullscreen='.($_REQUEST['fullscreen']?'0':'1');
+
+	$fs_icon = new CDiv(SPACE,'fullscreen');
+	$fs_icon->setAttribute('title',$_REQUEST['fullscreen']?S_NORMAL.' '.S_VIEW:S_FULLSCREEN);
+	$fs_icon->addAction('onclick',new CJSscript("javascript: document.location = '".$url."';"));
+
+	show_table_header(S_STATUS_OF_WEB_MONITORING_BIG, $fs_icon);
+	echo SBR;
+
+// 2nd header
+	$r_form = new CForm();
+	$r_form->setMethod('get');
+	$r_form->addVar('fullscreen',$_REQUEST['fullscreen']);
 
 	$available_groups = $PAGE_GROUPS['groupids'];
 	$available_hosts = $PAGE_HOSTS['hostids'];
@@ -122,21 +134,24 @@ include_once "include/page_header.php";
 	$cmbHosts = new CComboBox('hostid',$PAGE_HOSTS['selected'],'javascript: submit();');
 
 	foreach($PAGE_GROUPS['groups'] as $groupid => $name){
-		$cmbGroups->addItem($groupid, get_node_name_by_elid($groupid).$name);
+		$cmbGroups->addItem($groupid, get_node_name_by_elid($groupid, null, ': ').$name);
 	}
 	foreach($PAGE_HOSTS['hosts'] as $hostid => $name){
-		$cmbHosts->addItem($hostid, get_node_name_by_elid($hostid).$name);
+		$cmbHosts->addItem($hostid, get_node_name_by_elid($hostid, null, ': ').$name);
 	}
-	
-	$form->addItem(array(S_GROUP.SPACE,$cmbGroups));
-	$form->addItem(array(SPACE.S_HOST.SPACE,$cmbHosts));
-			
-	$p_elements[] = get_table_header(SPACE, $form);
+
+	$r_form->addItem(array(S_GROUP.SPACE,$cmbGroups));
+	$r_form->addItem(array(SPACE.S_HOST.SPACE,$cmbHosts));
+
+	$httpmon_wdgt->addHeader(S_WEB_CHECKS_BIG, $r_form);
+	$httpmon_wdgt->addItem(SPACE);
+//	show_table_header(S_STATUS_OF_WEB_MONITORING_BIG, $r_form);
+//-----------------
 
 // TABLE
 	$form = new CForm();
 	$form->setMethod('get');
-	
+
 	$form->setName('scenarios');
 	$form->addVar('hostid',$_REQUEST['hostid']);
 
@@ -147,7 +162,7 @@ include_once "include/page_header.php";
 
 	$table  = new CTableInfo();
 	$table->SetHeader(array(
-		is_show_subnodes() ? make_sorting_link(S_NODE,'h.hostid') : null,
+		is_show_all_nodes() ? make_sorting_link(S_NODE,'h.hostid') : null,
 		$_REQUEST['hostid'] ==0 ? make_sorting_link(S_HOST,'h.host') : NULL,
 		array($link, SPACE, make_sorting_link(S_NAME,'wt.name')),
 		S_NUMBER_OF_STEPS,
@@ -156,15 +171,15 @@ include_once "include/page_header.php";
 		S_STATUS));
 
 	$any_app_exist = false;
-	
+
 	$db_apps = array();
 	$db_appids = array();
-	
+
 	$sql_where = '';
 	if($_REQUEST['hostid']>0){
-		$sql_where = ' AND h.hostid='.$_REQUEST['hostid'];	
+		$sql_where = ' AND h.hostid='.$_REQUEST['hostid'];
 	}
-	
+
 	$sql = 'SELECT DISTINCT h.host,h.hostid,a.* '.
 			' FROM applications a,hosts h '.
 			' WHERE a.hostid=h.hostid '.
@@ -175,7 +190,7 @@ include_once "include/page_header.php";
 	$db_app_res = DBselect($sql);
 	while($db_app = DBfetch($db_app_res)){
 		$db_app['scenarios_cnt'] = 0;
-		
+
 		$db_apps[$db_app['applicationid']] = $db_app;
 		$db_appids[$db_app['applicationid']] = $db_app['applicationid'];
 	}
@@ -183,7 +198,7 @@ include_once "include/page_header.php";
 
 	$db_httptests = array();
 	$db_httptestids = array();
-	
+
 	$sql = 'SELECT wt.*,a.name as application, h.host,h.hostid '.
 		' FROM httptest wt '.
 			' LEFT JOIN applications a on wt.applicationid=a.applicationid '.
@@ -196,11 +211,11 @@ include_once "include/page_header.php";
 	while($httptest_data = DBfetch($db_httptests_res)){
 		$httptest_data['step_cout'] = null;
 		$db_apps[$httptest_data['applicationid']]['scenarios_cnt']++;
-		
+
 		$db_httptests[$httptest_data['httptestid']] = $httptest_data;
 		$db_httptestids[$httptest_data['httptestid']] = $httptest_data['httptestid'];
 	}
-	
+
 	$sql = 'SELECT hs.httptestid, COUNT(hs.httpstepid) as cnt '.
 			' FROM httpstep hs'.
 			' WHERE '.DBcondition('hs.httptestid',$db_httptestids).
@@ -211,17 +226,17 @@ include_once "include/page_header.php";
 		$db_httptests[$step_cout['httptestid']]['step_cout'] = $step_cout['cnt'];
 	}
 
-	$tab_rows = array();	
+	$tab_rows = array();
 	foreach($db_httptests as $httptestid => $httptest_data){
 		$db_app = &$db_apps[$httptest_data['applicationid']];
 
 		if(!isset($tab_rows[$db_app['applicationid']])) $tab_rows[$db_app['applicationid']] = array();
 		$app_rows = &$tab_rows[$db_app['applicationid']];
-		
+
 		if(!uint_in_array($db_app['applicationid'],$_REQUEST['applications']) && !isset($show_all_apps)) continue;
-				
+
 		$name = array();
-		array_push($name, new CLink($httptest_data['name'],'httpdetails.php?httptestid='.$httptest_data['httptestid'],'action'));
+		array_push($name, new CLink($httptest_data['name'],'httpdetails.php?httptestid='.$httptest_data['httptestid']));
 
 		if(isset($httptest_data['lastcheck']))
 			$lastcheck = date(S_DATE_FORMAT_YMDHMS,$httptest_data['lastcheck']);
@@ -257,7 +272,7 @@ include_once "include/page_header.php";
 		}
 
 		array_push($app_rows, new CRow(array(
-			is_show_subnodes()?SPACE:NULL,
+			is_show_all_nodes()?SPACE:NULL,
 			($_REQUEST['hostid']>0)?NULL:SPACE,
 			array(str_repeat(SPACE,6), $name),
 			$httptest_data['step_cout'],
@@ -268,10 +283,10 @@ include_once "include/page_header.php";
 	}
 	unset($app_rows);
 	unset($db_app);
-	
+
 	foreach($tab_rows as $appid => $app_rows){
 		$db_app = &$db_apps[$appid];
-		
+
 		if(uint_in_array($db_app['applicationid'],$_REQUEST['applications']) || isset($show_all_apps))
 			$link = new CLink(new CImg('images/general/opened.gif'),
 				'?close=1&applicationid='.$db_app['applicationid'].
@@ -293,24 +308,16 @@ include_once "include/page_header.php";
 			));
 
 		$any_app_exist = true;
-	
+
 		foreach($app_rows as $row)
 			$table->addRow($row);
 	}
 
 	$form->addItem($table);
-	
-	$p_elements[] = $form;
-	
-	$latest_hat = create_hat(
-			S_STATUS_OF_WEB_MONITORING_BIG,
-			$p_elements,
-			null,
-			'hat_httpmon',
-			get_profile('web.httpmon.hats.hat_httpmon.state',1)
-	);
 
-	$latest_hat->Show();
+	$httpmon_wdgt->addItem($form);
+
+	$httpmon_wdgt->show();
 ?>
 <?php
 
