@@ -1,5 +1,5 @@
 <?php
-/* 
+/*
 ** ZABBIX
 ** Copyright (C) 2000-2005 SIA Zabbix
 **
@@ -19,22 +19,22 @@
 **/
 ?>
 <?php
-	require_once "include/config.inc.php";
-	require_once "include/images.inc.php";
+	require_once('include/config.inc.php');
+	require_once('include/images.inc.php');
 
 	$page['file']	= 'image.php';
 	$page['title']	= 'S_IMAGE';
 	$page['type']	= PAGE_TYPE_IMAGE;
 
-include_once "include/page_header.php";
-	
+include_once('include/page_header.php');
+
 ?>
 <?php
 //		VAR			TYPE	OPTIONAL FLAGS	VALIDATION	EXCEPTION
 	$fields=array(
-		"imageid"=>		array(T_ZBX_INT, O_MAND,P_SYS,	DB_ID,	NULL),
-		"width"=>		array(T_ZBX_INT, O_OPT,	P_SYS,	BETWEEN(1,2000),	NULL),
-		"height"=>		array(T_ZBX_INT, O_OPT,	P_SYS,	BETWEEN(1,2000),	NULL),
+		'imageid'=>		array(T_ZBX_INT, O_MAND,P_SYS,	DB_ID,	NULL),
+		'width'=>		array(T_ZBX_INT, O_OPT,	P_SYS,	BETWEEN(1,2000),	NULL),
+		'height'=>		array(T_ZBX_INT, O_OPT,	P_SYS,	BETWEEN(1,2000),	NULL),
 	);
 	check_fields($fields);
 ?>
@@ -42,7 +42,7 @@ include_once "include/page_header.php";
 
 	$resize = 0;
 
-	if(isset($_REQUEST["width"]) || isset($_REQUEST["height"])){
+	if(isset($_REQUEST['width']) || isset($_REQUEST['height'])){
 		$resize = 1;
 		$th_width = get_request('width',0);
 		$th_height = get_request('height',0);
@@ -50,7 +50,7 @@ include_once "include/page_header.php";
 
 	if(!($row = get_image_by_imageid($_REQUEST['imageid']))){
 		error('Incorrect image index');
-		include_once "include/page_footer.php";
+		include_once('include/page_footer.php');
 	}
 
 	$source = imagecreatefromstring($row['image']);
@@ -64,10 +64,10 @@ include_once "include/page_header.php";
 		if($src_width > $th_width || $src_height > $th_height){
 			if($th_width == 0){
 				$th_width = $th_height * $src_width/$src_height;
-			} 
+			}
 			else if($th_height == 0){
 				$th_height = $th_width * $src_height/$src_width;
-			} 
+			}
 			else {
 				$a = $th_width/$th_height;
 				$b = $src_width/$src_height;
@@ -75,7 +75,7 @@ include_once "include/page_header.php";
 				if($a > $b){
 					$th_width  = $b * $th_height;
 					$th_height = $th_height;
-				} 
+				}
 				else {
 					$th_height = $th_width/$b;
 					$th_width  = $th_width;
@@ -91,9 +91,9 @@ include_once "include/page_header.php";
 
 			imagecopyresized(
 				$thumb, $source,
-				0, 0, 
-				0, 0, 
-				$th_width, $th_height, 
+				0, 0,
+				0, 0,
+				$th_width, $th_height,
 				$src_width, $src_height);
 
 			imagedestroy($source);
