@@ -27,12 +27,12 @@ function action_accessible($actionid,$perm){
 
 	$result = false;
 
-	if (DBselect('select actionid from actions where actionid='.$actionid.' and '.DBin_node('actionid'))){
+	if(DBselect('select actionid from actions where actionid='.$actionid.' and '.DBin_node('actionid'))){
 		$result = true;
-		
+
 		$available_hosts = get_accessible_hosts_by_user($USER_DETAILS,$perm,null,get_current_nodeid(true));
 		$available_groups = get_accessible_groups_by_user($USER_DETAILS,$perm,null,get_current_nodeid(true));
-		
+
 		$db_result = DBselect('SELECT * FROM conditions WHERE actionid='.$actionid);
 		while(($ac_data = DBfetch($db_result)) && $result){
 			if($ac_data['operator'] != 0) continue;
@@ -56,7 +56,7 @@ function action_accessible($actionid,$perm){
 							' AND f.triggerid=t.triggerid'.
 							' AND i.itemid=f.itemid '.
 							' AND '.DBcondition('i.hostid',$available_hosts, true);
-							
+
 					if(DBfetch(DBselect($sql,1))){
 						$result = false;
 					}
@@ -101,7 +101,7 @@ function check_permission_for_action_conditions($conditions){
 							' AND '.DBcondition('i.hostid',$available_hosts, true);
 //								' AND e.eventid='.$ac_data['value'].
 //								' AND t.triggerid=e.objectid';
-						
+
 				if(DBfetch(DBselect($sql,1))){
 					error(S_INCORRECT_TRIGGER);
 					$result = false;
@@ -114,20 +114,20 @@ function check_permission_for_action_conditions($conditions){
 }
 
 function get_action_by_actionid($actionid){
-	$sql="select * from actions where actionid=$actionid"; 
+	$sql='select * from actions where actionid='.$actionid;
 	$result=DBselect($sql);
 
 	if($row=DBfetch($result)){
 		return	$row;
 	}
 	else{
-		error("No action with actionid=[$actionid]");
+		error('No action with actionid=['.$actionid.']');
 	}
 return	$result;
 }
 
 function get_operations_by_actionid($actionid){
-	$sql='SELECT * FROM operations WHERE actionid='.$actionid; 
+	$sql='SELECT * FROM operations WHERE actionid='.$actionid;
 	$result=DBselect($sql);
 
 return	$result;
@@ -145,7 +145,7 @@ function add_action_condition($actionid, $condition){
 			$condition['operator'].','.
 			zbx_dbstr($condition['value']).
 		')');
-	
+
 	if(!$result)
 		return $result;
 
@@ -154,7 +154,7 @@ function add_action_condition($actionid, $condition){
 
 function add_action_operation($actionid, $operation){
 	$operationid = get_dbid('operations','operationid');
-	
+
 	if(!isset($operation['default_msg'])) $operation['default_msg'] = 0;
 	if(!isset($operation['opconditions'])) $operation['opconditions'] = array();
 
@@ -178,6 +178,8 @@ function add_action_operation($actionid, $operation){
 		$result &= add_operation_condition($operationid, $opcondition);
 	}
 
+	$result &= add_operation_mediatype($operationid, $operation['mediatypeid']);
+
 	return $operationid;
 }
 
@@ -192,14 +194,30 @@ function add_operation_condition($operationid, $opcondition){
 			$opcondition['operator'].','.
 			zbx_dbstr($opcondition['value']).
 		')');
-	
+
 	if(!$result)
 		return $result;
 
 return $opconditionid;
 }
 
-// Add Action			
+// Add operation mediatype
+function add_operation_mediatype($operationid, $mediatypeid){
+	if (0 == $mediatypeid)
+		return;
+
+	$opmediatypeid = get_dbid('opmediatypes', 'opmediatypeid');
+
+	$result = DBexecute('INSERT INTO opmediatypes (opmediatypeid,operationid,mediatypeid)'.
+		' values ('.$opmediatypeid.','.$operationid.','.$mediatypeid.')');
+
+	if(!$result)
+		return $result;
+
+return $opmediatypeid;
+}
+
+// Add Action
 function add_action($name, $eventsource, $esc_period, $def_shortdata, $def_longdata, $recovery_msg, $r_shortdata, $r_longdata, $evaltype, $status, $conditions, $operations){
 	if(!is_array($conditions) || count($conditions) == 0){
 		/*
@@ -220,17 +238,15 @@ function add_action($name, $eventsource, $esc_period, $def_shortdata, $def_longd
 		return false;
 	}
 
-	foreach($operations as $operation)
-		if( !validate_operation($operation) )	return false;
+	foreach($operations as $num => $operation){
+		if(!validate_operation($operation))	return false;
+	}
 
 	$actionid=get_dbid('actions','actionid');
 
 	$result = DBexecute('INSERT INTO actions (actionid,name,eventsource,esc_period,def_shortdata,def_longdata,recovery_msg,r_shortdata,r_longdata,evaltype,status)'.
 				' VALUES ('.$actionid.','.zbx_dbstr($name).','.$eventsource.','.$esc_period.','.zbx_dbstr($def_shortdata).','.zbx_dbstr($def_longdata).','.$recovery_msg.','.zbx_dbstr($r_shortdata).','.zbx_dbstr($r_longdata).','.$evaltype.','.$status.')');
 
-	if(!$result)
-		return $result;
-
 	foreach($operations as $operation)
 		if(!$result = add_action_operation($actionid, $operation))
 			break;
@@ -241,10 +257,13 @@ function add_action($name, $eventsource, $esc_period, $def_shortdata, $def_longd
 			break;
 	}
 
+	if(!$result)
+		return $result;
+
 return $actionid;
 }
 
-# Update Action
+// Update Action
 
 function update_action($actionid, $name, $eventsource, $esc_period, $def_shortdata, $def_longdata, $recovery_msg, $r_shortdata, $r_longdata, $evaltype, $status, $conditions, $operations){
 
@@ -267,8 +286,9 @@ function update_action($actionid, $name, $eventsource, $esc_period, $def_shortda
 		return false;
 	}
 
-	foreach($operations as $operation)
-		if( !validate_operation($operation) )	return false;
+	foreach($operations as $num => $operation){
+		if(!validate_operation($operation))	return false;
+	}
 
 	$result = DBexecute('UPDATE actions SET name='.zbx_dbstr($name).
 							',eventsource='.$eventsource.
@@ -288,9 +308,10 @@ function update_action($actionid, $name, $eventsource, $esc_period, $def_shortda
 		$opers = get_operations_by_actionid($actionid);
 		while($operation = DBFetch($opers)){
 			DBexecute('DELETE FROM opconditions WHERE operationid='.$operation['operationid']);
+			DBexecute('DELETE FROM opmediatypes WHERE operationid='.$operation['operationid']);
 		}
 		DBexecute('DELETE FROM operations WHERE actionid='.$actionid);
-		
+
 
 		foreach($operations as $operation)
 			if(!$result = add_action_operation($actionid, $operation))
@@ -300,13 +321,13 @@ function update_action($actionid, $name, $eventsource, $esc_period, $def_shortda
 			foreach($conditions as $condition)
 			if(!$result = add_action_condition($actionid, $condition))
 				break;
-		}		
+		}
 	}
 
 return $result;
 }
 
-# Delete Action
+// Delete Action
 
 function delete_action( $actionid ){
 	$return = DBexecute('delete from conditions where actionid='.$actionid);
@@ -315,7 +336,7 @@ function delete_action( $actionid ){
 	while($operation = DBFetch($opers)){
 		DBexecute('DELETE FROM opconditions WHERE operationid='.$operation['operationid']);
 	}
-	
+
 	if($return)
 		$result = DBexecute('delete from operations where actionid='.$actionid);
 
@@ -325,11 +346,10 @@ function delete_action( $actionid ){
 	if($return)
 		$result = DBexecute('delete from actions where actionid='.$actionid);
 
-	return $result;
+return $result;
 }
 
-function	condition_operator2str($operator)
-{
+function condition_operator2str($operator){
 	$str_op[CONDITION_OPERATOR_EQUAL] 	= '=';
 	$str_op[CONDITION_OPERATOR_NOT_EQUAL]	= '<>';
 	$str_op[CONDITION_OPERATOR_LIKE]	= S_LIKE_SMALL;
@@ -345,8 +365,7 @@ function	condition_operator2str($operator)
 	return S_UNKNOWN;
 }
 
-function	condition_type2str($conditiontype)
-{
+function condition_type2str($conditiontype){
 	$str_type[CONDITION_TYPE_HOST_GROUP]		= S_HOST_GROUP;
 	$str_type[CONDITION_TYPE_HOST_TEMPLATE]		= S_HOST_TEMPLATE;
 	$str_type[CONDITION_TYPE_TRIGGER]		= S_TRIGGER;
@@ -355,6 +374,11 @@ function	condition_type2str($conditiontype)
 	$str_type[CONDITION_TYPE_TRIGGER_VALUE]		= S_TRIGGER_VALUE;
 	$str_type[CONDITION_TYPE_TRIGGER_SEVERITY]	= S_TRIGGER_SEVERITY;
 	$str_type[CONDITION_TYPE_TIME_PERIOD]		= S_TIME_PERIOD;
+	$str_type[CONDITION_TYPE_MAINTENANCE]		= S_MAINTENANCE_STATUS;
+	$str_type[CONDITION_TYPE_NODE]			= S_NODE;
+	$str_type[CONDITION_TYPE_DRULE]			= S_DISCOVERY_RULE;
+	$str_type[CONDITION_TYPE_DCHECK]		= S_DISCOVERY_CHECK;
+	$str_type[CONDITION_TYPE_DOBJECT]		= S_DISCOVERED_OBJECT;
 	$str_type[CONDITION_TYPE_DHOST_IP]		= S_HOST_IP;
 	$str_type[CONDITION_TYPE_DSERVICE_TYPE]		= S_SERVICE_TYPE;
 	$str_type[CONDITION_TYPE_DSERVICE_PORT]		= S_SERVICE_PORT;
@@ -363,20 +387,32 @@ function	condition_type2str($conditiontype)
 	$str_type[CONDITION_TYPE_DVALUE]		= S_RECEIVED_VALUE;
 	$str_type[CONDITION_TYPE_EVENT_ACKNOWLEDGED]	= S_EVENT_ACKNOWLEDGED;
 	$str_type[CONDITION_TYPE_APPLICATION]		= S_APPLICATION;
+	$str_type[CONDITION_TYPE_PROXY]			= S_PROXY;
+	$str_type[CONDITION_TYPE_HOST_NAME]		= S_HOST_NAME;
 
 	if(isset($str_type[$conditiontype]))
 		return $str_type[$conditiontype];
 
-	return S_UNKNOWN;
+return S_UNKNOWN;
 }
-	
+
+function discovery_object2str($object){
+	$str_object[EVENT_OBJECT_DHOST]		= S_DEVICE;
+	$str_object[EVENT_OBJECT_DSERVICE]	= S_SERVICE;
+
+	if(isset($str_object[$object]))
+		return $str_object[$object];
+
+return S_UNKNOWN;
+}
+
 function condition_value2str($conditiontype, $value){
 	switch($conditiontype){
 		case CONDITION_TYPE_HOST_GROUP:
 			$group = get_hostgroup_by_groupid($value);
-			
+
 			$str_val = '';
-			if(id2nodeid($value) != get_current_nodeid()) $str_val = get_node_name_by_elid($value, true);
+			if(id2nodeid($value) != get_current_nodeid()) $str_val = get_node_name_by_elid($value, true, ': ');
 			$str_val.= $group['name'];
 			break;
 		case CONDITION_TYPE_TRIGGER:
@@ -384,12 +420,13 @@ function condition_value2str($conditiontype, $value){
 			break;
 		case CONDITION_TYPE_HOST:
 		case CONDITION_TYPE_HOST_TEMPLATE:
-			$host = get_host_by_hostid($value);			
+			$host = get_host_by_hostid($value);
 			$str_val = '';
-			if(id2nodeid($value) != get_current_nodeid()) $str_val = get_node_name_by_elid($value, true);
+			if(id2nodeid($value) != get_current_nodeid()) $str_val = get_node_name_by_elid($value, true, ': ');
 			$str_val.= $host['host'];
 			break;
 		case CONDITION_TYPE_TRIGGER_NAME:
+		case CONDITION_TYPE_HOST_NAME:
 			$str_val = $value;
 			break;
 		case CONDITION_TYPE_TRIGGER_VALUE:
@@ -401,6 +438,30 @@ function condition_value2str($conditiontype, $value){
 		case CONDITION_TYPE_TIME_PERIOD:
 			$str_val = $value;
 			break;
+		case CONDITION_TYPE_MAINTENANCE:
+			$str_val = S_MAINTENANCE_SMALL;
+			break;
+		case CONDITION_TYPE_NODE:
+			$node = get_node_by_nodeid($value);
+			$str_val = $node['name'];
+			break;
+		case CONDITION_TYPE_DRULE:
+			$drule = get_discovery_rule_by_druleid($value);
+			$str_val = $drule['name'];
+			break;
+		case CONDITION_TYPE_DCHECK:
+			$row = DBfetch(DBselect('SELECT DISTINCT r.name,c.dcheckid,c.type,c.key_,c.snmp_community,c.ports'.
+					' FROM drules r,dchecks c WHERE r.druleid=c.druleid AND c.dcheckid='.$value));
+			$str_val = $row['name'].':'.discovery_check2str($row['type'],
+					$row['snmp_community'], $row['key_'], $row['ports']);
+			break;
+		case CONDITION_TYPE_DOBJECT:
+			$str_val = discovery_object2str($value);
+			break;
+		case CONDITION_TYPE_PROXY:
+			$host = get_host_by_hostid($value);
+			$str_val = $host['host'];
+			break;
 		case CONDITION_TYPE_DHOST_IP:
 			$str_val = $value;
 			break;
@@ -450,11 +511,15 @@ function get_operation_desc($type=SHORT_DESCRITION, $data){
 				case OPERATION_TYPE_MESSAGE:
 					switch($data['object']){
 						case OPERATION_OBJECT_USER:
-							$obj_data = get_user_by_userid($data['objectid']);
+							$obj_data = CUser::get(array('userids' => $data['objectid'],  'extendoutput' => 1));
+							$obj_data = reset($obj_data);
+
 							$obj_data = S_USER.' "'.$obj_data['alias'].'"';
 							break;
 						case OPERATION_OBJECT_GROUP:
-							$obj_data = get_group_by_usrgrpid($data['objectid']);
+							$obj_data = CUserGroup::get(array('usrgrpids' => $data['objectid'],  'extendoutput' => 1));
+							$obj_data = reset($obj_data);
+
 							$obj_data = S_GROUP.' "'.$obj_data['name'].'"';
 							break;
 					}
@@ -469,6 +534,12 @@ function get_operation_desc($type=SHORT_DESCRITION, $data){
 				case OPERATION_TYPE_HOST_REMOVE:
 					$result = S_REMOVE_HOST;
 					break;
+				case OPERATION_TYPE_HOST_ENABLE:
+					$result = S_ENABLE_HOST;
+					break;
+				case OPERATION_TYPE_HOST_DISABLE:
+					$result = S_DISABLE_HOST;
+					break;
 				case OPERATION_TYPE_GROUP_ADD:
 					$obj_data = get_hostgroup_by_groupid($data['objectid']);
 					$result = S_ADD_TO_GROUP.' "'.$obj_data['name'].'"';
@@ -499,7 +570,7 @@ function get_operation_desc($type=SHORT_DESCRITION, $data){
 							$temp = bold(S_MESSAGE.':');
 							$result .= $temp->ToString()."\n".$_REQUEST['def_longdata'];
 						}
-						else if(isset($data['operationid'])){ 
+						else if(isset($data['operationid'])){
 							$sql = 'SELECT a.def_shortdata,a.def_longdata '.
 									' FROM actions a, operations o '.
 									' WHERE a.actionid=o.actionid '.
@@ -545,16 +616,28 @@ function get_conditions_by_eventsource($eventsource){
 			CONDITION_TYPE_TRIGGER_NAME,
 			CONDITION_TYPE_TRIGGER_SEVERITY,
 			CONDITION_TYPE_TRIGGER_VALUE,
-			CONDITION_TYPE_TIME_PERIOD
+			CONDITION_TYPE_TIME_PERIOD,
+			CONDITION_TYPE_MAINTENANCE
 		);
 	$conditions[EVENT_SOURCE_DISCOVERY] = array(
 			CONDITION_TYPE_DHOST_IP,
 			CONDITION_TYPE_DSERVICE_TYPE,
 			CONDITION_TYPE_DSERVICE_PORT,
+			CONDITION_TYPE_DRULE,
+			CONDITION_TYPE_DCHECK,
+			CONDITION_TYPE_DOBJECT,
 			CONDITION_TYPE_DSTATUS,
 			CONDITION_TYPE_DUPTIME,
-			CONDITION_TYPE_DVALUE
+			CONDITION_TYPE_DVALUE,
+			CONDITION_TYPE_PROXY
 		);
+	$conditions[EVENT_SOURCE_AUTO_REGISTRATION] = array(
+			CONDITION_TYPE_HOST_NAME,
+			CONDITION_TYPE_PROXY
+		);
+
+	if (ZBX_DISTRIBUTED)
+		array_push($conditions[EVENT_SOURCE_TRIGGERS], CONDITION_TYPE_NODE);
 
 	if(isset($conditions[$eventsource]))
 		return $conditions[$eventsource];
@@ -566,7 +649,7 @@ function get_opconditions_by_eventsource($eventsource){
 	$conditions[EVENT_SOURCE_TRIGGERS] = array(
 			CONDITION_TYPE_EVENT_ACKNOWLEDGED
 		);
-		
+
 	$conditions[EVENT_SOURCE_DISCOVERY] = array(
 		);
 
@@ -586,11 +669,21 @@ function get_operations_by_eventsource($eventsource){
 			OPERATION_TYPE_COMMAND,
 			OPERATION_TYPE_HOST_ADD,
 			OPERATION_TYPE_HOST_REMOVE,
+			OPERATION_TYPE_HOST_ENABLE,
+			OPERATION_TYPE_HOST_DISABLE,
 			OPERATION_TYPE_GROUP_ADD,
 			OPERATION_TYPE_GROUP_REMOVE,
 			OPERATION_TYPE_TEMPLATE_ADD,
 			OPERATION_TYPE_TEMPLATE_REMOVE
 		);
+	$operations[EVENT_SOURCE_AUTO_REGISTRATION] = array(
+			OPERATION_TYPE_MESSAGE,
+			OPERATION_TYPE_COMMAND,
+			OPERATION_TYPE_HOST_ADD,
+			OPERATION_TYPE_HOST_DISABLE,
+			OPERATION_TYPE_GROUP_ADD,
+			OPERATION_TYPE_TEMPLATE_ADD
+		);
 
 	if(isset($operations[$eventsource]))
 		return $operations[$eventsource];
@@ -604,6 +697,8 @@ function	operation_type2str($type)
 	$str_type[OPERATION_TYPE_COMMAND]		= S_REMOTE_COMMAND;
 	$str_type[OPERATION_TYPE_HOST_ADD]		= S_ADD_HOST;
 	$str_type[OPERATION_TYPE_HOST_REMOVE]		= S_REMOVE_HOST;
+	$str_type[OPERATION_TYPE_HOST_ENABLE]		= S_ENABLE_HOST;
+	$str_type[OPERATION_TYPE_HOST_DISABLE]		= S_DISABLE_HOST;
 	$str_type[OPERATION_TYPE_GROUP_ADD]		= S_ADD_TO_GROUP;
 	$str_type[OPERATION_TYPE_GROUP_REMOVE]		= S_DELETE_FROM_GROUP;
 	$str_type[OPERATION_TYPE_TEMPLATE_ADD]		= S_LINK_TO_TEMPLATE;
@@ -635,7 +730,7 @@ function	get_operators_by_conditiontype($conditiontype)
 		);
 	$operators[CONDITION_TYPE_TRIGGER_NAME] = array(
 			CONDITION_OPERATOR_LIKE,
-			CONDITION_OPERATOR_NOT_LIKE	
+			CONDITION_OPERATOR_NOT_LIKE
 		);
 	$operators[CONDITION_TYPE_TRIGGER_SEVERITY] = array(
 			CONDITION_OPERATOR_EQUAL,
@@ -650,6 +745,29 @@ function	get_operators_by_conditiontype($conditiontype)
 			CONDITION_OPERATOR_IN,
 			CONDITION_OPERATOR_NOT_IN
 		);
+	$operators[CONDITION_TYPE_MAINTENANCE] = array(
+			CONDITION_OPERATOR_IN,
+			CONDITION_OPERATOR_NOT_IN
+		);
+	$operators[CONDITION_TYPE_NODE] = array(
+			CONDITION_OPERATOR_EQUAL,
+			CONDITION_OPERATOR_NOT_EQUAL
+		);
+	$operators[CONDITION_TYPE_DRULE] = array(
+			CONDITION_OPERATOR_EQUAL,
+			CONDITION_OPERATOR_NOT_EQUAL
+		);
+	$operators[CONDITION_TYPE_DCHECK] = array(
+			CONDITION_OPERATOR_EQUAL,
+			CONDITION_OPERATOR_NOT_EQUAL
+		);
+	$operators[CONDITION_TYPE_DOBJECT] = array(
+			CONDITION_OPERATOR_EQUAL,
+		);
+	$operators[CONDITION_TYPE_PROXY] = array(
+			CONDITION_OPERATOR_EQUAL,
+			CONDITION_OPERATOR_NOT_EQUAL
+		);
 	$operators[CONDITION_TYPE_DHOST_IP] = array(
 			CONDITION_OPERATOR_EQUAL,
 			CONDITION_OPERATOR_NOT_EQUAL
@@ -683,7 +801,11 @@ function	get_operators_by_conditiontype($conditiontype)
 	$operators[CONDITION_TYPE_APPLICATION] = array(
 			CONDITION_OPERATOR_EQUAL,
 			CONDITION_OPERATOR_LIKE,
-			CONDITION_OPERATOR_NOT_LIKE	
+			CONDITION_OPERATOR_NOT_LIKE
+		);
+	$operators[CONDITION_TYPE_HOST_NAME] = array(
+			CONDITION_OPERATOR_LIKE,
+			CONDITION_OPERATOR_NOT_LIKE
 		);
 
 	if(isset($operators[$conditiontype]))
@@ -716,7 +838,7 @@ function validate_condition($conditiontype, $value){
 			}
 			break;
 		case CONDITION_TYPE_TRIGGER:
-			if( !DBfetch(DBselect('select triggerid from triggers where triggerid='.$value)) || 
+			if( !DBfetch(DBselect('select triggerid from triggers where triggerid='.$value)) ||
 				!check_right_on_trigger_by_triggerid(PERM_READ_ONLY, $value) )
 			{
 				error(S_INCORRECT_TRIGGER);
@@ -766,13 +888,20 @@ function validate_condition($conditiontype, $value){
 				return false;
 			}
 			break;
-		
+
 		case CONDITION_TYPE_TRIGGER_NAME:
 		case CONDITION_TYPE_TRIGGER_VALUE:
 		case CONDITION_TYPE_TRIGGER_SEVERITY:
+		case CONDITION_TYPE_MAINTENANCE:
+		case CONDITION_TYPE_NODE:
+		case CONDITION_TYPE_DRULE:
+		case CONDITION_TYPE_DCHECK:
+		case CONDITION_TYPE_DOBJECT:
+		case CONDITION_TYPE_PROXY:
 		case CONDITION_TYPE_DUPTIME:
 		case CONDITION_TYPE_DVALUE:
 		case CONDITION_TYPE_APPLICATION:
+		case CONDITION_TYPE_HOST_NAME:
 			break;
 		default:
 			error(S_INCORRECT_CONDITION_TYPE);
@@ -789,13 +918,15 @@ function validate_operation($operation){
 		case OPERATION_TYPE_MESSAGE:
 			switch($operation['object']){
 				case OPERATION_OBJECT_USER:
-					if( !get_user_by_userid($operation['objectid']) ){
+					$users = CUser::get(array('userids' => $operation['objectid'],  'extendoutput' => 1));
+					if(empty($users)){
 						error(S_INCORRECT_USER);
 						return false;
 					}
 					break;
 				case OPERATION_OBJECT_GROUP:
-					if( !get_group_by_usrgrpid($operation['objectid']) ){
+					$usrgrps = CUserGroup::get(array('usrgrpids' => $operation['objectid'],  'extendoutput' => 1));
+					if(empty($usrgrps)){
 						error(S_INCORRECT_GROUP);
 						return false;
 					}
@@ -809,17 +940,21 @@ function validate_operation($operation){
 			return validate_commands($operation['longdata']);
 		case OPERATION_TYPE_HOST_ADD:
 		case OPERATION_TYPE_HOST_REMOVE:
+		case OPERATION_TYPE_HOST_ENABLE:
+		case OPERATION_TYPE_HOST_DISABLE:
 			break;
 		case OPERATION_TYPE_GROUP_ADD:
 		case OPERATION_TYPE_GROUP_REMOVE:
-			if(!uint_in_array($operation['objectid'], get_accessible_groups_by_user($USER_DETAILS,PERM_READ_WRITE,PERM_RES_IDS_ARRAY))){
+			$available_groups = get_accessible_groups_by_user($USER_DETAILS,PERM_READ_WRITE);
+			if(!isset($available_groups[$operation['objectid']])){
 				error(S_INCORRECT_GROUP);
 				return false;
 			}
 			break;
 		case OPERATION_TYPE_TEMPLATE_ADD:
 		case OPERATION_TYPE_TEMPLATE_REMOVE:
-			if(!uint_in_array($operation['objectid'], get_accessible_hosts_by_user($USER_DETAILS,PERM_READ_WRITE,PERM_RES_IDS_ARRAY))){
+			$available_hosts = get_accessible_hosts_by_user($USER_DETAILS,PERM_READ_WRITE);
+			if(!isset($available_hosts[$operation['objectid']])){
 				error(S_INCORRECT_HOST);
 				return false;
 			}
@@ -832,23 +967,24 @@ return true;
 }
 
 function validate_commands($commands){
-	$cmd_list = split("\n",$commands);
+	$cmd_list = explode("\n",$commands);
 	foreach($cmd_list as $cmd){
 		$cmd = trim($cmd, "\x00..\x1F");
-		if(!ereg("^(({HOSTNAME})|".ZBX_EREG_INTERNAL_NAMES.")(:|#)[[:print:]]*$",$cmd,$cmd_items)){
-			error("Incorrect command: '$cmd'");
+//		if(!ereg("^(({HOSTNAME})|".ZBX_EREG_INTERNAL_NAMES.")(:|#)[[:print:]]*$",$cmd,$cmd_items)){
+		if(!preg_match("/^(({HOSTNAME})|".ZBX_PREG_INTERNAL_NAMES.")(:|#)[".ZBX_PREG_PRINT."]*$/", $cmd, $cmd_items)){
+			error(S_INCORRECT_COMMAND.": '$cmd'");
 			return FALSE;
 		}
-		
-		if($cmd_items[4] == "#"){ // group
-			if(!DBfetch(DBselect("select groupid from groups where name=".zbx_dbstr($cmd_items[1])))){
-				error("Unknown group name: '".$cmd_items[1]."' in command ".$cmd."'");
+
+		if($cmd_items[4] == '#'){ // group
+			if(!DBfetch(DBselect('select groupid from groups where name='.zbx_dbstr($cmd_items[1])))){
+				error(S_UNKNOWN_GROUP_NAME.": '".$cmd_items[1]."' ".S_IN_COMMAND_SMALL." '".$cmd."'");
 				return FALSE;
 			}
 		}
-		else if($cmd_items[4] == ":"){ // host
-			if(($cmd_items[1] != '{HOSTNAME}') && !DBfetch(DBselect("select hostid from hosts where host=".zbx_dbstr($cmd_items[1])))){
-				error("Unknown host name '".$cmd_items[1]."' in command '".$cmd."'");
+		else if($cmd_items[4] == ':'){ // host
+			if(($cmd_items[1] != '{HOSTNAME}') && !DBfetch(DBselect('select hostid from hosts where host='.zbx_dbstr($cmd_items[1])))){
+				error(S_UNKNOWN_HOST_NAME.": '".$cmd_items[1]."' ".S_IN_COMMAND_SMALL." '".$cmd."'");
 				return FALSE;
 			}
 		}
@@ -864,9 +1000,9 @@ function count_operations_delay($operations, $def_period=0){
 		$step_from = $operation['esc_step_from']?$operation['esc_step_from']:1;
 		$step_to = $operation['esc_step_to']?$operation['esc_step_to']:9999;
 		$esc_period = $operation['esc_period']?$operation['esc_period']:$def_period;
-		
+
 		$max_step = ($max_step>$step_from)?$max_step:$step_from;
-		
+
 		for($i=$step_from; $i<$step_to; $i++){
 			if(isset($periods[$i]) && ($periods[$i] < $esc_period)){
 			}
@@ -880,124 +1016,119 @@ function count_operations_delay($operations, $def_period=0){
 		$esc_period = isset($periods[$i])?$periods[$i]:$def_period;
 		$delays[$i+1] = $delays[$i] + $esc_period;
 	}
-	
+
 return $delays;
 }
 
-function get_history_of_actions($start,$num,$sql_cond=''){
+function get_history_of_actions($limit,&$last_clock=null,$sql_cond=''){
 	$available_triggers = get_accessible_triggers(PERM_READ_ONLY, array(), PERM_RES_IDS_ARRAY);
 
+	$alerts = array();
+	$clock = array();
 	$table = new CTableInfo(S_NO_ACTIONS_FOUND);
-	$table->SetHeader(array(
-			is_show_subnodes() ? make_sorting_link(S_NODES,'a.alertid') : null,
-			make_sorting_link(S_TIME,'a.clock'),
-			make_sorting_link(S_TYPE,'mt.description'),
-			make_sorting_link(S_STATUS,'a.status'),
-			make_sorting_link(S_RETRIES_LEFT,'a.retries'),
-			make_sorting_link(S_RECIPIENTS,'a.sendto'),
+	$table->setHeader(array(
+			is_show_all_nodes() ? make_sorting_link(S_NODES,'a.alertid') : null,
+			make_sorting_link(S_TIME,'clock'),
+			make_sorting_link(S_TYPE,'description'),
+			make_sorting_link(S_STATUS,'status'),
+			make_sorting_link(S_RETRIES_LEFT,'retries'),
+			make_sorting_link(S_RECIPIENTS,'sendto'),
 			S_MESSAGE,
 			S_ERROR
 			));
-			
-	$sql = 'SELECT DISTINCT a.alertid,a.clock,mt.description,a.sendto,a.subject,a.message,a.status,a.retries,a.error '.
-			' FROM events e,alerts a'.
-			' left join media_type mt on mt.mediatypeid=a.mediatypeid'.
-			' WHERE e.eventid = a.eventid and alerttype in ('.ALERT_TYPE_MESSAGE.')'.
+
+	$sql = 'SELECT a.alertid,a.clock,mt.description,a.sendto,a.subject,a.message,a.status,a.retries,a.error '.
+			' FROM events e, alerts a '.
+				' LEFT JOIN media_type mt ON mt.mediatypeid=a.mediatypeid '.
+			' WHERE e.eventid = a.eventid '.
+				' AND alerttype IN ('.ALERT_TYPE_MESSAGE.') '.
 				$sql_cond.
 				' AND '.DBcondition('e.objectid',$available_triggers).
 				' AND '.DBin_node('a.alertid').
-			order_by('a.clock,a.alertid,mt.description,a.sendto,a.status,a.retries');
-	$result=DBselect($sql,10*$start+$num);
-		
-	$col=0;
-	$skip=$start;
-	while(($row=DBfetch($result))&&($col<$num)){
-		if($skip > 0) {
-			$skip--;
-			continue;
-		}
-		$time=date("Y.M.d H:i:s",$row["clock"]);
+			' ORDER BY a.clock DESC';
+	$result=DBselect($sql,$limit);
+	while($row=DBfetch($result)){
+		$alerts[] = $row;
+		$clock[] = $row['clock'];
+	}
 
-		if($row["status"] == ALERT_STATUS_SENT){
-			$status=new CSpan(S_SENT,"green");
-			$retries=new CSpan(SPACE,"green");
+	$last_clock = !empty($clock)?min($clock):null;
+
+	order_page_result($alerts, 'clock', ZBX_SORT_DOWN);
+
+	foreach($alerts as $num => $row){
+		$time=date(S_DATE_FORMAT_YMDHMS,$row['clock']);
+
+		if($row['status'] == ALERT_STATUS_SENT){
+			$status=new CSpan(S_SENT,'green');
+			$retries=new CSpan(SPACE,'green');
 		}
-		else if($row["status"] == ALERT_STATUS_NOT_SENT){
-			$status=new CSpan(S_IN_PROGRESS,"orange");
-			$retries=new CSpan(ALERT_MAX_RETRIES - $row["retries"],"orange");
+		else if($row['status'] == ALERT_STATUS_NOT_SENT){
+			$status=new CSpan(S_IN_PROGRESS,'orange');
+			$retries=new CSpan(ALERT_MAX_RETRIES - $row['retries'],'orange');
 		}
 		else{
-			$status=new CSpan(S_NOT_SENT,"red");
-			$retries=new CSpan(0,"red");
+			$status=new CSpan(S_NOT_SENT,'red');
+			$retries=new CSpan(0,'red');
 		}
-		$sendto=$row["sendto"];
+		$sendto=$row['sendto'];
 
-		$message = array(bold(S_SUBJECT.': '),br(),$row["subject"],br(),br(),bold(S_MESSAGE.': '),br(),$row['message']);
+		$message = array(bold(S_SUBJECT.': '),br(),$row['subject'],br(),br(),bold(S_MESSAGE.': '),br(),$row['message']);
 
-		if(empty($row["error"])){
-			$error=new CSpan(SPACE,"off");
+		if(empty($row['error'])){
+			$error=new CSpan(SPACE,'off');
 		}
 		else{
-			$error=new CSpan($row["error"],"on");
+			$error=new CSpan($row['error'],'on');
 		}
-		$table->AddRow(array(
+
+		$table->addRow(array(
 			get_node_name_by_elid($row['alertid']),
 			new CCol($time, 'top'),
-			new CCol($row["description"], 'top'),
+			new CCol($row['description'], 'top'),
 			new CCol($status, 'top'),
 			new CCol($retries, 'top'),
 			new CCol($sendto, 'top'),
 			new CCol($message, 'top'),
 			new CCol($error, 'wraptext top')));
-		$col++;
 	}
-
-	return $table;
+return $table;
 }
-	
+
 // Author: Aly
 function get_action_msgs_for_event($eventid){
-	$hostids = array();
-	$sql = 'SELECT DISTINCT i.hostid '.
-			' FROM events e, functions f, items i '.
-			' WHERE e.eventid='.$eventid.
-				' AND e.object='.EVENT_SOURCE_TRIGGERS.
-				' AND f.triggerid=e.objectid '.
-				' AND i.itemid=f.itemid';
-	if($host = DBfetch(DBselect($sql,1))){
-		$hostids[$host['hostid']] = $host['hostid'];
-	}
-	$available_triggers = get_accessible_triggers(PERM_READ_ONLY, $hostids);
 
 	$table = new CTableInfo(S_NO_ACTIONS_FOUND);
-	$table->SetHeader(array(
-			is_show_subnodes() ? make_sorting_link(S_NODES,'a.alertid') : null,
-			make_sorting_link(S_TIME,'a.clock'),
-			make_sorting_link(S_TYPE,'mt.description'),
-			make_sorting_link(S_STATUS,'a.status'),
-			make_sorting_link(S_RETRIES_LEFT,'a.retries'),
-			make_sorting_link(S_RECIPIENTS,'a.sendto'),
-			S_MESSAGE,
-			S_ERROR
-			));
-			
-	$sql = 'SELECT DISTINCT a.alertid,a.clock,a.esc_step, mt.description,a.sendto,a.subject,a.message,a.status,a.retries,a.error '.
-			' FROM events e,alerts a'.
-				' left join media_type mt on mt.mediatypeid=a.mediatypeid'.
-			' WHERE a.eventid='.$eventid.
-				' AND a.alerttype='.ALERT_TYPE_MESSAGE.
-				' AND e.eventid = a.eventid'.
-				' AND '.DBcondition('e.objectid',$available_triggers).
-				' AND '.DBin_node('a.alertid').
-			order_by('a.clock,a.alertid,mt.description,a.sendto,a.status,a.retries');
-	$result=DBselect($sql);
+	$table->setHeader(array(
+		is_show_all_nodes() ? S_NODES:null,
+		S_TIME,
+		S_TYPE,
+		S_STATUS,
+		S_RETRIES_LEFT,
+		S_RECIPIENTS,
+		S_MESSAGE,
+		S_ERROR
+	));
 
-	while($row=DBfetch($result)){
-		$time=date("Y.M.d H:i:s",$row["clock"]);
+
+	$alerts = CAlert::get(array(
+		'eventids' => $eventid,
+		'alerttype' => ALERT_TYPE_MESSAGE,
+		'extendoutput' => 1,
+		'sortfield' => 'clock',
+		'sortorder' => ZBX_SORT_DOWN,
+		'select_mediatypes' => 1
+	));
+
+	foreach($alerts as $alertid => $row){
+// mediatypes
+		$mediatype = array_pop($row['mediatypes']);
+
+		$time=date(S_DATE_FORMAT_YMDHMS,$row["clock"]);
 		if($row['esc_step'] > 0){
-			$time = array(bold(S_STEP.': '),$row["esc_step"],br(),bold(S_TIME.': '),br(),$time);	
+			$time = array(bold(S_STEP.': '),$row["esc_step"],br(),bold(S_TIME.': '),br(),$time);
 		}
-		
+
 		if($row["status"] == ALERT_STATUS_SENT){
 			$status=new CSpan(S_SENT,"green");
 			$retries=new CSpan(SPACE,"green");
@@ -1014,22 +1145,22 @@ function get_action_msgs_for_event($eventid){
 
 		$message = array(bold(S_SUBJECT.':'),br(),$row["subject"],br(),br(),bold(S_MESSAGE.':'));
 		$msg = explode("\n",$row['message']);
-		foreach($msg as $m)
-		{
+
+		foreach($msg as $m){
 			array_push($message, BR(), $m);
 		}
-		
+
 		if(empty($row["error"])){
 			$error=new CSpan(SPACE,"off");
 		}
 		else{
 			$error=new CSpan($row["error"],"on");
 		}
-		
-		$table->AddRow(array(
+
+		$table->addRow(array(
 			get_node_name_by_elid($row['alertid']),
 			new CCol($time, 'top'),
-			new CCol($row["description"], 'top'),
+			new CCol((!empty($mediatype['description']) ? $mediatype['description'] : ''), 'top'),
 			new CCol($status, 'top'),
 			new CCol($retries, 'top'),
 			new CCol($sendto, 'top'),
@@ -1042,72 +1173,59 @@ return $table;
 
 // Author: Aly
 function get_action_cmds_for_event($eventid){
-	$hostids = array();
-	$sql = 'SELECT DISTINCT i.hostid '.
-			' FROM events e, functions f, items i '.
-			' WHERE e.eventid='.$eventid.
-				' AND e.object='.EVENT_SOURCE_TRIGGERS.
-				' AND f.triggerid=e.objectid '.
-				' AND i.itemid=f.itemid';
-	if($host = DBfetch(DBselect($sql,1))){
-		$hostids[$host['hostid']] = $host['hostid'];
-	}
-	$available_triggers = get_accessible_triggers(PERM_READ_ONLY, $hostids);
 
 	$table = new CTableInfo(S_NO_ACTIONS_FOUND);
-	$table->SetHeader(array(
-			is_show_subnodes()?S_NODES:null,
-			S_TIME,
-			S_STATUS,
-			S_COMMAND,
-			S_ERROR
-			));
-			
-	$sql = 'SELECT DISTINCT a.alertid,a.clock,a.sendto,a.esc_step,a.subject,a.message,a.status,a.retries,a.error '.
-			' FROM events e,alerts a'.
-			' WHERE a.eventid='.$eventid.
-				' AND a.alerttype='.ALERT_TYPE_COMMAND.
-				' AND e.eventid = a.eventid'.
-				' AND '.DBcondition('e.objectid',$available_triggers).
-				' AND '.DBin_node('a.alertid').
-			order_by('a.clock,a.alertid,a.sendto,a.status,a.retries');
-	$result=DBselect($sql);
+	$table->setHeader(array(
+		is_show_all_nodes()?S_NODES:null,
+		S_TIME,
+		S_STATUS,
+		S_COMMAND,
+		S_ERROR
+	));
 
-	while($row=DBfetch($result)){
-		$time=date("Y.M.d H:i:s",$row["clock"]);
+
+	$alerts = CAlert::get(array(
+		'eventids' => $eventid,
+		'alerttype' => ALERT_TYPE_COMMAND,
+		'extendoutput' => 1,
+		'sortfield' => 'clock',
+		'sortorder' => ZBX_SORT_DOWN
+	));
+
+	foreach($alerts as $alertid => $row){
+		$time = date('Y.M.d H:i:s', $row['clock']);
 		if($row['esc_step'] > 0){
-			$time = array(bold(S_STEP.': '),$row["esc_step"],br(),bold(S_TIME.': '),br(),$time);	
+			$time = array(bold(S_STEP.': '), $row['esc_step'], br(), bold(S_TIME.': '), br(), $time);
 		}
-		
-		if($row["status"] == ALERT_STATUS_SENT){
-			$status=new CSpan(S_EXECUTED,"green");
-		}
-		else if($row["status"] == ALERT_STATUS_NOT_SENT){
-			$status=new CSpan(S_IN_PROGRESS,"orange");
-		}
-		else{
-			$status=new CSpan(S_NOT_SENT,"red");
+
+		switch($row['status']){
+			case ALERT_STATUS_SENT:
+				$status = new CSpan(S_EXECUTED, 'green');
+			break;
+			case ALERT_STATUS_NOT_SENT:
+				$status = new CSpan(S_IN_PROGRESS, 'orange');
+			break;
+			default:
+				$status = new CSpan(S_NOT_SENT, 'red');
+			break;
 		}
 
 		$message = array(bold(S_COMMAND.':'));
-		$msg = explode("\n",$row['message']);
+		$msg = explode('\n', $row['message']);
 		foreach($msg as $m){
 			array_push($message, BR(), $m);
 		}
 
-		if(empty($row["error"])){
-			$error=new CSpan(SPACE,"off");
-		}
-		else{
-			$error=new CSpan($row["error"],"on");
-		}
-		
-		$table->AddRow(array(
+		$error = empty($row['error']) ? new CSpan(SPACE, 'off') : new CSpan($row['error'], 'on');
+
+
+		$table->addRow(array(
 			get_node_name_by_elid($row['alertid']),
 			new CCol($time, 'top'),
 			new CCol($status, 'top'),
 			new CCol($message, 'wraptext top'),
-			new CCol($error, 'wraptext top')));
+			new CCol($error, 'wraptext top')
+		));
 	}
 
 return $table;
@@ -1126,16 +1244,16 @@ function get_actions_hint_by_eventid($eventid,$status=NULL){
 		$hostids[$host['hostid']] = $host['hostid'];
 	}
 	$available_triggers = get_accessible_triggers(PERM_READ_ONLY, $hostids);
-	
+
 	$tab_hint = new CTableInfo(S_NO_ACTIONS_FOUND);
-	$tab_hint->AddOption('style', 'width: 300px;');
+	$tab_hint->setAttribute('style', 'width: 300px;');
 	$tab_hint->SetHeader(array(
-			is_show_subnodes() ? S_NODES : null,
+			is_show_all_nodes() ? S_NODES : null,
 			S_USER,
 			S_DETAILS,
 			S_STATUS
 			));
-/*			
+/*
 	$sql = 'SELECT DISTINCT a.alertid,mt.description,a.sendto,a.status,u.alias,a.retries '.
 			' FROM events e,users u,alerts a'.
 			' left join media_type mt on mt.mediatypeid=a.mediatypeid'.
@@ -1159,7 +1277,7 @@ function get_actions_hint_by_eventid($eventid,$status=NULL){
 				' AND '.DBcondition('e.objectid',$available_triggers).
 				' AND '.DBin_node('a.alertid').
 			' ORDER BY a.alertid';
-	$result=DBselect($sql);
+	$result=DBselect($sql,30);
 
 	while($row=DBfetch($result)){
 
@@ -1175,7 +1293,7 @@ function get_actions_hint_by_eventid($eventid,$status=NULL){
 			$status=new CSpan(S_NOT_SENT,"red");
 			$retries=new CSpan(0,"red");
 		}
-		
+
 		switch($row['alerttype']){
 			case ALERT_TYPE_MESSAGE:
 				$message = empty($row['description'])?'-':$row['description'];
@@ -1190,8 +1308,8 @@ function get_actions_hint_by_eventid($eventid,$status=NULL){
 			default:
 				$message = '-';
 		}
-		
-		$tab_hint->AddRow(array(
+
+		$tab_hint->addRow(array(
 			get_node_name_by_elid($row['alertid']),
 			empty($row['alias'])?' - ':$row['alias'],
 			$message,
@@ -1203,14 +1321,14 @@ return $tab_hint;
 }
 
 function get_event_actions_status($eventid){
-// Actions								
+// Actions
 	$actions= new CTable(' - ');
 
 	$sql='SELECT COUNT(a.alertid) as cnt_all'.
 			' FROM alerts a '.
 			' WHERE a.eventid='.$eventid.
 				' AND a.alerttype in ('.ALERT_TYPE_MESSAGE.','.ALERT_TYPE_COMMAND.')';
-			
+
 	$alerts=DBfetch(DBselect($sql));
 
 	if(isset($alerts['cnt_all']) && ($alerts['cnt_all'] > 0)){
@@ -1256,17 +1374,17 @@ function get_event_actions_status($eventid){
 		}
 		else{
 			$tdl = new CCol(($alerts['sent'])?(new CSpan($alerts['sent'],'green')):SPACE);
-			$tdl->AddOption('width','10');
-			
+			$tdl->setAttribute('width','10');
+
 			$tdr = new CCol(($alerts['failed'])?(new CSpan($alerts['failed'],'red')):SPACE);
-			$tdr->AddOption('width','10');
+			$tdr->setAttribute('width','10');
 
 			$status = new CRow(array($tdl,$tdr));
 		}
 
-		$actions->AddRow($status);
+		$actions->addRow($status);
 	}
-	
+
 return $actions;
 }
 
@@ -1278,7 +1396,7 @@ function get_event_actions_stat_hints($eventid){
 			' WHERE a.eventid='.$eventid.
 				' AND a.alerttype in ('.ALERT_TYPE_MESSAGE.','.ALERT_TYPE_COMMAND.')';
 
-			
+
 	$alerts=DBfetch(DBselect($sql));
 
 	if(isset($alerts['cnt']) && ($alerts['cnt'] > 0)){
@@ -1296,7 +1414,7 @@ function get_event_actions_stat_hints($eventid){
 			$alert_cnt->SetHint($hint);
 		}
 		$tdl = new CCol(($alerts['sent'])?$alert_cnt:SPACE);
-		$tdl->AddOption('width','10');
+		$tdl->setAttribute('width','10');
 
 		$sql='SELECT COUNT(a.alertid) as inprogress '.
 				' FROM alerts a '.
@@ -1309,10 +1427,10 @@ function get_event_actions_stat_hints($eventid){
 		$alert_cnt = new CSpan($alerts['inprogress'],'orange');
 		if($alerts['inprogress']){
 			$hint=get_actions_hint_by_eventid($eventid,ALERT_STATUS_NOT_SENT);
-			$alert_cnt->SetHint($hint);
+			$alert_cnt->setHint($hint);
 		}
 		$tdc = new CCol(($alerts['inprogress'])?$alert_cnt:SPACE);
-		$tdc->AddOption('width','10');
+		$tdc->setAttribute('width','10');
 
 		$sql='SELECT COUNT(a.alertid) as failed '.
 				' FROM alerts a '.
@@ -1325,13 +1443,13 @@ function get_event_actions_stat_hints($eventid){
 		$alert_cnt = new CSpan($alerts['failed'],'red');
 		if($alerts['failed']){
 			$hint=get_actions_hint_by_eventid($eventid,ALERT_STATUS_FAILED);
-			$alert_cnt->SetHint($hint);
+			$alert_cnt->setHint($hint);
 		}
 
 		$tdr = new CCol(($alerts['failed'])?$alert_cnt:SPACE);
-		$tdr->AddOption('width','10');
-		
-		$actions->AddRow(array($tdl,$tdc,$tdr));
+		$tdr->setAttribute('width','10');
+
+		$actions->addRow(array($tdl,$tdc,$tdr));
 	}
 return $actions;
 }
