@@ -1,5 +1,5 @@
 <?php
-/* 
+/*
 ** ZABBIX
 ** Copyright (C) 2000-2005 SIA Zabbix
 **
@@ -32,12 +32,12 @@ if(!isset($DB)){
 
 	function DBconnect(&$error){
 		$result = true;
-		
+
 		global $DB;
 
 		$DB['DB'] = null;
 		$DB['TRANSACTIONS'] = 0;
-		
+
 //Stats
 		$DB['SELECT_COUNT'] = 0;
 		$DB['EXECUTE_COUNT'] = 0;
@@ -49,11 +49,13 @@ if(!isset($DB)){
 			$result = false;
 		}
 		else{
+			$DB['TYPE'] = strtoupper($DB['TYPE']);
+
 			switch($DB['TYPE']){
 				case 'MYSQL':
 					$mysql_server = $DB['SERVER'].( !empty($DB['PORT']) ? ':'.$DB['PORT'] : '');
 
-					if (!$DB['DB']= mysql_pconnect($mysql_server,$DB['USER'],$DB['PASSWORD'])){
+					if (!$DB['DB']= mysql_connect($mysql_server,$DB['USER'],$DB['PASSWORD'])){
 						$error = 'Error connecting to database ['.mysql_error().']';
 						$result = false;
 					}
@@ -62,10 +64,14 @@ if(!isset($DB)){
 							$error = 'Error database selection ['.mysql_error().']';
 							$result = false;
 						}
+						else{
+							DBexecute('SET NAMES utf8');
+							DBexecute('SET CHARACTER SET utf8');
+						}
 					}
 					break;
 				case 'POSTGRESQL':
-					$pg_connection_string = 
+					$pg_connection_string =
 						( !empty($DB['SERVER']) ? 'host=\''.$DB['SERVER'].'\' ' : '').
 						'dbname=\''.$DB['DATABASE'].'\' '.
 						( !empty($DB['USER']) ? 'user=\''.$DB['USER'].'\' ' : '').
@@ -79,7 +85,18 @@ if(!isset($DB)){
 					}
 					break;
 				case 'ORACLE':
-					$DB['DB']= ociplogon($DB['USER'], $DB['PASSWORD'], $DB['DATABASE']);
+					$connect = '';
+					if (!empty($DB['SERVER'])){
+						$connect = '//'.$DB['SERVER'];
+
+						if ($DB['PORT'] != '0')
+							$connect .= ':'.$DB['PORT'];
+
+						if ($DB['DATABASE'])
+							$connect .= '/'.$DB['DATABASE'];
+					}
+
+					$DB['DB']= ociplogon($DB['USER'], $DB['PASSWORD'], $connect);
 //					$DB['DB']= ociplogon($DB['USER'], $DB['PASSWORD'], '(DESCRIPTION=(ADDRESS=(PROTOCOL=TCP)(HOST='.$DB['SERVER'].')(PORT=1521))(CONNECT_DATA=(SERVICE_NAME='.$DB['DATABASE'].')))');
 					if(!$DB['DB']){
 						$error = 'Error connecting to database';
@@ -113,7 +130,7 @@ if(!isset($DB)){
 						function unlock_db_access(){
 							global $ZBX_SEM_ID;
 
-							if($ZBX_SEM_ID && function_exists('sem_release')) 
+							if($ZBX_SEM_ID && function_exists('sem_release'))
 								sem_release($ZBX_SEM_ID);
 						}
 					}
@@ -138,7 +155,7 @@ if(!isset($DB)){
 						}
 					}
 					else{
-						$error = 'Missed database';
+						$error = 'Missing database';
 						$result = false;
 					}
 
@@ -161,8 +178,8 @@ if(!isset($DB)){
 
 		if( isset($DB['DB']) && !empty($DB['DB']) ){
 			switch($DB['TYPE']){
-				case 'MYSQL':		
-					$result = mysql_close($DB['DB']);	
+				case 'MYSQL':
+					$result = mysql_close($DB['DB']);
 					break;
 				case 'POSTGRESQL':
 					$result = pg_close($DB['DB']);
@@ -170,9 +187,9 @@ if(!isset($DB)){
 				case 'ORACLE':
 					$result = ocilogoff($DB['DB']);
 					break;
-				case 'SQLITE3':		
-					$result = true; 
-					sqlite3_close($DB['DB']);	
+				case 'SQLITE3':
+					$result = true;
+					sqlite3_close($DB['DB']);
 					free_db_access();
 					break;
 				default:		break;
@@ -189,7 +206,7 @@ if(!isset($DB)){
 			$GLOBALS['DB_PASSWORD'],
 			$GLOBALS['SQLITE_TRANSACTION']
 			);
-		
+
 		return $result;
 	}
 
@@ -200,42 +217,39 @@ if(!isset($DB)){
 			$error = 'DBloadfile. Missing file['.$file.']';
 			return false;
 		}
-		
+
 		$fl = file($file);
-		
+
 		foreach($fl as $n => $l) if(substr($l,0,2)=='--') unset($fl[$n]);
-		
+
 		$fl = explode(";\n", implode("\n",$fl));
 		unset($fl[count($fl)-1]);
-		
-		foreach($fl as $sql)
-		{
+
+		foreach($fl as $sql){
 			if(empty($sql)) continue;
 
-			if(!DBexecute($sql,0))
-			{
+			if(!DBexecute($sql,0)){
 				$error = '';
 				return false;
 			}
 		}
 		return true;
 	}
-	
-	function DBstart($comments=false){
+
+	function DBstart($strict=true){
 		global $DB;
 //SDI('DBStart(): '.$DB['TRANSACTIONS']);
-		$DB['COMMENTS'] = $comments;
-		if($DB['COMMENTS']) info(S_TRANSACTION.': '.S_STARTED_BIG);
-		
+		$DB['STRICT'] = $strict;
+
 		$DB['TRANSACTIONS']++;
 
 		if($DB['TRANSACTIONS']>1){
-			info('POSSIBLE ERROR: Used incorect logic in database processing, started subtransaction!');
+			info('POSSIBLE ERROR: Used incorrect logic in database processing, started subtransaction!');
 		return $DB['TRANSACTION_STATE'];
 		}
-		
+
 		$DB['TRANSACTION_STATE'] = true;
-		
+
 		$result = false;
 		if(isset($DB['DB']) && !empty($DB['DB']))
 		switch($DB['TYPE']){
@@ -249,7 +263,7 @@ if(!isset($DB)){
 				$result = true;
 // TODO			OCI_DEFAULT
 				break;
-			case 'SQLITE3':				
+			case 'SQLITE3':
 				if(1 == $DB['TRANSACTIONS']){
 					lock_db_access();
 					$result = DBexecute('begin');
@@ -258,52 +272,53 @@ if(!isset($DB)){
 		}
 	return $result;
 	}
-	
-	
+
+
 	function DBend($result=null){
 		global $DB;
 //SDI('DBend(): '.$DB['TRANSACTIONS']);
 		if($DB['TRANSACTIONS'] != 1){
 			$DB['TRANSACTIONS']--;
-			
+
 			if($DB['TRANSACTIONS'] < 1){
 				$DB['TRANSACTIONS'] = 0;
 				$DB['TRANSACTION_STATE'] = false;
-				info('POSSIBLE ERROR: Used incorect logic in database processing, transaction not started!');
+				info('POSSIBLE ERROR: Used incorrect logic in database processing, transaction not started!');
 			}
+
+		if(!is_null($result))
+			$DB['TRANSACTION_STATE'] = $result && $DB['TRANSACTION_STATE'];
+
 		return $DB['TRANSACTION_STATE'];
 		}
 
 		$DB['TRANSACTIONS'] = 0;
-		
+
 		if(is_null($result)){
 			$DBresult = $DB['TRANSACTION_STATE'];
 		}
 		else{
 			$DBresult = $result && $DB['TRANSACTION_STATE'];
 		}
-			
+
 //SDI('Result: '.$result);
 
 		if($DBresult){ // OK
 			$DBresult = DBcommit();
 		}
-		
-		$msg = S_TRANSACTION.': '.S_COMMITED_BIG;
+
 		if(!$DBresult){ // FAIL
 			DBrollback();
-			$msg = S_TRANSACTION.': '.S_ROLLBACKED_BIG;
 		}
-		if($DB['COMMENTS']) info($msg);
-		
+
 		$result = (!is_null($result) && $DBresult)?$result:$DBresult;
-		
+
 	return $result;
 	}
-	
+
 	function DBcommit(){
 		global $DB;
-		
+
 		$result = false;
 		if( isset($DB['DB']) && !empty($DB['DB']) )
 		switch($DB['TYPE']){
@@ -322,10 +337,10 @@ if(!isset($DB)){
 				unlock_db_access();
 				break;
 		}
-				
+
 	return $result;
 	}
-	
+
 	function DBrollback(){
 		global $DB;
 
@@ -341,45 +356,45 @@ if(!isset($DB)){
 			case 'ORACLE':
 				$result = ocirollback($DB['DB']);
 				break;
-			case 'SQLITE3':				
+			case 'SQLITE3':
 				$result = DBexecute('rollback');
 				unlock_db_access();
 				break;
 		}
-		
+
 	return $result;
 	}
 
+/* NOTE:
+	LIMIT and OFFSET records
 
-	/* NOTE:
-		LIMIT and OFFSET records
-		
-		Example: select 6-15 row.
+	Example: select 6-15 row.
 
-		MySQL:	
-			SELECT a FROM tbl LIMIT 5,10
-			SELECT a FROM tbl LIMIT 10 OFFSET 5
-		PostgreSQL:
-			SELECT a FROM tbl LIMIT 10 OFFSET 5
-		Oracle:
-			SELECT a FROM tbe WHERE ROWNUM < 15 // ONLY < 15
-			SELECT * FROM (SELECT ROWNUM as RN, * FROM tbl) WHERE RN BETWEEN 6 AND 15
-	*/
+	MySQL:
+		SELECT a FROM tbl LIMIT 5,10
+		SELECT a FROM tbl LIMIT 10 OFFSET 5
+	PostgreSQL:
+		SELECT a FROM tbl LIMIT 10 OFFSET 5
+	Oracle:
+		SELECT a FROM tbe WHERE ROWNUM < 15 // ONLY < 15
+		SELECT * FROM (SELECT ROWNUM as RN, * FROM tbl) WHERE RN BETWEEN 6 AND 15
+//*/
 
-	function &DBselect($query, $limit='NO'){
+	function &DBselect($query, $limit='NO', $offset=0){
 		global $DB;
-//COpt::savesqlrequest($query);
+
+		$time_start=microtime(true);
 		$result = false;
-		
+
 		if( isset($DB['DB']) && !empty($DB['DB']) ){
-//SDI('SQL: '.$query);
 			$DB['SELECT_COUNT']++;
-			
+//SDI('SQL['.$DB['SELECT_COUNT'].']: '.$query);
 			switch($DB['TYPE']){
 				case 'MYSQL':
 					if(zbx_numeric($limit)){
-						$query .= ' limit '.intval($limit);
+						$query .= ' LIMIT '.intval($limit).' OFFSET '.intval($offset);
 					}
+
 					$result=mysql_query($query,$DB['DB']);
 					if(!$result){
 						error('Error in query ['.$query.'] ['.mysql_error().']');
@@ -387,8 +402,9 @@ if(!isset($DB)){
 					break;
 				case 'POSTGRESQL':
 					if(zbx_numeric($limit)){
-						$query .= ' limit '.intval($limit);
+						$query .= ' LIMIT '.intval($limit).' OFFSET '.intval($offset);
 					}
+
 					$result = pg_query($DB['DB'],$query);
 					if(!$result){
 						error('Error in query ['.$query.'] ['.pg_last_error().']');
@@ -396,26 +412,32 @@ if(!isset($DB)){
 					break;
 				case 'ORACLE':
 					if(zbx_numeric($limit)){
-						$query = 'select * from ('.$query.') where rownum<='.intval($limit);
+						$till = $offset + $limit;
+						$query = 'SELECT * FROM ('.$query.') WHERE rownum BETWEEN '.intval($offset).' AND '.intval($till);
 					}
+
 					$result = DBexecute($query);
 					if(!$result){
 						$e = ocierror($result);
 						error('SQL error ['.$e['message'].'] in ['.$e['sqltext'].']');
 					}
-	
+
 					break;
 				case 'SQLITE3':
 					if(!$DB['TRANSACTIONS']){
 						lock_db_access();
 					}
-					
-					if(!($result = sqlite3_query($DB['DB'],$query))){
+
+					if(zbx_numeric($limit)){
+						$query .= ' LIMIT '.intval($limit).' OFFSET '.intval($offset);
+					}
+
+					if(!$result = sqlite3_query($DB['DB'],$query)){
 						error('Error in query ['.$query.'] ['.sqlite3_error($DB['DB']).']');
 					}
 					else{
 						$data = array();
-	
+
 						while($row = sqlite3_fetch_array($result)){
 							foreach($row as $id => $name){
 								if(!zbx_strstr($id,'.')) continue;
@@ -425,9 +447,9 @@ if(!isset($DB)){
 							}
 							$data[] = $row;
 						}
-	
+
 						sqlite3_query_close($result);
-	
+
 						$result = &$data;
 					}
 					if(!$DB['TRANSACTIONS']){
@@ -435,34 +457,38 @@ if(!isset($DB)){
 					}
 					break;
 			}
-			
+
 			if($DB['TRANSACTIONS'] && !$result){
 				$DB['TRANSACTION_STATE'] &= $result;
 	//			SDI($query);
 	//			SDI($DB['TRANSACTION_STATE']);
 			}
-		}		
+		}
+COpt::savesqlrequest(microtime(true)-$time_start,$query);
 		return $result;
 	}
 
 	function DBexecute($query, $skip_error_messages=0){
 		global $DB;
-//COpt::savesqlrequest($query);
 		$result = false;
 
+		$time_start=microtime(true);
 		if( isset($DB['DB']) && !empty($DB['DB']) ){
 			$DB['EXECUTE_COUNT']++;	// WRONG FOR ORACLE!!
-//SDI('SQL Exec: '.$query);
+//SDI('SQL xec: '.$query);
+
 			switch($DB['TYPE']){
 				case 'MYSQL':
 					$result=mysql_query($query,$DB['DB']);
-	
+
 					if(!$result){
 						error('Error in query ['.$query.'] ['.mysql_error().']');
 					}
 					break;
 				case 'POSTGRESQL':
-					if(!($result = pg_query($DB['DB'],$query))){
+					$result = (bool) pg_query($DB['DB'],$query);
+
+					if(!$result){
 						error('Error in query ['.$query.'] ['.pg_last_error().']');
 					}
 					break;
@@ -472,7 +498,7 @@ if(!isset($DB)){
 						$e=@ocierror();
 						error('SQL error ['.$e['message'].'] in ['.$e['sqltext'].']');
 					}
-					
+
 					$result=@OCIExecute($stid,($DB['TRANSACTIONS']?OCI_DEFAULT:OCI_COMMIT_ON_SUCCESS));
 					if(!$result){
 						$e=ocierror($stid);
@@ -481,51 +507,65 @@ if(!isset($DB)){
 					else{
 						$result = $stid;
 					}
-	
+
 					break;
 				case 'SQLITE3':
 					if(!$DB['TRANSACTIONS']){
 						lock_db_access();
 					}
-	
+
 					$result = sqlite3_exec($DB['DB'], $query);
 					if(!$result){
 						error('Error in query ['.$query.'] ['.sqlite3_error($DB['DB']).']');
 					}
-					
+
 					if(!$DB['TRANSACTIONS']){
 						unlock_db_access();
 					}
 					break;
 			}
-			
+
 			if($DB['TRANSACTIONS'] && !$result){
 				$DB['TRANSACTION_STATE'] &= $result;
 	//			SDI($query);
 	//			SDI($DB['TRANSACTION_STATE']);
 			}
 		}
+COpt::savesqlrequest(microtime(true)-$time_start,$query);
 	return $result;
 	}
 
 	function DBfetch(&$cursor){
 		global $DB;
-	
+
 		$result = false;
-		
+
 		if(isset($DB['DB']) && !empty($DB['DB']))
 		switch($DB['TYPE']){
 			case 'MYSQL':
 				$result = mysql_fetch_assoc($cursor);
+				if(!$result){
+					mysql_free_result($cursor);
+				}
 				break;
 			case 'POSTGRESQL':
 				$result = pg_fetch_assoc($cursor);
+				if(!$result){
+					pg_free_result($cursor);
+				}
 				break;
 			case 'ORACLE':
 				if(ocifetchinto($cursor, $row, (OCI_ASSOC+OCI_RETURN_NULLS))){
 					$result = array();
 					foreach($row as $key => $value){
-						$result[strtolower($key)] = (str_in_array(strtolower(ocicolumntype($cursor,$key)),array('varchar','varchar2','blob','clob')) && is_null($value))?'':$value;
+						$field_type = strtolower(oci_field_type($cursor,$key));
+						$value = (str_in_array($field_type,array('varchar','varchar2','blob','clob')) && is_null($value))?'':$value;
+
+						if(is_object($value) && (stristr($field_type, 'lob') !== false)){
+							$value = $value->load();
+						}
+
+						$result[strtolower($key)] = $value;
 					}
 				}
 				break;
@@ -536,16 +576,24 @@ if(!isset($DB)){
 				}
 				break;
 		}
-
+/*
+		if($result === false){
+			switch($DB['TYPE']){
+				case 'MYSQL': mysql_free_result($cursor); break;
+				case 'POSTGRESQL': pg_free_result($cursor); break;
+				case 'ORACLE': oci_free_statement($cursor); break;
+			}
+		}
+//*/
 	return $result;
 	}
-	
-/* string value prepearing */
+
+// string value prepearing
 if(isset($DB['TYPE']) && $DB['TYPE'] == 'ORACLE') {
 	function zbx_dbstr($var)	{
-		return "'".ereg_replace('\'','\'\'',$var)."'";	
+		return "'".preg_replace('/\'/','\'\'',$var)."'";
 	}
-	
+
 	function zbx_dbcast_2bigint($field){
 		return ' CAST('.$field.' AS NUMBER(20)) ';
 	}
@@ -554,7 +602,7 @@ else if(isset($DB['TYPE']) && $DB['TYPE'] == "MYSQL") {
 	function zbx_dbstr($var)	{
 		return "'".mysql_real_escape_string($var)."'";
 	}
-	
+
 	function zbx_dbcast_2bigint($field){
 		return ' CAST('.$field.' AS UNSIGNED) ';
 	}
@@ -563,20 +611,20 @@ else if(isset($DB['TYPE']) && $DB['TYPE'] == "POSTGRESQL") {
 	function zbx_dbstr($var)	{
 		return "'".pg_escape_string($var)."'";
 	}
-	
+
 	function zbx_dbcast_2bigint($field){
 		return ' CAST('.$field.' AS BIGINT) ';
 	}
 }
-else {			
+else {
 	function zbx_dbstr($var)	{
 		return "'".addslashes($var)."'";
 	}
-	
+
 	function zbx_dbcast_2bigint($field){
 		return ' CAST('.$field.' AS BIGINT) ';
 	}
-} 
+}
 
 	function zbx_dbconcat($params){
 		global $DB;
@@ -588,7 +636,7 @@ else {
 				return 'CONCAT('.implode(',',$params).')';
 		}
 	}
-	
+
 	function zbx_sql_mod($x,$y){
 		global $DB;
 
@@ -602,6 +650,7 @@ else {
 
 	function DBid2nodeid($id_name){
 		global $DB;
+
 		switch($DB['TYPE']){
 			case "MYSQL":
 				$result = '('.$id_name.' div 100000000000000)';
@@ -619,26 +668,37 @@ else {
 		return (int)bcdiv("$id_var",'100000000000000');
 	}
 
-	function DBin_node( $id_name, $nodes = null ){
+	function DBin_node($id_name, $nodes = null){
 		if(is_null($nodes))	$nodes = get_current_nodeid();
+		else if(is_bool($nodes)) $nodes = get_current_nodeid($nodes);
 
-		if(empty($nodes))	$nodes = 0;
+		if(empty($nodes)){
+			$nodes = array(0);
+		}
+		else if(!is_array($nodes)){
+			if(is_string($nodes)){
+				if(!preg_match('/^([0-9,]+)$/', $nodes))
+					fatal_error('Incorrect "nodes" for "DBin_node". Passed ['.$nodes.']');
+			}
+			else if(!zbx_ctype_digit($nodes)){
+				fatal_error('Incorrect type of "nodes" for "DBin_node". Passed ['.gettype($nodes).']');
+			}
 
-		if(is_array($nodes)){
-			$nodes = implode(',', $nodes);
+			$nodes = zbx_toArray($nodes);
 		}
-		else if(is_string($nodes)){
-			if ( !eregi('([0-9\,]+)', $nodes ) )
-				fatal_error('Incorrect "nodes" for "DBin_node". Passed ['.$nodes.']');
+
+		$sql = '';
+		foreach($nodes as $nnum => $nodeid){
+			$sql.= '('.$id_name.'  BETWEEN '.$nodeid.'00000000000000 AND '.$nodeid.'99999999999999)';
+			$sql.= ' OR ';
 		}
-		else if(!zbx_numeric($nodes)){
-			fatal_error('Incorrect type of "nodes" for "DBin_node". Passed ['.gettype($nodes).']');
-		}
-	return (' '.DBid2nodeid($id_name).' in ('.$nodes.') ');
+
+		$sql = '('.trim($sql, 'OR ').')';
+	return $sql;
 	}
 
 	function in_node( $id_var, $nodes = null ){
-		if(is_null($nodes))	
+		if(is_null($nodes))
 			$nodes = get_current_nodeid();
 
 		if(empty($nodes))
@@ -648,9 +708,9 @@ else {
 			$nodes = array($nodes);
 		}
 		else if(is_string($nodes)){
-			if(!eregi('([0-9\,]+)',$nodes))
+			if(!preg_match('/^([0-9,]+)$/', $nodes))
 				fatal_error('Incorrect "nodes" for "in_node". Passed ['.$nodes.']');
-				
+
 			$nodes = explode(',', $nodes);
 		}
 		else if(!is_array($nodes)){
@@ -661,46 +721,45 @@ else {
 	}
 
 	function get_dbid($table,$field){
+// PGSQL on transaction failure on all queries returns false..
+		global $DB, $ZBX_LOCALNODEID;
+		if(($DB['TYPE'] == 'POSTGRESQL') && $DB['TRANSACTIONS'] && !$DB['TRANSACTION_STATE']) return 1;
+//------
+
 		$nodeid = get_current_nodeid(false);
 
 		$found = false;
 		do{
-			global $ZBX_LOCALNODEID;
-
 			$min=bcadd(bcmul($nodeid,'100000000000000'),bcmul($ZBX_LOCALNODEID,'100000000000'));
 			$max=bcadd(bcadd(bcmul($nodeid,'100000000000000'),bcmul($ZBX_LOCALNODEID,'100000000000')),'99999999999');
-			$row = DBfetch(DBselect('SELECT nextid FROM ids WHERE nodeid='.$nodeid ." AND table_name='$table' AND field_name='$field'"));
+			$row = DBfetch(DBselect('SELECT nextid FROM ids WHERE nodeid='.$nodeid .' AND table_name='.zbx_dbstr($table).' AND field_name='.zbx_dbstr($field)));
 			if(!$row){
 				$row=DBfetch(DBselect('SELECT max('.$field.') AS id FROM '.$table.' WHERE '.$field.'>='.$min.' AND '.$field.'<='.$max));
-				if(!$row || is_null($row["id"])){
-				
-					DBexecute('INSERT INTO ids (nodeid,table_name,field_name,nextid) '.
-						" VALUES ($nodeid,'$table','$field',$min)");
+				if(!$row || is_null($row['id'])){
+					DBexecute("INSERT INTO ids (nodeid,table_name,field_name,nextid) VALUES ($nodeid,'$table','$field',$min)");
 				}
 				else{
-					/*
-					$ret1 = $row["id"];
+/*					$ret1 = $row["id"];
 					if($ret1 >= $max) {
 						"Maximum number of id's was exceeded"
 					}
-					*/
+//*/
 
-					DBexecute("INSERT INTO ids (nodeid,table_name,field_name,nextid) VALUES ($nodeid,'$table','$field',".$row["id"].')');
+					DBexecute("INSERT INTO ids (nodeid,table_name,field_name,nextid) VALUES ($nodeid,'$table','$field',".$row['id'].')');
 				}
 				continue;
 			}
 			else{
-				$ret1 = $row["nextid"];
+				$ret1 = $row['nextid'];
 				if((bccomp($ret1,$min) < 0) || !(bccomp($ret1,$max) < 0)) {
-					DBexecute("DELETE FROM ids WHERE nodeid=$nodeid AND table_name='$table' AND field_name='$field'");
+					DBexecute('DELETE FROM ids WHERE nodeid='.$nodeid.' AND table_name='.zbx_dbstr($table).' AND field_name='.zbx_dbstr($field));
 					continue;
 				}
-	
-				DBexecute("UPDATE ids SET nextid=nextid+1 WHERE nodeid=$nodeid AND table_name='$table' AND field_name='$field'");
-	
-				$row = DBfetch(DBselect('SELECT nextid FROM ids WHERE nodeid='.$nodeid." AND table_name='$table' AND field_name='$field'"));
+
+				DBexecute('UPDATE ids SET nextid=nextid+1 WHERE nodeid='.$nodeid.' AND table_name='.zbx_dbstr($table).' AND field_name='.zbx_dbstr($field));
+				$row = DBfetch(DBselect('SELECT nextid FROM ids WHERE nodeid='.$nodeid.' AND table_name='.zbx_dbstr($table).' AND field_name='.zbx_dbstr($field)));
 				if(!$row || is_null($row["nextid"])){
-					/* Should never be here */
+// Should never be here
 					continue;
 				}
 				else{
@@ -715,24 +774,24 @@ else {
 
 		return $ret2;
 	}
-	
+
 	function create_id_by_nodeid($id,$nodeid=0){
-			
+
 		global $ZBX_LOCALNODEID;
 		$nodeid = ($nodeid == 0)?get_current_nodeid(false):$nodeid;
-		
+
 		$id=remove_nodes_from_id($id);
 		$id=bcadd($id,bcadd(bcmul($nodeid,'100000000000000'),bcmul($ZBX_LOCALNODEID,'100000000000')));
 	return $id;
 	}
-	
+
 	function remove_nodes_from_id($id){
 		return bcmod($id,'100000000000');
 	}
 
 	function check_db_fields(&$db_fields, &$args){
 		if(!is_array($args)) return false;
-		
+
 		foreach($db_fields as $field => $def){
 			if(!isset($args[$field])){
 				if(is_null($def)){
@@ -745,16 +804,16 @@ else {
 		}
 	return true;
 	}
-	
+
 	function DBcondition($fieldname, &$array, $notin=false, $string=false){
 		global $DB;
 		$condition = '';
-		
+
 		if(!is_array($array)){
 			info('DBcondition Error: ['.$fieldname.'] = '.$array);
 			$array = explode(',',$array);
 			if(empty($array))
-				return ' 1=1 ';
+				return ' 1=0 ';
 		}
 
 		$in = 		$notin?' NOT IN ':' IN ';
@@ -770,16 +829,16 @@ else {
 				$items = array_chunk($array, 950);
 				foreach($items as $id => $values){
 					$condition.=!empty($condition)?')'.$concat.$fieldname.$in.'(':'';
-					
+
 					if($string)	$condition.= "'".implode($glue,$values)."'";
 					else		$condition.= implode($glue,$values);
 				}
 				break;
 		}
-		
+
 		if(zbx_empty($condition)) $condition = $string?"'-1'":'-1';
 
 	return ' ('.$fieldname.$in.'('.$condition.')) ';
 	}
-	
-?>
\ No newline at end of file
+
+?>
