@@ -26,7 +26,7 @@
  *     Represent integer value of graph item type into the string
  *
  * Author:
- *     Eugene Grigorjev 
+ *     Eugene Grigorjev
  *
  */
 	function graph_item_type2str($type,$count=null){
@@ -44,7 +44,7 @@
 		}
 	return $type;
 	}
-	
+
 /*
  * Function: graph_item_drawtypes
  *
@@ -52,7 +52,7 @@
  *     Return available drawing types for graph item
  *
  * Author:
- *     Eugene Grigorjev 
+ *     Eugene Grigorjev
  *
  */
 	function graph_item_drawtypes(){
@@ -61,10 +61,11 @@
 				GRAPH_ITEM_DRAWTYPE_FILLED_REGION,
 				GRAPH_ITEM_DRAWTYPE_BOLD_LINE,
 				GRAPH_ITEM_DRAWTYPE_DOT,
-				GRAPH_ITEM_DRAWTYPE_DASHED_LINE
-			    );
+				GRAPH_ITEM_DRAWTYPE_DASHED_LINE,
+				GRAPH_ITEM_DRAWTYPE_GRADIENT_LINE
+			);
 	}
-	
+
 /*
  * Function: graph_item_drawtype2str
  *
@@ -72,23 +73,23 @@
  *     Represent integer value of graph item drawing type into the string
  *
  * Author:
- *     Eugene Grigorjev 
+ *     Eugene Grigorjev
  *
  */
 	function graph_item_drawtype2str($drawtype,$type=null){
 		if($type == GRAPH_ITEM_AGGREGATED) return '-';
 
 		switch($drawtype){
-			case GRAPH_ITEM_DRAWTYPE_LINE:			$drawtype = S_LINE;				break;
-			case GRAPH_ITEM_DRAWTYPE_FILLED_REGION:	$drawtype = S_FILLED_REGION;	break;
-			case GRAPH_ITEM_DRAWTYPE_BOLD_LINE:		$drawtype = S_BOLD_LINE;		break;
-			case GRAPH_ITEM_DRAWTYPE_DOT:			$drawtype = S_DOT;				break;
-			case GRAPH_ITEM_DRAWTYPE_DASHED_LINE:	$drawtype = S_DASHED_LINE;		break;
+			case GRAPH_ITEM_DRAWTYPE_LINE:			$drawtype = S_LINE;		break;
+			case GRAPH_ITEM_DRAWTYPE_FILLED_REGION:		$drawtype = S_FILLED_REGION;	break;
+			case GRAPH_ITEM_DRAWTYPE_BOLD_LINE:		$drawtype = S_BOLD_LINE;	break;
+			case GRAPH_ITEM_DRAWTYPE_DOT:			$drawtype = S_DOT;		break;
+			case GRAPH_ITEM_DRAWTYPE_DASHED_LINE:		$drawtype = S_DASHED_LINE;	break;
+			case GRAPH_ITEM_DRAWTYPE_GRADIENT_LINE:	$drawtype = S_GRADIENT_LINE;  break;
 			default: $drawtype = S_UNKNOWN;		break;
 		}
 	return $drawtype;
 	}
-
 /*
  * Function: graph_item_calc_fnc2str
  *
@@ -96,38 +97,75 @@
  *     Represent integer value of calculation function into the string
  *
  * Author:
- *     Eugene Grigorjev 
+ *     Eugene Grigorjev
  *
  */
 	function graph_item_calc_fnc2str($calc_fnc, $type=null){
 		if($type == GRAPH_ITEM_AGGREGATED) return '-';
-		
+
 		switch($calc_fnc){
-			case CALC_FNC_ALL:      $calc_fnc = S_ALL_SMALL;        break;
-			case CALC_FNC_MIN:      $calc_fnc = S_MIN_SMALL;        break;
-			case CALC_FNC_MAX:      $calc_fnc = S_MAX_SMALL;        break;
-			case CALC_FNC_LST:		$calc_fnc = S_LST_SMALL;		break;
+			case 0:			$calc_fnc = S_COUNT;		break;
+			case CALC_FNC_ALL:	$calc_fnc = S_ALL_SMALL;	break;
+			case CALC_FNC_MIN:	$calc_fnc = S_MIN_SMALL;	break;
+			case CALC_FNC_MAX:	$calc_fnc = S_MAX_SMALL;	break;
+			case CALC_FNC_LST:	$calc_fnc = S_LST_SMALL;	break;
 			case CALC_FNC_AVG:
-			default:		$calc_fnc = S_AVG_SMALL;        break;
+			default:		$calc_fnc = S_AVG_SMALL;	break;
 		}
 	return $calc_fnc;
 	}
-	
+
+	function getGraphDims($graphid){
+// ZOOM featers
+		$graphDims = array();
+
+		$sql = 'SELECT MAX(g.graphtype) as graphtype, MIN(gi.yaxisside) as yaxissidel, MAX(gi.yaxisside) as yaxissider, MAX(g.height) as height'.
+				' FROM graphs g, graphs_items gi '.
+				' WHERE g.graphid='.$graphid.
+					' AND gi.graphid=g.graphid ';
+		$res = DBselect($sql);
+		if($graph=DBfetch($res)){
+			$graphDims['graphtype'] = $graph['graphtype'];
+			$graphDims['graphHeight'] = $graph['height'];
+			$yaxis = $graph['yaxissider'];
+			$yaxis = ($graph['yaxissidel'] == $yaxis)?($yaxis):(2);
+
+			$graphDims['yaxis'] = $yaxis;
+		}
+
+		if($yaxis == 2){
+			$graphDims['shiftXleft'] = 100;
+			$graphDims['shiftXright'] = 100;
+		}
+		else if($yaxis == 0){
+			$graphDims['shiftXleft'] = 100;
+			$graphDims['shiftXright'] = 50;
+		}
+		else{
+			$graphDims['shiftXleft'] = 50;
+			$graphDims['shiftXright'] = 100;
+		}
+//-------------
+
+	return $graphDims;
+	}
+
 	function get_graph_by_gitemid($gitemid){
 		$db_graphs = DBselect('SELECT distinct g.* '.
 						' FROM graphs g, graphs_items gi '.
 						' WHERE g.graphid=gi.graphid '.
 							' AND gi.gitemid='.$gitemid);
-			
+
 	return DBfetch($db_graphs);
 	}
 
 	function get_graphs_by_hostid($hostid){
-		return DBselect('SELECT distinct g.* '.
-						' FROM graphs g, graphs_items gi, items i '.
-						' WHERE g.graphid=gi.graphid '.
-							' AND gi.itemid=i.itemid '.
-							' AND i.hostid='.$hostid);
+		$sql = 'SELECT distinct g.* '.
+				' FROM graphs g, graphs_items gi, items i '.
+				' WHERE g.graphid=gi.graphid '.
+					' AND gi.itemid=i.itemid '.
+					' AND i.hostid='.$hostid;
+	return DBselect($sql);
 	}
 
 	function get_realhosts_by_graphid($graphid){
@@ -150,7 +188,7 @@
 		return DBselect('SELECT * '.
 					' FROM graphs_items '.
 					' WHERE graphid='.$graphid.
-					' ORDER BY itemid,drawtype,sortorder,color,yaxisside'); 
+					' ORDER BY itemid,drawtype,sortorder,color,yaxisside');
 	}
 
 /*
@@ -166,7 +204,7 @@
 	function graph_accessible($graphid){
 		global $USER_DETAILS;
 		$available_hosts = get_accessible_hosts_by_user($USER_DETAILS, PERM_READ_ONLY, PERM_RES_IDS_ARRAY,get_current_nodeid(true));
-		
+
 		$sql = 	'SELECT g.graphid '.
 				' FROM graphs g, graphs_items gi, items i '.
 				' WHERE g.graphid='.$graphid.
@@ -180,7 +218,6 @@
 	return true;
 	}
 
-
 /*
  * Function: get_accessible_graphs
  *
@@ -190,29 +227,29 @@
  * Author:
  *     Aly
  *
- */		
+ */
 	function get_accessible_graphs($perm,$hostids,$perm_res=null,$nodeid=null,$cache=1){
 		global $USER_DETAILS;
 		static $available_graphs;
-		
+
 		if(is_null($perm_res)) $perm_res = PERM_RES_IDS_ARRAY;
 		$nodeid_str =(is_array($nodeid))?implode('',$nodeid):strval($nodeid);
 		$hostid_str = implode('',$hostids);
-		
+
 		$cache_hash = md5($perm.$perm_res.$nodeid_str.$hostid_str);
 		if($cache && isset($available_graphs[$cache_hash])){
 			return $available_graphs[$cache_hash];
 		}
-		
+
 		$available_hosts = get_accessible_hosts_by_user($USER_DETAILS, $perm, PERM_RES_IDS_ARRAY, $nodeid);
 
 		$denied_graphs = array();
 		$result = array();
-		
+
 		$sql_where = '';
 		if(!empty($hostids)){
 			$sql_where.= ' AND '.DBcondition('i.hostid',$hostids);
-		}		
+		}
 		$sql = 	'SELECT DISTINCT g.graphid '.
 				' FROM graphs g, graphs_items gi, items i '.
 				' WHERE g.graphid=gi.graphid '.
@@ -235,9 +272,9 @@
 		while($graph = DBfetch($db_graphs)){
 			$result[$graph['graphid']] = $graph['graphid'];
 		}
-		
+
 		if(PERM_RES_STRING_LINE == $perm_res){
-			if(count($result) == 0) 
+			if(count($result) == 0)
 				$result = '-1';
 			else
 				$result = implode(',',$result);
@@ -252,15 +289,15 @@
  * Function: get_min_itemclock_by_graphid
  *
  * Description:
- *     Return the time of the 1st apearance of items included in graph in trends
+ *     Return the time of the 1st appearance of items included in graph in trends
  *
  * Author:
  *     Aly
  *
  * Comment:
- *	   sql is splited to many sql's to optimize search on history tables
+ *	sql is split to many sql's to optimize search on history tables
  *
- */	
+ */
 	function get_min_itemclock_by_graphid($graphid){
 		$itemids = array();
 		$sql = 'SELECT DISTINCT gi.itemid '.
@@ -278,34 +315,34 @@
  * Function: get_min_itemclock_by_itemid
  *
  * Description:
- *     Return the time of the 1st apearance of item in trends
+ *     Return the time of the 1st appearance of item in trends
  *
  * Author:
  *     Aly
  *
- */	
+ */
 	function get_min_itemclock_by_itemid($itemids){
 		zbx_value2array($itemids);
 		$min = null;
 		$result = time() - 86400*365;
-		
-		$items_by_type = array(ITEM_VALUE_TYPE_FLOAT => array(), ITEM_VALUE_TYPE_STR =>  array(), ITEM_VALUE_TYPE_LOG => array(), 
+
+		$items_by_type = array(ITEM_VALUE_TYPE_FLOAT => array(), ITEM_VALUE_TYPE_STR =>  array(), ITEM_VALUE_TYPE_LOG => array(),
 						ITEM_VALUE_TYPE_UINT64 => array(), ITEM_VALUE_TYPE_TEXT => array());
-						
+
 		$sql = 'SELECT i.itemid, i.value_type '.
 				' FROM items i WHERE '.DBcondition('i.itemid', $itemids);
 		$db_result = DBselect($sql);
-		
+
 		while($item = DBfetch($db_result)) {
 			$items_by_type[$item['value_type']][$item['itemid']] = $item['itemid'];
 		}
-		
+
 		// data for ITEM_VALUE_TYPE_FLOAT and ITEM_VALUE_TYPE_UINT64 can be stored in trends tables or history table
 		// get max trends and history values for such type items to find out in what tables to look for data
 		$sql_from = 'history';
 		$sql_from_num = '';
 		if(!empty($items_by_type[ITEM_VALUE_TYPE_FLOAT]) || !empty($items_by_type[ITEM_VALUE_TYPE_UINT64])) {
-			$itemids_numeric = array_merge($items_by_type[ITEM_VALUE_TYPE_FLOAT], $items_by_type[ITEM_VALUE_TYPE_UINT64]);
+			$itemids_numeric = zbx_array_merge($items_by_type[ITEM_VALUE_TYPE_FLOAT], $items_by_type[ITEM_VALUE_TYPE_UINT64]);
 			$sql = 'SELECT MAX(i.history) as history, MAX(i.trends) as trends FROM items i WHERE '.DBcondition('i.itemid', $itemids_numeric);
 
 			if($table_for_numeric = DBfetch(DBselect($sql))){
@@ -313,6 +350,7 @@
 				$result = time() - (86400 * max($table_for_numeric['history'],$table_for_numeric['trends']));
 			}
 		}
+
 		foreach($items_by_type as $type => $items) {
 			if(empty($items)) continue;
 			switch($type) {
@@ -334,6 +372,7 @@
 				default:
 					$sql_from = 'history';
 			}
+
 			foreach($items as $itemid) {
 				$sql = 'SELECT ht.clock '.
 						' FROM '.$sql_from.' ht '.
@@ -342,48 +381,21 @@
 				if($min_tmp = DBfetch(DBselect($sql,1))){
 					$min = (is_null($min)) ? $min_tmp['clock'] : min($min, $min_tmp['clock']);
 				}
-			}			
+			}
 		}
 		$result = is_null($min)?$result:$min;
-		
-	return $result;
-	}
-	
-// Show History Graph
-	function show_history($itemid,$from,$stime,$period){
-		//$till=date(S_DATE_FORMAT_YMDHMS,time(NULL)-$from*3600);   
-		
-		//show_table_header(S_TILL.SPACE.$till.' ( '.zbx_date2age($stime,$stime+$period).' )');
 
-		$td = new CCol(get_js_sizeable_graph('graph','chart.php?itemid='.$itemid.
-				url_param($from,false,'from').
-				url_param($stime,false,'stime').
-				url_param($period,false,'period')));
-		$td->addOption('align','center');
-		
-		$tr = new CRow($td);
-		$tr->addOption('bgcolor','#dddddd');
-		
-		$table = new CTable();
-		$table->addOption('width','100%');
-		$table->addOption('bgcolor','#cccccc');
-		$table->addOption('cellspacing','1');
-		$table->addOption('cellpadding','3');
-		
-		$table->addRow($tr);
-		
-		$table->show();
-		echo SBR;
+	return $result;
 	}
 
 	function get_graphitem_by_gitemid($gitemid){
-		$result=DBselect("SELECT * FROM graphs_items WHERE gitemid=$gitemid");
+		$result=DBselect('SELECT * FROM graphs_items WHERE gitemid='.$gitemid);
 		$row=DBfetch($result);
 		if($row){
 			return	$row;
 		}
 		error("No graph item with gitemid=[$gitemid]");
-		
+
 	return	$result;
 	}
 
@@ -420,11 +432,11 @@
  *     Replace items for specified host
  *
  * Author:
- *     Eugene Grigorjev 
+ *     Eugene Grigorjev
  *
  * Comments: !!! Don't forget sync code with C !!!
  * Only PHP:
- *		$error= true : rise Error if item doesn't exists(error generated), false: special processing (NO error generated)
+ *		$error= true : rise Error if item doesn't exist (error generated), false: special processing (NO error generated)
  */
 	function get_same_graphitems_for_host($gitems, $dest_hostid, $error=true){
 		$result = array();
@@ -455,7 +467,7 @@
 
 		return $result;
 	}
-	
+
         /*
          * Function: add_graph
          *
@@ -463,19 +475,19 @@
          *     Add graph without items and recursion for templates
          *
          * Author:
-         *     Eugene Grigorjev 
+         *     Eugene Grigorjev
          *
          * Comments: !!! Don't forget sync code with C !!!
          *
          */
-	function add_graph($name,$width,$height,$yaxistype,$yaxismin,$yaxismax,$showworkperiod,$showtriggers,$graphtype,$legend,$graph3d,$percent_left,$percent_right,$templateid=0)
+	function add_graph($name,$width,$height,$ymin_type,$ymax_type,$yaxismin,$yaxismax,$ymin_itemid,$ymax_itemid,$showworkperiod,$showtriggers,$graphtype,$legend,$graph3d,$percent_left,$percent_right,$templateid=0)
 	{
 		$graphid = get_dbid("graphs","graphid");
 
 		$result=DBexecute('INSERT INTO graphs '.
-			' (graphid,name,width,height,yaxistype,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right) '.
-			" VALUES ($graphid,".zbx_dbstr($name).",$width,$height,$yaxistype,$yaxismin,".
-			" $yaxismax,$templateid,$showworkperiod,$showtriggers,$graphtype,$legend,$graph3d,$percent_left,$percent_right)");
+			' (graphid,name,width,height,ymin_type,ymax_type,yaxismin,yaxismax,ymin_itemid,ymax_itemid,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right) '.
+			" VALUES ($graphid,".zbx_dbstr($name).",$width,$height,$ymin_type,$ymax_type,$yaxismin,$yaxismax,$ymin_itemid,$ymax_itemid,".
+			" $templateid,$showworkperiod,$showtriggers,$graphtype,$legend,$graph3d,$percent_left,$percent_right)");
 
 		return ( $result ? $graphid : $result);
 	}
@@ -487,12 +499,12 @@
          *     Add graph with items and recursion for templates
          *
          * Author:
-         *     Eugene Grigorjev 
+         *     Eugene Grigorjev
          *
          * Comments: !!! Don't forget sync code with C !!!
          *
          */
-	function add_graph_with_items($name,$width,$height,$yaxistype,$yaxismin,$yaxismax,$showworkperiod,$showtriggers,$graphtype,$legend,$graph3d,$percent_left,$percent_right,$gitems=array(),$templateid=0)
+	function add_graph_with_items($name,$width,$height,$ymin_type,$ymax_type,$yaxismin,$yaxismax,$ymin_itemid,$ymax_itemid,$showworkperiod,$showtriggers,$graphtype,$legend,$graph3d,$percent_left,$percent_right,$gitems=array(),$templateid=0)
 	{
 		$result = false;
 
@@ -513,7 +525,7 @@
 							' FROM items i, hosts h '.
 							' WHERE h.hostid=i.hostid '.
 								' AND '.DBcondition('i.itemid',$itemid));
-								
+
 		while($db_item_host = DBfetch($db_item_hosts)){
 			$host_list[] = '"'.$db_item_host['host'].'"';
 
@@ -526,7 +538,7 @@
 			return $result;
 		}
 
-		if($graphid = add_graph($name,$width,$height,$yaxistype,$yaxismin,$yaxismax,$showworkperiod,$showtriggers,$graphtype,$legend,$graph3d,$percent_left,$percent_right,$templateid)){
+		if($graphid = add_graph($name,$width,$height,$ymin_type,$ymax_type,$yaxismin,$yaxismax,$ymin_itemid,$ymax_itemid,$showworkperiod,$showtriggers,$graphtype,$legend,$graph3d,$percent_left,$percent_right,$templateid)){
 			$result = true;
 			foreach($gitems as $gitem){
 				if (!$result = add_item_to_graph(
@@ -573,22 +585,36 @@
          *     Update graph without items and recursion for template
          *
          * Author:
-         *     Eugene Grigorjev 
+         *     Eugene Grigorjev
          *
          * Comments: !!! Don't forget sync code with C !!!
          *
          */
-	function update_graph($graphid,$name,$width,$height,$yaxistype,$yaxismin,$yaxismax,$showworkperiod,$showtriggers,$graphtype,$legend,$graph3d,$percent_left,$percent_right,$templateid=0){
+	function update_graph($graphid,$name,$width,$height,$ymin_type,$ymax_type,$yaxismin,$yaxismax,$ymin_itemid,$ymax_itemid,$showworkperiod,$showtriggers,$graphtype,$legend,$graph3d,$percent_left,$percent_right,$templateid=0){
+
 		$g_graph = get_graph_by_graphid($graphid);
 
-		if ( ($result = DBexecute(
-				'UPDATE graphs '.
-				'SET name='.zbx_dbstr($name).',width='.$width.',height='.$height.
-					',yaxistype='.$yaxistype.',yaxismin='.$yaxismin.',yaxismax='.$yaxismax.',templateid='.$templateid.
-					',show_work_period='.$showworkperiod.',show_triggers='.$showtriggers.',graphtype='.$graphtype.',show_legend='.$legend.
-					',show_3d='.$graph3d.',percent_left='.$percent_left.',percent_right='.$percent_right.
-				' WHERE graphid='.$graphid)) )
-		{
+		$sql = 'UPDATE graphs SET '.
+				'name='.zbx_dbstr($name).','.
+				'width='.$width.','.
+				'height='.$height.','.
+				'ymin_type='.$ymin_type.','.
+				'ymax_type='.$ymax_type.','.
+				'yaxismin='.$yaxismin.','.
+				'yaxismax='.$yaxismax.','.
+				'ymin_itemid='.$ymin_itemid.','.
+				'ymax_itemid='.$ymax_itemid.','.
+				'templateid='.$templateid.','.
+				'show_work_period='.$showworkperiod.','.
+				'show_triggers='.$showtriggers.','.
+				'graphtype='.$graphtype.','.
+				'show_legend='.$legend.','.
+				'show_3d='.$graph3d.','.
+				'percent_left='.$percent_left.','.
+				'percent_right='.$percent_right.
+			' WHERE graphid='.$graphid;
+
+		if($result = DBexecute($sql)){
 			if($g_graph['graphtype'] != $graphtype && $graphtype == GRAPH_TYPE_STACKED){
 				$result = DBexecute('UPDATE graphs_items SET calc_fnc='.CALC_FNC_AVG.',drawtype=1,type='.GRAPH_ITEM_SIMPLE.
 					' WHERE graphid='.$graphid);
@@ -597,19 +623,19 @@
 		return $result;
 	}
 
-        /*
-         * Function: update_graph_with_items
-         *
-         * Description:
-         *     Update graph with items and recursion for template
-         *
-         * Author:
-         *     Eugene Grigorjev 
-         *
-         * Comments: !!! Don't forget sync code with C !!!
-         *
-         */
-	function update_graph_with_items($graphid,$name,$width,$height,$yaxistype,$yaxismin,$yaxismax,$showworkperiod,$showtriggers,$graphtype,$legend,$graph3d,$percent_left,$percent_right,$gitems=array(),$templateid=0)
+/*
+ * Function: update_graph_with_items
+ *
+ * Description:
+ *     Update graph with items and recursion for template
+ *
+ * Author:
+ *     Eugene Grigorjev
+ *
+ * Comments: !!! Don't forget sync code with C !!!
+ *
+ */
+	function update_graph_with_items($graphid,$name,$width,$height,$ymin_type,$ymax_type,$yaxismin,$yaxismax,$ymin_itemid,$ymax_itemid,$showworkperiod,$showtriggers,$graphtype,$legend,$graph3d,$percent_left,$percent_right,$gitems=array(),$templateid=0)
 	{
 		$result = false;
 
@@ -618,7 +644,7 @@
 			return $result;
 		}
 
-		/* check items for template graph */
+// check items for template graph
 		$tmp_hosts = get_hosts_by_graphid($graphid);
 		$host = DBfetch($tmp_hosts);
 		if($host["status"] == HOST_STATUS_TEMPLATE ){
@@ -644,19 +670,19 @@
 			}
 		}
 
-		/* firstly update child graphs */
+// firstly update child graphs
 		$chd_graphs = get_graphs_by_templateid($graphid);
 		while($chd_graph = DBfetch($chd_graphs)){
 			$tmp_hosts = get_hosts_by_graphid($chd_graph['graphid']);
 			$chd_host = DBfetch($tmp_hosts);
-			
+
 			if(!$new_gitems = get_same_graphitems_for_host($gitems, $chd_host['hostid'])){ /* skip host with missing items */
 				error('Can not update graph "'.$name.'" for host "'.$chd_host['host'].'"');
 				return $result;
 			}
 
 			if (!$result = update_graph_with_items($chd_graph['graphid'], $name, $width, $height,
-				$yaxistype, $yaxismin, $yaxismax,
+				$ymin_type,$ymax_type,$yaxismin,$yaxismax,$ymin_itemid,$ymax_itemid,
 				$showworkperiod, $showtriggers, $graphtype, $legend, $graph3d, $percent_left, $percent_right, $new_gitems, $graphid))
 			{
 				return $result;
@@ -666,7 +692,7 @@
 		DBexecute('DELETE FROM graphs_items WHERE graphid='.$graphid);
 
 		foreach($gitems as $gitem){
-			if ( ! ($result = add_item_to_graph(
+			if (!$result = add_item_to_graph(
 					$graphid,
 					$gitem['itemid'],
 					$gitem['color'],
@@ -675,13 +701,13 @@
 					$gitem['yaxisside'],
 					$gitem['calc_fnc'],
 					$gitem['type'],
-					$gitem['periods_cnt'])) )
+					$gitem['periods_cnt']))
 			{
 				return $result;
 			}
 		}
 
-		if ($result = update_graph($graphid,$name,$width,$height,$yaxistype,$yaxismin,$yaxismax,$showworkperiod,
+		if ($result = update_graph($graphid,$name,$width,$height,$ymin_type,$ymax_type,$yaxismin,$yaxismax,$ymin_itemid,$ymax_itemid,$showworkperiod,
 						$showtriggers,$graphtype,$legend,$graph3d,$percent_left,$percent_right,$templateid))
 		{
 			$host_list = array();
@@ -695,7 +721,7 @@
 
 		return $result;
 	}
-	
+
 /*
  * Function: delete_graph
  *
@@ -703,21 +729,21 @@
  *     Delete graph with templates
  *
  * Author:
- *     Eugene Grigorjev 
+ *     Eugene Grigorjev
  *
  * Comments: !!! Don't forget sync code with C !!!
  *
  */
 	function delete_graph($graphids){
 		zbx_value2array($graphids);
-		
+
 		$result = true;
-		
+
 		$graphs = array();
 		$host_list = array();
 		foreach($graphids as $id => $graphid){
 			$graphs[$graphid] = get_graph_by_graphid($graphid);
-	
+
 			$host_list[$graphid] = array();
 			$db_hosts = get_hosts_by_graphid($graphid);
 			while($db_host = DBfetch($db_hosts)){
@@ -725,7 +751,7 @@
 			}
 		}
 
-// firstly remove child graphs 
+// first remove child graphs
 		$del_chd_graphs = array();
 		$chd_graphs = get_graphs_by_templateid($graphids);
 		while($chd_graph = DBfetch($chd_graphs)){ /* recursion */
@@ -734,13 +760,13 @@
 		if(!empty($del_chd_graphs)){
 			$result &= delete_graph($del_chd_graphs);
 		}
-		
+
 		DBexecute('DELETE FROM screens_items WHERE '.DBcondition('resourceid',$graphids).' AND resourcetype='.SCREEN_RESOURCE_GRAPH);
 
-// delete graph 
+// delete graph
 		DBexecute('DELETE FROM graphs_items WHERE '.DBcondition('graphid',$graphids));
 		DBexecute("DELETE FROM profiles WHERE idx='web.favorite.graphids' AND source='graphid' AND ".DBcondition('value_id',$graphids));
-		
+
 		$result = DBexecute('DELETE FROM graphs WHERE '.DBcondition('graphid',$graphids));
 		if($result){
 			foreach($graphs as $graphid => $graph){
@@ -752,24 +778,23 @@
 	return $result;
 	}
 
-        /*
-         * Function: cmp_graphitems
-         *
-         * Description:
-         *     Compare two graph items
-         *
-         * Author:
-         *     Eugene Grigorjev 
-         *
-         * Comments: !!! Don't forget sync code with C !!!
-         *
-         */
-	function	cmp_graphitems(&$gitem1, &$gitem2)
-	{
+/*
+ * Function: cmp_graphitems
+ *
+ * Description:
+ *     Compare two graph items
+ *
+ * Author:
+ *     Eugene Grigorjev
+ *
+ * Comments: !!! Don't forget sync code with C !!!
+ *
+ */
+	function cmp_graphitems(&$gitem1, &$gitem2){
 		if($gitem1["drawtype"]	!= $gitem2["drawtype"])		return 1;
-		if($gitem1["sortorder"] != $gitem2["sortorder"])	return 2;
+		if($gitem1["sortorder"]	!= $gitem2["sortorder"])	return 2;
 		if($gitem1["color"]	!= $gitem2["color"])		return 3;
-		if($gitem1["yaxisside"] != $gitem2["yaxisside"])	return 4;
+		if($gitem1["yaxisside"]	!= $gitem2["yaxisside"])	return 4;
 
 		$item1 = get_item_by_itemid($gitem1["itemid"]);
 		$item2 = get_item_by_itemid($gitem2["itemid"]);
@@ -779,20 +804,19 @@
 		return 0;
 	}
 
-        /*
-         * Function: add_item_to_graph
-         *
-         * Description:
-         *     Add item to graph
-         *
-         * Author:
-         *     Eugene Grigorjev 
-         *
-         * Comments: !!! Don't forget sync code with C !!!
-         *
-         */
-	function	add_item_to_graph($graphid,$itemid,$color,$drawtype,$sortorder,$yaxisside,$calc_fnc,$type,$periods_cnt)
-	{
+/*
+ * Function: add_item_to_graph
+ *
+ * Description:
+ *     Add item to graph
+ *
+ * Author:
+ *     Eugene Grigorjev
+ *
+ * Comments: !!! Don't forget sync code with C !!!
+ *
+ */
+	function add_item_to_graph($graphid,$itemid,$color,$drawtype,$sortorder,$yaxisside,$calc_fnc,$type,$periods_cnt){
 		$gitemid = get_dbid('graphs_items','gitemid');
 
 		$result = DBexecute('insert into graphs_items'.
@@ -802,7 +826,7 @@
 
 		return ( $result ? $gitemid : $result );
 	}
-	
+
 /*
  * Function: delete_template_graphs
  *
@@ -810,14 +834,14 @@
  *     Delete template graph from specified host
  *
  * Author:
- *     Eugene Grigorjev 
+ *     Eugene Grigorjev
  *
  * Comments: !!! Don't forget sync code with C !!!
  *
  */
 	function delete_template_graphs($hostid, $templateids = null /* array format 'arr[id]=name' */, $unlink_mode = false){
 		zbx_value2array($templateids);
-		
+
 		$db_graphs = get_graphs_by_hostid($hostid);
 		while($db_graph = DBfetch($db_graphs)){
 			if($db_graph['templateid'] == 0)
@@ -833,32 +857,32 @@
 			if($unlink_mode){
 				if(DBexecute('UPDATE graphs SET templateid=0 WHERE graphid='.$db_graph['graphid'])){
 					info('Graph "'.$db_graph['name'].'" unlinked');
-				}	
+				}
 			}
 			else{
 				delete_graph($db_graph['graphid']);
 			}
 		}
 	}
-	
-/*
- * Function: copy_template_graphs
- *
- * Description:
- *     Copy all graphs to the specified host
- *
- * Author:
- *     Eugene Grigorjev 
- *
- * Comments: !!! Don't forget sync code with C !!!
- *
- */
+
+        /*
+         * Function: copy_template_graphs
+         *
+         * Description:
+         *     Copy all graphs to the specified host
+         *
+         * Author:
+         *     Eugene Grigorjev
+         *
+         * Comments: !!! Don't forget sync code with C !!!
+         *
+         */
 	function copy_template_graphs($hostid, $templateid = null /* array format 'arr[key]=id' */, $copy_mode = false){
 		if($templateid == null){
 			$templateid = get_templates_by_hostid($hostid);
 			$templateid = array_keys($templateid);
 		}
-		
+
 		if(is_array($templateid)){
 			foreach($templateid as $key => $id)
 				copy_template_graphs($hostid, $id, $copy_mode); // attention recursion
@@ -872,18 +896,18 @@
 		}
 	}
 
-        /*
-         * Function: copy_graph_to_host
-         *
-         * Description:
-         *     Copy specified graph to the specified host
-         *
-         * Author:
-         *     Eugene Grigorjev 
-         *
-         * Comments: !!! Don't forget sync code with C !!!
-         *
-         */
+/*
+ * Function: copy_graph_to_host
+ *
+ * Description:
+ *     Copy specified graph to the specified host
+ *
+ * Author:
+ *     Eugene Grigorjev
+ *
+ * Comments: !!! Don't forget sync code with C !!!
+ *
+ */
 	function copy_graph_to_host($graphid, $hostid, $copy_mode = false){
 		$result = false;
 
@@ -907,9 +931,9 @@
 
 		if($new_gitems = get_same_graphitems_for_host($gitems, $hostid)){
 			unset($chd_graphid);
-			
+
 			$chd_graphs = get_graphs_by_hostid($hostid);
-			while( !isset($chd_graphid) && $chd_graph = DBfetch($chd_graphs)){ 
+			while( !isset($chd_graphid) && $chd_graph = DBfetch($chd_graphs)){
 /* compare graphs */
 				if ( $chd_graph['templateid'] != 0 ) continue;
 
@@ -917,7 +941,7 @@
 				$chd_gitems = get_graphitems_by_graphid($chd_graph["graphid"]);
 				while($chd_gitem = DBfetch($chd_gitems)){
 					unset($gitem_equal);
-					
+
 					foreach($new_gitems as $new_gitem){
 						if(cmp_graphitems($new_gitem, $chd_gitem))	continue;
 
@@ -930,14 +954,14 @@
 						break;
 					}
 
-					/* founded equal graph item */
+					/* found equal graph item */
 					if(!isset($equal))$equal = 0;
 
 					$equal++;
 				}
 
-				if(isset($equal) && (count($new_gitems) == $equal)){ 
-/* founded equal graph */
+				if(isset($equal) && (count($new_gitems) == $equal)){
+/* found equal graph */
 					$chd_graphid = $chd_graph['graphid'];
 					break;
 				}
@@ -945,38 +969,52 @@
 
 			if(isset($chd_graphid)){
 				$result = update_graph_with_items($chd_graphid, $db_graph['name'], $db_graph['width'], $db_graph['height'],
-					$db_graph['yaxistype'], $db_graph['yaxismin'], $db_graph['yaxismax'],
-					$db_graph['show_work_period'], $db_graph['show_triggers'], $db_graph['graphtype'],$db_graph['show_legend'], 
+					$db_graph['ymin_type'], $db_graph['ymax_type'], $db_graph['yaxismin'], $db_graph['yaxismax'],
+					$db_graph['ymin_itemid'], $db_graph['ymax_itemid'],
+					$db_graph['show_work_period'], $db_graph['show_triggers'], $db_graph['graphtype'],$db_graph['show_legend'],
 					$db_graph['show_3d'], $db_graph['percent_left'], $db_graph['percent_right'], $new_gitems, ($copy_mode ? 0: $db_graph['graphid']));
 			}
 			else{
 				$result = add_graph_with_items($db_graph['name'], $db_graph['width'], $db_graph['height'],
-					$db_graph['yaxistype'], $db_graph['yaxismin'], $db_graph['yaxismax'],
-					$db_graph['show_work_period'], $db_graph['show_triggers'], $db_graph['graphtype'],$db_graph['show_legend'], 
+					$db_graph['ymin_type'], $db_graph['ymax_type'], $db_graph['yaxismin'], $db_graph['yaxismax'],
+					$db_graph['ymin_itemid'], $db_graph['ymax_itemid'],
+					$db_graph['show_work_period'], $db_graph['show_triggers'], $db_graph['graphtype'],$db_graph['show_legend'],
 					$db_graph['show_3d'], $db_graph['percent_left'], $db_graph['percent_right'], $new_gitems, ($copy_mode ? 0: $db_graph['graphid']));
 			}
 		}
 		else{
 			$host = get_host_by_hostid($hostid);
-			info('Skipped coping of graph "'.$db_graph["name"].'" to host "'.$host['host'].'"');
+			info('Skipped copying of graph "'.$db_graph["name"].'" to host "'.$host['host'].'"');
 		}
 
 	return $result;
 	}
 
-	function navigation_bar_calc(){
+	function navigation_bar_calc($idx=null, $idx2=null){
+//SDI($_REQUEST['stime']);
+		if(!is_null($idx) && (is_null($idx2) || ($idx2 > 0))){
+			if(isset($_REQUEST['period']) && ($_REQUEST['period'] >= ZBX_MIN_PERIOD))
+				update_profile($idx.'.period',$_REQUEST['period'],PROFILE_TYPE_INT, $idx2);
+			else
+				$_REQUEST['period'] = get_profile($idx.'.period', ZBX_PERIOD_DEFAULT, $idx2);
+
+			if(isset($_REQUEST['stime']))
+				update_profile($idx.'.stime',$_REQUEST['stime'], PROFILE_TYPE_STR, $idx2);
+			else
+				$_REQUEST['stime'] = get_profile($idx.'.stime', null, $idx2);
+		}
+
 		$_REQUEST['period'] = get_request('period', ZBX_PERIOD_DEFAULT);
-		$_REQUEST['from'] = get_request('from', 0);
 		$_REQUEST['stime'] = get_request('stime', null);
 
 		if($_REQUEST['period']<ZBX_MIN_PERIOD){
 			show_message(S_WARNING.'. '.S_TIME_PERIOD.SPACE.S_MIN_VALUE_SMALL.': '.ZBX_MIN_PERIOD.' ('.(int)(ZBX_MIN_PERIOD/3600).'h)');
 			$_REQUEST['period'] = ZBX_MIN_PERIOD;
-			
+
 		}
 		else if($_REQUEST['period'] > ZBX_MAX_PERIOD){
 			show_message(S_WARNING.'. '.S_TIME_PERIOD.SPACE.S_MAX_VALUE_SMALL.': '.ZBX_MAX_PERIOD.' ('.(int)(ZBX_MAX_PERIOD/86400).'d)');
-			$_REQUEST['period'] = ZBX_MAX_PERIOD;			
+			$_REQUEST['period'] = ZBX_MAX_PERIOD;
 		}
 
 		if(isset($_REQUEST['stime'])){
@@ -986,113 +1024,26 @@
 				$_REQUEST['stime'] = date('YmdHi', time()-$_REQUEST['period']);
 			}
 		}
+		else{
+			$_REQUEST['stime'] = date('YmdHi', time()-$_REQUEST['period']);
+		}
+
 	return $_REQUEST['period'];
 	}
 
-	function navigation_bar($url,$ext_saved_request=NULL){
-		$saved_request = array("screenid","itemid","action","from","fullscreen");
-
-		if(is_array($ext_saved_request))
-			$saved_request = array_merge($saved_request, $ext_saved_request);
-		elseif(is_string($ext_saved_request))
-			array_push($saved_request,$ext_saved_request);
-
-		$form = new CForm($url);
-		$form->SetMethod('get');	
-		
-		$form->AddItem(S_PERIOD.SPACE);
-
-		$period = get_request('period',ZBX_PERIOD_DEFAULT);
-
-		if(uint_in_array($period,array(3600,2*3600,4*3600,8*3600,12*3600,24*3600,7*24*3600,31*24*3600,365*24*3600)))
-			$custom_per = ZBX_MIN_PERIOD;
-		else
-			$custom_per = $period;
-
-		$cmbPeriod = new CComboBox("period",$period,"submit()");
-		$cmbPeriod->AddItem($custom_per,"custom");
-		$cmbPeriod->AddItem(3600,"1h");
-		$cmbPeriod->AddItem(2*3600,"2h");
-		$cmbPeriod->AddItem(4*3600,"4h");
-		$cmbPeriod->AddItem(8*3600,"8h");
-		$cmbPeriod->AddItem(12*3600,"12h");
-		$cmbPeriod->AddItem(24*3600,"24h");
-		$cmbPeriod->AddItem(7*24*3600,"week");
-		$cmbPeriod->AddItem(31*24*3600,"month");
-		$cmbPeriod->AddItem(365*24*3600,"year");
-		$form->AddItem($cmbPeriod);
-
-		$cmbDec = new CComboBox("dec",0,"submit()");
-		$cmbDec->AddItem(0,S_DECREASE);
-		$cmbDec->AddItem(3600,"-1h");
-		$cmbDec->AddItem(4*3600,"-4h");
-		$cmbDec->AddItem(24*3600,"-24h");
-		$cmbDec->AddItem(7*24*3600,"-week");
-		$cmbDec->AddItem(31*24*3600,"-month");
-		$cmbDec->AddItem(365*24*3600,"-year");
-		$form->AddItem($cmbDec);
-
-		$cmbInc = new CComboBox("inc",0,"submit()");
-		$cmbInc->AddItem(0,S_INCREASE);
-		$cmbInc->AddItem(3600,"+1h");
-		$cmbInc->AddItem(4*3600,"+4h");
-		$cmbInc->AddItem(24*3600,"+24h");
-		$cmbInc->AddItem(7*24*3600,"+week");
-		$cmbInc->AddItem(31*24*3600,"+month");
-		$cmbInc->AddItem(365*24*3600,"+year");
-		$form->AddItem($cmbInc);
-
-		$form->AddItem(SPACE.S_MOVE.SPACE);
-
-		$cmbLeft = new CComboBox("left",0,"submit()");
-		$cmbLeft->AddItem(0,S_LEFT_DIR);
-		$cmbLeft->AddItem(1,"-1h");
-		$cmbLeft->AddItem(4,"-4h");
-		$cmbLeft->AddItem(24,"-24h");
-		$cmbLeft->AddItem(7*24,"-week");
-		$cmbLeft->AddItem(31*24,"-month");
-		$cmbLeft->AddItem(365*24,"-year");
-		$form->AddItem($cmbLeft);
-
-		$cmbRight = new CComboBox("right",0,"submit()");
-		$cmbRight->AddItem(0,S_RIGHT_DIR);
-		$cmbRight->AddItem(1,"+1h");
-		$cmbRight->AddItem(4,"+4h");
-		$cmbRight->AddItem(24,"+24h");
-		$cmbRight->AddItem(7*24,"+week");
-		$cmbRight->AddItem(31*24,"+month");
-		$cmbRight->AddItem(365*24,"+year");
-		$form->AddItem($cmbRight);
-
-		$form->AddItem(array(SPACE,
-			new CTextBox("stime","yyyymmddhhmm",12),SPACE,
-			new CButton("action","go"),
-			new CButton("reset","reset")));
-
-		foreach($saved_request as $item)
-			if(isset($_REQUEST[$item]))
-				$form->AddVar($item,$_REQUEST[$item]);
-
-		show_table_header(
-			S_NAVIGATE,
-			$form);
-
-		return;
-	}
-	
-	/*
-	 * Function: 
-	 *		make_array_from_gitems
-	 *
-	 * Description:
-	 *     Creates array with items params for prepare_url function
-	 *
-	 * Author:
-	 *     Aly
-	 *
-	 * Comments
-	 *
-	 */
+/*
+ * Function:
+ *		make_array_from_gitems
+ *
+ * Description:
+ *     Creates array with items params for prepare_url function
+ *
+ * Author:
+ *     Aly
+ *
+ * Comments
+ *
+ */
 	function make_url_from_gitems($gitems){
 
 		$gurl=array();
@@ -1104,7 +1055,7 @@
 						'yaxisside'	=> 1,
 						'calc_fnc'	=> 1,
 						'type'		=> 1,
-						'periods_cnt'=>1
+						'periods_cnt'	=> 1
 					);
 
 		foreach($gitems as $gitem){
@@ -1118,19 +1069,19 @@
 	return prepare_url($gurl);
 	}
 
-	/*
-	 * Function: 
-	 *		make_array_from_graphid
-	 *
-	 * Description:
-	 *     Creates array with graph params for preapare_url function
-	 *
-	 * Author:
-	 *     Aly
-	 *
-	 * Comments
-	 *	$full= false: for screens(WITHOUT width && height), true=all params
-	 */	
+/*
+ * Function:
+ *		make_array_from_graphid
+ *
+ * Description:
+ *     Creates array with graph params for prepare_url function
+ *
+ * Author:
+ *     Aly
+ *
+ * Comments
+ *	$full= false: for screens(WITHOUT width && height), true=all params
+ */
 	function make_url_from_graphid($graphid,$full=false){
 
 		$gurl=array();
@@ -1143,7 +1094,7 @@
 						'width'	=> 1
 					);
 		}
-		
+
 		$graph=get_graph_by_graphid($graphid);
 		if($graph){
 			foreach($graph as $name => $value){
@@ -1157,4 +1108,167 @@
 		}
 	return $url;
 	}
+
+//Author:	Aly
+	function get_next_color($palettetype=0){
+		static $prev_color = array('dark'=>true, 'color'=>0, 'grad'=>0);
+
+		switch($palettetype){
+			case 1: $grad = array(200,150,255,100,50,0); break;
+			case 2: $grad = array(100,50,200,150,250,0); break;
+			case 0:
+			default: $grad = array(255,200,150,100,50,0); break;
+		}
+
+		$set_grad = $grad[$prev_color['grad']];
+
+//		$r = $g = $b = $prev_color['dark']?0:250;
+		$r = $g = $b = (100<$set_grad)?0:255;
+
+		switch($prev_color['color']){
+			case 0: $r = $set_grad; break;
+			case 1: $g = $set_grad; break;
+			case 2:	$b = $set_grad;	break;
+			case 3:	$r = $b = $set_grad; break;
+			case 4: $g = $b = $set_grad; break;
+			case 5: $r = $g = $set_grad; break;
+			case 6: $r = $g = $b = $set_grad; break;
+		}
+//SDI($prev_color);
+		$prev_color['dark'] = $prev_color['dark']?false:true;
+		if($prev_color['color'] == 6) $prev_color['grad'] = ($prev_color['grad']+1) % 6 ;
+		$prev_color['color'] = ($prev_color['color']+1) % 7;
+
+	return array($r,$g,$b);
+	}
+
+//Author:	Aly
+	function get_next_palette($palette=0,$palettetype=0){
+		static $prev_color = array(0,0,0,0);
+
+		switch($palette){
+			case 0: $palettes = array(array(150,0,0), array(0,100,150), array(170,180,180), array(152,100,0),
+									array(130,0,150), array(0,0,150), array(200,100,50),
+									array(250,40,40), array(50,150,150), array(100,150,0));
+				break;
+			case 1: $palettes = array(array(0,100,150), array(153,0,30), array(100,150,0),
+									array(130,0,150), array(0,0,100), array(200,100,50), array(152,100,0),
+									array(0,100,0), array(170,180,180), array(50,150,150));
+				break;
+			case 2: $palettes = array( array(170,180,180), array(152,100,0), array(50,200,200),
+									array(153,0,30), array(0,0,100), array(100,150,0), array(130,0,150),
+									array(0,100,150), array(200,100,50), array(0,100,0),);
+				break;
+			case 3:
+			default:
+				return get_next_color($palettetype);
+		}
+
+		if(isset($palettes[$prev_color[$palette]]) )
+			$result = $palettes[$prev_color[$palette]];
+		else
+			return get_next_color($palettetype);
+
+		switch($palettetype){
+			case 0: $diff = 0; break;
+			case 1:	$diff = -50; break;
+			case 2:	$diff = 50; break;
+		}
+
+		foreach($result as $n => $color){
+			if(($color + $diff) < 0) $result[$n] = 0;
+			else if(($color + $diff) > 255) $result[$n] = 255;
+			else $result[$n] += $diff;
+		}
+
+		$prev_color[$palette]++;
+
+	return $result;
+	}
+
+	function imageText($image, $fontsize, $angle, $x, $y, $color, $string){
+		$gdinfo = gd_info();
+
+		if($gdinfo['FreeType Support'] && function_exists('imagettftext')){
+			$ttf = ZBX_FONTPATH.'/'.ZBX_GRAPH_FONT_NAME.'.ttf';
+/*
+			$ar = imagettfbbox($fontsize, $angle, $ttf, $string);
+//sdii($ar);
+			if(!$angle)	imagerectangle($image, $x, $y+$ar[1], $x+abs($ar[0] - $ar[4]), $y+$ar[5], $color);
+			else imagerectangle($image, $x, $y, $x-abs($ar[0] - $ar[4]), $y+($ar[5]-$ar[1]), $color);
+//*/
+			imagettftext($image, $fontsize, $angle, $x, $y, $color, $ttf, $string);
+		}
+		else{
+			$dims = imageTextSize($fontsize, $angle, $string);
+
+			switch($fontsize){
+				case 5: $fontsize = 1; break;
+				case 6: $fontsize = 1; break;
+				case 7: $fontsize = 2; break;
+				case 8: $fontsize = 2; break;
+				case 9:	$fontsize = 3; break;
+				case 10: $fontsize = 3; break;
+				case 11: $fontsize = 4; break;
+				case 12: $fontsize = 4; break;
+				case 13: $fontsize = 5; break;
+				case 14: $fontsize = 5; break;
+				default: $fontsize = 2; break;
+			}
+
+//SDI($dims);
+			if($angle){
+				$x -= $dims['width'];
+				$y -= 2;
+			}
+			else{
+				$y -= $dims['height'] - 2;
+			}
+
+			if($angle > 0)	return imagestringup($image, $fontsize, $x, $y, $string, $color);
+			return imagestring($image, $fontsize, $x, $y, $string, $color);
+		}
+
+	return true;
+	}
+
+	function imageTextSize($fontsize, $angle, $string){
+		$gdinfo = gd_info();
+
+		$result = array();
+		if($gdinfo['FreeType Support'] && function_exists('imagettfbbox')){
+			$ttf = ZBX_FONTPATH.'/'.ZBX_GRAPH_FONT_NAME.'.ttf';
+
+			$ar = imagettfbbox($fontsize, $angle, $ttf, $string);
+
+			$result['height'] = abs($ar[1] - $ar[5]);
+			$result['width'] = abs($ar[0] - $ar[4]);
+		}
+		else{
+			switch($fontsize){
+				case 5: $fontsize = 1; break;
+				case 6: $fontsize = 1; break;
+				case 7: $fontsize = 2; break;
+				case 8: $fontsize = 2; break;
+				case 9:	$fontsize = 3; break;
+				case 10: $fontsize = 3; break;
+				case 11: $fontsize = 4; break;
+				case 12: $fontsize = 4; break;
+				case 13: $fontsize = 5; break;
+				case 14: $fontsize = 5; break;
+				default: $fontsize = 2; break;
+			}
+
+			if($angle){
+				$result['width'] = imagefontheight($fontsize);
+				$result['height'] = imagefontwidth($fontsize) * strlen($string);
+			}
+			else{
+				$result['height'] = imagefontheight($fontsize);
+				$result['width'] = imagefontwidth($fontsize) * strlen($string);
+			}
+		}
+
+	return $result;
+	}
 ?>
