@@ -17,26 +17,25 @@
 ** along with this program; if not, write to the Free Software
 ** Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 **/
-	require_once('include/defines.inc.php');
-	require_once('include/items.inc.php');
 ?>
 <?php
-	function	httptest_status2str($status)
-	{
-		switch($status)
-		{
+require_once('include/defines.inc.php');
+require_once('include/items.inc.php');
+
+
+	function httptest_status2str($status){
+		switch($status){
 			case HTTPTEST_STATUS_ACTIVE:	$status = S_ACTIVE;		break;
 			case HTTPTEST_STATUS_DISABLED:	$status = S_DISABLED;		break;
 			default:
 				$status = S_UNKNOWN;		break;
 		}
-		return $status;
+
+	return $status;
 	}
-	
-	function	httptest_status2style($status)
-	{
-		switch($status)
-		{
+
+	function httptest_status2style($status){
+		switch($status){
 			case HTTPTEST_STATUS_ACTIVE:	$status = 'off';	break;
 			case HTTPTEST_STATUS_DISABLED:	$status = 'on';		break;
 			default:
@@ -51,15 +50,16 @@
 			return false;
 		}
 
-		if(!eregi('^([0-9a-zA-Z\_\.[.-.]\$ ]+)$', $name)){
+//		if(!eregi('^([0-9a-zA-Z\_\.[.-.]\$ ]+)$', $name)){
+		if(!preg_match('/^([0-9a-z_\.\-\$\s]+)$/i', $name)){
 			error("Scenario step name should contain '0-9a-zA-Z_ .$'- characters only");
 			return false;
 		}
 
 		if(!$httpstep_data = DBfetch(DBselect('select httpstepid from httpstep where httptestid='.$httptestid.' and name='.zbx_dbstr($name)))){
-			
+
 			$httpstepid = get_dbid("httpstep","httpstepid");
-			
+
 			if (!DBexecute('insert into httpstep'.
 				' (httpstepid, httptestid, name, no, url, timeout, posts, required, status_codes) '.
 				' values ('.$httpstepid.','.$httptestid.','.zbx_dbstr($name).','.$no.','.
@@ -96,7 +96,7 @@
 				'units'		=> '',
 				'httpstepitemtype'=> HTTPSTEP_ITEM_TYPE_RSPCODE),
 			);
-		
+
 		foreach($monitored_items as $item){
 			$item_data = DBfetch(DBselect('select i.itemid,i.history,i.trends,i.status,i.delta,i.valuemapid '.
 				' from items i, httpstepitem hi '.
@@ -109,36 +109,42 @@
 			}
 
 			$item_args = array(
-				'description'	=> $item['description'],
+				'description'		=> $item['description'],
 				'key_'			=> $item['key_'],
 				'hostid'		=> $hostid,
 				'delay'			=> $delay,
 				'type'			=> ITEM_TYPE_HTTPTEST,
-				'snmp_community'=> '',
+				'snmp_community'=>	'',
 				'snmp_oid'		=> '',
-				'value_type'	=> $item['type'],
-				'trapper_hosts'	=> 'localhost',
+				'value_type'		=> $item['type'],
+				'data_type'		=> ITEM_DATA_TYPE_DECIMAL,
+				'trapper_hosts'		=> 'localhost',
 				'snmp_port'		=> 161,
 				'units'			=> $item['units'],
-				'multiplier'	=> 0,
+				'multiplier'		=> 0,
 				'snmpv3_securityname'	=> '',
 				'snmpv3_securitylevel'	=> 0,
 				'snmpv3_authpassphrase'	=> '',
 				'snmpv3_privpassphrase'	=> '',
-				'formula'			=> 0,
+				'formula'		=> 0,
 				'logtimefmt'		=> '',
 				'delay_flex'		=> '',
-				'params'			=> '',
+				'authtype'		=> 0,
+				'username'		=> '',
+				'password'		=> '',
+				'publickey'		=> '',
+				'privatekey'		=> '',
+				'params'		=> '',
 				'ipmi_sensor'		=> '',
 				'applications'		=> array($applicationid));
-				
+
 			if(!$item_data){
 				$item_args['history'] = $history;
 				$item_args['status'] = ITEM_STATUS_ACTIVE;
 				$item_args['delta'] = 0;
 				$item_args['trends'] = $trends;
 				$item_args['valuemapid'] = 0;
-				
+
 				if(!$itemid = add_item($item_args)){
 					return false;
 				}
@@ -151,12 +157,12 @@
 				$item_args['delta'] = $item_data['delta'];
 				$item_args['trends'] = $item_data['trends'];
 				$item_args['valuemapid'] = $item_data['valuemapid'];
-					
+
 				if(!update_item($itemid, $item_args)){
 					return false;
 				}
 			}
-			
+
 			$httpstepitemid = get_dbid('httpstepitem', 'httpstepitemid');
 
 			DBexecute('delete from httpstepitem where itemid='.$itemid);
@@ -171,17 +177,17 @@
 		return $httpstepid;
 	}
 
-	function	db_save_httptest($httptestid, $hostid, $application, $name, $delay, $status, $agent, $macros, $steps){
-		$history = 30; // TODO !!! Allow user set this parametr
-		$trends = 90; // TODO !!! Allow user set this parametr
+	function db_save_httptest($httptestid, $hostid, $application, $name, $authentication, $http_user, $http_password, $delay, $status, $agent, $macros, $steps){
+		$history = 30; // TODO !!! Allow user to set this parameter
+		$trends = 90; // TODO !!! Allow user to set this parameter
 
- 		if(!eregi('^([0-9a-zA-Z\_\.[.-.]\$ ]+)$', $name)) {
-			error("Scenario name should contain '0-9a-zA-Z_.$ '- characters only");
+		if(!preg_match('/^(['.ZBX_PREG_PRINT.'])+$/u', $name)) {
+			error("Only characters are allowed");
 			return false;
 		}
-		
+
 		DBstart();
-		
+
 		if($applicationid = DBfetch(DBselect('select applicationid from applications '.
 			' where name='.zbx_dbstr($application).
 			' and hostid='.$hostid)))
@@ -195,27 +201,29 @@
 				return false;
 			}
 		}
-		
+
 		if(isset($httptestid)){
-			$result = DBexecute('update httptest set '.
-				' applicationid='.$applicationid.', name='.zbx_dbstr($name).', delay='.$delay.','.
-				' status='.$status.', agent='.zbx_dbstr($agent).', macros='.zbx_dbstr($macros).','.
-				' error='.zbx_dbstr('').', curstate='.HTTPTEST_STATE_UNKNOWN.
+			$result = DBexecute('update httptest'.
+				' set applicationid='.$applicationid.', name='.zbx_dbstr($name).','.
+					' authentication='.$authentication.','.' http_user='.zbx_dbstr($http_user).','.' http_password='.zbx_dbstr($http_password).','.
+					' delay='.$delay.','.' status='.$status.', agent='.zbx_dbstr($agent).', macros='.zbx_dbstr($macros).','.
+					' error='.zbx_dbstr('').', curstate='.HTTPTEST_STATE_UNKNOWN.
 				' where httptestid='.$httptestid);
 		}
 		else{
 			$httptestid = get_dbid("httptest","httptestid");
-			
+
 			if(DBfetch(DBselect('select t.httptestid from httptest t, applications a where t.applicationid=a.applicationid '.
 				' and a.hostid='.$hostid.' and t.name='.zbx_dbstr($name))))
 			{
 				error('Scenario with name ['.$name.'] already exist');
 				return false;
 			}
-			
+
 			$result = DBexecute('insert into httptest'.
-				' (httptestid, applicationid, name, delay, status, agent, macros, curstate) '.
+				' (httptestid, applicationid, name, authentication, http_user, http_password, delay, status, agent, macros, curstate) '.
 				' values ('.$httptestid.','.$applicationid.','.zbx_dbstr($name).','.
+				$authentication.','.zbx_dbstr($http_user).','.zbx_dbstr($http_password).','.
 				$delay.','.$status.','.zbx_dbstr($agent).','.zbx_dbstr($macros).','.HTTPTEST_STATE_UNKNOWN.')'
 				);
 
@@ -227,17 +235,17 @@
 			foreach($steps as $sid => $s){
 				if(!isset($s['name']))		$s['name'] = '';
 				if(!isset($s['timeout']))	$s['timeout'] = 15;
-				if(!isset($s['url']))       	$s['url'] = '';
-				if(!isset($s['posts']))       	$s['posts'] = '';
-				if(!isset($s['required']))      $s['required'] = '';
-				if(!isset($s['status_codes']))  $s['status_codes'] = '';
-			
+				if(!isset($s['url']))		$s['url'] = '';
+				if(!isset($s['posts']))		$s['posts'] = '';
+				if(!isset($s['required']))	$s['required'] = '';
+				if(!isset($s['status_codes']))	$s['status_codes'] = '';
+
 				$result = db_save_step($hostid, $applicationid, $httptestid,
 						$name, $s['name'], $sid+1, $s['timeout'], $s['url'], $s['posts'], $s['required'],$s['status_codes'],
 						$delay, $history, $trends);
-				
+
 				if(!$result) break;
-				
+
 				$httpstepids[$result] = $result;
 			}
 			if($result){
@@ -265,7 +273,7 @@
 					'units'		=> '',
 					'httptestitemtype'=> HTTPSTEP_ITEM_TYPE_LASTSTEP)
 				);
-			
+
 			foreach($monitored_items as $item){
 				$item_data = DBfetch(DBselect('select i.itemid,i.history,i.trends,i.status,i.delta,i.valuemapid '.
 					' from items i, httptestitem hi '.
@@ -286,6 +294,7 @@
 					'snmp_community'=> '',
 					'snmp_oid'		=> '',
 					'value_type'	=> $item['type'],
+					'data_type'		=> ITEM_DATA_TYPE_DECIMAL,
 					'trapper_hosts'	=> 'localhost',
 					'snmp_port'		=> 161,
 					'units'			=> $item['units'],
@@ -297,17 +306,22 @@
 					'formula'			=> 0,
 					'logtimefmt'		=> '',
 					'delay_flex'		=> '',
+					'authtype'		=> 0,
+					'username'		=> '',
+					'password'		=> '',
+					'publickey'		=> '',
+					'privatekey'		=> '',
 					'params'			=> '',
 					'ipmi_sensor'		=> '',
 					'applications'		=> array($applicationid));
-					
+
 				if(!$item_data){
 					$item_args['history'] = $history;
 					$item_args['status'] = ITEM_STATUS_ACTIVE;
 					$item_args['delta'] = 0;
 					$item_args['trends'] = $trends;
 					$item_args['valuemapid'] = 0;
-					
+
 					if(!$itemid = add_item($item_args)){
 						$result = false;
 						break;
@@ -321,14 +335,14 @@
 					$item_args['delta'] = $item_data['delta'];
 					$item_args['trends'] = $item_data['trends'];
 					$item_args['valuemapid'] = $item_data['valuemapid'];
-						
+
 					if(!update_item($itemid, $item_args)){
 						$result = false;
 						break;
 					}
 				}
 
-				
+
 				$httptestitemid = get_dbid('httptestitem', 'httptestitemid');
 
 				DBexecute('delete from httptestitem where itemid='.$itemid);
@@ -351,45 +365,43 @@
 
 		return $result;
 	}
-	
-	function	add_httptest($hostid, $application, $name, $delay, $status, $agent, $macros, $steps)
-	{
-		$result = db_save_httptest(null, $hostid, $application, $name, $delay, $status, $agent, $macros, $steps);
-		
-		if($result) info("Sceanrio '".$name."' added");
 
-		return $result;
-	}
-	
-	function	update_httptest($httptestid, $hostid, $application, $name, $delay, $status, $agent, $macros, $steps)
-	{
-		$result = db_save_httptest($httptestid, $hostid, $application, $name, $delay, $status, $agent, $macros, $steps);
-		
-		if($result)	info("Sceanrio '".$name."' updated");
+	function add_httptest($hostid, $application, $name, $authentication, $http_user, $http_password, $delay, $status, $agent, $macros, $steps){
+		$result = db_save_httptest(null, $hostid, $application, $name, $authentication, $http_user, $http_password, $delay, $status, $agent, $macros, $steps);
 
-		return $result;
+		if($result) info("Scenario '".$name."' added");
+
+	return $result;
 	}
-	
+
+	function update_httptest($httptestid, $hostid, $application, $name, $authentication, $http_user, $http_password, $delay, $status, $agent, $macros, $steps){
+		$result = db_save_httptest($httptestid, $hostid, $application, $name, $authentication, $http_user, $http_password, $delay, $status, $agent, $macros, $steps);
+
+		if($result)	info("Scenario '".$name."' updated");
+
+	return $result;
+	}
+
 	function delete_httpstep($httpstepids){
 		zbx_value2array($httpstepids);
-		
+
 		$db_httpstepitems = DBselect('SELECT DISTINCT * FROM httpstepitem WHERE '.DBcondition('httpstepid',$httpstepids));
 		while($httpstepitem_data = DBfetch($db_httpstepitems)){
 			if(!DBexecute('DELETE FROM httpstepitem WHERE httpstepitemid='.$httpstepitem_data['httpstepitemid'])) return false;
 			if(!delete_item($httpstepitem_data['itemid'])) return false;
 		}
-			
+
 	return DBexecute('DELETE FROM httpstep WHERE '.DBcondition('httpstepid',$httpstepids));
 	}
-	
+
 	function delete_httptest($httptestids){
 		zbx_value2array($httptestids);
-	
+
 		$httptests = array();
 		foreach($httptestids as $id => $httptestid){
 			$httptests[$httptestid] =  DBfetch(DBselect('SELECT * FROM httptest WHERE httptestid='.$httptestid));
 		}
-		
+
 		$db_httpstep = DBselect('SELECT DISTINCT s.httpstepid '.
 								' FROM httpstep s '.
 								' WHERE '.DBcondition('s.httptestid',$httptestids));
@@ -398,31 +410,31 @@
 			$del_httpsteps[$httpstep_data['httpstepid']] = $httpstep_data['httpstepid'];
 		}
 		delete_httpstep($del_httpsteps);
-		
+
 		$httptestitemids_del = array();
 		$itemids_del = array();
 		$sql = 'SELECT httptestitemid, itemid '.
 				' FROM httptestitem '.
 				' WHERE '.DBcondition('httptestid',$httptestids);
-				
+
 		$db_httptestitems = DBselect($sql);
 		while($httptestitem_data = DBfetch($db_httptestitems)){
 			$httptestitemids_del[$httptestitem_data['httptestitemid']] = $httptestitem_data['httptestitemid'];
 			$itemids_del[$httptestitem_data['itemid']] = $httptestitem_data['itemid'];
 		}
-		
+
 		if(!DBexecute('DELETE FROM httptestitem WHERE '.DBcondition('httptestitemid',$httptestitemids_del))) return false;
 		if (!delete_item($itemids_del)) return false;
 
 		if(!DBexecute('DELETE FROM httptest WHERE '.DBcondition('httptestid',$httptestids))) return false;
 
 		foreach($httptests as $id => $httptest){
-			info("Sceanrio '".$httptest["name"]."' deleted");
-		}		
-		
+			info("Scenario '".$httptest["name"]."' deleted");
+		}
+
 	return true;
 	}
-	
+
 	function activate_httptest($httptestid){
 		return DBexecute('UPDATE httptest SET status='.HTTPTEST_STATUS_ACTIVE.' WHERE httptestid='.$httptestid);
 	}
@@ -458,7 +470,7 @@
 	function get_httpstep_by_no($httptestid, $no){
 		return DBfetch(DBselect('select * from httpstep where httptestid='.$httptestid.' and no='.$no));
 	}
-	
+
 	function get_httptests_by_hostid($hostids){
 		zbx_value2array($hostids);
 		$sql = 'SELECT DISTINCT ht.* '.
