@@ -1,5 +1,5 @@
 <?php
-/* 
+/*
 ** ZABBIX
 ** Copyright (C) 2000-2008 SIA Zabbix
 **
@@ -24,6 +24,7 @@
 	$TRANSLATION=array(
 
 	'S_DATE_FORMAT_YMDHMS'=>			'M d H:i:s',
+	'S_DATE_FORMAT_YMD'=>			'Y M d',
 	'S_HTML_CHARSET'=>			'UTF-8',
 	'S_ACTIVATE_SELECTED'=>			'A kiválasztott aktíválása',
 	'S_DISABLE_SELECTED'=>			'Kiválasztott tiltása',
@@ -43,9 +44,6 @@
 	'S_NO_DISCOVERY_RULES_DEFINED'=>			'Nincs felderítési szabály definiálva',
 	'S_IP_RANGE'=>			'IP tartomány',
 	'S_CHECKS'=>			'Vizsgálat',
-	'S_ENABLE_SELECTED_RULES_Q'=>			'Engedélyezed a kiválasztott szabályt?',
-	'S_DISABLE_SELECTED_RULES_Q'=>			'Kikapcsolod a kiválasztott szabályt?',
-	'S_DELETE_SELECTED_RULES_Q'=>			'Törlöd a kiválasztott szabályt?',
 	'S_CREATE_RULE'=>			'Új szabály',
 	'S_DELETE_RULE_Q'=>			'Szabály törlése?',
 	'S_EVENT_SOURCE'=>			'Esemény forrása',
@@ -98,11 +96,7 @@
 	'S_SCENARIO_DELETED'=>			'Scenario deleted',
 	'S_SCENARIO_ACTIVATED'=>			'Scenario activated',
 	'S_SCENARIO_DISABLED'=>			'Scenario disabled',
-	'S_ACTIVATE_SELECTED_SCENARIOS_Q'=>			'Activate selected scenarios?',
-	'S_DISABLE_SELECTED_SCENARIOS_Q'=>			'Disable selected scenarios?',
-	'S_DELETE_SELECTED_SCENARIOS_Q'=>			'Delete selected scenarios?',
 	'S_DELETE_SCENARIO_Q'=>			'Delete scenario?',
-	'S_CLEAN_HISTORY_SELECTED_SCENARIOS'=>			'Clean history selected scenarios',
 	'S_SCENARIO_UPDATED'=>			'Scenario updated',
 	'S_CANNOT_UPDATE_SCENARIO'=>			'Cannot update scenario',
 	'S_SCENARIO_ADDED'=>			'Scenario added',
@@ -129,7 +123,6 @@
 	'S_BACK'=>			'Back',
 	'S_NO_DATA_FOR_EXPORT'=>			'No data for export',
 	'S_RULES'=>			'Rules',
-	'S_SKIP'=>			'Skip',
 	'S_EXISTING'=>			'Existing',
 	'S_MISSING'=>			'Missing',
 	'S_REFRESH'=>			'Refresh',
@@ -147,7 +140,7 @@
 	'S_DO_NOT_KEEP_HISTORY_OLDER_THAN'=>			'Do not keep history older than (in days)',
 	'S_DO_NOT_KEEP_TRENDS_OLDER_THAN'=>			'Do not keep trends older than (in days)',
 	'S_MASTER_NODE'=>			'Master node',
-	'S_REMOTE'=>			'Remote',
+	'S_CHILD'=>			'Remote',
 	'S_MASTER'=>			'Master',
 	'S_NODE_UPDATED'=>			'Node updated',
 	'S_CANNOT_UPDATE_NODE'=>			'Cannot update node',
@@ -156,14 +149,10 @@
 	'S_NODE_DELETED'=>			'Node deleted',
 	'S_CANNOT_DELETE_NODE'=>			'Cannot delete node',
 	'S_CURRENT_NODE'=>			'Current node',
-	'S_CURRENT_NODE_ONLY'=>			'Current node only',
-	'S_WITH_SUBNODES'=>			'With subnodes',
 	'S_ACKNOWLEDGES'=>			'Igazolások',
 	'S_ACKNOWLEDGE'=>			'Igazolás',
 	'S_ACKNOWLEDGE_ALARM_BY'=>			'Acknowledge alarm by',
 	'S_ADD_COMMENT_BY'=>			'Add comment by',
-	'S_COMMENT_ADDED'=>			'Comment added',
-	'S_CANNOT_ADD_COMMENT'=>			'Cannot add coment',
 	'S_ALARM_ACKNOWLEDGES_BIG'=>			'ALARM ACKNOWLEDGES',
 	'S_ACKNOWLEDGE_ADDED'=>			'Acknowledge added',
 	'S_CONFIGURATION_OF_ACTIONS'=>			'Eljárás beállítása',
@@ -234,9 +223,6 @@
 	'S_OR'=>			'or',
 	'S_TYPE_OF_CALCULATION'=>			'Képzés tipusa',
 	'S_CREATE_ACTION'=>			'Új eljárás',
-	'S_ENABLE_SELECTED_ACTIONS_Q'=>			'Engedélyezi a kiválasztott eljárást?',
-	'S_DISABLE_SELECTED_ACTIONS_Q'=>			'Tiltja a kiválasztott eljárást?',
-	'S_DELETE_SELECTED_ACTIONS_Q'=>			'Törli a kiválasztott eljárásokat?',
 	'S_DELETE_SELECTED_ACTION_Q'=>			'Törli a kiválasztott eljárást?',
 	'S_LIKE_SMALL'=>			'like',
 	'S_NOT_LIKE_SMALL'=>			'not like',
@@ -246,6 +232,8 @@
 	'S_TIME'=>			'Idő',
 	'S_STATUS'=>			'Státusz',
 	'S_DURATION'=>			'Időtartam',
+	'S_TRUE_BIG'=>			'IGAZ',
+	'S_FALSE_BIG'=>			'HAMIS',
 	'S_UNKNOWN_BIG'=>			'ISMERETLEN',
 	'S_TYPE'=>			'Típus',
 	'S_RECIPIENTS'=>			'Recipient(s)',
@@ -257,12 +245,6 @@
 	'S_GRAPHS_BIG'=>			'GRAPHS',
 	'S_SELECT_GRAPH_TO_DISPLAY'=>			'Select graph to display',
 	'S_PERIOD'=>			'Period',
-	'S_MOVE'=>			'Move',
-	'S_NAVIGATE'=>			'Navigate',
-	'S_INCREASE'=>			'Increase',
-	'S_DECREASE'=>			'Decrease',
-	'S_RIGHT_DIR'=>			'Jobb',
-	'S_LEFT_DIR'=>			'Bal',
 	'S_SELECT_GRAPH_DOT_DOT_DOT'=>			'Select graph...',
 	'S_CANNNOT_UPDATE_VALUE_MAP'=>			'Cannot update value map',
 	'S_VALUE_MAP_ADDED'=>			'Value map added',
@@ -301,6 +283,8 @@
 	'S_HOUSEKEEPER'=>			'Házfelügyelő',
 	'S_MEDIA_TYPES'=>			'Értesítési módok',
 	'S_ESCALATION_RULES'=>			'Escalation rules',
+	'S_ESCALATION'=>			'Escalation',
+	'S_ESCALATION_RULE'=>			'Escalation rule',
 	'S_DEFAULT'=>			'Default',
 	'S_IMAGES'=>			'Images',
 	'S_IMAGE'=>			'Image',
@@ -324,7 +308,7 @@
 	'S_USER_GROUP_FOR_DATABASE_DOWN_MESSAGE'=>			'User group for database down message',
 	'S_INCORRECT_GROUP'=>			'Érvénytelen csoport',
 	'S_NOTHING_TO_DO'=>			'Nincs feladat',
-	'S_ICORRECT_WORK_PERIOD'=>			'Icorrect work period',
+	'S_INCORRECT_WORK_PERIOD'=>			'Icorrect work period',
 	'S_NODE'=>			'Node',
 	'S_NODES'=>			'Nodes',
 	'S_NODES_BIG'=>			'NODES',
@@ -333,6 +317,7 @@
 	'S_NO_PERMISSIONS'=>			'No permissions !',
 	'S_LATEST_DATA_BIG'=>			'AKTUÁLIS ADATOK',
 	'S_ALL_SMALL'=>			'mind',
+	'S_MINUS_ALL_MINUS'=>			'- mind -',
 	'S_MINUS_OTHER_MINUS'=>			'- egyéb -',
 	'S_GRAPH'=>			'Grafikon',
 	'S_COPYRIGHT_BY'=>			'Copyright 2001-2007 by',
@@ -372,7 +357,6 @@
 	'S_NO_GRAPHS_DEFINED'=>			'No graphs defined',
 	'S_NO_GRAPH_DEFINED'=>			'No graph defined',
 	'S_DELETE_GRAPH_Q'=>			'Delete graph?',
-	'S_YAXIS_TYPE'=>			'Y axis type',
 	'S_YAXIS_MIN_VALUE'=>			'Y axis MIN value',
 	'S_YAXIS_MAX_VALUE'=>			'Y axis MAX value',
 	'S_CALCULATED'=>			'Calculated',
@@ -389,7 +373,6 @@
 	'S_TIMESTAMP'=>			'Timestamp',
 	'S_LOCAL'=>			'Local',
 	'S_SOURCE'=>			'Source',
-	'S_SHOW_UNKNOWN'=>			'Show unknown',
 	'S_SHOW_SELECTED'=>			'Show selected',
 	'S_HIDE_SELECTED'=>			'Hide selectede',
 	'S_MARK_SELECTED'=>			'Mark selected',
@@ -401,11 +384,8 @@
 	'S_APPLICATIONS'=>			'Applications',
 	'S_APPLICATIONS_BIG'=>			'APPLICATIONS',
 	'S_CREATE_APPLICATION'=>			'Create application',
-	'S_DELETE_SELECTED_APPLICATIONS_Q'=>			'Delete selected applications?',
-	'S_DISABLE_ITEMS_FROM_SELECTED_APPLICATIONS_Q'=>			'Disable items from selected applications?',
 	'S_ACTIVATE_ITEMS'=>			'Activate Items',
 	'S_DISABLE_ITEMS'=>			'Disable Items',
-	'S_ACTIVATE_ITEMS_FROM_SELECTED_APPLICATIONS_Q'=>			'Activate items from selected applications?',
 	'S_APPLICATION_UPDATED'=>			'Application updated',
 	'S_CANNOT_UPDATE_APPLICATION'=>			'Cannot update application',
 	'S_APPLICATION_ADDED'=>			'Application added',
@@ -426,7 +406,6 @@
 	'S_CANNOT_UPDATE_HOST_STATUS'=>			'Cannot update host status',
 	'S_HOST_DELETED'=>			'Host deleted',
 	'S_CANNOT_DELETE_HOST'=>			'Cannot delete host',
-	'S_CONFIGURATION_OF_HOSTS_GROUPS_AND_TEMPLATES'=>			'CONFIGURATION OF HOSTS, GROUPS AND TEMPLATES',
 	'S_HOST_GROUPS_BIG'=>			'HOST GROUPS',
 	'S_NO_HOST_GROUPS_DEFINED'=>			'No host groups defined',
 	'S_NO_HOSTS_DEFINED'=>			'No hosts defined',
@@ -450,7 +429,6 @@
 	'S_LINK_WITH_TEMPLATE'=>			'Link with Template',
 	'S_USE_PROFILE'=>			'Use profile',
 	'S_DELETE_SELECTED_HOST_Q'=>			'Delete selected host?',
-	'S_DELETE_SELECTED_GROUPS_Q'=>			'Delete selected groups?',
 	'S_DELETE_SELECTED_WITH_LINKED_ELEMENTS'=>			'Delete selected with linked elements',
 	'S_GROUP_NAME'=>			'Group name',
 	'S_HOST_GROUP'=>			'Host group',
@@ -474,23 +452,19 @@
 	'S_DELETE_FROM_GROUP'=>			'Delete from group',
 	'S_UPDATE_IN_GROUP'=>			'Update in group',
 	'S_DELETE_SELECTED_HOSTS_Q'=>			'Delete selected hosts?',
-	'S_DISABLE_SELECTED_HOSTS_Q'=>			'Disable selected hosts?',
-	'S_ACTIVATE_SELECTED_HOSTS_Q'=>			'Activate selected hosts?',
 	'S_CREATE_HOST'=>			'Create Host',
 	'S_CREATE_TEMPLATE'=>			'Create Template',
 	'S_TEMPLATE_LINKAGE'=>			'Template linkage',
-	'S_TEMPLATE_LINKAGE_BIG'=>			'TEMPLATE LINKAGE',
-	'S_NO_LINKAGES'=>			'No Linkages',
 	'S_TEMPLATES'=>			'Minták',
 	'S_TEMPLATES_BIG'=>			'MINTÁK',
 	'S_UNLINK'=>			'Unlink',
 	'S_UNLINK_AND_CLEAR'=>			'Unlink and clear',
 	'S_NO_ITEMS_DEFINED'=>			'No items defined',
 	'S_NO_ITEM_DEFINED'=>			'No item defined',
-	'S_HISTORY_CLEANED'=>			'History cleaned',
-	'S_CLEAN_HISTORY_SELECTED_ITEMS'=>			'Clean history selected items',
-	'S_CLEAN_HISTORY'=>			'Clean history',
-	'S_CANNOT_CLEAN_HISTORY'=>			'Cannot clean history',
+	'S_HISTORY_CLEARED'=>			'History cleaned',
+	'S_CLEAR_HISTORY_FOR_SELECTED'=>			'Clean history selected items',
+	'S_CLEAR_HISTORY'=>			'Clean history',
+	'S_CANNOT_CLEAR_HISTORY'=>			'Cannot clean history',
 	'S_CONFIGURATION_OF_ITEMS'=>			'Configuration of items',
 	'S_CONFIGURATION_OF_ITEMS_BIG'=>			'CONFIGURATION OF ITEMS',
 	'S_CANNOT_UPDATE_ITEM'=>			'Cannot update item',
@@ -521,9 +495,6 @@
 	'S_WEB_MONITORING'=>			'Web felügyelet',
 	'S_ACTIVE'=>			'Aktív',
 	'S_NOT_SUPPORTED'=>			'Nem támogatott',
-	'S_ACTIVATE_SELECTED_ITEMS_Q'=>			'Aktiválja a kiválasztott elemeket?',
-	'S_DISABLE_SELECTED_ITEMS_Q'=>			'Tiltja a kiválasztott elemeket?',
-	'S_DELETE_SELECTED_ITEMS_Q'=>			'Törli a kiválasztott elemeket?',
 	'S_EMAIL'=>			'Email',
 	'S_JABBER'=>			'Jabber',
 	'S_JABBER_IDENTIFIER'=>			'Jabber Azonosító',
@@ -557,6 +528,7 @@
 	'S_CUSTOM_MULTIPLIER'=>			'Custom multiplier',
 	'S_DO_NOT_USE'=>			'Ne használja',
 	'S_USE_MULTIPLIER'=>			'Use multiplier',
+	'S_SELECT_HOST_DOT_DOT_DOT'=>			'Select host...',
 	'S_LOG_TIME_FORMAT'=>			'Log time format',
 	'S_CREATE_ITEM'=>			'Create Item',
 	'S_X_ELEMENTS_COPY_TO_DOT_DOT_DOT'=>			'elements copy to ...',
@@ -567,12 +539,9 @@
 	'S_UPDATE_EXISTING_NON_LINKED_ITEMS'=>			'update existing non linked items',
 	'S_COPY'=>			'Copy',
 	'S_SHOW_ITEMS_WITH_DESCRIPTION_LIKE'=>			'Mutasd azokat melyek leírásában szerepel a(z)...',
-	'S_SHOW_DISABLED_ITEMS'=>			'Show disabled items',
-	'S_HIDE_DISABLED_ITEMS'=>			'Hide disabled items',
-	'S_HISTORY_CLEANING_CAN_TAKE_A_LONG_TIME_CONTINUE_Q'=>			'History cleaning can take a long time. Continue?',
-	'S_SELECTION_MODE'=>			'Selection mode',
-	'S_ADVANCED'=>			'Advanced',
+	'S_HISTORY_CLEARING_CAN_TAKE_A_LONG_TIME_CONTINUE_Q'=>			'History cleaning can take a long time. Continue?',
 	'S_MASS_UPDATE'=>			'Mass update',
+	'S_SEARCH'=>			'Search',
 	'S_ORIGINAL'=>			'Original',
 	'S_NEW_FLEXIBLE_INTERVAL'=>			'New flexible interval',
 	'S_FLEXIBLE_INTERVALS'=>			'Flexible intervals (sec)',
@@ -586,8 +555,6 @@
 	'S_X'=>			'X',
 	'S_Y'=>			'Y',
 	'S_ICON_UNKNOWN'=>			'Icon (unknown)',
-	'S_ELEMENT_1'=>			'Element 1',
-	'S_ELEMENT_2'=>			'Element 2',
 	'S_LINK_STATUS_INDICATOR'=>			'Link status indicator',
 	'S_CONFIGURATION_OF_NETWORK_MAPS'=>			'CONFIGURATION OF NETWORK MAPS',
 	'S_MAPS_BIG'=>			'MAPS',
@@ -657,8 +624,6 @@
 	'S_AVAILABILITY_REPORT'=>			'Létező jelentések',
 	'S_AVAILABILITY_REPORT_BIG'=>			'LÉTEZŐ JELENTÉSEK',
 	'S_SHOW'=>			'Mutasd',
-	'S_TRUE'=>			'Igaz',
-	'S_FALSE'=>			'Hamis',
 	'S_IT_SERVICES_AVAILABILITY_REPORT'=>			'IT services availability report',
 	'S_IT_SERVICES_AVAILABILITY_REPORT_BIG'=>			'IT SERVICES AVAILABILITY REPORT',
 	'S_FROM'=>			'-tól',
@@ -737,9 +702,9 @@
 	'S_LOCAL_TIME'=>			'Helyi idő',
 	'S_STYLE'=>			'Stílus',
 	'S_VERTICAL'=>			'Függőleges',
-	'S_HORISONTAL'=>			'Vízszintes',
-	'S_HORISONTAL_ALIGN'=>			'Vízszintes igazítás',
-	'S_CENTER'=>			'Középre',
+	'S_HORIZONTAL'=>			'Vízszintes',
+	'S_HORIZONTAL_ALIGN'=>			'Vízszintes igazítás',
+	'S_CENTRE'=>			'Középre',
 	'S_RIGHT'=>			'Jobbra',
 	'S_VERTICAL_ALIGN'=>			'Függőleges igazítás',
 	'S_MIDDLE'=>			'Középre',
@@ -794,7 +759,6 @@
 	'S_SERVICE'=>			'Service',
 	'S_SERVICES'=>			'Services',
 	'S_REASON'=>			'Reason',
-	'S_SLA_LAST_7_DAYS'=>			'SLA (last 7 days)',
 	'S_NO_TRIGGER'=>			'Nincs trigger',
 	'S_NO_TRIGGERS_DEFINED'=>			'Nincs triggers definiálva',
 	'S_NO_TRIGGER_DEFINED'=>			'Nincs trigger definiálva',
@@ -811,9 +775,6 @@
 	'S_DISABLED'=>			'Tiltva',
 	'S_ENABLED'=>			'Engedélyezve',
 	'S_ENABLE_SELECTED'=>			'Kiválasztott engedélyezése',
-	'S_ENABLE_SELECTED_TRIGGERS_Q'=>			'Valóban engedélyezi a kiválasztott triggers?',
-	'S_DISABLE_SELECTED_TRIGGERS_Q'=>			'Valóban tiltja a kiválasztott triggers?',
-	'S_DELETE_SELECTED_TRIGGERS_Q'=>			'Valóban törli a kiválasztott triggers?',
 	'S_CHANGE'=>			'Változás',
 	'S_TRIGGER_UPDATED'=>			'Trigger módositva',
 	'S_CANNOT_UPDATE_TRIGGER'=>			'Nem lehet módositani a trigger',
@@ -832,7 +793,6 @@
 	'S_ADD'=>			'Új',
 	'S_STATUS_OF_TRIGGERS'=>			'Status of triggers',
 	'S_STATUS_OF_TRIGGERS_BIG'=>			'STATUS OF TRIGGERS',
-	'S_SHOW_ACTIONS'=>			'Show actions',
 	'S_SHOW_DETAILS'=>			'Show details',
 	'S_SELECT'=>			'Select',
 	'S_TRIGGERS_BIG'=>			'TRIGGEREK',
@@ -852,7 +812,6 @@
 	'S_USER_DELETED'=>			'User deleted',
 	'S_CANNOT_DELETE_USER'=>			'Cannot delete user',
 	'S_USER_UPDATED'=>			'User updated',
-	'S_ONLY_FOR_GUEST_ALLOWED_EMPTY_PASSWORD'=>			'Only user \"guest\" may have an empty password.',
 	'S_CANNOT_UPDATE_USER'=>			'Cannot update user',
 	'S_CANNOT_UPDATE_USER_BOTH_PASSWORDS'=>			'Cannot update user. Both passwords must be equal.',
 	'S_GROUP_ADDED'=>			'Group added',
@@ -932,6 +891,6 @@
 	'S_LATEST_DATA'=>			'Legutolsó adat',
 	'S_INCORRECT_DESCRIPTION'=>			'Incorrect description',
 	'S_CANT_FORMAT_TREE'=>			'Can\"t format Tree',
-	
+
 	);
 ?>
