@@ -1,5 +1,5 @@
 <?php
-/* 
+/*
 ** ZABBIX
 ** Copyright (C) 2000-2005 SIA Zabbix
 **
@@ -31,7 +31,7 @@
 	'S_DISABLE_SELECTED'=>			'선택 항목 비활성화',
 	'S_DELETE_SELECTED'=>			'선택 항목 삭제',
 	'S_COPY_SELECTED_TO'=>			'선택 항목 복사...',
-	
+
 //	dicoveryconf.php
 	'S_HOST_IP'=>				'호스트 IP 주소',
 	'S_SERVICE_TYPE'=>			'서비스 종류',
@@ -48,11 +48,7 @@
 	'S_CONFIGURATION_OF_DISCOVERY_BIG'=>	'디스커버리 설정',
 	'S_NO_DISCOVERY_RULES_DEFINED'=>	'디스커버리 규칙이 정의되어 있지 않습니다',
 	'S_IP_RANGE'=>				'IP 주소 범위',
-	'S_INTERVALS'=>				'간격',
 	'S_CHECKS'=>				'검사 항목',
-	'S_ENABLE_SELECTED_RULES_Q'=>		'선택한 규칙을 활성화하시겠습니까?',
-	'S_DISABLE_SELECTED_RULES_Q'=>		'선택한 규칙을 비활성화하시겠습니까?',
-	'S_DELETE_SELECTED_RULES_Q'=>		'선택한 규칙을 삭제하시겠습니까?',
 	'S_CREATE_RULE'=>			'규칙 작성',
 	'S_DELETE_RULE_Q'=>			'규칙을 삭제하시겠습니까?',
 
@@ -114,16 +110,11 @@
 	'S_SCENARIO_DELETED'=>			'시나리오를 삭제하였습니다',
 	'S_SCENARIO_ACTIVATED'=>		'시나리오를 활성화하였습니다',
 	'S_SCENARIO_DISABLED'=>			'시나리오를 비활성화하였습니다',
-	'S_ACTIVATE_SELECTED_SCENARIOS_Q'=>	'선택한 시나리오를 활성화하시겠습니까?',
-	'S_DISABLE_SELECTED_SCENARIOS_Q'=>	'선택한 시나리오를 비활성화하시겠습니까?',
-	'S_DELETE_SELECTED_SCENARIOS_Q'=>	'선택한 시나리오를 삭제하시겠습니까?',
 	'S_DELETE_SCENARIO_Q'=>			'시나리오를 삭제하시겠습니까?',
-	'S_CLEAN_HISTORY_SELECTED_SCENARIOS'=>	'선택한 시나리오 이력 삭제',
 	'S_SCENARIO_UPDATED'=>			'시나리오를 갱신하였습니다',
 	'S_CANNOT_UPDATE_SCENARIO'=>		'시나리오를 갱신할 수 없습니다',
 	'S_SCENARIO_ADDED'=>			'시나리오를 추가하였습니다',
 	'S_CANNOT_ADD_SCENARIO'=>		'시나리오를 추가할 수 없습니다',
-	'S_SCENARIO_DELETED'=>			'시나리오를 삭제하였습니다',
 	'S_CANNOT_DELETE_SCENARIO'=>		'시나리오를 삭제할 수 없습니다',
 	'S_AGENT'=>				'에이전트',
 	'S_VARIABLES'=>				'변수',
@@ -133,7 +124,7 @@
 	'S_POST'=>				'POST',
 	'S_REQUIRED'=>				'요구 문자열',
 	'S_STEP_OF_SCENARIO'=>			'시나리오 스텝',
-	
+
 //	exp_imp.php
 	'S_ELEMENT'=>				'항목',
 	'S_ELEMENTS'=>				'항목',
@@ -142,16 +133,12 @@
 	'S_IMPORT_FILE'=>			'파일 가져오기',
 	'S_IMPORT'=>				'가져오기',
 	'S_IMPORT_BIG'=>			'가져오기',
-	'S_IMPORT_HOSTS'=>			'호스트 가져오기',
-	'S_IMPORT_HOSTS_BIG'=>			'호스트 가져오기',
 	'S_EXPORT'=>				'내보내기',
-	'S_EXPORT_FILE'=>			'파일 내보내기',
 	'S_EXPORT_BIG'=>			'내보내기',
 	'S_PREVIEW'=>				'미리보기',
 	'S_BACK'=>				'뒤로',
 	'S_NO_DATA_FOR_EXPORT'=>		'내보낼 데이터가 없습니다',
 	'S_RULES'=>				'규칙',
-	'S_SKIP'=>				'건너뜀',
 	'S_EXISTING'=>				'존재하는 경우',
 	'S_MISSING'=>				'존재하지 않는 경우',
 	'S_REFRESH'=>				'갱신',
@@ -167,13 +154,13 @@
 	'S_NEW_INSTALLATION'=>			'새로 설치',
 	'S_NEW_INSTALLATION_BIG'=>		'새로 설치',
 	'S_INSTALLATION_UPDATE'=>		'설치/갱신',
-	
+
 //	node.php
 	'S_TIME_ZONE'=>				'시간대',
 	'S_DO_NOT_KEEP_HISTORY_OLDER_THAN'=>	'이력 보존 기간(일)',
 	'S_DO_NOT_KEEP_TRENDS_OLDER_THAN'=>	'트렌드 보존 기간(일)',
 	'S_MASTER_NODE'=>			'마스터 노드',
-	'S_REMOTE'=>				'리모트',
+	'S_CHILD'=>				'리모트',
 	'S_MASTER'=>				'마스터',
 	'S_NODE_UPDATED'=>			'노드를 갱신하였습니다',
 	'S_CANNOT_UPDATE_NODE'=>		'노드를 갱신할 수 없습니다',
@@ -182,36 +169,24 @@
 	'S_NODE_DELETED'=>			'노드를 삭제하였습니다',
 	'S_CANNOT_DELETE_NODE'=>		'노드를 삭제할 수 없습니다',
 	'S_CURRENT_NODE'=>			'현재 노드',
-	'S_CURRENT_NODE_ONLY'=>			'현재 노드만',
-	'S_WITH_SUBNODES'=>			'하위 노드도 포함',
-	
+
 //	acknow.php
 	'S_ACKNOWLEDGES'=>			'인지',
 	'S_ACKNOWLEDGE'=>			'인지',
 	'S_RETURN'=>				'뒤로',
 	'S_ACKNOWLEDGE_ALARM_BY'=>		'인지 사용자:',
 	'S_ADD_COMMENT_BY'=>			'주석 추가',
-	'S_COMMENT_ADDED'=>			'주석을 추가하였습니다',
-	'S_CANNOT_ADD_COMMENT'=>		'주석을 추가할 수 없습니다',
 	'S_ALARM_ACKNOWLEDGES_BIG'=>		'알람 확인',
 	'S_ACKNOWLEDGE_ADDED'=>			'인지를 추가하였습니다',
 
 //	actionconf.php
 	'S_CONFIGURATION_OF_ACTIONS'=>		'액션 설정',
 	'S_CONFIGURATION_OF_ACTIONS_BIG'=>	'액션 설정',
-	'S_FILTER_HOST_GROUP'=>			'필터: 호스트 그룹',
-	'S_FILTER_HOST'=>			'필터: 호스트',
-	'S_FILTER_TRIGGER'=>			'필터: 트리거',
-	'S_FILTER_TRIGGER_NAME'=>		'필터: 트리거 이름',
-	'S_FILTER_TRIGGER_SEVERITY'=>		'필터: 트리거 심각도',
-	'S_FILTER_WHEN_TRIGGER_BECOMES'=>	'필터: 트리거 상태',
 	'S_OPERATION_TYPE'=>			'오퍼레이션 종류',
 	'S_SEND_MESSAGE'=>			'메시지 송신',
 	'S_REMOTE_COMMAND'=>			'원격 명령',
 	'S_REMOTE_COMMANDS'=>			'원격 명령',
 	'S_FILTER'=>				'필터',
-	'S_FILTER_TYPE'=>			'필터 이름',
-	'S_TRIGGER_NAME'=>			'트리거 이름',
 	'S_TRIGGER_SEVERITY'=>			'트리거 심각도',
 	'S_TRIGGER_VALUE'=>			'트리거 값',
 	'S_TIME_PERIOD'=>			'기간',
@@ -220,8 +195,6 @@
 	'S_CONDITION'=>				'조건',
 	'S_NEW_CONDITION'=>			'새 조건',
 	'S_OPERATIONS'=>			'오퍼레이션',
-	'S_OPERATION'=>				'오퍼레이션',
-	'S_NEW_OPERATION'=>			'새 오퍼레이션',
 	'S_EDIT_OPERATION'=>			'오퍼레이션 편집',
 	'S_NO_CONDITIONS_DEFINED'=>		'조건이 정의되어 있지 않습니다',
 	'S_ACTIONS_DELETED'=>			'액션을 삭제하였습니다',
@@ -254,10 +227,8 @@
 	'S_CANNOT_UPDATE_ACTION'=>		'액션을 갱신할 수 없습니다',
 	'S_ACTION_DELETED'=>			'액션을 삭제하였습니다',
 	'S_CANNOT_DELETE_ACTION'=>		'액션을 삭제할 수 없습니다',
-	'S_SCOPE'=>				'Scope',
 	'S_SEND_MESSAGE_TO'=>			'메시지 송신처',
 	'S_RUN_REMOTE_COMMANDS'=>		'원격 명령 실행',
-	'S_WHEN_TRIGGER'=>			'When trigger',
 	'S_DELAY'=>				'갱신 간격',
 	'S_SUBJECT'=>				'제목',
 	'S_ON'=>				'ON',
@@ -267,14 +238,7 @@
 	'S_USER_GROUP'=>			'사용자 그룹',
 	'S_GROUP'=>				'그룹',
 	'S_USER'=>				'사용자',
-	'S_ON_OR_OFF'=>				'ON / OFF',
-	'S_DELAY_BETWEEN_MESSAGES_IN_SEC'=>	'메시지 간격(초)',
-	'S_DELAY_BETWEEN_EXECUTIONS_IN_SEC'=>			'실행 간격(초)',
 	'S_MESSAGE'=>				'메시지',
-	'S_THIS_TRIGGER_ONLY'=>			'이 트리거만',
-	'S_ALL_TRIGGERS_OF_THIS_HOST'=>		'이 호스트의 모든 트리거',
-	'S_ALL_TRIGGERS'=>			'모든 트리거',
-	'S_USE_IF_TRIGGER_SEVERITY'=>		'트리거 심각도',
 	'S_NOT_CLASSIFIED'=>			'미분류',
 	'S_INFORMATION'=>			'정보',
 	'S_WARNING'=>				'경고',
@@ -289,9 +253,6 @@
 	'S_OR'=>				'or',
 	'S_TYPE_OF_CALCULATION'=>		'계산 종류',
 	'S_CREATE_ACTION'=>			'액션 작성',
-	'S_ENABLE_SELECTED_ACTIONS_Q'=>		'선택한 액션을 활성화하시겠습니까?',
-	'S_DISABLE_SELECTED_ACTIONS_Q'=>	'선택한 액션을 비활성화하시겠습니까?',
-	'S_DELETE_SELECTED_ACTIONS_Q'=>		'선택한 액션을 삭제하시겠습니까?',
 	'S_DELETE_SELECTED_ACTION_Q'=>		'선택한 액션을 삭제하시겠습니까?',
 	'S_LIKE_SMALL'=>			'포함',
 	'S_NOT_LIKE_SMALL'=>			'포함 안함',
@@ -300,72 +261,30 @@
 	'S_RETRIES_LEFT'=>			'남은 재시도 횟수',
 
 //	alarms.php
-	'S_ALARMS'=>				'알람',
-	'S_ALARMS_SMALL'=>			'알람',
-	'S_ALARMS_BIG'=>			'알람',
-	'S_SHOW_ONLY_LAST_100'=>		'최근의 100건을 표시',
 	'S_SHOW_ALL'=>				'모두 보이기',
 	'S_TIME'=>				'시각',
 	'S_STATUS'=>				'상태',
 	'S_DURATION'=>				'기간',
-	'S_SUM'=>				'합계',
 	'S_TRUE_BIG'=>				'장애',
 	'S_FALSE_BIG'=>				'정상',
-	'S_DISABLED_BIG'=>			'무효',
 	'S_UNKNOWN_BIG'=>			'알 수 없음',
 
 //	actions.php
-	'S_HISTORY_OF_ACTIONS_BIG'=>		'액션 이력',
-	'S_LATEST_ACTIONS'=>			'최근 액션',
-	'S_ALERTS_BIG'=>			'경고',
 	'S_TYPE'=>				'종류',
 	'S_RECIPIENTS'=>			'수신처',
 	'S_ERROR'=>				'에러',
 	'S_SENT'=>				'송신 완료',
 	'S_NOT_SENT'=>				'미송신',
 	'S_NO_ACTIONS_FOUND'=>			'액션을 찾을 수 없습니다',
-	'S_SHOW_NEXT_100'=>			'다음 100건을 표시',
-	'S_SHOW_PREVIOUS_100'=>			'이전 100건을 표시',
 
 //	charts.php
 	'S_CUSTOM_GRAPHS'=>			'커스텀 그래프',
 	'S_GRAPHS_BIG'=>			'그래프',
-	'S_NO_GRAPHS_TO_DISPLAY'=>		'표시할 그래프가 없습니다',
 	'S_SELECT_GRAPH_TO_DISPLAY'=>		'표시할 그래프를 선택하십시오',
 	'S_PERIOD'=>				'기간',
-	'S_1H'=>				'1시간',
-	'S_2H'=>				'2시간',
-	'S_4H'=>				'4시간',
-	'S_8H'=>				'8시간',
-	'S_12H'=>				'12시간',
-	'S_24H'=>				'24시간',
-	'S_WEEK_SMALL'=>			'주',
-	'S_MONTH_SMALL'=>			'월',
-	'S_YEAR_SMALL'=>			'년',
-	'S_KEEP_PERIOD'=>			'기간 유지',
-	'S_ON_C'=>				'ON',
-	'S_OFF_C'=>				'OFF',
-	'S_MOVE'=>				'이동',
-	'S_NAVIGATE'=>				'이동/조정',
-	'S_INCREASE'=>				'증가',
-	'S_DECREASE'=>				'감소',
-	'S_NAVIGATE'=>				'이동/조정',
-	'S_RIGHT_DIR'=>				'오른쪽',
-	'S_LEFT_DIR'=>				'왼쪽',
 	'S_SELECT_GRAPH_DOT_DOT_DOT'=>		'그래프 선택...',
 
 // Colors
-	'S_BLACK'=>				'검정',
-	'S_BLUE'=>				'파랑',
-	'S_CYAN'=>				'남색',
-	'S_DARK_BLUE'=>				'짙은 파랑',
-	'S_DARK_GREEN'=>			'짙은 녹색',
-	'S_DARK_RED'=>				'짙은 빨강',
-	'S_DARK_YELLOW'=>			'짙은 노랑',
-	'S_GREEN'=>				'녹색',
-	'S_RED'=>				'빨강',
-	'S_WHITE'=>				'흰색',
-	'S_YELLOW'=>				'노랑',
 
 // Lines
         'S_LINE'=>                              '선',
@@ -413,28 +332,8 @@
 	'S_MEDIA_TYPES'=>			'연락 방법',
 	'S_ESCALATION_RULES'=>			'에스컬레이션 규칙',
 	'S_ESCALATION'=>			'에스컬레이션',
-	'S_ESCALATION_RULES_BIG'=>		'에스컬레이션 규칙',
-	'S_NO_ESCALATION_RULES_DEFINED'=>	'에스컬레이션 규칙이 정의되어 있지 않습니다',
-	'S_NO_ESCALATION_DETAILS'=>		'에스컬레이션 이름이 없습니다',
-	'S_ESCALATION_DETAILS_BIG'=>		'에스컬레이션 이름',
-	'S_ESCALATION_ADDED'=>			'에스컬레이션을 추가하였습니다',
-	'S_ESCALATION_WAS_NOT_ADDED'=>		'에스컬레이션을 추가할 수 없습니다',
-	'S_ESCALATION_RULE_ADDED'=>		'에스컬레이션 규칙을 추가하였습니다',
-	'S_ESCALATION_RULE_WAS_NOT_ADDED'=>	'에스컬레이션 규칙을 추가할 수 없습니다',
-	'S_ESCALATION_RULE_UPDATED'=>		'에스컬레이션 규칙을 갱신하였습니다',
-	'S_ESCALATION_RULE_WAS_NOT_UPDATED'=>	'에스컬레이션 규칙을 갱신할 수 없습니다',
-	'S_ESCALATION_RULE_DELETED'=>		'에스컬레이션 규칙을 삭제하였습니다',
-	'S_ESCALATION_RULE_WAS_NOT_DELETED'=>	'에스컬레이션 규칙을 삭제할 수 없습니다',
-	'S_ESCALATION_UPDATED'=>		'에스컬레이션을 갱신하였습니다',
-	'S_ESCALATION_WAS_NOT_UPDATED'=>	'에스컬레이션을 갱신할 수 없습니다',
-	'S_ESCALATION_DELETED'=>		'에스컬레이션을 삭제하였습니다',
-	'S_ESCALATION_WAS_NOT_DELETED'=>	'에스컬레이션을 삭제할 수 없습니다',
 	'S_ESCALATION_RULE'=>			'에스컬레이션 규칙',
-	'S_DO'=>				'실행',
 	'S_DEFAULT'=>				'Default',
-	'S_IS_DEFAULT'=>			'Is default',
-	'S_LEVEL'=>				'레벨',
-	'S_DELAY_BEFORE_ACTION'=>		'액션 실행 전 지연',
 	'S_IMAGES'=>				'이미지',
 	'S_IMAGE'=>				'이미지',
 	'S_IMAGES_BIG'=>			'이미지',
@@ -448,21 +347,17 @@
 	'S_CANNOT_DELETE_IMAGE'=>		'이미지를 삭제할 수 없습니다',
 	'S_IMAGE_UPDATED'=>			'이미지를 갱신하였습니다',
 	'S_CANNOT_UPDATE_IMAGE'=>		'이미지를 갱신할 수 없습니다',
-	'S_UPDATE_SELECTED_IMAGE'=>		'선택한 이미지를 갱신하시겠습니까?',
-	'S_PRIORITY'=>				'중요도',
-	'S_PATTERN'=>				'패턴',
 	'S_OTHER'=>				'기타',
 	'S_OTHER_PARAMETERS'=>			'기타 파라미터',
 	'S_REFRESH_UNSUPPORTED_ITEMS'=>		'취득불가 아이템 갱신 간격(초)',
 	'S_CREATE_MEDIA_TYPE'=>			'연락 방법 작성',
 	'S_CREATE_IMAGE'=>			'이미지 작성',
-	'S_CREATE_RULE'=>			'규칙 작성',
 	'S_WORKING_TIME'=>			'Working time',
 	'S_USER_GROUP_FOR_DATABASE_DOWN_MESSAGE'=>'데이터베이스 정지 메시지 송신 대상 사용자 그룹',
 	'S_INCORRECT_GROUP'=>			'부적절한 그룹',
 	'S_NOTHING_TO_DO'=>			'실행할 것이 없습니다',
-	'S_ICORRECT_WORK_PERIOD'=>		'부적절한 Working time',
-	
+	'S_INCORRECT_WORK_PERIOD'=>		'부적절한 Working time',
+
 //	nodes.php
 	'S_NODE'=>				'노드',
 	'S_NODES'=>				'노드',
@@ -471,38 +366,27 @@
 	'S_NO_NODES_DEFINED'=>			'노드가 정의되어 있지 않습니다',
 
 //	Latest values
-	'S_LATEST_VALUES'=>			'최근 값',
 	'S_NO_PERMISSIONS'=>			'권한이 없습니다!',
 	'S_LATEST_DATA_BIG'=>			'최근 데이터',
 	'S_ALL_SMALL'=>				'전체',
 	'S_MINUS_ALL_MINUS'=>			'- all -',
 	'S_MINUS_OTHER_MINUS'=>			'- 기타 -',
-	'S_DESCRIPTION_LARGE'=>			'이름',
-	'S_DESCRIPTION_SMALL'=>			'이름',
 	'S_GRAPH'=>				'그래프',
-	'S_TREND'=>				'경향',
-	'S_COMPARE'=>				'비교',
 
 //	Footer
 	'S_CONNECTED_AS'=>			'다음 사용자로 로그인 중',
 	'S_SIA_ZABBIX'=>			'SIA Zabbix',
 
 //	graph.php
-	'S_CONFIGURATION_OF_GRAPH'=>		'그래프 설정',
-	'S_CONFIGURATION_OF_GRAPH_BIG'=>	'그래프 설정',
 	'S_ITEM_ADDED'=>			'아이템을 추가하였습니다',
 	'S_ITEM_UPDATED'=>			'아이템을 갱신하였습니다',
 	'S_ITEMS_UPDATED'=>			'아이템을 갱신하였습니다',
-	'S_SORT_ORDER_UPDATED'=>		'노드 순서를 갱신하였습니다',
-	'S_CANNOT_UPDATE_SORT_ORDER'=>		'노드 순서를 갱신할 수 없습니다',
-	'S_DISPLAYED_PARAMETERS_BIG'=>		'표시 파라미터',
-	'S_SORT_ORDER'=>			'노드 순서',
 	'S_PARAMETER'=>				'파라미터',
 	'S_COLOR'=>				'색',
 	'S_UP'=>				'UP',
 	'S_DOWN'=>				'DOWN',
 	'S_NEW_ITEM_FOR_THE_GRAPH'=>		'그래프에 추가할 아이템',
-	'S_SORT_ORDER_1_100'=>			'정렬 순서(0->100)',
+	'S_SORT_ORDER_0_100'=>			'정렬 순서(0->100)',
 	'S_YAXIS_SIDE'=>			'Y축',
 	'S_LEFT'=>				'왼쪽',
 	'S_FUNCTION'=>				'기능',
@@ -510,7 +394,6 @@
 	'S_AVG_SMALL'=>				'평균',
 	'S_MAX_SMALL'=>				'최대',
 	'S_DRAW_STYLE'=>			'종류',
-	'S_SIMPLE'=>				'단순',
 	'S_GRAPH_TYPE'=>			'그래프 종류',
 	'S_STACKED'=>				'누적 그래프',
 	'S_NORMAL'=>				'꺾은선 그래프',
@@ -530,7 +413,6 @@
 	'S_NO_GRAPHS_DEFINED'=>			'그래프가 정의되어 있지 않습니다',
 	'S_NO_GRAPH_DEFINED'=>			'그래프가 정의되어 있지 않습니다',
 	'S_DELETE_GRAPH_Q'=>			'그래프를 삭제하시겠습니까?',
-	'S_YAXIS_TYPE'=>			'Y축 종류',
 	'S_YAXIS_MIN_VALUE'=>			'Y축 최솟값',
 	'S_YAXIS_MAX_VALUE'=>			'Y축 최댓값',
 	'S_CALCULATED'=>			'자동 계산',
@@ -545,16 +427,10 @@
 	'S_LAST_HOUR_GRAPH'=>			'최근 1시간의 그래프',
 	'S_LAST_WEEK_GRAPH'=>			'최근 1주일의 그래프',
 	'S_LAST_MONTH_GRAPH'=>			'최근 1개월의 그래프',
-	'S_VALUES_OF_LAST_HOUR'=>		'최근 1시간의 값',
 	'S_500_LATEST_VALUES'=>			'최근 500개의 값',
-	'S_GRAPH_OF_SPECIFIED_PERIOD'=>		'특정 기간의 그래프',
-	'S_VALUES_OF_SPECIFIED_PERIOD'=>	'특정 기간의 값',
-	'S_VALUES_IN_PLAIN_TEXT_FORMAT'=>	'일반 텍스트 값',
 	'S_TIMESTAMP'=>				'타임 스탬프',
 	'S_LOCAL'=>				'로컬',
 	'S_SOURCE'=>				'소스',
-	'S_SHOW_UNKNOWN'=>			'알 수 없는 항목 보이기',
-	'S_HIDE_UNKNOWN'=>			'알 수 없는 항목 감추기',
 
 	'S_SHOW_SELECTED'=>			'선택 항목 보이기',
 	'S_HIDE_SELECTED'=>			'선택 항목 감추기',
@@ -570,11 +446,8 @@
 	'S_APPLICATIONS'=>			'애플리케이션',
 	'S_APPLICATIONS_BIG'=>			'애플리케이션',
 	'S_CREATE_APPLICATION'=>		'애플리케이션 작성',
-	'S_DELETE_SELECTED_APPLICATIONS_Q'=>	'선택한 애플리케이션을 삭제하시겠습니까?',
-	'S_DISABLE_ITEMS_FROM_SELECTED_APPLICATIONS_Q'=>'선택한 애플리케이션의 아이템을 비활성화하시겠습니까?',
 	'S_ACTIVATE_ITEMS'=>			'아이템 활성화',
 	'S_DISABLE_ITEMS'=>			'아이템 비활성화',
-	'S_ACTIVATE_ITEMS_FROM_SELECTED_APPLICATIONS_Q'=>'선택한 애플리케이션의 아이템을 활성화하시겠습니까?',
 	'S_APPLICATION_UPDATED'=>		'애플리케이션을 갱신하였습니다',
 	'S_CANNOT_UPDATE_APPLICATION'=>		'애플리케이션을 갱신할 수 없습니다',
 	'S_APPLICATION_ADDED'=>			'애플리케이션을 추가하였습니다',
@@ -590,40 +463,25 @@
 	'S_GRAPHS'=>				'그래프',
 	'S_HOST_ADDED'=>			'호스트를 추가하였습니다',
 	'S_CANNOT_ADD_HOST'=>			'호스트를 추가할 수 없습니다',
-	'S_ITEMS_ADDED'=>			'아이템을 추가하였습니다',
-	'S_CANNOT_ADD_ITEMS'=>			'아이템을 추가할 수 없습니다',
 	'S_HOST_UPDATED'=>			'호스트를 갱신하였습니다',
 	'S_CANNOT_UPDATE_HOST'=>		'호스트를 갱신할 수 없습니다',
 	'S_HOST_STATUS_UPDATED'=>		'호스트 상태를 갱신하였습니다',
 	'S_CANNOT_UPDATE_HOST_STATUS'=>		'호스트 상태를 갱신할 수 없습니다',
 	'S_HOST_DELETED'=>			'호스트를 삭제하였습니다',
 	'S_CANNOT_DELETE_HOST'=>		'호스트를 삭제할 수 없습니다',
-	'S_TEMPLATE_LINKAGE_ADDED'=>		'템플릿 링크를 추가하였습니다',
-	'S_CANNOT_ADD_TEMPLATE_LINKAGE'=>	'템플릿 링크를 추가할 수 없습니다',
-	'S_TEMPLATE_LINKAGE_UPDATED'=>		'템플릿 링크를 갱신하였습니다',
-	'S_CANNOT_UPDATE_TEMPLATE_LINKAGE'=>	'템플릿 링크를 갱신할 수 없습니다',
-	'S_TEMPLATE_LINKAGE_DELETED'=>		'템플릿 링크를 삭제하였습니다',
-	'S_CANNOT_DELETE_TEMPLATE_LINKAGE'=>	'템플릿 링크를 삭제할 수 없습니다',
-	'S_CONFIGURATION_OF_HOSTS_GROUPS_AND_TEMPLATES'=>'호스트/그룹/템플릿 설정',
 	'S_HOST_GROUPS_BIG'=>			'호스트 그룹',
-	'S_START'=>				'시작',
-	'S_STOP'=>				'중지',
 	'S_NO_HOST_GROUPS_DEFINED'=>		'호스트 그룹이 정의되어 있지 않습니다',
-	'S_NO_LINKAGES_DEFINED'=>		'링크가 정의되어 있지 않습니다',
 	'S_NO_HOSTS_DEFINED'=>			'호스트가 정의되어 있지 않습니다',
 	'S_NO_TEMPLATES_DEFINED'=>		'템플릿이 정의되어 있지 않습니다',
 	'S_HOSTS_BIG'=>				'호스트',
 	'S_HOST'=>				'호스트',
-	'S_HOST_BIG'=>				'호스트',
 	'S_CONNECT_TO'=>			'접속 방법',
 	'S_DNS'=>				'DNS',
 	'S_IP'=>				'IP 주소',
 	'S_PORT'=>				'포트',
 	'S_MONITORED'=>				'감시 중',
 	'S_NOT_MONITORED'=>			'미감시',
-	'S_UNREACHABLE'=>			'응답 없음',
 	'S_TEMPLATE'=>				'템플릿',
-	'S_TEMPLATE_SMALL'=>			'템플릿',
 	'S_DELETED'=>				'삭제',
 	'S_UNKNOWN'=>				'알 수 없음',
 	'S_GROUPS'=>				'그룹',
@@ -634,8 +492,6 @@
 	'S_LINK_WITH_TEMPLATE'=>		'템플릿 링크',
 	'S_USE_PROFILE'=>			'프로파일 사용',
 	'S_DELETE_SELECTED_HOST_Q'=>		'선택한 호스트를 삭제하시겠습니까?',
-	'S_DELETE_SELECTED_GROUP_Q'=>		'선택한 그룹을 삭제하시겠습니까?',
-	'S_DELETE_SELECTED_GROUPS_Q'=>		'선택한 그룹을 삭제하시겠습니까?',
 	'S_DELETE_SELECTED_WITH_LINKED_ELEMENTS'=>'선택 항목 및 연결된 구성요소 삭제',
 	'S_GROUP_NAME'=>			'그룹 이름',
 	'S_HOST_GROUP'=>			'호스트 그룹',
@@ -656,39 +512,25 @@
 	'S_LOCATION'=>				'장소',
 	'S_NOTES'=>				'비고',
 	'S_MACADDRESS'=>			'MAC 주소',
-	'S_PROFILE_ADDED'=>			'프로파일을 추가하였습니다',
-	'S_CANNOT_ADD_PROFILE'=>		'프로파일을 추가할 수 없습니다',
-	'S_PROFILE_UPDATED'=>			'프로파일을 갱신하였습니다',
-	'S_CANNOT_UPDATE_PROFILE'=>		'프로파일을 갱신할 수 없습니다',
-	'S_PROFILE_DELETED'=>			'프로파일을 삭제하였습니다',
-	'S_CANNOT_DELETE_PROFILE'=>		'프로파일을 삭제할 수 없습니다',
 	'S_ADD_TO_GROUP'=>			'그룹에 추가',
 	'S_DELETE_FROM_GROUP'=>			'그룹에서 삭제',
 	'S_UPDATE_IN_GROUP'=>			'그룹 갱신',
 	'S_DELETE_SELECTED_HOSTS_Q'=>		'선택한 호스트를 삭제하시겠습니까?',
-	'S_DISABLE_SELECTED_HOSTS_Q'=>		'선택한 호스트를 비활성화하시겠습니까?',
-	'S_ACTIVATE_SELECTED_HOSTS_Q'=>		'선택한 호스트를 활성화하시겠습니까?',
-	'S_SELECT_HOST_TEMPLATE_FIRST'=>	'Select host template first',
 	'S_CREATE_HOST'=>			'호스트 작성',
 	'S_CREATE_TEMPLATE'=>			'템플릿 작성',
 	'S_TEMPLATE_LINKAGE'=>			'템플릿 링크',
-	'S_TEMPLATE_LINKAGE_BIG'=>		'템플릿 링크',
-	'S_NO_LINKAGES'=>			'링크가 없습니다',
 	'S_TEMPLATES'=>				'템플릿',
 	'S_TEMPLATES_BIG'=>			'템플릿',
-	'S_HOSTS'=>				'호스트',
 	'S_UNLINK'=>				'링크 삭제',
 	'S_UNLINK_AND_CLEAR'=>			'링크와 보존 데이터 삭제',
-	'S_UNLINKED_SMALL'=>			'링크 삭제',
-	'S_CLEANED_SMALL'=>			'cleaned',
 
 //	items.php
 	'S_NO_ITEMS_DEFINED'=>			'아이템이 정의되어 있지 않습니다',
 	'S_NO_ITEM_DEFINED'=>			'아이템이 정의되어 있지 않습니다',
-	'S_HISTORY_CLEANED'=>			'이력이 삭제되었습니다',
-	'S_CLEAN_HISTORY_SELECTED_ITEMS'=>	'선택 아이템 이력 삭제',
-	'S_CLEAN_HISTORY'=>			'이력 삭제',
-	'S_CANNOT_CLEAN_HISTORY'=>		'이력을 삭제할 수 없습니다',
+	'S_HISTORY_CLEARED'=>			'이력이 삭제되었습니다',
+	'S_CLEAR_HISTORY_FOR_SELECTED'=>	'선택 아이템 이력 삭제',
+	'S_CLEAR_HISTORY'=>			'이력 삭제',
+	'S_CANNOT_CLEAR_HISTORY'=>		'이력을 삭제할 수 없습니다',
 	'S_CONFIGURATION_OF_ITEMS'=>		'아이템 설정',
 	'S_CONFIGURATION_OF_ITEMS_BIG'=>	'아이템 설정',
 	'S_CANNOT_UPDATE_ITEM'=>		'아이템을 갱신할 수 없습니다',
@@ -700,16 +542,12 @@
 	'S_ITEMS_DELETED'=>			'아이템을 삭제하였습니다',
 	'S_CANNOT_DELETE_ITEMS'=>		'아이템을 삭제할 수 없습니다',
 	'S_ITEMS_ACTIVATED'=>			'아이템을 활성화하였습니다',
-	'S_CANNOT_ACTIVATE_ITEMS'=>		'아이템을 활성화할 수 없습니다',
 	'S_ITEMS_DISABLED'=>			'아이템을 비활성화하였습니다',
-	'S_CANNOT_DISABLE_ITEMS'=>		'아이템을 비활성화할 수 없습니다',
-	'S_SERVERNAME'=>			'서버 이름',
 	'S_KEY'=>				'키',
 	'S_DESCRIPTION'=>			'이름',
 	'S_UPDATE_INTERVAL'=>			'갱신 간격',
 	'S_HISTORY'=>				'이력',
 	'S_TRENDS'=>				'트렌드',
-	'S_SHORT_NAME'=>			'이름',
 	'S_ZABBIX_AGENT'=>			'ZABBIX 에이전트',
 	'S_ZABBIX_AGENT_ACTIVE'=>		'ZABBIX 에이전트(활성)',
 	'S_SNMPV1_AGENT'=>			'SNMPv1 에이전트',
@@ -721,13 +559,8 @@
 	'S_ZABBIX_AGGREGATE'=>			'ZABBIX 집합',
 	'S_EXTERNAL_CHECK'=>			'외부 검사',
 	'S_WEB_MONITORING'=>			'웹 감시',
-	'S_ZABBIX_UNKNOWN'=>			'알 수 없음',
 	'S_ACTIVE'=>				'활성',
-	'S_NOT_ACTIVE'=>			'비활성',
 	'S_NOT_SUPPORTED'=>			'취득 불가',
-	'S_ACTIVATE_SELECTED_ITEMS_Q'=>		'선택한 아이템을 활성화하시겠습니까?',
-	'S_DISABLE_SELECTED_ITEMS_Q'=>		'선택한 아이템을 비활성화하시겠습니까?',
-	'S_DELETE_SELECTED_ITEMS_Q'=>		'선택한 아이템을 삭제하시겠습니까?',
 	'S_EMAIL'=>				'전자우편',
 	'S_JABBER'=>				'Jabber',
 	'S_JABBER_IDENTIFIER'=>			'JabberID',
@@ -735,7 +568,6 @@
 	'S_SCRIPT'=>				'스크립트',
 	'S_GSM_MODEM'=>				'GSM 모뎀',
 	'S_UNITS'=>				'단위',
-	'S_MULTIPLIER'=>			'승수',
 	'S_UPDATE_INTERVAL_IN_SEC'=>		'갱신 간격(초)',
 	'S_KEEP_HISTORY_IN_DAYS'=>		'이력 보존 기간(일)',
 	'S_KEEP_TRENDS_IN_DAYS'=>		'경향 보존 기간(일)',
@@ -765,7 +597,6 @@
 	'S_SELECT_HOST_DOT_DOT_DOT'=>		'호스트 선택...',
 	'S_LOG_TIME_FORMAT'=>			'로그 시간 형식',
 	'S_CREATE_ITEM'=>			'아이템 작성',
-	'S_ADD_ITEM'=>				'아이템 추가',
 	'S_X_ELEMENTS_COPY_TO_DOT_DOT_DOT'=>	'아이템 복사 대상...',
 	'S_MODE'=>				'모드',
 	'S_TARGET'=>				'대상',
@@ -774,16 +605,10 @@
 	'S_UPDATE_EXISTING_NON_LINKED_ITEMS'=>	'기존 미 연결 아이템을 갱신',
 	'S_COPY'=>				'복사',
 	'S_SHOW_ITEMS_WITH_DESCRIPTION_LIKE'=>	'이름에 다음 문자열을 포함한 아이템만 보이기',
-	'S_SHOW_DISABLED_ITEMS'=>               '비활성 아이템 보이기',
-	'S_HIDE_DISABLED_ITEMS'=>               '비활성 아이템 감추기',
-	'S_HISTORY_CLEANING_CAN_TAKE_A_LONG_TIME_CONTINUE_Q' => '이력 삭제에 시간이 걸릴 수도 있습니다. 계속하시겠습니까?',
-	'S_ITEM_SELECTION'=>			'아이템 선택',
-	'S_SELECTION_MODE'=>			'선택 모드',
-	'S_ADVANCED'=>				'확장',
+	'S_HISTORY_CLEARING_CAN_TAKE_A_LONG_TIME_CONTINUE_Q' => '이력 삭제에 시간이 걸릴 수도 있습니다. 계속하시겠습니까?',
 	'S_SIMPLE'=>				'표준',
 	'S_MASS_UPDATE'=>			'일괄갱신',
 	'S_SEARCH'=>				'찾기',
-	'S_EXTERNAL_FILTER'=>			'상세 필터',
 	'S_ORIGINAL'=>				'변경 안함',
 	'S_NEW_FLEXIBLE_INTERVAL'=>		'새로운 유동적인 갱신 간격',
 	'S_FLEXIBLE_INTERVALS'=>		'유동적인 갱신 간격(초)',
@@ -796,33 +621,22 @@
 
 //	latest.php
 	'S_LAST_CHECK'=>			'최근 검사',
-	'S_LAST_CHECK_BIG'=>			'최근 검사',
 	'S_LAST_VALUE'=>			'최근 값',
 
 //	sysmap.php
 	'S_LINK'=>				'연결',
 	'S_X'=>					'X',
 	'S_Y'=>					'Y',
-	'S_ICON_ON'=>				'아이콘(장애)',
-	'S_ICON_OFF'=>				'아이콘(정상)',
 	'S_ICON_UNKNOWN'=>			'아이콘(알 수 없음)',
-	'S_ELEMENT_1'=>				'구성요소1',
-	'S_ELEMENT_2'=>				'구성요소2',
 	'S_LINK_STATUS_INDICATOR'=>		'연결 상태 표시기',
 	'S_CONFIGURATION_OF_NETWORK_MAPS'=>	'네트워크 맵 설정',
 	'S_CONFIGURATION_OF_NETWORK_MAPS_BIG'=>	'네트워크 맵 설정',
-	'S_DISPLAYED_ELEMENTS'=>		'표시 구성요소',
 	'S_CONNECTORS'=>			'연결',
 	'S_ADD_ELEMENT'=>			'표시 구성요소 추가',
-	'S_CREATE_CONNECTION'=>			'연결 작성',
 	'S_COORDINATE_X'=>			'X좌표',
 	'S_COORDINATE_Y'=>			'Y좌표',
-	'S_TYPE_OFF'=>				'선 종류(정상)',
-	'S_TYPE_ON'=>				'선 종류(장애)',
-	'S_COLOR_OFF'=>				'색(정상)',
-	'S_COLOR_ON'=>				'색(장애)',
-	
-	
+
+
 
 //	sysmaps.php
 	'S_MAPS_BIG'=>				'맵',
@@ -834,15 +648,11 @@
 
 //	map.php
 	'S_OK_BIG'=>				'정상',
-	'S_PROBLEMS_SMALL'=>			'장애',
 	'S_ZABBIX_URL'=>			'http://www.zabbix.com',
 
 //	maps.php
 	'S_NETWORK_MAPS'=>			'네트워크 맵',
 	'S_NETWORK_MAPS_BIG'=>			'네트워크 맵',
-	'S_NO_MAPS_TO_DISPLAY'=>		'표시할 맵이 없습니다',
-	'S_SELECT_MAP_TO_DISPLAY'=>		'Select map to display',
-	'S_SELECT_MAP_DOT_DOT_DOT'=>		'Select map...',
 	'S_BACKGROUND_IMAGE'=>			'배경 이미지',
 	'S_ICON_LABEL_TYPE'=>			'아이콘 라벨 종류',
 	'S_LABEL'=>				'라벨',
@@ -854,53 +664,19 @@
 //	media.php
 	'S_CONFIGURATION_OF_MEDIA_TYPES_BIG'=>	'연락 방법 설정',
 	'S_MEDIA'=>				'연락 방법',
-	'S_MEDIA_BIG'=>				'연락 방법',
-	'S_MEDIA_ACTIVATED'=>			'연락 방법을 활성화하였습니다',
-	'S_CANNOT_ACTIVATE_MEDIA'=>		'연락 방법을 활성화할 수 없습니다',
-	'S_MEDIA_DISABLED'=>			'연락 방법을 비활성화하였습니다',
-	'S_CANNOT_DISABLE_MEDIA'=>		'연락 방법을 비활성화할 수 없습니다',
-	'S_MEDIA_ADDED'=>			'연락 방법을 추가하였습니다',
-	'S_CANNOT_ADD_MEDIA'=>			'연락 방법을 추가할 수 없습니다',
-	'S_MEDIA_UPDATED'=>			'연락 방법을 갱신하였습니다',
-	'S_CANNOT_UPDATE_MEDIA'=>		'연락 방법을 갱신할 수 없습니다',
-	'S_MEDIA_DELETED'=>			'연락 방법을 삭제하였습니다',
-	'S_CANNOT_DELETE_MEDIA'=>		'연락 방법을 삭제할 수 없습니다',
 	'S_SEND_TO'=>				'수신처',
 	'S_WHEN_ACTIVE'=>			'연락 허용 시간대',
 	'S_NO_MEDIA_DEFINED'=>			'연락 방법이 정의되어 있지 않습니다',
 	'S_NEW_MEDIA'=>				'새 연락 방법',
 	'S_USE_IF_SEVERITY'=>			'심각도 선택',
-	'S_DELETE_SELECTED_MEDIA_Q'=>		'선택한 연락 방법을 삭제하시겠습니까?',
-	'S_CREATE_MEDIA'=>			'연락 방법 작성',
 	'S_SAVE'=>				'저장',
 	'S_CANCEL'=>				'취소',
 
 //	Menu
-	'S_MENU_LATEST_VALUES'=>		'최근 데이터',
-	'S_MENU_TRIGGERS'=>			'트리거',
-	'S_MENU_QUEUE'=>			'큐',
-	'S_MENU_ALARMS'=>			'ALARMS',
-	'S_MENU_ALERTS'=>			'ALERTS',
-	'S_MENU_NETWORK_MAPS'=>			'NETWORK MAPS',
-	'S_MENU_GRAPHS'=>			'GRAPHS',
-	'S_MENU_SCREENS'=>			'SCREENS',
-	'S_MENU_IT_SERVICES'=>			'IT SERVICES',
-	'S_MENU_HOME'=>				'HOME',
-	'S_MENU_ABOUT'=>			'ABOUT',
-	'S_MENU_STATUS_OF_ZABBIX'=>		'STATUS OF ZABBIX',
-	'S_MENU_AVAILABILITY_REPORT'=>		'AVAILABILITY REPORT',
-	'S_MENU_CONFIG'=>			'CONFIG',
-	'S_MENU_USERS'=>			'USERS',
-	'S_MENU_HOSTS'=>			'HOSTS',
-	'S_MENU_ITEMS'=>			'ITEMS',
-	'S_MENU_AUDIT'=>			'AUDIT',
-	'S_SWITCH_NODE'=>			'Switch node',
 
 //	overview.php
-	'S_SELECT_GROUP_DOT_DOT_DOT'=>		'Select group ...',
 	'S_OVERVIEW'=>				'개요',
 	'S_OVERVIEW_BIG'=>			'개요',
-	'S_EXCL'=>				'!',
 	'S_DATA'=>				'데이터',
 	'S_SHOW_GRAPH_OF_ITEM'=>		'아이템의 그래프 표시',
 	'S_SHOW_VALUES_OF_ITEM'=>		'아이템의 값 표시',
@@ -920,16 +696,13 @@
 	'S_30_SECONDS'=>			'30초',
 	'S_1_MINUTE'=>				'1분',
 	'S_5_MINUTES'=>				'5분',
-	'S_MORE_THAN_5_MINUTES'=>		'5분 이상',
 
 //	report1.php
 	'S_STATUS_OF_ZABBIX'=>			'ZABBIX 서버 상태',
 	'S_STATUS_OF_ZABBIX_BIG'=>		'ZABBIX 서버 상태',
 	'S_VALUE'=>				'값',
 	'S_ZABBIX_SERVER_IS_RUNNING'=>		'ZABBIX 서버 가동 중',
-	'S_NUMBER_OF_VALUES_STORED'=>		'Number of values stored',
 	'S_VALUES_STORED'=>			'Values stored',
-	'S_NUMBER_OF_TRENDS_STORED'=>		'Number of trends stored',
 	'S_TRENDS_STORED'=>			'Trends stored',
 	'S_NUMBER_OF_EVENTS'=>			'이벤트 수',
 	'S_NUMBER_OF_ALERTS'=>			'경고 수',
@@ -950,8 +723,6 @@
 	'S_AVAILABILITY_REPORT'=>		'가동 보고서',
 	'S_AVAILABILITY_REPORT_BIG'=>		'가동 보고서',
 	'S_SHOW'=>				'표시',
-	'S_TRUE'=>				'장애',
-	'S_FALSE'=>				'정상',
 
 //	report3.php
 	'S_IT_SERVICES_AVAILABILITY_REPORT'=>	'IT 서비스 가동 보고서',
@@ -982,7 +753,7 @@
 	'S_NUMBER_OF_STATUS_CHANGES'=>		'상태 변경 횟수',
 	'S_WEEK'=>				'주',
 	'S_LAST'=>				'최근',
- 
+
 //	screenconf.php
 	'S_SCREENS'=>				'스크린',
 	'S_SCREEN'=>				'스크린',
@@ -1001,8 +772,6 @@
 	'S_CONFIGURATION_OF_SCREEN_BIG'=>	'스크린 설정',
 	'S_SCREEN_CELL_CONFIGURATION'=>		'스크린 셀 설정',
 	'S_RESOURCE'=>				'리소스',
-	'S_RESOURCES'=>				'리소스',
-	'S_RESOURCE_TYPE'=>			'리소스 종류',
 	'S_RIGHTS_OF_RESOURCES'=>		'사용자 권한',
 	'S_NO_RESOURCES_DEFINED'=>		'리소스가 정의되어 있지 않습니다',
 	'S_SIMPLE_GRAPH'=>			'단순 그래프',
@@ -1045,25 +814,18 @@
 
 	'S_STYLE'=>				'표시 형식',
 	'S_VERTICAL'=>				'세로',
-	'S_HORISONTAL'=>			'가로',
+	'S_HORIZONTAL'=>			'가로',
 
-	'S_HORISONTAL_ALIGN'=>			'가로 위치',
-	'S_LEFT'=>				'왼쪽',
-	'S_CENTER'=>				'가운데',
+	'S_HORIZONTAL_ALIGN'=>			'가로 위치',
+	'S_CENTRE'=>				'가운데',
 	'S_RIGHT'=>				'오른쪽',
 
 	'S_VERTICAL_ALIGN'=>			'세로 위치',
-	'S_TOP'=>				'위쪽',
 	'S_MIDDLE'=>				'가운데',
-	'S_BOTTOM'=>				'아래쪽',
 
 //	screens.php
 	'S_CUSTOM_SCREENS'=>			'커스텀 스크린',
 	'S_SCREENS_BIG'=>			'스크린',
-	'S_NO_SCREENS_TO_DISPLAY'=>		'표시할 스크린이 없습니다',
-	'S_SELECT_SCREEN_TO_DISPLAY'=>		'표시할 스크린을 선택하십시오',
-	'S_SELECT_SCREEN_DOT_DOT_DOT'=>		'스크린 선택...',
-	'S_NO_SCREENS_DEFINED'=>		'스크린이 정의되어 있지 않습니다',
 
 	'S_SLIDESHOW_UPDATED'=>			'슬라이드쇼를 갱신하였습니다',
 	'S_CANNOT_UPDATE_SLIDESHOW'=>		'슬라이드쇼를 갱신할 수 없습니다',
@@ -1082,42 +844,20 @@
 	'S_CANNOT_UPDATE_SERVICE'=>		'서비스를 갱신할 수 없습니다',
 	'S_SERVICE_ADDED'=>			'서비스를 추가하였습니다',
 	'S_CANNOT_ADD_SERVICE'=>		'서비스를 추가할 수 없습니다',
-	'S_LINK_ADDED'=>			'연결을 추가하였습니다',
-	'S_CANNOT_ADD_LINK'=>			'연결을 추가할 수 없습니다',
 	'S_SERVICE_DELETED'=>			'서비스를 삭제하였습니다',
 	'S_CANNOT_DELETE_SERVICE'=>		'서비스를 삭제할 수 없습니다',
-	'S_LINK_DELETED'=>			'연결을 삭제하였습니다',
-	'S_CANNOT_DELETE_LINK'=>		'연결을 삭제할 수 없습니다',
 	'S_STATUS_CALCULATION'=>		'상태 계산',
 	'S_STATUS_CALCULATION_ALGORITHM'=>	'상태 계산 알고리즘',
 	'S_NONE'=>				'없음',
-	'S_MAX_OF_CHILDS'=>			'최대 자식 수',
-	'S_MIN_OF_CHILDS'=>			'최소 자식 수',
-	'S_SERVICE_1'=>				'서비스1',
-	'S_SERVICE_2'=>				'서비스2',
-	'S_SOFT_HARD_LINK'=>			'Soft/Hard 연결',
 	'S_SOFT'=>				'Soft',
-	'S_HARD'=>				'Hard',
 	'S_DO_NOT_CALCULATE'=>			'계산 안함',
-	'S_MAX_BIG'=>				'최대',
-	'S_MIN_BIG'=>				'최소',
-	'S_SHOW_SLA'=>				'SLA 표시',
 	'S_ACCEPTABLE_SLA_IN_PERCENT'=>		'SLA 허용 값(%)',
 	'S_LINK_TO_TRIGGER_Q'=>			'트리거와 연결',
 	'S_SORT_ORDER_0_999'=>			'정렬 순서(0->999)',
-	'S_DELETE_SERVICE_Q'=>			'서비스를 삭제하시겠습니까?',
-	'S_LINK_TO'=>				'연결 대상',
-	'S_SOFT_LINK_Q'=>			'Soft 연결',
-	'S_ADD_SERVER_DETAILS'=>		'서버 상세 정보 추가',
 	'S_TRIGGER'=>				'트리거',
 	'S_SERVER'=>				'서버',
 	'S_DELETE'=>				'삭제',
 	'S_CLONE'=>				'복제',
-	'S_DELETE_SELECTED'=>			'선택 항목 삭제',
-	'S_DELETE_SELECTED_SERVICES'=>		'선택한 서비스를 삭제하시겠습니까?',
-	'S_DELETE_SELECTED_LINKS'=>		'선택한 연결을 삭제하시겠습니까?',
-	'S_SERVICES_DELETED'=>			'서비스를 삭제하였습니다',
-	'S_CANNOT_DELETE_SERVICES'=>		'서비스를 삭제할 수 없습니다',
 	'S_UPTIME'=>				'가동 시간',
 	'S_DOWNTIME'=>				'정지 시간',
 	'S_ONE_TIME_DOWNTIME'=>			'일시적인 정지 시간',
@@ -1125,7 +865,6 @@
 	'S_SERVICE_TIMES'=>			'서비스 시간',
 	'S_NEW_SERVICE_TIME'=>			'새 서비스 시간',
 	'S_NOTE'=>				'설명',
-	'S_SOFT_LINK'=>				'Soft 연결',
 	'S_REMOVE'=>				'삭제',
 	'S_DEPENDS_ON'=>			'의존 대상',
 
@@ -1142,9 +881,6 @@
 	'S_SERVICE'=>				'서비스',
 	'S_SERVICES'=>				'서비스',
 	'S_REASON'=>				'이유',
-	'S_SLA_LAST_7_DAYS'=>			'SLA(최근 7일)',
-	'S_PLANNED_CURRENT_SLA'=>		'계획/현재 SLA',
-	'S_TRIGGER_BIG'=>			'트리거',
 
 //	triggers.php
 	'S_NO_TRIGGER'=>			'트리거가 없습니다',
@@ -1152,40 +888,25 @@
 	'S_NO_TRIGGER_DEFINED'=>		'트리거가 정의되어 있지 않습니다',
 	'S_CONFIGURATION_OF_TRIGGERS'=>		'트리거 설정',
 	'S_CONFIGURATION_OF_TRIGGERS_BIG'=>	'트리거 설정',
-	'S_DEPENDENCY_ADDED'=>			'Dependency added',
-	'S_CANNOT_ADD_DEPENDENCY'=>		'Cannot add dependency',
-	'S_TRIGGERS_UPDATED'=>			'트리거를 갱신하였습니다',
-	'S_CANNOT_UPDATE_TRIGGERS'=>		'트리거를 갱신할 수 없습니다',
-	'S_TRIGGERS_DISABLED'=>			'트리거를 비활성화하였습니다',
-	'S_CANNOT_DISABLE_TRIGGERS'=>		'트리거를 비활성화할 수 없습니다',
 	'S_TRIGGERS_DELETED'=>			'트리거를 삭제하였습니다',
 	'S_CANNOT_DELETE_TRIGGERS'=>		'트리거를 삭제할 수 없습니다',
 	'S_TRIGGER_DELETED'=>			'트리거를 삭제하였습니다',
 	'S_CANNOT_DELETE_TRIGGER'=>		'트리거를 삭제할 수 없습니다',
-	'S_INVALID_TRIGGER_EXPRESSION'=>	'트리거 표현이 적절하지 않습니다',
 	'S_TRIGGER_ADDED'=>			'트리거를 추가하였습니다',
 	'S_CANNOT_ADD_TRIGGER'=>		'트리거를 추가할 수 없습니다',
 	'S_SEVERITY'=>				'심각도',
 	'S_EXPRESSION'=>			'조건식',
 	'S_DISABLED'=>				'비활성',
 	'S_ENABLED'=>				'활성',
-	'S_DISABLE_SELECTED'=>			'선택 항목 비활성화',
 	'S_ENABLE_SELECTED'=>			'선택 항목 활성화',
-	'S_ENABLE_SELECTED_TRIGGERS_Q'=>	'선택한 트리거를 활성화하시겠습니까?',
-	'S_DISABLE_SELECTED_TRIGGERS_Q'=>	'선택한 트리거를 비활성화하시겠습니까?',
-	'S_DELETE_SELECTED_TRIGGERS_Q'=>	'선택한 트리거를 삭제하시겠습니까?',
 	'S_CHANGE'=>				'변경',
 	'S_TRIGGER_UPDATED'=>			'트리거를 갱신하였습니다',
 	'S_CANNOT_UPDATE_TRIGGER'=>		'트리거를 갱신할 수 없습니다',
-	'S_DEPENDS_ON'=>			'의존 대상',
 	'S_URL'=>				'URL',
-	'S_INVALID_URL'=>			'부적절한 URL',
 	'S_CREATE_TRIGGER'=>			'트리거 작성',
 	'S_INSERT'=>				'삽입',
-	'S_TIMES'=>				'Time',
 	'S_SECONDS'=>				'초',
 	'S_SEC_SMALL'=>				'초',
-	'S_COUNTS'=>				'Counts',
 	'S_LAST_OF'=>				'최근',
 	'S_SHOW_DISABLED_TRIGGERS'=>		'비활성 트리거 보이기',
 	'S_HIDE_DISABLED_TRIGGERS'=>		'비활성 트리거 감추기',
@@ -1204,19 +925,9 @@
 //	tr_status.php
 	'S_STATUS_OF_TRIGGERS'=>		'트리거 상태',
 	'S_STATUS_OF_TRIGGERS_BIG'=>		'트리거 상태',
-	'S_SHOW_ONLY_TRUE'=>			'장애만 보이기',
-	'S_HIDE_ACTIONS'=>			'액션 감추기',
-	'S_SHOW_ACTIONS'=>			'액션 보이기',
-	'S_SHOW_ALL_TRIGGERS'=>			'모든 트리거 보이기',
-	'S_HIDE_DETAILS'=>			'상세 감추기',
 	'S_SHOW_DETAILS'=>			'상세 보이기',
 	'S_SELECT'=>				'선택',
-	'S_INVERSE_SELECT'=>                    '반전 선택',
-	'S_HIDE_SELECT'=>			'선택 감추기',
 	'S_TRIGGERS_BIG'=>			'트리거',
-	'S_NAME_BIG'=>				'이름',
-	'S_SEVERITY_BIG'=>			'심각도',
-	'S_LAST_CHANGE_BIG'=>			'최근 갱신',
 	'S_LAST_CHANGE'=>			'최근 갱신',
 	'S_COMMENTS'=>				'주석',
 	'S_ACKNOWLEDGED'=>			'인지 완료',
@@ -1234,12 +945,7 @@
 	'S_CANNOT_ADD_USER_BOTH_PASSWORDS_MUST'=>'사용자를 추가할 수 없습니다. 암호가 일치하지 않습니다.',
 	'S_USER_DELETED'=>			'사용자를 삭제하였습니다',
 	'S_CANNOT_DELETE_USER'=>		'사용자를 삭제할 수 없습니다',
-	'S_PERMISSION_DELETED'=>		'권한을 삭제하였습니다',
-	'S_CANNOT_DELETE_PERMISSION'=>		'권한을 삭제할 수 없습니다',
-	'S_PERMISSION_ADDED'=>			'권한을 추가하였습니다',
-	'S_CANNOT_ADD_PERMISSION'=>		'권한을 추가할 수 없습니다',
 	'S_USER_UPDATED'=>			'사용자를 갱신하였습니다',
-	'S_ONLY_FOR_GUEST_ALLOWED_EMPTY_PASSWORD'=>	'guest 사용자만이 빈 암호를 가질 수 있습니다.',
 	'S_CANNOT_UPDATE_USER'=>		'사용자를 갱신할 수 없습니다',
 	'S_CANNOT_UPDATE_USER_BOTH_PASSWORDS'=>	'사용자를 갱신할 수 없습니다. 암호가 일치하지 않습니다.',
 	'S_GROUP_ADDED'=>			'그룹을 추가하였습니다',
@@ -1253,21 +959,14 @@
 	'S_USERS_BIG'=>				'사용자',
 	'S_USER_GROUPS'=>			'사용자 그룹',
 	'S_MEMBERS'=>				'구성원',
-	'S_TEMPLATES'=>				'템플릿',
-	'S_HOSTS_TEMPLATES_LINKAGE'=>		'Hosts/templates linkage',
-	'S_CONFIGURATION_OF_TEMPLATES_LINKAGE'=>'CONFIGURATION OF TEMPLATES LINKAGE',
-	'S_LINKED_TEMPLATES_BIG'=>		'LINKED TEMPLATES',
 	'S_NO_USER_GROUPS_DEFINED'=>		'사용자 그룹이 정의되어 있지 않습니다',
 	'S_ALIAS'=>				'로그인 이름',
 	'S_NAME'=>				'이름',
 	'S_SURNAME'=>				'성',
 	'S_IS_ONLINE_Q'=>			'로그인 상태',
 	'S_NO_USERS_DEFINED'=>			'사용자가 정의되어 있지 않습니다',
-	'S_PERMISSION'=>			'권한',
-	'S_RIGHT'=>				'오른쪽',
 	'S_RIGHTS'=>				'권한',
 	'S_NO_RIGHTS_DEFINED'=>			'권한이 정의되어 있지 않습니다',
-	'S_RESOURCE_NAME'=>			'Resource name',
 	'S_READ_ONLY'=>				'읽기 전용',
 	'S_READ_WRITE'=>			'쓰기 가능',
 	'S_DENY'=>				'거부',
@@ -1276,7 +975,6 @@
 	'S_CHANGE_PASSWORD'=>			'암호변경',
 	'S_PASSWORD_ONCE_AGAIN'=>		'암호 확인',
 	'S_URL_AFTER_LOGIN'=>			'로그인 후 URL',
-	'S_AUTO_LOGOUT_IN_SEC'=>		'자동 로그아웃(초)',
 	'S_SCREEN_REFRESH'=>                    '새로 고침(초)',
 	'S_CREATE_USER'=>			'사용자 작성',
 	'S_CREATE_GROUP'=>			'그룹 작성',
@@ -1284,15 +982,11 @@
 	'S_NO_ACCESSIBLE_RESOURCES'=>		'사용할 수 있는 리소스가 없습니다',
 
 //	audit.php
-	'S_AUDIT_LOG'=>				'감사 로그',
-	'S_AUDIT_LOG_BIG'=>			'감사 로그',
 	'S_ACTION'=>				'액션',
 	'S_DETAILS'=>				'자세히',
 	'S_UNKNOWN_ACTION'=>			'알 수 없는 액션',
 	'S_ADDED'=>				'추가',
 	'S_UPDATED'=>				'갱신',
-	'S_LOGGED_IN'=>				'로그인',
-	'S_LOGGED_OUT'=>			'로그아웃',
 	'S_MEDIA_TYPE'=>			'연락 방법',
 	'S_GRAPH_ELEMENT'=>			'그래프 구성요소',
 	'S_UNKNOWN_RESOURCE'=>			'알 수 없는 리소스',
@@ -1314,7 +1008,6 @@
 	'S_CHINESE_CN'=>			'중국어 (CN)',
 	'S_DUTCH_NL'=>				'네덜란드어 (NL)',
 	'S_HUNGARY_HU'=>                        '헝가리어 (HU)',
-	'S_KOREAN_KR'=>				'한국어 (KR)',
 
 //	index.php
 	'S_ZABBIX_BIG'=>			'ZABBIX',
