@@ -1,5 +1,5 @@
 <?php
-/* 
+/*
 ** ZABBIX
 ** Copyright (C) 2000-2008 SIA Zabbix
 **
@@ -43,11 +43,7 @@
 	'S_CONFIGURATION_OF_DISCOVERY_BIG'=>			'CONFIGURAÇÃO DA AUTO BUSCA',
 	'S_NO_DISCOVERY_RULES_DEFINED'=>			'Não há regras',
 	'S_IP_RANGE'=>			'Intervalo de IPs',
-	'S_INTERVALS'=>			'Intervalos',
 	'S_CHECKS'=>			'Checagens',
-	'S_ENABLE_SELECTED_RULES_Q'=>			'Habilitar regras selecionadas?',
-	'S_DISABLE_SELECTED_RULES_Q'=>			'Desabilitar regras selecionadas?',
-	'S_DELETE_SELECTED_RULES_Q'=>			'Remover regras selecionadas?',
 	'S_CREATE_RULE'=>			'Criar Regra',
 	'S_DELETE_RULE_Q'=>			'Remover regra?',
 	'S_EVENT_SOURCE'=>			'Origem do evento',
@@ -100,11 +96,7 @@
 	'S_SCENARIO_DELETED'=>			'Cenário removido',
 	'S_SCENARIO_ACTIVATED'=>			'Cenário ativado',
 	'S_SCENARIO_DISABLED'=>			'Cenário desabilitado',
-	'S_ACTIVATE_SELECTED_SCENARIOS_Q'=>			'Ativar cenários selecionados?',
-	'S_DISABLE_SELECTED_SCENARIOS_Q'=>			'Desabilitar cenários selecionados?',
-	'S_DELETE_SELECTED_SCENARIOS_Q'=>			'Remover cenários selecionados?',
 	'S_DELETE_SCENARIO_Q'=>			'Remover cenário?',
-	'S_CLEAN_HISTORY_SELECTED_SCENARIOS'=>			'Zerar histórico cenários selecionados',
 	'S_SCENARIO_UPDATED'=>			'Cenário atualizado',
 	'S_CANNOT_UPDATE_SCENARIO'=>			'Cenário não foi atualizado',
 	'S_SCENARIO_ADDED'=>			'Cenário adicionado',
@@ -125,16 +117,12 @@
 	'S_IMPORT_FILE'=>			'Importar arquivo',
 	'S_IMPORT'=>			'Importar',
 	'S_IMPORT_BIG'=>			'IMPORTAR',
-	'S_IMPORT_HOSTS'=>			'Importar hosts',
-	'S_IMPORT_HOSTS_BIG'=>			'IMPORTAR HOSTS',
 	'S_EXPORT'=>			'Exportar',
-	'S_EXPORT_FILE'=>			'Exportar arquivo',
 	'S_EXPORT_BIG'=>			'EXPORTAR',
 	'S_PREVIEW'=>			'Visualizar',
 	'S_BACK'=>			'Atrás',
 	'S_NO_DATA_FOR_EXPORT'=>			'Não há dados para exportar',
 	'S_RULES'=>			'Regras',
-	'S_SKIP'=>			'Pular',
 	'S_EXISTING'=>			'Existente',
 	'S_MISSING'=>			'Esperado',
 	'S_REFRESH'=>			'Atualizar',
@@ -152,7 +140,7 @@
 	'S_DO_NOT_KEEP_HISTORY_OLDER_THAN'=>			'Não manter no histórico mais do que (dias)',
 	'S_DO_NOT_KEEP_TRENDS_OLDER_THAN'=>			'Não arquivar trends mais do que (dias)',
 	'S_MASTER_NODE'=>			'Nodo mestre',
-	'S_REMOTE'=>			'Remoto',
+	'S_CHILD'=>			'Remoto',
 	'S_MASTER'=>			'Mestre',
 	'S_NODE_UPDATED'=>			'Nodo atualizado',
 	'S_CANNOT_UPDATE_NODE'=>			'Nodo não foi atualizado',
@@ -161,31 +149,19 @@
 	'S_NODE_DELETED'=>			'Node removido',
 	'S_CANNOT_DELETE_NODE'=>			'Não não foi removido',
 	'S_CURRENT_NODE'=>			'Nodo atual',
-	'S_CURRENT_NODE_ONLY'=>			'Nodo atual somente',
-	'S_WITH_SUBNODES'=>			'Com subnodos',
 	'S_ACKNOWLEDGES'=>			'Vistos',
 	'S_ACKNOWLEDGE'=>			'Visto',
 	'S_ACKNOWLEDGE_ALARM_BY'=>			'Alarme visto por',
 	'S_ADD_COMMENT_BY'=>			'Comentário incluído por',
-	'S_COMMENT_ADDED'=>			'Comentário incluído',
-	'S_CANNOT_ADD_COMMENT'=>			'Comentário não foi adicionado',
 	'S_ALARM_ACKNOWLEDGES_BIG'=>			'VISTOS DADOS EM ALARMES',
 	'S_ACKNOWLEDGE_ADDED'=>			'Visto incluído',
 	'S_CONFIGURATION_OF_ACTIONS'=>			'Configuração de ações',
 	'S_CONFIGURATION_OF_ACTIONS_BIG'=>			'CONFIGURAÇÃO DE AÇÕES',
-	'S_FILTER_HOST_GROUP'=>			'Filtro: Grupo de Servidores',
-	'S_FILTER_HOST'=>			'Filtro: Servidor',
-	'S_FILTER_TRIGGER'=>			'Filtro: Trigger',
-	'S_FILTER_TRIGGER_NAME'=>			'Filtro: Nome da trigger',
-	'S_FILTER_TRIGGER_SEVERITY'=>			'Filtro: Risco da trigger',
-	'S_FILTER_WHEN_TRIGGER_BECOMES'=>			'Filtro: Quando a trigger ativar',
 	'S_OPERATION_TYPE'=>			'Tipo da operação',
 	'S_SEND_MESSAGE'=>			'Enviar mensagem',
 	'S_REMOTE_COMMAND'=>			'Comando remoto',
 	'S_REMOTE_COMMANDS'=>			'Comandos remotos',
 	'S_FILTER'=>			'Filtro',
-	'S_FILTER_TYPE'=>			'Filtro tipo',
-	'S_TRIGGER_NAME'=>			'Nome da trigger',
 	'S_TRIGGER_SEVERITY'=>			'Risco da trigger',
 	'S_TRIGGER_VALUE'=>			'Valor da trigger',
 	'S_TIME_PERIOD'=>			'Intervalo',
@@ -194,8 +170,6 @@
 	'S_CONDITION'=>			'Condição',
 	'S_NEW_CONDITION'=>			'Nova condição',
 	'S_OPERATIONS'=>			'Ações',
-	'S_OPERATION'=>			'Ação',
-	'S_NEW_OPERATION'=>			'Nova ação',
 	'S_EDIT_OPERATION'=>			'Editar ação',
 	'S_NO_CONDITIONS_DEFINED'=>			'Nenhuma condição',
 	'S_ACTIONS_DELETED'=>			'Ações removidas',
@@ -224,10 +198,8 @@
 	'S_CANNOT_UPDATE_ACTION'=>			'Ação não foi atualizada',
 	'S_ACTION_DELETED'=>			'Ação removida',
 	'S_CANNOT_DELETE_ACTION'=>			'Ação não foi removida',
-	'S_SCOPE'=>			'Escopo',
 	'S_SEND_MESSAGE_TO'=>			'Enviar mensagem para',
 	'S_RUN_REMOTE_COMMANDS'=>			'Rodar comandos remotos',
-	'S_WHEN_TRIGGER'=>			'Quando a trigger',
 	'S_DELAY'=>			'Espera',
 	'S_SUBJECT'=>			'Assunto',
 	'S_ON'=>			'ATIVO',
@@ -237,14 +209,7 @@
 	'S_USER_GROUP'=>			'Grupo de usuários',
 	'S_GROUP'=>			'Grupo',
 	'S_USER'=>			'Usuário',
-	'S_ON_OR_OFF'=>			'ATIVO ou INATIVO',
-	'S_DELAY_BETWEEN_MESSAGES_IN_SEC'=>			'Tempo entre mensagens (em seg)',
-	'S_DELAY_BETWEEN_EXECUTIONS_IN_SEC'=>			'Tempo entre execuções (em seg)',
 	'S_MESSAGE'=>			'Mensagem',
-	'S_THIS_TRIGGER_ONLY'=>			'Somente esta trigger',
-	'S_ALL_TRIGGERS_OF_THIS_HOST'=>			'Todas as trigers deste host',
-	'S_ALL_TRIGGERS'=>			'Todas triggers',
-	'S_USE_IF_TRIGGER_SEVERITY'=>			'Usar se o risco da trigger for maior ou igual a',
 	'S_NOT_CLASSIFIED'=>			'Não classificada',
 	'S_INFORMATION'=>			'Informação',
 	'S_WARNING'=>			'Advertência',
@@ -258,73 +223,29 @@
 	'S_OR'=>			'ou',
 	'S_TYPE_OF_CALCULATION'=>			'Tipo do cálculo',
 	'S_CREATE_ACTION'=>			'Criar ação',
-	'S_ENABLE_SELECTED_ACTIONS_Q'=>			'Habilitar ações selecionadas?',
-	'S_DISABLE_SELECTED_ACTIONS_Q'=>			'Desativar ações selecionadas?',
-	'S_DELETE_SELECTED_ACTIONS_Q'=>			'Remover ações selecionadas?',
 	'S_DELETE_SELECTED_ACTION_Q'=>			'Remover ação selecionada?',
 	'S_LIKE_SMALL'=>			'como',
 	'S_NOT_LIKE_SMALL'=>			'diferente',
 	'S_IN_SMALL'=>			'em',
 	'S_NOT_IN_SMALL'=>			'não em',
-	'S_ALARMS'=>			'Alarmes',
-	'S_ALARMS_SMALL'=>			'Alarmes',
-	'S_ALARMS_BIG'=>			'ALARMES',
-	'S_SHOW_ONLY_LAST_100'=>			'Mostrar últimos 100',
 	'S_SHOW_ALL'=>			'Mostrar todos',
 	'S_TIME'=>			'Data',
 	'S_STATUS'=>			'Status',
 	'S_DURATION'=>			'Duração',
-	'S_SUM'=>			'Soma',
 	'S_TRUE_BIG'=>			'VERD',
 	'S_FALSE_BIG'=>			'FALSO',
-	'S_DISABLED_BIG'=>			'DESABILITADO',
 	'S_UNKNOWN_BIG'=>			'DESCONHECIDO',
-	'S_HISTORY_OF_ACTIONS_BIG'=>			'HISTÓRICO DAS AÇÕES',
-	'S_LATEST_ACTIONS'=>			'Últimas ações',
-	'S_ALERTS_BIG'=>			'ALERTAS',
 	'S_TYPE'=>			'Tipo',
 	'S_RECIPIENTS'=>			'Destinatário(s)',
 	'S_ERROR'=>			'Erro',
 	'S_SENT'=>			'enviado',
 	'S_NOT_SENT'=>			'não enviado',
 	'S_NO_ACTIONS_FOUND'=>			'Nenhuma ação encontrada',
-	'S_SHOW_NEXT_100'=>			'Próximos 100',
-	'S_SHOW_PREVIOUS_100'=>			'100 anteriores',
 	'S_CUSTOM_GRAPHS'=>			'Gráficos personalizados',
 	'S_GRAPHS_BIG'=>			'GRÁFICOS',
-	'S_NO_GRAPHS_TO_DISPLAY'=>			'Nenhum gráfico',
 	'S_SELECT_GRAPH_TO_DISPLAY'=>			'Selecione gráfico',
 	'S_PERIOD'=>			'Período',
-	'S_1H'=>			'1h',
-	'S_2H'=>			'2h',
-	'S_4H'=>			'4h',
-	'S_8H'=>			'8h',
-	'S_12H'=>			'12h',
-	'S_24H'=>			'24h',
-	'S_WEEK_SMALL'=>			'semana',
-	'S_MONTH_SMALL'=>			'mês',
-	'S_YEAR_SMALL'=>			'ano',
-	'S_KEEP_PERIOD'=>			'Manter período',
-	'S_ON_C'=>			'Ligado',
-	'S_OFF_C'=>			'Desligado',
-	'S_MOVE'=>			'Mover',
-	'S_NAVIGATE'=>			'Navegar',
-	'S_INCREASE'=>			'Aumentar',
-	'S_DECREASE'=>			'Decrementar',
-	'S_RIGHT_DIR'=>			'Direita',
-	'S_LEFT_DIR'=>			'Esquerda',
 	'S_SELECT_GRAPH_DOT_DOT_DOT'=>			'Selecione gráfico...',
-	'S_BLACK'=>			'Preto',
-	'S_BLUE'=>			'Azul',
-	'S_CYAN'=>			'Ciano',
-	'S_DARK_BLUE'=>			'Azul escuro',
-	'S_DARK_GREEN'=>			'Verde escuro',
-	'S_DARK_RED'=>			'Vermelho escuro',
-	'S_DARK_YELLOW'=>			'Amarelo',
-	'S_GREEN'=>			'Verde',
-	'S_RED'=>			'Vermelho',
-	'S_WHITE'=>			'Branco',
-	'S_YELLOW'=>			'Amarelo claro',
 	'S_CANNNOT_UPDATE_VALUE_MAP'=>			'Mapeamento não foi atualizado',
 	'S_VALUE_MAP_ADDED'=>			'Mapeamento de valor incluído',
 	'S_CANNNOT_ADD_VALUE_MAP'=>			'Mapeamento de valor não foi incluído',
@@ -363,28 +284,8 @@
 	'S_MEDIA_TYPES'=>			'Tipos de mídias',
 	'S_ESCALATION_RULES'=>			'Regras de escalonamento',
 	'S_ESCALATION'=>			'Escalonamento',
-	'S_ESCALATION_RULES_BIG'=>			'REGRAS DE ESCALONAMENTO',
-	'S_NO_ESCALATION_RULES_DEFINED'=>			'Nenhuma regra definida',
-	'S_NO_ESCALATION_DETAILS'=>			'Nenhum detalhamento',
-	'S_ESCALATION_DETAILS_BIG'=>			'DETALHAMENTO DE ESCALONAMENTO',
-	'S_ESCALATION_ADDED'=>			'Escalonamento incluído',
-	'S_ESCALATION_WAS_NOT_ADDED'=>			'Escalonamento não foi incluído',
-	'S_ESCALATION_RULE_ADDED'=>			'Regra de escalonamento incluída',
-	'S_ESCALATION_RULE_WAS_NOT_ADDED'=>			'Regra não foi incluída',
-	'S_ESCALATION_RULE_UPDATED'=>			'Regra de escalonamento atualizada',
-	'S_ESCALATION_RULE_WAS_NOT_UPDATED'=>			'Regra não foi atualizada',
-	'S_ESCALATION_RULE_DELETED'=>			'Regra de escalonamento removida',
-	'S_ESCALATION_RULE_WAS_NOT_DELETED'=>			'Regra de escalonamento não foi removida',
-	'S_ESCALATION_UPDATED'=>			'Escalonamento atualizado',
-	'S_ESCALATION_WAS_NOT_UPDATED'=>			'Escalonamento não foi atualizado',
-	'S_ESCALATION_DELETED'=>			'Escalonamento removido',
-	'S_ESCALATION_WAS_NOT_DELETED'=>			'Escalonamento não foi removido',
 	'S_ESCALATION_RULE'=>			'Regra de escalonamento',
-	'S_DO'=>			'Executar',
 	'S_DEFAULT'=>			'Default',
-	'S_IS_DEFAULT'=>			'É default',
-	'S_LEVEL'=>			'Nível',
-	'S_DELAY_BEFORE_ACTION'=>			'Espera antes da ação',
 	'S_IMAGES'=>			'Imagens',
 	'S_IMAGE'=>			'Imagem',
 	'S_IMAGES_BIG'=>			'IMAGENS',
@@ -398,9 +299,6 @@
 	'S_CANNOT_DELETE_IMAGE'=>			'Imagem não foi removida',
 	'S_IMAGE_UPDATED'=>			'Imagem atualizada',
 	'S_CANNOT_UPDATE_IMAGE'=>			'Imagem não foi atualizada',
-	'S_UPDATE_SELECTED_IMAGE'=>			'Atualizar imagem selecionada?',
-	'S_PRIORITY'=>			'Prioridade',
-	'S_PATTERN'=>			'Padrão',
 	'S_OTHER'=>			'Outro',
 	'S_OTHER_PARAMETERS'=>			'Outros parâmetros',
 	'S_REFRESH_UNSUPPORTED_ITEMS'=>			'Atualizar itens não suportados (em segundos)',
@@ -410,40 +308,28 @@
 	'S_USER_GROUP_FOR_DATABASE_DOWN_MESSAGE'=>			'Grupo de usuários que receberá a mensagem de BD indisponível',
 	'S_INCORRECT_GROUP'=>			'Grupo incorreto',
 	'S_NOTHING_TO_DO'=>			'Nada a ser feito',
-	'S_ICORRECT_WORK_PERIOD'=>			'Período de trabalho incorreto',
+	'S_INCORRECT_WORK_PERIOD'=>			'Período de trabalho incorreto',
 	'S_NODE'=>			'Nodo',
 	'S_NODES'=>			'Nodos',
 	'S_NODES_BIG'=>			'NODOS',
 	'S_NEW_NODE'=>			'Novo nodo',
 	'S_NO_NODES_DEFINED'=>			'Não há nodos',
-	'S_LATEST_VALUES'=>			'Valores recentes',
 	'S_NO_PERMISSIONS'=>			'Não tem permissão!',
 	'S_LATEST_DATA_BIG'=>			'DADOS RECENTES',
 	'S_ALL_SMALL'=>			'todos',
 	'S_MINUS_ALL_MINUS'=>			'- todos -',
 	'S_MINUS_OTHER_MINUS'=>			'- outro -',
-	'S_DESCRIPTION_LARGE'=>			'DESCRIÇÃO',
-	'S_DESCRIPTION_SMALL'=>			'Descrição',
 	'S_GRAPH'=>			'Gráfico',
-	'S_TREND'=>			'Trend',
-	'S_COMPARE'=>			'Comparar',
 	'S_CONNECTED_AS'=>			'Conectado como',
-	'S_SIA_ZABBIX'=>			'',
-	'S_CONFIGURATION_OF_GRAPH'=>			'Configuração de gráficos',
-	'S_CONFIGURATION_OF_GRAPH_BIG'=>			'CONFIGURAÇÃO DE GRÁFICOS',
 	'S_ITEM_ADDED'=>			'Item incluído',
 	'S_ITEM_UPDATED'=>			'Item atualizada',
 	'S_ITEMS_UPDATED'=>			'Ítens atualizados',
-	'S_SORT_ORDER_UPDATED'=>			'Ordem atualizada',
-	'S_CANNOT_UPDATE_SORT_ORDER'=>			'Ordem não foi atualizada',
-	'S_DISPLAYED_PARAMETERS_BIG'=>			'PARÂMETROS MOSTRADOS',
-	'S_SORT_ORDER'=>			'Ordem',
 	'S_PARAMETER'=>			'Parâmetro',
 	'S_COLOR'=>			'Cor',
 	'S_UP'=>			'Acima',
 	'S_DOWN'=>			'Abaixo',
 	'S_NEW_ITEM_FOR_THE_GRAPH'=>			'Novo item de gráfico',
-	'S_SORT_ORDER_1_100'=>			'Posição (0->100)',
+	'S_SORT_ORDER_0_100'=>			'Posição (0->100)',
 	'S_YAXIS_SIDE'=>			'Eixo Y',
 	'S_LEFT'=>			'Esquerda',
 	'S_FUNCTION'=>			'Função',
@@ -469,7 +355,6 @@
 	'S_NO_GRAPHS_DEFINED'=>			'Nenhum gráfico',
 	'S_NO_GRAPH_DEFINED'=>			'Nenhum gráfico',
 	'S_DELETE_GRAPH_Q'=>			'Remover gráfico?',
-	'S_YAXIS_TYPE'=>			'Tipo no eixo Y',
 	'S_YAXIS_MIN_VALUE'=>			'Valor MÍNIMO no eixo Y',
 	'S_YAXIS_MAX_VALUE'=>			'Valor MÁXIMO no eixo Y',
 	'S_CALCULATED'=>			'Calculado',
@@ -482,15 +367,10 @@
 	'S_LAST_HOUR_GRAPH'=>			'Gráfico última hora',
 	'S_LAST_WEEK_GRAPH'=>			'Gráfico última semana',
 	'S_LAST_MONTH_GRAPH'=>			'Gráfico último mês',
-	'S_VALUES_OF_LAST_HOUR'=>			'Valores última hora',
 	'S_500_LATEST_VALUES'=>			'Últimos 500 valores',
-	'S_GRAPH_OF_SPECIFIED_PERIOD'=>			'Gráfico do período dado',
-	'S_VALUES_OF_SPECIFIED_PERIOD'=>			'Valores do período dado',
-	'S_VALUES_IN_PLAIN_TEXT_FORMAT'=>			'Valores em texto puro',
 	'S_TIMESTAMP'=>			'Hora',
 	'S_LOCAL'=>			'Local',
 	'S_SOURCE'=>			'Origem',
-	'S_SHOW_UNKNOWN'=>			'Mostrar desconhecido',
 	'S_SHOW_SELECTED'=>			'Mostrar selecionados',
 	'S_HIDE_SELECTED'=>			'Esconder selecionados',
 	'S_MARK_SELECTED'=>			'Marcar selecionados',
@@ -502,11 +382,8 @@
 	'S_APPLICATIONS'=>			'Aplicações',
 	'S_APPLICATIONS_BIG'=>			'APPLICAÇÃO',
 	'S_CREATE_APPLICATION'=>			'Criar aplicação',
-	'S_DELETE_SELECTED_APPLICATIONS_Q'=>			'Remover aplicação selecionada?',
-	'S_DISABLE_ITEMS_FROM_SELECTED_APPLICATIONS_Q'=>			'Desabilitar ítens das aplicações  selecionadas?',
 	'S_ACTIVATE_ITEMS'=>			'Ativar Ítens',
 	'S_DISABLE_ITEMS'=>			'Desabilitar Ítens',
-	'S_ACTIVATE_ITEMS_FROM_SELECTED_APPLICATIONS_Q'=>			'Ativar os ítens das aplicações selecionadas?',
 	'S_APPLICATION_UPDATED'=>			'Aplicação atualizada',
 	'S_CANNOT_UPDATE_APPLICATION'=>			'Aplicação não foi atualizada',
 	'S_APPLICATION_ADDED'=>			'Aplicação incluída',
@@ -521,40 +398,25 @@
 	'S_GRAPHS'=>			'Gráficos',
 	'S_HOST_ADDED'=>			'Host incluído',
 	'S_CANNOT_ADD_HOST'=>			'Host não foi incluído',
-	'S_ITEMS_ADDED'=>			'Ítens incluídos',
-	'S_CANNOT_ADD_ITEMS'=>			'Ítens não foram incluídos',
 	'S_HOST_UPDATED'=>			'Host atualizado',
 	'S_CANNOT_UPDATE_HOST'=>			'Host não foi atualizado',
 	'S_HOST_STATUS_UPDATED'=>			'Status do host atualizado',
 	'S_CANNOT_UPDATE_HOST_STATUS'=>			'Status do host não foi atualizado',
 	'S_HOST_DELETED'=>			'Host removido',
 	'S_CANNOT_DELETE_HOST'=>			'Host não foi removido',
-	'S_TEMPLATE_LINKAGE_ADDED'=>			'Associação a template incluída',
-	'S_CANNOT_ADD_TEMPLATE_LINKAGE'=>			'Associação a template não foi incluída',
-	'S_TEMPLATE_LINKAGE_UPDATED'=>			'Associação a template atualizada',
-	'S_CANNOT_UPDATE_TEMPLATE_LINKAGE'=>			'Associação a template não foi atualizada',
-	'S_TEMPLATE_LINKAGE_DELETED'=>			'Associação a template removida',
-	'S_CANNOT_DELETE_TEMPLATE_LINKAGE'=>			'Associação a template não foi removida',
-	'S_CONFIGURATION_OF_HOSTS_GROUPS_AND_TEMPLATES'=>			'CONFIGURAÇÃO DE HOSTS, GRUPOS E TEMPLATES',
 	'S_HOST_GROUPS_BIG'=>			'GRUPOS DE HOSTS',
-	'S_START'=>			'Iniciar',
-	'S_STOP'=>			'Parar',
 	'S_NO_HOST_GROUPS_DEFINED'=>			'Nenhum grupo definido',
-	'S_NO_LINKAGES_DEFINED'=>			'Nenhuma associação',
 	'S_NO_HOSTS_DEFINED'=>			'Nenhum host',
 	'S_NO_TEMPLATES_DEFINED'=>			'Nenhuma templates',
 	'S_HOSTS_BIG'=>			'HOSTS',
 	'S_HOST'=>			'Host',
-	'S_HOST_BIG'=>			'HOST',
 	'S_CONNECT_TO'=>			'Connectado a',
 	'S_DNS'=>			'DNS',
 	'S_IP'=>			'IP',
 	'S_PORT'=>			'Porta',
 	'S_MONITORED'=>			'Monitorado',
 	'S_NOT_MONITORED'=>			'Não monitorado',
-	'S_UNREACHABLE'=>			'Inacessível',
 	'S_TEMPLATE'=>			'Template',
-	'S_TEMPLATE_SMALL'=>			'template',
 	'S_DELETED'=>			'Removido',
 	'S_UNKNOWN'=>			'Desconhecido',
 	'S_GROUPS'=>			'Grupos',
@@ -565,8 +427,6 @@
 	'S_LINK_WITH_TEMPLATE'=>			'Associar a Template',
 	'S_USE_PROFILE'=>			'Usar inventário',
 	'S_DELETE_SELECTED_HOST_Q'=>			'Remover host selecionado?',
-	'S_DELETE_SELECTED_GROUP_Q'=>			'Remover grupo selecionado?',
-	'S_DELETE_SELECTED_GROUPS_Q'=>			'Remover grupos selecionados?',
 	'S_DELETE_SELECTED_WITH_LINKED_ELEMENTS'=>			'Remover selecionado e elementos associados',
 	'S_GROUP_NAME'=>			'Nome do Grupo',
 	'S_HOST_GROUP'=>			'Grupo de Hosts',
@@ -586,36 +446,23 @@
 	'S_LOCATION'=>			'Local',
 	'S_NOTES'=>			'Notas',
 	'S_MACADDRESS'=>			'Endereço MAC',
-	'S_PROFILE_ADDED'=>			'Inventário incluído',
-	'S_CANNOT_ADD_PROFILE'=>			'Inventário não foi incluído',
-	'S_PROFILE_UPDATED'=>			'Inventário atualizado',
-	'S_CANNOT_UPDATE_PROFILE'=>			'Inventário não foi atualizado',
-	'S_PROFILE_DELETED'=>			'Inventário removido',
-	'S_CANNOT_DELETE_PROFILE'=>			'Inventário não foi removido',
 	'S_ADD_TO_GROUP'=>			'Adicionar ao grupo',
 	'S_DELETE_FROM_GROUP'=>			'Remover do grupo',
 	'S_UPDATE_IN_GROUP'=>			'Atualizar no grupo',
 	'S_DELETE_SELECTED_HOSTS_Q'=>			'Remover hosts selecionados?',
-	'S_DISABLE_SELECTED_HOSTS_Q'=>			'Desabilitar hosts selecionados?',
-	'S_ACTIVATE_SELECTED_HOSTS_Q'=>			'Ativar hosts selecionados?',
-	'S_SELECT_HOST_TEMPLATE_FIRST'=>			'Selecionar template do host primeiro',
 	'S_CREATE_HOST'=>			'Criar Host',
 	'S_CREATE_TEMPLATE'=>			'Criar Template',
 	'S_TEMPLATE_LINKAGE'=>			'Associação a templates',
-	'S_TEMPLATE_LINKAGE_BIG'=>			'ASSOCIAÇÃO A TEMPLATES',
-	'S_NO_LINKAGES'=>			'Nenhuma associação',
 	'S_TEMPLATES'=>			'Templates',
 	'S_TEMPLATES_BIG'=>			'TEMPLATES',
 	'S_UNLINK'=>			'Desassociar',
 	'S_UNLINK_AND_CLEAR'=>			'Desassociar e limpar',
-	'S_UNLINKED_SMALL'=>			'desassociado',
-	'S_CLEANED_SMALL'=>			'limpo',
 	'S_NO_ITEMS_DEFINED'=>			'Nenhum item definido',
 	'S_NO_ITEM_DEFINED'=>			'Nenhum item  definido',
-	'S_HISTORY_CLEANED'=>			'Histórico zerado',
-	'S_CLEAN_HISTORY_SELECTED_ITEMS'=>			'Zerar histórico dos ítens selecionados',
-	'S_CLEAN_HISTORY'=>			'Zerar histórico',
-	'S_CANNOT_CLEAN_HISTORY'=>			'Histórico não foi zerado',
+	'S_HISTORY_CLEARED'=>			'Histórico zerado',
+	'S_CLEAR_HISTORY_FOR_SELECTED'=>			'Zerar histórico dos ítens selecionados',
+	'S_CLEAR_HISTORY'=>			'Zerar histórico',
+	'S_CANNOT_CLEAR_HISTORY'=>			'Histórico não foi zerado',
 	'S_CONFIGURATION_OF_ITEMS'=>			'Configuração de ítens',
 	'S_CONFIGURATION_OF_ITEMS_BIG'=>			'CONFIGURAÇÃO DE ÍTENS',
 	'S_CANNOT_UPDATE_ITEM'=>			'Item não foi atualizado',
@@ -627,16 +474,12 @@
 	'S_ITEMS_DELETED'=>			'Ítens removidos',
 	'S_CANNOT_DELETE_ITEMS'=>			'Ítens não foram removidos',
 	'S_ITEMS_ACTIVATED'=>			'Ítens ativados',
-	'S_CANNOT_ACTIVATE_ITEMS'=>			'Ítens não foram ativados',
 	'S_ITEMS_DISABLED'=>			'Ítens desativados',
-	'S_CANNOT_DISABLE_ITEMS'=>			'Ítens não foram desativados',
-	'S_SERVERNAME'=>			'Nome do servidor',
 	'S_KEY'=>			'Chave',
 	'S_DESCRIPTION'=>			'Descrição',
 	'S_UPDATE_INTERVAL'=>			'Intervalo de atualização',
 	'S_HISTORY'=>			'Histórico',
 	'S_TRENDS'=>			'Estatísticas',
-	'S_SHORT_NAME'=>			'Nome curto',
 	'S_ZABBIX_AGENT'=>			'Agente ZABBIX',
 	'S_ZABBIX_AGENT_ACTIVE'=>			'Agente ZABBIX (ativo)',
 	'S_SNMPV1_AGENT'=>			'Agente SNMPv1',
@@ -648,13 +491,8 @@
 	'S_ZABBIX_AGGREGATE'=>			'ZABBIX agregado',
 	'S_EXTERNAL_CHECK'=>			'Monitoramento externo',
 	'S_WEB_MONITORING'=>			'Monitoramento Web',
-	'S_ZABBIX_UNKNOWN'=>			'Desconhecido',
 	'S_ACTIVE'=>			'Ativo',
-	'S_NOT_ACTIVE'=>			'Inativo',
 	'S_NOT_SUPPORTED'=>			'Não suportado',
-	'S_ACTIVATE_SELECTED_ITEMS_Q'=>			'Ativar ítens selecionados?',
-	'S_DISABLE_SELECTED_ITEMS_Q'=>			'Desativar ítens selecionados?',
-	'S_DELETE_SELECTED_ITEMS_Q'=>			'Remover ítens selecionados?',
 	'S_EMAIL'=>			'Email',
 	'S_JABBER'=>			'Jabber',
 	'S_JABBER_IDENTIFIER'=>			'Identificador Jabber',
@@ -662,7 +500,6 @@
 	'S_SCRIPT'=>			'Script',
 	'S_GSM_MODEM'=>			'Modem GSM',
 	'S_UNITS'=>			'Unidades',
-	'S_MULTIPLIER'=>			'Multiplicador',
 	'S_UPDATE_INTERVAL_IN_SEC'=>			'Intervalo atualização (em seg)',
 	'S_KEEP_HISTORY_IN_DAYS'=>			'Manter histórico (em dias)',
 	'S_KEEP_TRENDS_IN_DAYS'=>			'Manter estatísticas (em dias)',
@@ -692,7 +529,6 @@
 	'S_SELECT_HOST_DOT_DOT_DOT'=>			'Selecione host...',
 	'S_LOG_TIME_FORMAT'=>			'Formato da data no log',
 	'S_CREATE_ITEM'=>			'Criar Item',
-	'S_ADD_ITEM'=>			'Adicionar Item',
 	'S_X_ELEMENTS_COPY_TO_DOT_DOT_DOT'=>			'elementos a copiar para ...',
 	'S_MODE'=>			'Modo',
 	'S_TARGET'=>			'Destino',
@@ -701,15 +537,9 @@
 	'S_UPDATE_EXISTING_NON_LINKED_ITEMS'=>			'atualizar ítens não associados',
 	'S_COPY'=>			'Copiar',
 	'S_SHOW_ITEMS_WITH_DESCRIPTION_LIKE'=>			'Mostrar ítens com a descrição',
-	'S_SHOW_DISABLED_ITEMS'=>			'Mostrar ítens desativados',
-	'S_HIDE_DISABLED_ITEMS'=>			'Esconder  ítens desativados',
-	'S_HISTORY_CLEANING_CAN_TAKE_A_LONG_TIME_CONTINUE_Q'=>			'Zerar o histórico pode levar um tempo bem longo. Continuar?',
-	'S_ITEM_SELECTION'=>			'Seleção de item',
-	'S_SELECTION_MODE'=>			'Modo de seleção',
-	'S_ADVANCED'=>			'Avançado',
+	'S_HISTORY_CLEARING_CAN_TAKE_A_LONG_TIME_CONTINUE_Q'=>			'Zerar o histórico pode levar um tempo bem longo. Continuar?',
 	'S_MASS_UPDATE'=>			'Atualização em massa',
 	'S_SEARCH'=>			'Pesquisar',
-	'S_EXTERNAL_FILTER'=>			'Pesquisa avançada',
 	'S_ORIGINAL'=>			'Original',
 	'S_NEW_FLEXIBLE_INTERVAL'=>			'Novo intervalo flexível',
 	'S_FLEXIBLE_INTERVALS'=>			'Intervalos flexíveis (seg)',
@@ -717,17 +547,12 @@
 	'S_HISTORY_OF_EVENTS_BIG'=>			'HISTÓRICO DE EVENTOS',
 	'S_NO_EVENTS_FOUND'=>			'Nenhum evento encontrado',
 	'S_LAST_CHECK'=>			'Última checagem',
-	'S_LAST_CHECK_BIG'=>			'ÚLTIMA CHECAGEM',
 	'S_LAST_VALUE'=>			'Último valor',
 	'S_LINK'=>			'Link',
 	'S_LABEL'=>			'Texto',
 	'S_X'=>			'X',
 	'S_Y'=>			'Y',
-	'S_ICON_ON'=>			'Ícone (ligado)',
-	'S_ICON_OFF'=>			'Ícone (desligado)',
 	'S_ICON_UNKNOWN'=>			'Ícone (desconhecido)',
-	'S_ELEMENT_1'=>			'Elemento 1',
-	'S_ELEMENT_2'=>			'Elemento 2',
 	'S_LINK_STATUS_INDICATOR'=>			'Indicador do estado do link',
 	'S_CONFIGURATION_OF_NETWORK_MAPS'=>			'CONFIGURAÇÃO DE MAPAS DE REDE',
 	'S_MAPS_BIG'=>			'MAPAS',
@@ -737,13 +562,9 @@
 	'S_BOTTOM'=>			'Abaixo',
 	'S_TOP'=>			'Topo',
 	'S_OK_BIG'=>			'OK',
-	'S_PROBLEMS_SMALL'=>			'problemas',
 	'S_ZABBIX_URL'=>			'http://www.zabbix.com',
 	'S_NETWORK_MAPS'=>			'Mapas de rede',
 	'S_NETWORK_MAPS_BIG'=>			'MAPAS DE REDE',
-	'S_NO_MAPS_TO_DISPLAY'=>			'Nenhum mapa',
-	'S_SELECT_MAP_TO_DISPLAY'=>			'Selecione o mapa',
-	'S_SELECT_MAP_DOT_DOT_DOT'=>			'Selecione mapa...',
 	'S_BACKGROUND_IMAGE'=>			'Imagem de fundo',
 	'S_ICON_LABEL_TYPE'=>			'Tipo do texto do ícone',
 	'S_LABEL_LOCATION'=>			'Texto de localização',
@@ -752,49 +573,15 @@
 	'S_NOTHING'=>			'Nada',
 	'S_CONFIGURATION_OF_MEDIA_TYPES_BIG'=>			'CONFIGURAÇÃO DE TIPOS DE MÍDIA',
 	'S_MEDIA'=>			'Mídia',
-	'S_MEDIA_BIG'=>			'MÍDIA',
-	'S_MEDIA_ACTIVATED'=>			'Mídia ativada',
-	'S_CANNOT_ACTIVATE_MEDIA'=>			'Mídia não foi ativada',
-	'S_MEDIA_DISABLED'=>			'Mídia desabilitada',
-	'S_CANNOT_DISABLE_MEDIA'=>			'Mídia não foi desabilitada',
-	'S_MEDIA_ADDED'=>			'Mídia adicionada',
-	'S_CANNOT_ADD_MEDIA'=>			'Mídia não foi incluída',
-	'S_MEDIA_UPDATED'=>			'Mídia',
-	'S_CANNOT_UPDATE_MEDIA'=>			'Mídia não foi atualizada',
-	'S_MEDIA_DELETED'=>			'Mídia removida',
-	'S_CANNOT_DELETE_MEDIA'=>			'Mídia não foi removida',
 	'S_SEND_TO'=>			'Enviar para',
 	'S_WHEN_ACTIVE'=>			'Quando ativo',
 	'S_NO_MEDIA_DEFINED'=>			'Não há mídia definida',
 	'S_NEW_MEDIA'=>			'Nova mídia',
 	'S_USE_IF_SEVERITY'=>			'Usar se risco',
-	'S_DELETE_SELECTED_MEDIA_Q'=>			'Remover mídia selecionada?',
-	'S_CREATE_MEDIA'=>			'Criar mídia',
 	'S_SAVE'=>			'Salvar',
 	'S_CANCEL'=>			'Cancelar',
-	'S_MENU_LATEST_VALUES'=>			'VALORES RECENTES',
-	'S_MENU_TRIGGERS'=>			'TRIGGERS',
-	'S_MENU_QUEUE'=>			'FILA',
-	'S_MENU_ALARMS'=>			'ALARMES',
-	'S_MENU_ALERTS'=>			'ALERTAS',
-	'S_MENU_NETWORK_MAPS'=>			'MAPAS DE REDE',
-	'S_MENU_GRAPHS'=>			'GRÁFICOS',
-	'S_MENU_SCREENS'=>			'TELAS',
-	'S_MENU_IT_SERVICES'=>			'SERVIÇOS IT',
-	'S_MENU_HOME'=>			'HOME',
-	'S_MENU_ABOUT'=>			'SOBRE',
-	'S_MENU_STATUS_OF_ZABBIX'=>			'STATUS DO ZABBIX',
-	'S_MENU_AVAILABILITY_REPORT'=>			'RELATÓRIO DE DISPONIBILIDADE',
-	'S_MENU_CONFIG'=>			'CONFIGURAÇÃO',
-	'S_MENU_USERS'=>			'USUÁRIOS',
-	'S_MENU_HOSTS'=>			'HOSTS',
-	'S_MENU_ITEMS'=>			'íTENS',
-	'S_MENU_AUDIT'=>			'AUDITORIA',
-	'S_SWITCH_NODE'=>			'Nodo de troca',
-	'S_SELECT_GROUP_DOT_DOT_DOT'=>			'Selecionar grupo ...',
 	'S_OVERVIEW'=>			'Visão geral',
 	'S_OVERVIEW_BIG'=>			'VISÃO GERAL',
-	'S_EXCL'=>			'!',
 	'S_DATA'=>			'Dados',
 	'S_SHOW_GRAPH_OF_ITEM'=>			'Ver gráfico do ítem',
 	'S_SHOW_VALUES_OF_ITEM'=>			'Ver valores do ítem',
@@ -812,14 +599,11 @@
 	'S_30_SECONDS'=>			'30 segundos',
 	'S_1_MINUTE'=>			'1 minutos',
 	'S_5_MINUTES'=>			'5 minutos',
-	'S_MORE_THAN_5_MINUTES'=>			'Mais de 5 minutos',
 	'S_STATUS_OF_ZABBIX'=>			'Status do ZABBIX',
 	'S_STATUS_OF_ZABBIX_BIG'=>			'STATUS DO ZABBIX',
 	'S_VALUE'=>			'Valor',
 	'S_ZABBIX_SERVER_IS_RUNNING'=>			'ZABBIX está rodando',
-	'S_NUMBER_OF_VALUES_STORED'=>			'Número de valores armazenados',
 	'S_VALUES_STORED'=>			'Valores armazenados',
-	'S_NUMBER_OF_TRENDS_STORED'=>			'Número de estatísticas armazenadas',
 	'S_TRENDS_STORED'=>			'Estatísticas armazenadas',
 	'S_NUMBER_OF_EVENTS'=>			'Número de eventos',
 	'S_NUMBER_OF_ALERTS'=>			'Número de alertas',
@@ -838,8 +622,6 @@
 	'S_AVAILABILITY_REPORT'=>			'Relatório de disponibilidade',
 	'S_AVAILABILITY_REPORT_BIG'=>			'RELATÓRIO DE DISPONIBILIDADE',
 	'S_SHOW'=>			'Mostrar',
-	'S_TRUE'=>			'Verdadeiro',
-	'S_FALSE'=>			'Falso',
 	'S_IT_SERVICES_AVAILABILITY_REPORT'=>			'Relatório de dispnibilidade dos serviços IT',
 	'S_IT_SERVICES_AVAILABILITY_REPORT_BIG'=>			'RELATÓRIO DE DISPONIBILIDADE DOS SERVIÇOS IT',
 	'S_FROM'=>			'De',
@@ -881,8 +663,6 @@
 	'S_CONFIGURATION_OF_SCREEN_BIG'=>			'CONFIGURAÇÃO DE TELA',
 	'S_SCREEN_CELL_CONFIGURATION'=>			'Tela de configuração para celular',
 	'S_RESOURCE'=>			'Recurso',
-	'S_RESOURCES'=>			'Recursos',
-	'S_RESOURCE_TYPE'=>			'Tipo do recurso',
 	'S_RIGHTS_OF_RESOURCES'=>			'Direitos do usuário',
 	'S_NO_RESOURCES_DEFINED'=>			'Nenhum recurso definido',
 	'S_SIMPLE_GRAPH'=>			'Gráfico simples',
@@ -920,17 +700,14 @@
 	'S_LOCAL_TIME'=>			'Hora local',
 	'S_STYLE'=>			'Estilo',
 	'S_VERTICAL'=>			'Vertical',
-	'S_HORISONTAL'=>			'Horizontal',
-	'S_HORISONTAL_ALIGN'=>			'Alinhamento horizontal',
-	'S_CENTER'=>			'Centro',
+	'S_HORIZONTAL'=>			'Horizontal',
+	'S_HORIZONTAL_ALIGN'=>			'Alinhamento horizontal',
+	'S_CENTRE'=>			'Centro',
 	'S_RIGHT'=>			'Direita',
 	'S_VERTICAL_ALIGN'=>			'Alinhamento vertical',
 	'S_MIDDLE'=>			'Centro',
 	'S_CUSTOM_SCREENS'=>			'Telas personalizadas',
 	'S_SCREENS_BIG'=>			'TELAS',
-	'S_NO_SCREENS_TO_DISPLAY'=>			'Nenhuma tela',
-	'S_SELECT_SCREEN_TO_DISPLAY'=>			'Selecione tela a mostrar',
-	'S_SELECT_SCREEN_DOT_DOT_DOT'=>			'Selecione a tela ...',
 	'S_SLIDESHOW_UPDATED'=>			'Slideshow atualizado',
 	'S_CANNOT_UPDATE_SLIDESHOW'=>			'Slideshow não foi atualizado',
 	'S_SLIDESHOW_ADDED'=>			'Slideshow incluído',
@@ -946,41 +723,20 @@
 	'S_CANNOT_UPDATE_SERVICE'=>			'Serviços não foram atualizados',
 	'S_SERVICE_ADDED'=>			'Serviço incluído',
 	'S_CANNOT_ADD_SERVICE'=>			'Serviço não foi incluído',
-	'S_LINK_ADDED'=>			'Link incluído',
-	'S_CANNOT_ADD_LINK'=>			'Link não foi incluído',
 	'S_SERVICE_DELETED'=>			'Serviço removido',
 	'S_CANNOT_DELETE_SERVICE'=>			'Serviço não foi removido',
-	'S_LINK_DELETED'=>			'Link removido',
-	'S_CANNOT_DELETE_LINK'=>			'Link não foi removido',
 	'S_STATUS_CALCULATION'=>			'Cálculo do status',
 	'S_STATUS_CALCULATION_ALGORITHM'=>			'Algoritmo de cálculo do status',
 	'S_NONE'=>			'Nenhum',
-	'S_MAX_OF_CHILDS'=>			'MAX de instâncias',
-	'S_MIN_OF_CHILDS'=>			'MIN de instâncias',
-	'S_SERVICE_1'=>			'Serviço 1',
-	'S_SERVICE_2'=>			'Serviço 2',
-	'S_SOFT_HARD_LINK'=>			'Soft/hard link',
 	'S_SOFT'=>			'Soft',
-	'S_HARD'=>			'Hard',
 	'S_DO_NOT_CALCULATE'=>			'Não calcula',
-	'S_MAX_BIG'=>			'MAX',
-	'S_MIN_BIG'=>			'MIN',
-	'S_SHOW_SLA'=>			'Mostrar SLA',
 	'S_ACCEPTABLE_SLA_IN_PERCENT'=>			'SLA  aceitável (em %)',
 	'S_LINK_TO_TRIGGER_Q'=>			'Associar a trigger?',
 	'S_SORT_ORDER_0_999'=>			'Posicionar em (0->999)',
-	'S_DELETE_SERVICE_Q'=>			'Remover serviço?',
-	'S_LINK_TO'=>			'Associar a',
-	'S_SOFT_LINK_Q'=>			'Soft link?',
-	'S_ADD_SERVER_DETAILS'=>			'Incluir detalhes do servidor?',
 	'S_TRIGGER'=>			'Trigger',
 	'S_SERVER'=>			'Servidor',
 	'S_DELETE'=>			'Remover',
 	'S_CLONE'=>			'Clonar',
-	'S_DELETE_SELECTED_SERVICES'=>			'Remover serviços selecionados?',
-	'S_DELETE_SELECTED_LINKS'=>			'Remover links selecionados?',
-	'S_SERVICES_DELETED'=>			'Serviços removidos',
-	'S_CANNOT_DELETE_SERVICES'=>			'Serviços não foram removidos',
 	'S_UPTIME'=>			'Uptime',
 	'S_DOWNTIME'=>			'Downtime',
 	'S_ONE_TIME_DOWNTIME'=>			'One-time downtime',
@@ -988,7 +744,6 @@
 	'S_SERVICE_TIMES'=>			'Horário de serviço',
 	'S_NEW_SERVICE_TIME'=>			'Novo horário de serviço',
 	'S_NOTE'=>			'Nota',
-	'S_SOFT_LINK'=>			'Soft Link',
 	'S_REMOVE'=>			'Remove',
 	'S_DEPENDS_ON'=>			'Depende de',
 	'S_SUNDAY'=>			'Domingo',
@@ -1002,25 +757,15 @@
 	'S_SERVICE'=>			'Serviços',
 	'S_SERVICES'=>			'Serviços',
 	'S_REASON'=>			'Razão',
-	'S_SLA_LAST_7_DAYS'=>			'SLA (últimos 7 dias)',
-	'S_PLANNED_CURRENT_SLA'=>			'SLA planejado/atual',
-	'S_TRIGGER_BIG'=>			'TRIGGER',
 	'S_NO_TRIGGER'=>			'Sem trigger',
 	'S_NO_TRIGGERS_DEFINED'=>			'Nenhuma trigger definida',
 	'S_NO_TRIGGER_DEFINED'=>			'Nenhuma trigger definida',
 	'S_CONFIGURATION_OF_TRIGGERS'=>			'Configuração das triggers',
 	'S_CONFIGURATION_OF_TRIGGERS_BIG'=>			'CONFIGURAÇÃO DAS TRIGGERS',
-	'S_DEPENDENCY_ADDED'=>			'Dependência adicionada',
-	'S_CANNOT_ADD_DEPENDENCY'=>			'Dependência não foi adicionada',
-	'S_TRIGGERS_UPDATED'=>			'Triggers atualizadas',
-	'S_CANNOT_UPDATE_TRIGGERS'=>			'Triggers não foram atualizadas',
-	'S_TRIGGERS_DISABLED'=>			'Triggers desabilitadas',
-	'S_CANNOT_DISABLE_TRIGGERS'=>			'Triggers não foram desabilitadas',
 	'S_TRIGGERS_DELETED'=>			'Triggers removidas',
 	'S_CANNOT_DELETE_TRIGGERS'=>			'Triggers não foram removidas',
 	'S_TRIGGER_DELETED'=>			'Trigger removida',
 	'S_CANNOT_DELETE_TRIGGER'=>			'Trigger não foi removida',
-	'S_INVALID_TRIGGER_EXPRESSION'=>			'Expressão inválida',
 	'S_TRIGGER_ADDED'=>			'Trigger adicionada',
 	'S_CANNOT_ADD_TRIGGER'=>			'Tigger não foi adicionada',
 	'S_SEVERITY'=>			'Risco',
@@ -1028,20 +773,14 @@
 	'S_DISABLED'=>			'Inativa',
 	'S_ENABLED'=>			'Ativa',
 	'S_ENABLE_SELECTED'=>			'Ativar selecionadas',
-	'S_ENABLE_SELECTED_TRIGGERS_Q'=>			'Habilitar triggers selecionadas?',
-	'S_DISABLE_SELECTED_TRIGGERS_Q'=>			'Desativar triggers selecionadas?',
-	'S_DELETE_SELECTED_TRIGGERS_Q'=>			'Remover triggers selecionadas?',
 	'S_CHANGE'=>			'Alterar',
 	'S_TRIGGER_UPDATED'=>			'Trigger atualizada',
 	'S_CANNOT_UPDATE_TRIGGER'=>			'Trigger não foi atualizada',
 	'S_URL'=>			'URL',
-	'S_INVALID_URL'=>			'URL inválida',
 	'S_CREATE_TRIGGER'=>			'Criar Trigger',
 	'S_INSERT'=>			'Inserir',
-	'S_TIMES'=>			'Tempos',
 	'S_SECONDS'=>			'Segundos',
 	'S_SEC_SMALL'=>			'seg',
-	'S_COUNTS'=>			'Contadores',
 	'S_LAST_OF'=>			'Última de',
 	'S_SHOW_DISABLED_TRIGGERS'=>			'Mostrar triggers inativas',
 	'S_HIDE_DISABLED_TRIGGERS'=>			'Esconder triggers inativas',
@@ -1052,17 +791,9 @@
 	'S_ADD'=>			'Adicionar',
 	'S_STATUS_OF_TRIGGERS'=>			'Status das triggers',
 	'S_STATUS_OF_TRIGGERS_BIG'=>			'STATUS DAS TRIGGERS',
-	'S_SHOW_ONLY_TRUE'=>			'Mostrar verdadeiras',
-	'S_HIDE_ACTIONS'=>			'Esconder ações',
-	'S_SHOW_ACTIONS'=>			'Mostrar ações',
-	'S_HIDE_DETAILS'=>			'Esconder detalhes',
 	'S_SHOW_DETAILS'=>			'Mostrar detalhes',
 	'S_SELECT'=>			'Selecionar',
-	'S_HIDE_SELECT'=>			'Esconder selecionar',
 	'S_TRIGGERS_BIG'=>			'TRIGGERS',
-	'S_NAME_BIG'=>			'NOME',
-	'S_SEVERITY_BIG'=>			'RISCO',
-	'S_LAST_CHANGE_BIG'=>			'ÚLTIMA ALTERAÇÃO',
 	'S_LAST_CHANGE'=>			'Última alteração',
 	'S_COMMENTS'=>			'Comentários',
 	'S_ACKNOWLEDGED'=>			'Visto',
@@ -1078,12 +809,7 @@
 	'S_CANNOT_ADD_USER_BOTH_PASSWORDS_MUST'=>			'Usuário não foi incluído. Senhas não conferem.',
 	'S_USER_DELETED'=>			'Usuário removido',
 	'S_CANNOT_DELETE_USER'=>			'Usuário não foi removido',
-	'S_PERMISSION_DELETED'=>			'Permissão removida',
-	'S_CANNOT_DELETE_PERMISSION'=>			'Permissão não foi removida',
-	'S_PERMISSION_ADDED'=>			'Permissão incluída',
-	'S_CANNOT_ADD_PERMISSION'=>			'Permissão não foi incluída',
 	'S_USER_UPDATED'=>			'Usuário atualizado',
-	'S_ONLY_FOR_GUEST_ALLOWED_EMPTY_PASSWORD'=>			'Somente usuário \'visitante\' pode ter senha vazia.',
 	'S_CANNOT_UPDATE_USER'=>			'Usuário não foi atualizado',
 	'S_CANNOT_UPDATE_USER_BOTH_PASSWORDS'=>			'Usuário não foi atualizado. Ambas as senhas devem ser iguais.',
 	'S_GROUP_ADDED'=>			'Grupo incluído',
@@ -1097,19 +823,14 @@
 	'S_USERS_BIG'=>			'USUÁRIOS',
 	'S_USER_GROUPS'=>			'Grupos de usuários',
 	'S_MEMBERS'=>			'Membros',
-	'S_HOSTS_TEMPLATES_LINKAGE'=>			'Hosts/templates associados',
-	'S_CONFIGURATION_OF_TEMPLATES_LINKAGE'=>			'CONFIGURAÇÃO DE ASSOCIAÇÃO À TEMPLATES',
-	'S_LINKED_TEMPLATES_BIG'=>			'ASSOCIADO ÀS TEMPLATES',
 	'S_NO_USER_GROUPS_DEFINED'=>			'Nenhum grupo de usuário definido',
 	'S_ALIAS'=>			'Alias',
 	'S_NAME'=>			'Nome',
 	'S_SURNAME'=>			'Sobrenome',
 	'S_IS_ONLINE_Q'=>			'Online?',
 	'S_NO_USERS_DEFINED'=>			'Não há usuários',
-	'S_PERMISSION'=>			'Permissão',
 	'S_RIGHTS'=>			'Permissões',
 	'S_NO_RIGHTS_DEFINED'=>			'Nenhuma permissão definida',
-	'S_RESOURCE_NAME'=>			'Nome do recurso',
 	'S_READ_ONLY'=>			'Somente leitura',
 	'S_READ_WRITE'=>			'Leitura-escrita',
 	'S_DENY'=>			'Nega',
@@ -1118,21 +839,16 @@
 	'S_CHANGE_PASSWORD'=>			'Alterar senha',
 	'S_PASSWORD_ONCE_AGAIN'=>			'Senha (novamente)',
 	'S_URL_AFTER_LOGIN'=>			'URL (ao sair)',
-	'S_AUTO_LOGOUT_IN_SEC'=>			'Auto-logout (em seg=>0 - desabilita)',
 	'S_SCREEN_REFRESH'=>			'Atualização da tela (em seg)',
 	'S_CREATE_USER'=>			'Cria Usuário',
 	'S_CREATE_GROUP'=>			'Criar Grupo',
 	'S_DELETE_SELECTED_USERS_Q'=>			'Apagar usuários selecionados?',
 	'S_NO_ACCESSIBLE_RESOURCES'=>			'Nenhum recurso acessível',
-	'S_AUDIT_LOG'=>			'Log de auditoria',
-	'S_AUDIT_LOG_BIG'=>			'LOG DE AUDITORIA',
 	'S_ACTION'=>			'Ação',
 	'S_DETAILS'=>			'Detalhes',
 	'S_UNKNOWN_ACTION'=>			'Ação desconhecida',
 	'S_ADDED'=>			'Adicionado',
 	'S_UPDATED'=>			'Atualizado',
-	'S_LOGGED_IN'=>			'Conectado',
-	'S_LOGGED_OUT'=>			'Desconectado',
 	'S_MEDIA_TYPE'=>			'Tipo de mídia',
 	'S_GRAPH_ELEMENT'=>			'Elemento gráfico',
 	'S_UNKNOWN_RESOURCE'=>			'Recurso desconhecido',
@@ -1178,7 +894,6 @@
 	'S_FILL_WITH_DEFAULT_VALUE'=>                   'Fill with default value',
 	'S_CREATE'=>                            'Criar',
 	'S_NEW_SMALL'=>                         'Novo',
-	'S_FILE_SMALL'=>                        'Arquivo',
 	'S_LOCALES'=>                           'Idiomas',
 	'S_LOCALE_SMALL'=>                      'idiomas',
 	'S_DOWNLOAD'=>                          'Download',
