@@ -1,5 +1,5 @@
 <?php
-/* 
+/*
 ** ZABBIX
 ** Copyright (C) 2000-2008 SIA Zabbix
 **
@@ -43,11 +43,7 @@
 	'S_CONFIGURATION_OF_DISCOVERY_BIG'=>			'CONFIGURACIÓN DE DESCUBRIMIENTO',
 	'S_NO_DISCOVERY_RULES_DEFINED'=>			'No se han definido reglas de descubrimiento',
 	'S_IP_RANGE'=>			'Rango de IP\'s',
-	'S_INTERVALS'=>			'Intervalos',
 	'S_CHECKS'=>			'Comprobaciones',
-	'S_ENABLE_SELECTED_RULES_Q'=>			'¿Activar reglas seleccionadas?',
-	'S_DISABLE_SELECTED_RULES_Q'=>			'¿Desactivar reglas seleccionadas?',
-	'S_DELETE_SELECTED_RULES_Q'=>			'¿Eliminar reglas seleccionadas?',
 	'S_CREATE_RULE'=>			'Crear Regla',
 	'S_DELETE_RULE_Q'=>			'¿Eliminar la regla?',
 	'S_EVENT_SOURCE'=>			'Origen del evento',
@@ -100,11 +96,7 @@
 	'S_SCENARIO_DELETED'=>			'Escenario eliminado',
 	'S_SCENARIO_ACTIVATED'=>			'Escenario activado',
 	'S_SCENARIO_DISABLED'=>			'Escenario deshabilitado',
-	'S_ACTIVATE_SELECTED_SCENARIOS_Q'=>			'¿Activar los escenarios seleccionados?',
-	'S_DISABLE_SELECTED_SCENARIOS_Q'=>			'¿Desactivar los escenarios seleccionados?',
-	'S_DELETE_SELECTED_SCENARIOS_Q'=>			'¿Eliminar los escenarios seleccionados?',
 	'S_DELETE_SCENARIO_Q'=>			'¿Eliminar escenario?',
-	'S_CLEAN_HISTORY_SELECTED_SCENARIOS'=>			'Limpiar el histórico',
 	'S_SCENARIO_UPDATED'=>			'Escenario actualizado',
 	'S_CANNOT_UPDATE_SCENARIO'=>			'No es posible actualizar el escenario',
 	'S_SCENARIO_ADDED'=>			'Escenario añadido',
@@ -125,16 +117,12 @@
 	'S_IMPORT_FILE'=>			'Fichero para importar',
 	'S_IMPORT'=>			'Importar',
 	'S_IMPORT_BIG'=>			'IMPORTAR',
-	'S_IMPORT_HOSTS'=>			'Importar equipos',
-	'S_IMPORT_HOSTS_BIG'=>			'IMPORTAR EQUIPOS',
 	'S_EXPORT'=>			'Exportar',
-	'S_EXPORT_FILE'=>			'Exportar fichero',
 	'S_EXPORT_BIG'=>			'EXPORTAR',
 	'S_PREVIEW'=>			'Previsualizar',
 	'S_BACK'=>			'Retroceder',
 	'S_NO_DATA_FOR_EXPORT'=>			'No existen datos para exportar',
 	'S_RULES'=>			'Reglas aplicables a cada grupo',
-	'S_SKIP'=>			'Omitir',
 	'S_EXISTING'=>			'Si existe',
 	'S_MISSING'=>			'Si no existe',
 	'S_REFRESH'=>			'Refrescar',
@@ -152,7 +140,7 @@
 	'S_DO_NOT_KEEP_HISTORY_OLDER_THAN'=>			'No mantener el histórico más de (en días)',
 	'S_DO_NOT_KEEP_TRENDS_OLDER_THAN'=>			'No mantener las tendencias más de (en días)',
 	'S_MASTER_NODE'=>			'Nodo maestro',
-	'S_REMOTE'=>			'Remoto',
+	'S_CHILD'=>			'Remoto',
 	'S_MASTER'=>			'Maestro',
 	'S_NODE_UPDATED'=>			'Nodo actualizado',
 	'S_CANNOT_UPDATE_NODE'=>			'No es posible actualizar el nodo',
@@ -161,31 +149,19 @@
 	'S_NODE_DELETED'=>			'Nodo eliminado',
 	'S_CANNOT_DELETE_NODE'=>			'No es posible eliminar el nodo',
 	'S_CURRENT_NODE'=>			'Nodo actual',
-	'S_CURRENT_NODE_ONLY'=>			'Sólo el nodo actual',
-	'S_WITH_SUBNODES'=>			'Incluir subnodos',
 	'S_ACKNOWLEDGES'=>			'Aceptadas',
 	'S_ACKNOWLEDGE'=>			'Aceptada',
 	'S_ACKNOWLEDGE_ALARM_BY'=>			'Alarma aceptada por',
 	'S_ADD_COMMENT_BY'=>			'Comentario añadido por',
-	'S_COMMENT_ADDED'=>			'Comentario añadido',
-	'S_CANNOT_ADD_COMMENT'=>			'No es posible añadir el comentario',
 	'S_ALARM_ACKNOWLEDGES_BIG'=>			'ALARMAS ACEPTADAS',
 	'S_ACKNOWLEDGE_ADDED'=>			'Aceptación añadida',
 	'S_CONFIGURATION_OF_ACTIONS'=>			'Configuración de acciones',
 	'S_CONFIGURATION_OF_ACTIONS_BIG'=>			'CONFIGURACIÓN DE ACCIONES',
-	'S_FILTER_HOST_GROUP'=>			'Filtro: Grupo de equipos',
-	'S_FILTER_HOST'=>			'Filtro: Equipo',
-	'S_FILTER_TRIGGER'=>			'Filtro: Iniciador',
-	'S_FILTER_TRIGGER_NAME'=>			'Filtro: Nombre del iniciador',
-	'S_FILTER_TRIGGER_SEVERITY'=>			'Filtro: Gravedad del iniciador',
-	'S_FILTER_WHEN_TRIGGER_BECOMES'=>			'Filtro: Cuando se lanza el iniciador',
 	'S_OPERATION_TYPE'=>			'Operación a realizar',
 	'S_SEND_MESSAGE'=>			'Enviar mensaje',
 	'S_REMOTE_COMMAND'=>			'Comando remoto',
 	'S_REMOTE_COMMANDS'=>			'Comandos remotos',
 	'S_FILTER'=>			'Filtro',
-	'S_FILTER_TYPE'=>			'Tipo de alerta',
-	'S_TRIGGER_NAME'=>			'Nombre del iniciador',
 	'S_TRIGGER_SEVERITY'=>			'Gravedad del iniciador',
 	'S_TRIGGER_VALUE'=>			'Valor del iniciador',
 	'S_TIME_PERIOD'=>			'Período de tiempo',
@@ -194,8 +170,6 @@
 	'S_CONDITION'=>			'Condición',
 	'S_NEW_CONDITION'=>			'Nueva condición',
 	'S_OPERATIONS'=>			'Operaciones',
-	'S_OPERATION'=>			'Operación',
-	'S_NEW_OPERATION'=>			'Nueva operación',
 	'S_EDIT_OPERATION'=>			'Editar operación',
 	'S_NO_CONDITIONS_DEFINED'=>			'No se han definido condiciones',
 	'S_ACTIONS_DELETED'=>			'Acciones eliminadas',
@@ -224,10 +198,8 @@
 	'S_CANNOT_UPDATE_ACTION'=>			'No es posible actualizar la acción',
 	'S_ACTION_DELETED'=>			'Acción eliminada',
 	'S_CANNOT_DELETE_ACTION'=>			'No es posible eliminar la acción',
-	'S_SCOPE'=>			'Alcance',
 	'S_SEND_MESSAGE_TO'=>			'Enviar mensaje a',
 	'S_RUN_REMOTE_COMMANDS'=>			'Ejecutar comandos remotos',
-	'S_WHEN_TRIGGER'=>			'Cuando el iniciador:',
 	'S_DELAY'=>			'Demora',
 	'S_SUBJECT'=>			'Título',
 	'S_ON'=>			'ACTIVO',
@@ -237,14 +209,7 @@
 	'S_USER_GROUP'=>			'Un grupo de usuarios',
 	'S_GROUP'=>			'Grupo',
 	'S_USER'=>			'Usuario',
-	'S_ON_OR_OFF'=>			'Activo o Inactivo',
-	'S_DELAY_BETWEEN_MESSAGES_IN_SEC'=>			'Demora entre mensajes (en seg)',
-	'S_DELAY_BETWEEN_EXECUTIONS_IN_SEC'=>			'Demora entre ejecuciones (en seg)',
 	'S_MESSAGE'=>			'Mensaje',
-	'S_THIS_TRIGGER_ONLY'=>			'Sólo para este iniciador',
-	'S_ALL_TRIGGERS_OF_THIS_HOST'=>			'Todos los iniciadores de este equipo',
-	'S_ALL_TRIGGERS'=>			'Todos los iniciadores',
-	'S_USE_IF_TRIGGER_SEVERITY'=>			'Utilizar si la gravedad del iniciador es igual o mayor que',
 	'S_NOT_CLASSIFIED'=>			'No clasificada',
 	'S_INFORMATION'=>			'Informativa',
 	'S_WARNING'=>			'Baja',
@@ -258,73 +223,29 @@
 	'S_OR'=>			'o',
 	'S_TYPE_OF_CALCULATION'=>			'Tipo de cálculo',
 	'S_CREATE_ACTION'=>			'Crear acción',
-	'S_ENABLE_SELECTED_ACTIONS_Q'=>			'¿Activar acciones seleccionadas?',
-	'S_DISABLE_SELECTED_ACTIONS_Q'=>			'¿Desactivar acciones seleccionadas?',
-	'S_DELETE_SELECTED_ACTIONS_Q'=>			'¿Eliminar acciones seleccionadas?',
 	'S_DELETE_SELECTED_ACTION_Q'=>			'¿Eliminar acción seleccionada?',
 	'S_LIKE_SMALL'=>			'igual que',
 	'S_NOT_LIKE_SMALL'=>			'distinto de',
 	'S_IN_SMALL'=>			'contenido en',
 	'S_NOT_IN_SMALL'=>			'no contenido en',
-	'S_ALARMS'=>			'Alarmas',
-	'S_ALARMS_SMALL'=>			'Alarmas',
-	'S_ALARMS_BIG'=>			'ALARMAS',
-	'S_SHOW_ONLY_LAST_100'=>			'Mostrar únicamente las últimas 100',
 	'S_SHOW_ALL'=>			'Mostrar todo',
 	'S_TIME'=>			'Fecha y hora',
 	'S_STATUS'=>			'Estado',
 	'S_DURATION'=>			'Duración',
-	'S_SUM'=>			'Suma',
 	'S_TRUE_BIG'=>			'ACTIVO',
 	'S_FALSE_BIG'=>			'INACTIVO',
-	'S_DISABLED_BIG'=>			'DESACTIVADO',
 	'S_UNKNOWN_BIG'=>			'DESCONOCIDO',
-	'S_HISTORY_OF_ACTIONS_BIG'=>			'HISTÓRICO DE ACCIONES',
-	'S_LATEST_ACTIONS'=>			'Últimas acciones',
-	'S_ALERTS_BIG'=>			'ALERTAS',
 	'S_TYPE'=>			'Tipo',
 	'S_RECIPIENTS'=>			'Receptor(es)',
 	'S_ERROR'=>			'Error',
 	'S_SENT'=>			'enviada',
 	'S_NOT_SENT'=>			'no enviada',
 	'S_NO_ACTIONS_FOUND'=>			'No se han encontrado acciones',
-	'S_SHOW_NEXT_100'=>			'Mostrar las 100 siguientes',
-	'S_SHOW_PREVIOUS_100'=>			'Mostrar las 100 anteriores',
 	'S_CUSTOM_GRAPHS'=>			'Personalizar gráficos',
 	'S_GRAPHS_BIG'=>			'GRÁFICOS',
-	'S_NO_GRAPHS_TO_DISPLAY'=>			'No existen gráficos para mostrar',
 	'S_SELECT_GRAPH_TO_DISPLAY'=>			'Seleccionar el gráfico a mostrar',
 	'S_PERIOD'=>			'Período',
-	'S_1H'=>			'1h',
-	'S_2H'=>			'2h',
-	'S_4H'=>			'4h',
-	'S_8H'=>			'8h',
-	'S_12H'=>			'12h',
-	'S_24H'=>			'24h',
-	'S_WEEK_SMALL'=>			'Semana',
-	'S_MONTH_SMALL'=>			'Mes',
-	'S_YEAR_SMALL'=>			'Año',
-	'S_KEEP_PERIOD'=>			'Mantener el período',
-	'S_ON_C'=>			'On',
-	'S_OFF_C'=>			'Off',
-	'S_MOVE'=>			'Mover',
-	'S_NAVIGATE'=>			'Navegar',
-	'S_INCREASE'=>			'Incrementar',
-	'S_DECREASE'=>			'Decrementar',
-	'S_RIGHT_DIR'=>			'Derecha',
-	'S_LEFT_DIR'=>			'Izquierda',
 	'S_SELECT_GRAPH_DOT_DOT_DOT'=>			'Seleccionar gráfico...',
-	'S_BLACK'=>			'Negro',
-	'S_BLUE'=>			'Azul',
-	'S_CYAN'=>			'Turquesa',
-	'S_DARK_BLUE'=>			'Azul oscuro',
-	'S_DARK_GREEN'=>			'Verde oscuro',
-	'S_DARK_RED'=>			'Rojo oscuro',
-	'S_DARK_YELLOW'=>			'Amarillo Oscuro',
-	'S_GREEN'=>			'Verde',
-	'S_RED'=>			'Rojo',
-	'S_WHITE'=>			'Blanco',
-	'S_YELLOW'=>			'Amarillo',
 	'S_CANNNOT_UPDATE_VALUE_MAP'=>			'No es posible actualizar la asignación',
 	'S_VALUE_MAP_ADDED'=>			'Asignación añadida',
 	'S_CANNNOT_ADD_VALUE_MAP'=>			'No es posible añadir la asignación',
@@ -363,28 +284,8 @@
 	'S_MEDIA_TYPES'=>			'Tipos de medios',
 	'S_ESCALATION_RULES'=>			'Reglas de escalado',
 	'S_ESCALATION'=>			'Escalado',
-	'S_ESCALATION_RULES_BIG'=>			'REGLAS DE ESCALADO',
-	'S_NO_ESCALATION_RULES_DEFINED'=>			'No se han definido reglas de escalado',
-	'S_NO_ESCALATION_DETAILS'=>			'No existen detalles de escalado',
-	'S_ESCALATION_DETAILS_BIG'=>			'DETALLES DE ESCALADO',
-	'S_ESCALATION_ADDED'=>			'Escalado añadido',
-	'S_ESCALATION_WAS_NOT_ADDED'=>			'Escalado no añadido',
-	'S_ESCALATION_RULE_ADDED'=>			'Regla de escalado añadida',
-	'S_ESCALATION_RULE_WAS_NOT_ADDED'=>			'Regla de escalado no añadida',
-	'S_ESCALATION_RULE_UPDATED'=>			'Regla de escalado actualizada',
-	'S_ESCALATION_RULE_WAS_NOT_UPDATED'=>			'Regla de escalado no actualizada',
-	'S_ESCALATION_RULE_DELETED'=>			'Regla de escalado eliminada',
-	'S_ESCALATION_RULE_WAS_NOT_DELETED'=>			'Regla de escalado no eliminada',
-	'S_ESCALATION_UPDATED'=>			'Escalado actualizado',
-	'S_ESCALATION_WAS_NOT_UPDATED'=>			'Escalado no actualizado',
-	'S_ESCALATION_DELETED'=>			'Escalado eliminado',
-	'S_ESCALATION_WAS_NOT_DELETED'=>			'Escalado no eliminado',
 	'S_ESCALATION_RULE'=>			'Regla de escalado',
-	'S_DO'=>			'Hacer',
 	'S_DEFAULT'=>			'Por defecto',
-	'S_IS_DEFAULT'=>			'Es por defecto',
-	'S_LEVEL'=>			'Nivel',
-	'S_DELAY_BEFORE_ACTION'=>			'Demora antes de la acción',
 	'S_IMAGES'=>			'Imágenes',
 	'S_IMAGE'=>			'Imágen',
 	'S_IMAGES_BIG'=>			'IMÁGENES',
@@ -398,9 +299,6 @@
 	'S_CANNOT_DELETE_IMAGE'=>			'No es posible eliminar la imágen',
 	'S_IMAGE_UPDATED'=>			'Imágen actualizada',
 	'S_CANNOT_UPDATE_IMAGE'=>			'No es posible actualizar la imágen',
-	'S_UPDATE_SELECTED_IMAGE'=>			'¿Actualizar la imágen seleccionada?',
-	'S_PRIORITY'=>			'Prioridad',
-	'S_PATTERN'=>			'Modelo',
 	'S_OTHER'=>			'Otras configuraciones',
 	'S_OTHER_PARAMETERS'=>			'Otras configuraciones',
 	'S_REFRESH_UNSUPPORTED_ITEMS'=>			'Tiempo de refresco para monitores no soportados en (segudos)',
@@ -410,41 +308,30 @@
 	'S_USER_GROUP_FOR_DATABASE_DOWN_MESSAGE'=>			'Grupo de usuarios para mensajes de base de datos caída',
 	'S_INCORRECT_GROUP'=>			'Grupo incorrecto',
 	'S_NOTHING_TO_DO'=>			'Nada que hacer',
-	'S_ICORRECT_WORK_PERIOD'=>			'Período de trabajo incorrecto',
+	'S_INCORRECT_WORK_PERIOD'=>			'Período de trabajo incorrecto',
 	'S_NODE'=>			'Nodo',
 	'S_NODES'=>			'Nodos',
 	'S_NODES_BIG'=>			'NODOS',
 	'S_NEW_NODE'=>			'Nuevo nodo',
 	'S_NO_NODES_DEFINED'=>			'No se han definido nodos',
-	'S_LATEST_VALUES'=>			'Últimos valores',
 	'S_NO_PERMISSIONS'=>			'Sin permisos !',
 	'S_LATEST_DATA_BIG'=>			'ÚLTIMA FECHA',
 	'S_ALL_SMALL'=>			'todo',
 	'S_MINUS_ALL_MINUS'=>			'- todo -',
 	'S_MINUS_OTHER_MINUS'=>			'- otros -',
-	'S_DESCRIPTION_LARGE'=>			'DESCRIPCIÓN',
-	'S_DESCRIPTION_SMALL'=>			'Descripción',
 	'S_GRAPH'=>			'Gráficos',
-	'S_TREND'=>			'Tendencia',
-	'S_COMPARE'=>			'Comparar',
 	'S_COPYRIGHT_BY'=>			'Copyright 2001-2007 por',
 	'S_CONNECTED_AS'=>			'Conectado como',
 	'S_SIA_ZABBIX'=>			'SIA Zabbix',
-	'S_CONFIGURATION_OF_GRAPH'=>			'Configuración del gráfico',
-	'S_CONFIGURATION_OF_GRAPH_BIG'=>			'CONFIGURACIÓN DEL GRÁFICO',
 	'S_ITEM_ADDED'=>			'Monitor añadido',
 	'S_ITEM_UPDATED'=>			'Monitor actualizado',
 	'S_ITEMS_UPDATED'=>			'Monitores actualizados',
-	'S_SORT_ORDER_UPDATED'=>			'Órden de clasificación actualizada',
-	'S_CANNOT_UPDATE_SORT_ORDER'=>			'No es posible actualizar el órden de clasificación',
-	'S_DISPLAYED_PARAMETERS_BIG'=>			'PARÁMETROS MOSTRADOS',
-	'S_SORT_ORDER'=>			'Órden de clasificación',
 	'S_PARAMETER'=>			'Parámetro',
 	'S_COLOR'=>			'Color',
 	'S_UP'=>			'Arriba',
 	'S_DOWN'=>			'Abajo',
 	'S_NEW_ITEM_FOR_THE_GRAPH'=>			'Nuevo elemento para el gráfico',
-	'S_SORT_ORDER_1_100'=>			'Órden de clasificación (0->100)',
+	'S_SORT_ORDER_0_100'=>			'Órden de clasificación (0->100)',
 	'S_YAXIS_SIDE'=>			'Lado del eje Y',
 	'S_LEFT'=>			'Izquierda',
 	'S_FUNCTION'=>			'Función',
@@ -470,7 +357,6 @@
 	'S_NO_GRAPHS_DEFINED'=>			'No se han definido gráficos',
 	'S_NO_GRAPH_DEFINED'=>			'No se ha definido gráfico',
 	'S_DELETE_GRAPH_Q'=>			'¿Eliminar el gráfico?',
-	'S_YAXIS_TYPE'=>			'Tipo del eje Y',
 	'S_YAXIS_MIN_VALUE'=>			'Valor MIN del eje Y',
 	'S_YAXIS_MAX_VALUE'=>			'Valor MAX del eje Y',
 	'S_CALCULATED'=>			'Calculado',
@@ -483,15 +369,10 @@
 	'S_LAST_HOUR_GRAPH'=>			'Gráfico de la última hora',
 	'S_LAST_WEEK_GRAPH'=>			'Gráfico de la última semana',
 	'S_LAST_MONTH_GRAPH'=>			'Gráfico del último mes',
-	'S_VALUES_OF_LAST_HOUR'=>			'Valores de la última hora',
 	'S_500_LATEST_VALUES'=>			'Los 500 últimos valores',
-	'S_GRAPH_OF_SPECIFIED_PERIOD'=>			'Gráfico del perídodo especificado',
-	'S_VALUES_OF_SPECIFIED_PERIOD'=>			'Valores del período especificado',
-	'S_VALUES_IN_PLAIN_TEXT_FORMAT'=>			'Valores en formato de texto plano',
 	'S_TIMESTAMP'=>			'Feha y hora',
 	'S_LOCAL'=>			'Local',
 	'S_SOURCE'=>			'Orígen',
-	'S_SHOW_UNKNOWN'=>			'Mostrar desconocidos',
 	'S_SHOW_SELECTED'=>			'Mostrar seleccionados',
 	'S_HIDE_SELECTED'=>			'Ocultar seleccionados',
 	'S_MARK_SELECTED'=>			'Marcar seleccionados',
@@ -503,11 +384,8 @@
 	'S_APPLICATIONS'=>			'Aplicaciones',
 	'S_APPLICATIONS_BIG'=>			'APLICACIONES',
 	'S_CREATE_APPLICATION'=>			'Crear aplicación',
-	'S_DELETE_SELECTED_APPLICATIONS_Q'=>			'¿Eliminar aplicaciones seleccionadas?',
-	'S_DISABLE_ITEMS_FROM_SELECTED_APPLICATIONS_Q'=>			'¿Desactivar los elementos de las aplicaciones seleccionadas?',
 	'S_ACTIVATE_ITEMS'=>			'Activar',
 	'S_DISABLE_ITEMS'=>			'Desactivar',
-	'S_ACTIVATE_ITEMS_FROM_SELECTED_APPLICATIONS_Q'=>			'¿Activar los elementos de las aplicaciones seleccionadas?',
 	'S_APPLICATION_UPDATED'=>			'Aplicación actualizada',
 	'S_CANNOT_UPDATE_APPLICATION'=>			'No es posible actualizar la aplicación',
 	'S_APPLICATION_ADDED'=>			'Aplicación añadida',
@@ -522,40 +400,25 @@
 	'S_GRAPHS'=>			'Gráficos',
 	'S_HOST_ADDED'=>			'Equipo añadido',
 	'S_CANNOT_ADD_HOST'=>			'No es posible añadir el equipo',
-	'S_ITEMS_ADDED'=>			'Monitores añadidos',
-	'S_CANNOT_ADD_ITEMS'=>			'No es posible añadir elementos',
 	'S_HOST_UPDATED'=>			'Equipo actualizado',
 	'S_CANNOT_UPDATE_HOST'=>			'No es posible actualizar el equipo',
 	'S_HOST_STATUS_UPDATED'=>			'Estado del equipo actualizado',
 	'S_CANNOT_UPDATE_HOST_STATUS'=>			'No es posible actualizar el estado del equipo',
 	'S_HOST_DELETED'=>			'Equipo eliminado',
 	'S_CANNOT_DELETE_HOST'=>			'No es posible eliminar el equipo',
-	'S_TEMPLATE_LINKAGE_ADDED'=>			'Plantilla vinculada añadida',
-	'S_CANNOT_ADD_TEMPLATE_LINKAGE'=>			'No es posible añadir la plantilla vinculada',
-	'S_TEMPLATE_LINKAGE_UPDATED'=>			'Plantilla vinculada actualizada',
-	'S_CANNOT_UPDATE_TEMPLATE_LINKAGE'=>			'No es posible actualizar la plantilla vinculada',
-	'S_TEMPLATE_LINKAGE_DELETED'=>			'Plantilla vinculada eliminada',
-	'S_CANNOT_DELETE_TEMPLATE_LINKAGE'=>			'No es posible eliminar la plantilla vinculada',
-	'S_CONFIGURATION_OF_HOSTS_GROUPS_AND_TEMPLATES'=>			'CONFIGURACIÓN DE EQUIPOS, PLANTILLAS, GRUPOS Y APLICACIONES',
 	'S_HOST_GROUPS_BIG'=>			'GRUPOS DE EQUIPOS',
-	'S_START'=>			'Iniciar',
-	'S_STOP'=>			'Detener',
 	'S_NO_HOST_GROUPS_DEFINED'=>			'No se han definido grupos de equipos',
-	'S_NO_LINKAGES_DEFINED'=>			'No se han definido vínculos',
 	'S_NO_HOSTS_DEFINED'=>			'No se han definido equipos',
 	'S_NO_TEMPLATES_DEFINED'=>			'No se han definido plantillas',
 	'S_HOSTS_BIG'=>			'EQUIPOS',
 	'S_HOST'=>			'Equipo/Plantilla',
-	'S_HOST_BIG'=>			'EQUIPO',
 	'S_CONNECT_TO'=>			'Conectado a',
 	'S_DNS'=>			'DNS',
 	'S_IP'=>			'IP',
 	'S_PORT'=>			'Puerto',
 	'S_MONITORED'=>			'Monitorizado',
 	'S_NOT_MONITORED'=>			'No monitorizado',
-	'S_UNREACHABLE'=>			'Inaccesible',
 	'S_TEMPLATE'=>			'Plantilla',
-	'S_TEMPLATE_SMALL'=>			'plantilla',
 	'S_DELETED'=>			'Eliminado',
 	'S_UNKNOWN'=>			'Desconocido',
 	'S_GROUPS'=>			'Grupos',
@@ -566,8 +429,6 @@
 	'S_LINK_WITH_TEMPLATE'=>			'Vincular con plantilla',
 	'S_USE_PROFILE'=>			'Utilizar perfil',
 	'S_DELETE_SELECTED_HOST_Q'=>			'¿Eliminar equipo seleccionado?',
-	'S_DELETE_SELECTED_GROUP_Q'=>			'¿Eliminar grupo seleccionado?',
-	'S_DELETE_SELECTED_GROUPS_Q'=>			'¿Eliminar grupos seleccionados?',
 	'S_DELETE_SELECTED_WITH_LINKED_ELEMENTS'=>			'Eliminar selección junto con los elementos vinculados',
 	'S_GROUP_NAME'=>			'Nombre del grupo',
 	'S_HOST_GROUP'=>			'Grupo del equipo',
@@ -587,36 +448,23 @@
 	'S_LOCATION'=>			'Localización',
 	'S_NOTES'=>			'Notas',
 	'S_MACADDRESS'=>			'Dirección MAC',
-	'S_PROFILE_ADDED'=>			'Perfil añadido',
-	'S_CANNOT_ADD_PROFILE'=>			'No es posible añadir el perfil',
-	'S_PROFILE_UPDATED'=>			'Perfil actualizado',
-	'S_CANNOT_UPDATE_PROFILE'=>			'No es posible actualizar el perfil',
-	'S_PROFILE_DELETED'=>			'Perfil eliminado',
-	'S_CANNOT_DELETE_PROFILE'=>			'No es posible eliminar el perfil',
 	'S_ADD_TO_GROUP'=>			'Añadir al grupo',
 	'S_DELETE_FROM_GROUP'=>			'Eliminar del grupo',
 	'S_UPDATE_IN_GROUP'=>			'Actualizar en el grupo',
 	'S_DELETE_SELECTED_HOSTS_Q'=>			'¿Eliminar equipos seleccionados?',
-	'S_DISABLE_SELECTED_HOSTS_Q'=>			'¿Desactivar equipos seleccionados?',
-	'S_ACTIVATE_SELECTED_HOSTS_Q'=>			'¿Activar equipos seleccionados?',
-	'S_SELECT_HOST_TEMPLATE_FIRST'=>			'Seleccionar primero una plantilla de equipo',
 	'S_CREATE_HOST'=>			'Crear Equipo',
 	'S_CREATE_TEMPLATE'=>			'Crear Plantilla',
 	'S_TEMPLATE_LINKAGE'=>			'Plantilla vinculada',
-	'S_TEMPLATE_LINKAGE_BIG'=>			'PLANTILLA VINCULADA',
-	'S_NO_LINKAGES'=>			'Sin vínculos',
 	'S_TEMPLATES'=>			'Plantillas',
 	'S_TEMPLATES_BIG'=>			'PLANTILLAS',
 	'S_UNLINK'=>			'Desvincular',
 	'S_UNLINK_AND_CLEAR'=>			'Desvincular y eliminar',
-	'S_UNLINKED_SMALL'=>			'desvinculado',
-	'S_CLEANED_SMALL'=>			'eliminado',
 	'S_NO_ITEMS_DEFINED'=>			'No se han definido monitores',
 	'S_NO_ITEM_DEFINED'=>			'No se ha definido monitor',
-	'S_HISTORY_CLEANED'=>			'Histórico eliminado',
-	'S_CLEAN_HISTORY_SELECTED_ITEMS'=>			'Eliminar histórico del monitor seleccionado',
-	'S_CLEAN_HISTORY'=>			'Eliminar histórico',
-	'S_CANNOT_CLEAN_HISTORY'=>			'No es posible eliminar el histórico',
+	'S_HISTORY_CLEARED'=>			'Histórico eliminado',
+	'S_CLEAR_HISTORY_FOR_SELECTED'=>			'Eliminar histórico del monitor seleccionado',
+	'S_CLEAR_HISTORY'=>			'Eliminar histórico',
+	'S_CANNOT_CLEAR_HISTORY'=>			'No es posible eliminar el histórico',
 	'S_CONFIGURATION_OF_ITEMS'=>			'Configuración de monitores',
 	'S_CONFIGURATION_OF_ITEMS_BIG'=>			'CONFIGURACIÓN DE MONITORES',
 	'S_CANNOT_UPDATE_ITEM'=>			'No es posible actualizar el monitor',
@@ -628,16 +476,12 @@
 	'S_ITEMS_DELETED'=>			'Monitores eliminados',
 	'S_CANNOT_DELETE_ITEMS'=>			'No es posible eliminar los monitores',
 	'S_ITEMS_ACTIVATED'=>			'Monitores activados',
-	'S_CANNOT_ACTIVATE_ITEMS'=>			'No es posible activar los monitores',
 	'S_ITEMS_DISABLED'=>			'Monitores desactivados',
-	'S_CANNOT_DISABLE_ITEMS'=>			'No es posible desactivar los monitores',
-	'S_SERVERNAME'=>			'Nombre del Servidor',
 	'S_KEY'=>			'Monitor',
 	'S_DESCRIPTION'=>			'Nombre descriptivo',
 	'S_UPDATE_INTERVAL'=>			'Refrescar cada (s)',
 	'S_HISTORY'=>			'Histórico (días)',
 	'S_TRENDS'=>			'Tendencias (días)',
-	'S_SHORT_NAME'=>			'Nombre corto',
 	'S_ZABBIX_AGENT'=>			'Agente ZABBIX',
 	'S_ZABBIX_AGENT_ACTIVE'=>			'Agente ZABBIX (activo)',
 	'S_SNMPV1_AGENT'=>			'Agente SNMPv1',
@@ -649,13 +493,8 @@
 	'S_ZABBIX_AGGREGATE'=>			'ZABBIX añadido',
 	'S_EXTERNAL_CHECK'=>			'Comprobación externa',
 	'S_WEB_MONITORING'=>			'Monitorización Web',
-	'S_ZABBIX_UNKNOWN'=>			'Desconocido',
 	'S_ACTIVE'=>			'Activado',
-	'S_NOT_ACTIVE'=>			'No activo',
 	'S_NOT_SUPPORTED'=>			'No soportado',
-	'S_ACTIVATE_SELECTED_ITEMS_Q'=>			'¿Activar los monitores seleccionados?',
-	'S_DISABLE_SELECTED_ITEMS_Q'=>			'¿Desactivar los monitores seleccionados?',
-	'S_DELETE_SELECTED_ITEMS_Q'=>			'¿Eliminar los monitores seleccionados?',
 	'S_EMAIL'=>			'Email',
 	'S_JABBER'=>			'Jabber',
 	'S_JABBER_IDENTIFIER'=>			'Identificador Jabber',
@@ -663,7 +502,6 @@
 	'S_SCRIPT'=>			'Script',
 	'S_GSM_MODEM'=>			'Modem GSM',
 	'S_UNITS'=>			'Unidad',
-	'S_MULTIPLIER'=>			'Multiplicador',
 	'S_UPDATE_INTERVAL_IN_SEC'=>			'Intervalo de actualización (en segundos)',
 	'S_KEEP_HISTORY_IN_DAYS'=>			'Conservar el histórico durante (en días)',
 	'S_KEEP_TRENDS_IN_DAYS'=>			'Conservar las tendencias durante (en días)',
@@ -693,7 +531,6 @@
 	'S_SELECT_HOST_DOT_DOT_DOT'=>			'Seleccionar equipo...',
 	'S_LOG_TIME_FORMAT'=>			'Formato de fecha para el registro',
 	'S_CREATE_ITEM'=>			'Crear monitor',
-	'S_ADD_ITEM'=>			'Añadir monitor',
 	'S_X_ELEMENTS_COPY_TO_DOT_DOT_DOT'=>			'Elementos copiados a...',
 	'S_MODE'=>			'Modo',
 	'S_TARGET'=>			'Destino',
@@ -702,15 +539,9 @@
 	'S_UPDATE_EXISTING_NON_LINKED_ITEMS'=>			'Actualizar monitores no vinculados',
 	'S_COPY'=>			'Copiar',
 	'S_SHOW_ITEMS_WITH_DESCRIPTION_LIKE'=>			'Mostrar monitores cuya descripción sea',
-	'S_SHOW_DISABLED_ITEMS'=>			'Mostrar monitores desactivados',
-	'S_HIDE_DISABLED_ITEMS'=>			'Ocultar monitores desactivados',
-	'S_HISTORY_CLEANING_CAN_TAKE_A_LONG_TIME_CONTINUE_Q'=>			'Eliminar el histórico puede llevarse tiempo. ¿Continuar?',
-	'S_ITEM_SELECTION'=>			'Búsqueda avanzada de monitores',
-	'S_SELECTION_MODE'=>			'Cambiar el modo de búsqueda a',
-	'S_ADVANCED'=>			'Avanzado',
+	'S_HISTORY_CLEARING_CAN_TAKE_A_LONG_TIME_CONTINUE_Q'=>			'Eliminar el histórico puede llevarse tiempo. ¿Continuar?',
 	'S_MASS_UPDATE'=>			'Actualizar masivamente',
 	'S_SEARCH'=>			'Buscar',
-	'S_EXTERNAL_FILTER'=>			'Búsqueda avanzada',
 	'S_ORIGINAL'=>			'Original',
 	'S_NEW_FLEXIBLE_INTERVAL'=>			'Nuevo intervalo flexible',
 	'S_FLEXIBLE_INTERVALS'=>			'Intervalos flexibles (sec)',
@@ -718,17 +549,12 @@
 	'S_HISTORY_OF_EVENTS_BIG'=>			'HISTÓRICO DE EVENTOS',
 	'S_NO_EVENTS_FOUND'=>			'No se han encontrado eventos',
 	'S_LAST_CHECK'=>			'Última comprobación',
-	'S_LAST_CHECK_BIG'=>			'ÚLTIMA COMPROBACIÓN',
 	'S_LAST_VALUE'=>			'Último valor',
 	'S_LINK'=>			'Vínculo',
 	'S_LABEL'=>			'Etiqueta',
 	'S_X'=>			'X',
 	'S_Y'=>			'Y',
-	'S_ICON_ON'=>			'Icono (correcto)',
-	'S_ICON_OFF'=>			'Icono (problema)',
 	'S_ICON_UNKNOWN'=>			'Icono (desconocido)',
-	'S_ELEMENT_1'=>			'Primer elemento',
-	'S_ELEMENT_2'=>			'Segundo elemento',
 	'S_LINK_STATUS_INDICATOR'=>			'Vincular con el estado del iniciador',
 	'S_CONFIGURATION_OF_NETWORK_MAPS'=>			'CONFIGURACIÓN DE LOS MAPAS DE LA RED',
 	'S_MAPS_BIG'=>			'MAPAS',
@@ -738,13 +564,9 @@
 	'S_BOTTOM'=>			'Debajo',
 	'S_TOP'=>			'Encima',
 	'S_OK_BIG'=>			'OK',
-	'S_PROBLEMS_SMALL'=>			'problemas',
 	'S_ZABBIX_URL'=>			'http://www.zabbix.com',
 	'S_NETWORK_MAPS'=>			'Mapas de la red',
 	'S_NETWORK_MAPS_BIG'=>			'MAPAS DE LA RED',
-	'S_NO_MAPS_TO_DISPLAY'=>			'No existen mapas para mostrar',
-	'S_SELECT_MAP_TO_DISPLAY'=>			'Seleccionar mapa a mostrar',
-	'S_SELECT_MAP_DOT_DOT_DOT'=>			'Seleccionar mapa...',
 	'S_BACKGROUND_IMAGE'=>			'Imagen de fondo',
 	'S_ICON_LABEL_TYPE'=>			'Tipo de etiqueta para el icono',
 	'S_LABEL_LOCATION'=>			'Posición de la etiqueta',
@@ -753,49 +575,15 @@
 	'S_NOTHING'=>			'Nada',
 	'S_CONFIGURATION_OF_MEDIA_TYPES_BIG'=>			'CONFIGURACIÓN DE TIPOS DE MEDIO',
 	'S_MEDIA'=>			'Medio',
-	'S_MEDIA_BIG'=>			'MEDIO',
-	'S_MEDIA_ACTIVATED'=>			'Medio activado',
-	'S_CANNOT_ACTIVATE_MEDIA'=>			'No es posible activar el medio',
-	'S_MEDIA_DISABLED'=>			'Medio desactivado',
-	'S_CANNOT_DISABLE_MEDIA'=>			'No es posible desactivar el medio',
-	'S_MEDIA_ADDED'=>			'Medio añadido',
-	'S_CANNOT_ADD_MEDIA'=>			'No es posible añadir el medio',
-	'S_MEDIA_UPDATED'=>			'Medio actualizado',
-	'S_CANNOT_UPDATE_MEDIA'=>			'No es posible actualizar el medio',
-	'S_MEDIA_DELETED'=>			'Medio eliminado',
-	'S_CANNOT_DELETE_MEDIA'=>			'No es posible eliminar el medio',
 	'S_SEND_TO'=>			'Enviar a',
 	'S_WHEN_ACTIVE'=>			'Cuando se active',
 	'S_NO_MEDIA_DEFINED'=>			'No se han definido medios',
 	'S_NEW_MEDIA'=>			'Nuevo medio',
 	'S_USE_IF_SEVERITY'=>			'Utilizar si la gravedad es',
-	'S_DELETE_SELECTED_MEDIA_Q'=>			'¿Eliminar el medio seleccionado?',
-	'S_CREATE_MEDIA'=>			'Crear Medio',
 	'S_SAVE'=>			'Guardar',
 	'S_CANCEL'=>			'Cancelar',
-	'S_MENU_LATEST_VALUES'=>			'ÚLTIMOS VALORES',
-	'S_MENU_TRIGGERS'=>			'INICIADORES',
-	'S_MENU_QUEUE'=>			'COLA',
-	'S_MENU_ALARMS'=>			'ALARMAS',
-	'S_MENU_ALERTS'=>			'ALERTAS',
-	'S_MENU_NETWORK_MAPS'=>			'MAPAS DE LA RED',
-	'S_MENU_GRAPHS'=>			'GRÁFICOS',
-	'S_MENU_SCREENS'=>			'PANTALLAS',
-	'S_MENU_IT_SERVICES'=>			'SERVICIOS TI',
-	'S_MENU_HOME'=>			'INICIO',
-	'S_MENU_ABOUT'=>			'ACERCA DE',
-	'S_MENU_STATUS_OF_ZABBIX'=>			'ESTADO DE ZABBIX',
-	'S_MENU_AVAILABILITY_REPORT'=>			'INFORME DE DISPONIBILIDAD',
-	'S_MENU_CONFIG'=>			'CONFIGURACIÓN',
-	'S_MENU_USERS'=>			'USUARIOS',
-	'S_MENU_HOSTS'=>			'EQUIPOS',
-	'S_MENU_ITEMS'=>			'ELEMENTO',
-	'S_MENU_AUDIT'=>			'AUDITORÍA',
-	'S_SWITCH_NODE'=>			'Nodo switch',
-	'S_SELECT_GROUP_DOT_DOT_DOT'=>			'Seleccionar grupo ...',
 	'S_OVERVIEW'=>			'Vistazo general',
 	'S_OVERVIEW_BIG'=>			'VISTAZO GENERAL',
-	'S_EXCL'=>			'!',
 	'S_DATA'=>			'Monitores',
 	'S_SHOW_GRAPH_OF_ITEM'=>			'Mostrar gráficos del elemento',
 	'S_SHOW_VALUES_OF_ITEM'=>			'Mostrar valores del elemento',
@@ -813,14 +601,11 @@
 	'S_30_SECONDS'=>			'30 segundos',
 	'S_1_MINUTE'=>			'1 minuto',
 	'S_5_MINUTES'=>			'5 minutos',
-	'S_MORE_THAN_5_MINUTES'=>			'Más de 5 minutos',
 	'S_STATUS_OF_ZABBIX'=>			'Estado de ZABBIX',
 	'S_STATUS_OF_ZABBIX_BIG'=>			'ESTADO DE ZABBIX',
 	'S_VALUE'=>			'Estado',
 	'S_ZABBIX_SERVER_IS_RUNNING'=>			'Servidor ZABBIX operativo',
-	'S_NUMBER_OF_VALUES_STORED'=>			'Número de valores almacenados',
 	'S_VALUES_STORED'=>			'Valores almacenados',
-	'S_NUMBER_OF_TRENDS_STORED'=>			'Número de tendencias almacenadas',
 	'S_TRENDS_STORED'=>			'Tendencias almacenadas',
 	'S_NUMBER_OF_EVENTS'=>			'Número de eventos',
 	'S_NUMBER_OF_ALERTS'=>			'Número de alertas',
@@ -839,8 +624,6 @@
 	'S_AVAILABILITY_REPORT'=>			'Informe de disponibilidad',
 	'S_AVAILABILITY_REPORT_BIG'=>			'INFORME DE DISPONIBILIDAD',
 	'S_SHOW'=>			'Mostrar',
-	'S_TRUE'=>			'Verdadero',
-	'S_FALSE'=>			'Falso',
 	'S_IT_SERVICES_AVAILABILITY_REPORT'=>			'Informe de disponibilidad de servicios TI',
 	'S_IT_SERVICES_AVAILABILITY_REPORT_BIG'=>			'INFORME DE DISPONIBILIDAD DE SERVICIOS TI',
 	'S_FROM'=>			'Desde',
@@ -882,8 +665,6 @@
 	'S_CONFIGURATION_OF_SCREEN_BIG'=>			'CONFIGURACIÓN DE LA PANTALLA',
 	'S_SCREEN_CELL_CONFIGURATION'=>			'Configuración de la celda de la pantalla',
 	'S_RESOURCE'=>			'Recurso',
-	'S_RESOURCES'=>			'Recursos',
-	'S_RESOURCE_TYPE'=>			'Tipo de recurso',
 	'S_RIGHTS_OF_RESOURCES'=>			'Derechos del usuario',
 	'S_NO_RESOURCES_DEFINED'=>			'No se han definido recursos',
 	'S_SIMPLE_GRAPH'=>			'Gráfico sencillo',
@@ -921,17 +702,14 @@
 	'S_LOCAL_TIME'=>			'Tiempo local',
 	'S_STYLE'=>			'Estilo',
 	'S_VERTICAL'=>			'Vertical',
-	'S_HORISONTAL'=>			'Horizontal',
-	'S_HORISONTAL_ALIGN'=>			'Alineación horizontal',
-	'S_CENTER'=>			'Centro',
+	'S_HORIZONTAL'=>			'Horizontal',
+	'S_HORIZONTAL_ALIGN'=>			'Alineación horizontal',
+	'S_CENTRE'=>			'Centro',
 	'S_RIGHT'=>			'Derecho',
 	'S_VERTICAL_ALIGN'=>			'Alineación vertical',
 	'S_MIDDLE'=>			'Medio',
 	'S_CUSTOM_SCREENS'=>			'Personalizar pantallas',
 	'S_SCREENS_BIG'=>			'PANTALLAS',
-	'S_NO_SCREENS_TO_DISPLAY'=>			'No existen pantallas que mostrar',
-	'S_SELECT_SCREEN_TO_DISPLAY'=>			'Seleccionar pantalla a mostrar',
-	'S_SELECT_SCREEN_DOT_DOT_DOT'=>			'Seleccionar pantalla...',
 	'S_SLIDESHOW_UPDATED'=>			'Diapositiva actualizada',
 	'S_CANNOT_UPDATE_SLIDESHOW'=>			'No es posible actualizar la diapositiva',
 	'S_SLIDESHOW_ADDED'=>			'Diapositiva añadida',
@@ -947,41 +725,20 @@
 	'S_CANNOT_UPDATE_SERVICE'=>			'No es posible actualizar el servicio',
 	'S_SERVICE_ADDED'=>			'Servicio añadido',
 	'S_CANNOT_ADD_SERVICE'=>			'No es posible añadir el servicio',
-	'S_LINK_ADDED'=>			'Vínculo añadido',
-	'S_CANNOT_ADD_LINK'=>			'No es posible añadir el vínculo',
 	'S_SERVICE_DELETED'=>			'Servicio eliminado',
 	'S_CANNOT_DELETE_SERVICE'=>			'No es posible eliminar el servicio',
-	'S_LINK_DELETED'=>			'Vínculo eliminado',
-	'S_CANNOT_DELETE_LINK'=>			'No es posible eliminar el vínculo',
 	'S_STATUS_CALCULATION'=>			'Cálculo del estado',
 	'S_STATUS_CALCULATION_ALGORITHM'=>			'Algoritmo para el cálculo del estado',
 	'S_NONE'=>			'Ninguno',
-	'S_MAX_OF_CHILDS'=>			'MAX número de hijos',
-	'S_MIN_OF_CHILDS'=>			'MIN número de hijos',
-	'S_SERVICE_1'=>			'Primer servicio',
-	'S_SERVICE_2'=>			'Segundo servicio',
-	'S_SOFT_HARD_LINK'=>			'Vínculo blando/duro',
 	'S_SOFT'=>			'Blando',
-	'S_HARD'=>			'Duro',
 	'S_DO_NOT_CALCULATE'=>			'No calculado',
-	'S_MAX_BIG'=>			'MAX',
-	'S_MIN_BIG'=>			'MIN',
-	'S_SHOW_SLA'=>			'Mostrar SLA',
 	'S_ACCEPTABLE_SLA_IN_PERCENT'=>			'SLA aceptable (en %)',
 	'S_LINK_TO_TRIGGER_Q'=>			'¿Vincular al iniciador?',
 	'S_SORT_ORDER_0_999'=>			'Orden de clasificación (0->999)',
-	'S_DELETE_SERVICE_Q'=>			'¿Eliminar el servicio?',
-	'S_LINK_TO'=>			'Vincular a',
-	'S_SOFT_LINK_Q'=>			'¿Vínculo blando?',
-	'S_ADD_SERVER_DETAILS'=>			'Añadir detalles al servidor',
 	'S_TRIGGER'=>			'Iniciadores',
 	'S_SERVER'=>			'Servidor',
 	'S_DELETE'=>			'Eliminar',
 	'S_CLONE'=>			'Clonar',
-	'S_DELETE_SELECTED_SERVICES'=>			'¿Eliminar servicios seleccionados?',
-	'S_DELETE_SELECTED_LINKS'=>			'¿Eliminar vínculos seleccionados?',
-	'S_SERVICES_DELETED'=>			'Servicios eliminados',
-	'S_CANNOT_DELETE_SERVICES'=>			'No es posible eliminar los servicios',
 	'S_UPTIME'=>			'Tiempo operativo',
 	'S_DOWNTIME'=>			'Tiempo inoperativo',
 	'S_ONE_TIME_DOWNTIME'=>			'Una vez inoperativo',
@@ -989,7 +746,6 @@
 	'S_SERVICE_TIMES'=>			'Tiempos del servicio',
 	'S_NEW_SERVICE_TIME'=>			'Nuevo tiempo del servicio',
 	'S_NOTE'=>			'Nota',
-	'S_SOFT_LINK'=>			'Enlance blando',
 	'S_REMOVE'=>			'Eliminar',
 	'S_DEPENDS_ON'=>			'Depende de',
 	'S_SUNDAY'=>			'Domingo',
@@ -1003,25 +759,15 @@
 	'S_SERVICE'=>			'Servicio',
 	'S_SERVICES'=>			'Servicios',
 	'S_REASON'=>			'Causa',
-	'S_SLA_LAST_7_DAYS'=>			'SLA (últimos 7 días)',
-	'S_PLANNED_CURRENT_SLA'=>			'SLA Previsto / SLA Actual',
-	'S_TRIGGER_BIG'=>			'INICIADOR',
 	'S_NO_TRIGGER'=>			'Sin iniciadores',
 	'S_NO_TRIGGERS_DEFINED'=>			'No se han definido iniciadores',
 	'S_NO_TRIGGER_DEFINED'=>			'No se ha definido iniciador',
 	'S_CONFIGURATION_OF_TRIGGERS'=>			'Configuración del iniciador',
 	'S_CONFIGURATION_OF_TRIGGERS_BIG'=>			'CONFIGURACIÓN DEL INICIADOR',
-	'S_DEPENDENCY_ADDED'=>			'Dependencia añadida',
-	'S_CANNOT_ADD_DEPENDENCY'=>			'No es posible añadir la dependencia',
-	'S_TRIGGERS_UPDATED'=>			'Iniciadores actualizados',
-	'S_CANNOT_UPDATE_TRIGGERS'=>			'No es posible actualizar los iniciadores',
-	'S_TRIGGERS_DISABLED'=>			'Iniciadores desactivados',
-	'S_CANNOT_DISABLE_TRIGGERS'=>			'No es posible desactivar los iniciadores',
 	'S_TRIGGERS_DELETED'=>			'Iniciadores eliminados',
 	'S_CANNOT_DELETE_TRIGGERS'=>			'No es posible eliminar los iniciadores',
 	'S_TRIGGER_DELETED'=>			'Iniciador eliminado',
 	'S_CANNOT_DELETE_TRIGGER'=>			'No es posible eliminar los iniciadores',
-	'S_INVALID_TRIGGER_EXPRESSION'=>			'Expresión del iniciador no válida',
 	'S_TRIGGER_ADDED'=>			'Iniciador añadido',
 	'S_CANNOT_ADD_TRIGGER'=>			'No es posible añadir el iniciador',
 	'S_SEVERITY'=>			'Gravedad',
@@ -1029,20 +775,14 @@
 	'S_DISABLED'=>			'Desactivado',
 	'S_ENABLED'=>			'Activado',
 	'S_ENABLE_SELECTED'=>			'Activar',
-	'S_ENABLE_SELECTED_TRIGGERS_Q'=>			'¿Activar los iniciadores seleccionados?',
-	'S_DISABLE_SELECTED_TRIGGERS_Q'=>			'¿Desactivar los iniciadores seleccionados?',
-	'S_DELETE_SELECTED_TRIGGERS_Q'=>			'¿Eliminar los iniciadores seleccionados?',
 	'S_CHANGE'=>			'Variación con valor anterior',
 	'S_TRIGGER_UPDATED'=>			'Iniciador actualizado',
 	'S_CANNOT_UPDATE_TRIGGER'=>			'No es posible actualizar el iniciador',
 	'S_URL'=>			'URL',
-	'S_INVALID_URL'=>			'URL no válida',
 	'S_CREATE_TRIGGER'=>			'Crear iniciador',
 	'S_INSERT'=>			'Insertar',
-	'S_TIMES'=>			'Tiempos',
 	'S_SECONDS'=>			'Segundos',
 	'S_SEC_SMALL'=>			'seg',
-	'S_COUNTS'=>			'Contador',
 	'S_LAST_OF'=>			'El último de',
 	'S_SHOW_DISABLED_TRIGGERS'=>			'Mostrar iniciadores desactivados',
 	'S_HIDE_DISABLED_TRIGGERS'=>			'Ocultar iniciadores desactivados',
@@ -1053,17 +793,9 @@
 	'S_ADD'=>			'Añadir',
 	'S_STATUS_OF_TRIGGERS'=>			'Estado de los iniciadores',
 	'S_STATUS_OF_TRIGGERS_BIG'=>			'ESTADO DE LOS INICIADORES',
-	'S_SHOW_ONLY_TRUE'=>			'Mostrar sólo con problemas',
-	'S_HIDE_ACTIONS'=>			'Ocultar las acciones',
-	'S_SHOW_ACTIONS'=>			'Mostrar las acciones',
-	'S_HIDE_DETAILS'=>			'Ocultar detalles',
 	'S_SHOW_DETAILS'=>			'Mostrar detalles',
 	'S_SELECT'=>			'Seleccionar / Examinar...',
-	'S_HIDE_SELECT'=>			'Ocultar seleccionados',
 	'S_TRIGGERS_BIG'=>			'INICIADORES',
-	'S_NAME_BIG'=>			'NOMBRE',
-	'S_SEVERITY_BIG'=>			'GRAVEDAD',
-	'S_LAST_CHANGE_BIG'=>			'ÚLTIMO CAMBIO',
 	'S_LAST_CHANGE'=>			'Último cambio',
 	'S_COMMENTS'=>			'Comentarios',
 	'S_ACKNOWLEDGED'=>			'Aceptada',
@@ -1079,12 +811,7 @@
 	'S_CANNOT_ADD_USER_BOTH_PASSWORDS_MUST'=>			'No es posible añadir al usuario. Ambas contraseñas deben ser iguales.',
 	'S_USER_DELETED'=>			'Usuario eliminado',
 	'S_CANNOT_DELETE_USER'=>			'No es posible eliminar al usuario',
-	'S_PERMISSION_DELETED'=>			'Permiso eliminado',
-	'S_CANNOT_DELETE_PERMISSION'=>			'No es posible eliminar el permiso',
-	'S_PERMISSION_ADDED'=>			'Permiso añadido',
-	'S_CANNOT_ADD_PERMISSION'=>			'No es posible añadir el permiso',
 	'S_USER_UPDATED'=>			'Usuario actualizado',
-	'S_ONLY_FOR_GUEST_ALLOWED_EMPTY_PASSWORD'=>			'Sólo el usuario \'invitado\' puede tener vacía la contraseña.',
 	'S_CANNOT_UPDATE_USER'=>			'No es posible actualizar al usuario',
 	'S_CANNOT_UPDATE_USER_BOTH_PASSWORDS'=>			'No es posible actualizar al usuario. Ambas contraseñas deben ser iguales.',
 	'S_GROUP_ADDED'=>			'Grupo añadido',
@@ -1098,19 +825,14 @@
 	'S_USERS_BIG'=>			'USUARIOS',
 	'S_USER_GROUPS'=>			'Grupos de usuarios',
 	'S_MEMBERS'=>			'Miembros',
-	'S_HOSTS_TEMPLATES_LINKAGE'=>			'Vínculos de Equipos / Plantillas',
-	'S_CONFIGURATION_OF_TEMPLATES_LINKAGE'=>			'CONFIGURACION DE VÍNCULOS DE PLANTILLAS',
-	'S_LINKED_TEMPLATES_BIG'=>			'PLANTILLAS VINCULADAS',
 	'S_NO_USER_GROUPS_DEFINED'=>			'No se han definio grupos de usuarios',
 	'S_ALIAS'=>			'Alias',
 	'S_NAME'=>			'Nombre',
 	'S_SURNAME'=>			'Apellido',
 	'S_IS_ONLINE_Q'=>			'¿Está conectado?',
 	'S_NO_USERS_DEFINED'=>			'No se han definido usuarios',
-	'S_PERMISSION'=>			'Permiso',
 	'S_RIGHTS'=>			'Derechos',
 	'S_NO_RIGHTS_DEFINED'=>			'No se han definido derechos',
-	'S_RESOURCE_NAME'=>			'Nombre del recurso',
 	'S_READ_ONLY'=>			'Sólo lectura',
 	'S_READ_WRITE'=>			'Lectura-escritura',
 	'S_DENY'=>			'Denegar',
@@ -1119,21 +841,16 @@
 	'S_CHANGE_PASSWORD'=>			'Cambiar la contraseña',
 	'S_PASSWORD_ONCE_AGAIN'=>			'Contraseña (de nuevo)',
 	'S_URL_AFTER_LOGIN'=>			'URL (después de iniciar sesión)',
-	'S_AUTO_LOGOUT_IN_SEC'=>			'Auto finalizar sesión (en segundos =>0 - desactiva)',
 	'S_SCREEN_REFRESH'=>			'Refrescar (en segundos)',
 	'S_CREATE_USER'=>			'Crear Usuario',
 	'S_CREATE_GROUP'=>			'Crear Grupo',
 	'S_DELETE_SELECTED_USERS_Q'=>			'¿Eliminar usuarios seccionados?',
 	'S_NO_ACCESSIBLE_RESOURCES'=>			'Sin recursos accesibles',
-	'S_AUDIT_LOG'=>			'Registro de Auditoria',
-	'S_AUDIT_LOG_BIG'=>			'REGISTRO DE AUDITORIA',
 	'S_ACTION'=>			'Acción',
 	'S_DETAILS'=>			'Detalles',
 	'S_UNKNOWN_ACTION'=>			'Acción desconocida',
 	'S_ADDED'=>			'Añadido',
 	'S_UPDATED'=>			'Actualizado',
-	'S_LOGGED_IN'=>			'Conectado',
-	'S_LOGGED_OUT'=>			'Desconectado',
 	'S_MEDIA_TYPE'=>			'Tipo de medio',
 	'S_GRAPH_ELEMENT'=>			'Elemento del gráfico',
 	'S_UNKNOWN_RESOURCE'=>			'Recurso desconocido',
@@ -1174,6 +891,6 @@
 	'S_LATEST_DATA'=>			'Última fecha',
 	'S_INCORRECT_DESCRIPTION'=>			'Descripción incorrecta',
 	'S_CANT_FORMAT_TREE'=>			'No es posible dar formato al Árbol',
-	
+
 	);
-?>
\ No newline at end of file
+?>
