@@ -1,5 +1,5 @@
 <?php
-/* 
+/*
 ** ZABBIX
 ** Copyright (C) 2000-2008 SIA Zabbix
 **
@@ -31,22 +31,12 @@
 	'S_ACKNOWLEDGE'=>			'Bekräfta',
 	'S_ACKNOWLEDGE_ALARM_BY'=>			'Bekräfta alarm för',
 	'S_ADD_COMMENT_BY'=>			'Lägg till kommentar av',
-	'S_COMMENT_ADDED'=>			'Kommentar lades till',
-	'S_CANNOT_ADD_COMMENT'=>			'Kan inte lägga till kommentar',
 	'S_ALARM_ACKNOWLEDGES_BIG'=>			'ALARMBEKRÄFTELSER',
 	'S_CONFIGURATION_OF_ACTIONS'=>			'Konfiguration av åtgärder',
 	'S_CONFIGURATION_OF_ACTIONS_BIG'=>			'KONFIGURATION AV ÅTGÄRDER',
-	'S_FILTER_HOST_GROUP'=>			'Filter: Värdgrupp',
-	'S_FILTER_HOST'=>			'Filter: Värd',
-	'S_FILTER_TRIGGER'=>			'Filter: Utlösare',
-	'S_FILTER_TRIGGER_NAME'=>			'Filter: Namn på utlösare',
-	'S_FILTER_TRIGGER_SEVERITY'=>			'Filter: Allvarligtsgrad för utlösare',
-	'S_FILTER_WHEN_TRIGGER_BECOMES'=>			'Filter: När utlösare blir',
 	'S_SEND_MESSAGE'=>			'Skicka meddelande',
 	'S_REMOTE_COMMAND'=>			'Fjärrkommando',
 	'S_FILTER'=>			'Filter',
-	'S_FILTER_TYPE'=>			'Filtertyp',
-	'S_TRIGGER_NAME'=>			'Namn på utlösare',
 	'S_TRIGGER_SEVERITY'=>			'Allvarlighetsgrad för utlösare',
 	'S_TRIGGER_VALUE'=>			'Värde för utlösare',
 	'S_TIME_PERIOD'=>			'Tidsperiod',
@@ -64,9 +54,7 @@
 	'S_CANNOT_UPDATE_ACTION'=>			'Kan inte uppdatera åtgärd',
 	'S_ACTION_DELETED'=>			'Åtgärd borttagen',
 	'S_CANNOT_DELETE_ACTION'=>			'Kan inte ta bort åtgärd',
-	'S_SCOPE'=>			'Omfång',
 	'S_SEND_MESSAGE_TO'=>			'Skicka meddelande till',
-	'S_WHEN_TRIGGER'=>			'När utlösare',
 	'S_DELAY'=>			'Fördröjning',
 	'S_SUBJECT'=>			'Ämne',
 	'S_ON'=>			'P',
@@ -76,14 +64,7 @@
 	'S_USER_GROUP'=>			'Användargrupp',
 	'S_GROUP'=>			'Grupp',
 	'S_USER'=>			'Användare',
-	'S_ON_OR_OFF'=>			'PÅ eller AV',
-	'S_DELAY_BETWEEN_MESSAGES_IN_SEC'=>			'Fördröjning mellan meddelanden (i sekunder)',
-	'S_DELAY_BETWEEN_EXECUTIONS_IN_SEC'=>			'Fördröjning mellan körningar (i sekunder)',
 	'S_MESSAGE'=>			'Meddelande',
-	'S_THIS_TRIGGER_ONLY'=>			'Endast denna utlösare',
-	'S_ALL_TRIGGERS_OF_THIS_HOST'=>			'Alla utlösare på denna värd',
-	'S_ALL_TRIGGERS'=>			'Alla utlösare',
-	'S_USE_IF_TRIGGER_SEVERITY'=>			'Använd om utlösarens allvarlighetsgrad är lika med eller mer än',
 	'S_NOT_CLASSIFIED'=>			'Inte klassifierad',
 	'S_INFORMATION'=>			'Information',
 	'S_WARNING'=>			'Varning',
@@ -91,65 +72,24 @@
 	'S_HIGH'=>			'Hög',
 	'S_DISASTER'=>			'Allvarlig',
 	'S_CREATE_ACTION'=>			'Skapa åtgärd',
-	'S_ALARMS'=>			'Alarm',
-	'S_ALARMS_SMALL'=>			'Alarm',
-	'S_ALARMS_BIG'=>			'ALARM',
-	'S_SHOW_ONLY_LAST_100'=>			'Visa endast de 100 senaste',
 	'S_SHOW_ALL'=>			'Visa alla',
 	'S_TIME'=>			'Tid',
 	'S_STATUS'=>			'Status',
 	'S_DURATION'=>			'Längd',
-	'S_SUM'=>			'Summa',
 	'S_TRUE_BIG'=>			'SANT',
 	'S_FALSE_BIG'=>			'FALSKT',
-	'S_DISABLED_BIG'=>			'INAKTIVERAT',
 	'S_UNKNOWN_BIG'=>			'OKÄNT',
-	'S_HISTORY_OF_ACTIONS_BIG'=>			'ÅTGÄRDSHISTORIK',
-	'S_LATEST_ACTIONS'=>			'Senaste åtgärderna',
-	'S_ALERTS_BIG'=>			'LARM',
 	'S_TYPE'=>			'Typ',
 	'S_RECIPIENTS'=>			'Mottagare',
 	'S_ERROR'=>			'Fel',
 	'S_SENT'=>			'skickat',
 	'S_NOT_SENT'=>			'inte skickat',
 	'S_NO_ACTIONS_FOUND'=>			'Inga åtgärder hittades',
-	'S_SHOW_NEXT_100'=>			'Visa nästa 100',
-	'S_SHOW_PREVIOUS_100'=>			'Visa föregående 100',
 	'S_CUSTOM_GRAPHS'=>			'Anpassade diagram',
 	'S_GRAPHS_BIG'=>			'DIAGRAM',
-	'S_NO_GRAPHS_TO_DISPLAY'=>			'Inga diagram att visa',
 	'S_SELECT_GRAPH_TO_DISPLAY'=>			'Välj diagram att visa',
 	'S_PERIOD'=>			'Period',
-	'S_1H'=>			'1h',
-	'S_2H'=>			'2h',
-	'S_4H'=>			'4h',
-	'S_8H'=>			'8h',
-	'S_12H'=>			'12h',
-	'S_24H'=>			'24h',
-	'S_WEEK_SMALL'=>			'vecka',
-	'S_MONTH_SMALL'=>			'månad',
-	'S_YEAR_SMALL'=>			'år',
-	'S_KEEP_PERIOD'=>			'Behåll period',
-	'S_ON_C'=>			'P',
-	'S_OFF_C'=>			'Av',
-	'S_MOVE'=>			'Flytta',
-	'S_NAVIGATE'=>			'Navigera',
-	'S_INCREASE'=>			'Öka',
-	'S_DECREASE'=>			'Minska',
-	'S_RIGHT_DIR'=>			'Höger',
-	'S_LEFT_DIR'=>			'Vänster',
 	'S_SELECT_GRAPH_DOT_DOT_DOT'=>			'Välj diagram...',
-	'S_BLACK'=>			'Svart',
-	'S_BLUE'=>			'Bl',
-	'S_CYAN'=>			'Cyan',
-	'S_DARK_BLUE'=>			'Mörkblå',
-	'S_DARK_GREEN'=>			'Mörkgrön',
-	'S_DARK_RED'=>			'Mörkröd',
-	'S_DARK_YELLOW'=>			'Mörkgul',
-	'S_GREEN'=>			'Grön',
-	'S_RED'=>			'Röd',
-	'S_WHITE'=>			'Vit',
-	'S_YELLOW'=>			'Gul',
 	'S_CANNNOT_UPDATE_VALUE_MAP'=>			'Kan inte uppdatera värdeskarta',
 	'S_VALUE_MAP_ADDED'=>			'Värdeskarta lades till',
 	'S_CANNNOT_ADD_VALUE_MAP'=>			'Kan inte lägga till värdeskarta',
@@ -187,28 +127,8 @@
 	'S_MEDIA_TYPES'=>			'Mediatyper',
 	'S_ESCALATION_RULES'=>			'Eskaleringsregler',
 	'S_ESCALATION'=>			'Eskalering',
-	'S_ESCALATION_RULES_BIG'=>			'ESKALERINGSREGLER',
-	'S_NO_ESCALATION_RULES_DEFINED'=>			'Inga eskaleringsregler har definierats',
-	'S_NO_ESCALATION_DETAILS'=>			'Inga eskaleringsdetaljer',
-	'S_ESCALATION_DETAILS_BIG'=>			'ESKALERINGSDETALJER',
-	'S_ESCALATION_ADDED'=>			'Eskalering lades till',
-	'S_ESCALATION_WAS_NOT_ADDED'=>			'Eskalering lades inte till',
-	'S_ESCALATION_RULE_ADDED'=>			'Eskaleringsregel lades till',
-	'S_ESCALATION_RULE_WAS_NOT_ADDED'=>			'Eskaleringsregel lades inte till',
-	'S_ESCALATION_RULE_UPDATED'=>			'Eskaleringsregel uppdaterades',
-	'S_ESCALATION_RULE_WAS_NOT_UPDATED'=>			'Eskaleringsregel uppdaterades inte',
-	'S_ESCALATION_RULE_DELETED'=>			'Eskaleringsregel togs bort',
-	'S_ESCALATION_RULE_WAS_NOT_DELETED'=>			'Eskaleringsregel togs inte bort',
-	'S_ESCALATION_UPDATED'=>			'Eskalering uppdaterad',
-	'S_ESCALATION_WAS_NOT_UPDATED'=>			'Eskalering inte uppdaterad',
-	'S_ESCALATION_DELETED'=>			'Eskalering togs bort',
-	'S_ESCALATION_WAS_NOT_DELETED'=>			'Eskalering togs inte bort',
 	'S_ESCALATION_RULE'=>			'Eskaleringsregel',
-	'S_DO'=>			'Gör',
 	'S_DEFAULT'=>			'Standard',
-	'S_IS_DEFAULT'=>			'Är standard',
-	'S_LEVEL'=>			'Niv',
-	'S_DELAY_BEFORE_ACTION'=>			'Fördröjning innan åtgärd',
 	'S_IMAGES'=>			'Bilder',
 	'S_IMAGE'=>			'Bild',
 	'S_IMAGES_BIG'=>			'BILDER',
@@ -222,41 +142,27 @@
 	'S_CANNOT_DELETE_IMAGE'=>			'Kan inte ta bort bild',
 	'S_IMAGE_UPDATED'=>			'Bild uppdaterades',
 	'S_CANNOT_UPDATE_IMAGE'=>			'Kan inte uppdatera bild',
-	'S_UPDATE_SELECTED_IMAGE'=>			'Uppdatera markerad bild?',
-	'S_PRIORITY'=>			'Prioritet',
-	'S_PATTERN'=>			'Mönster',
 	'S_OTHER'=>			'Övrigt',
 	'S_OTHER_PARAMETERS'=>			'Övriga parametrar',
 	'S_REFRESH_UNSUPPORTED_ITEMS'=>			'Uppdatera objekt som inte stöds (i sekunder)',
 	'S_CREATE_MEDIA_TYPE'=>			'Skapa mediatyp',
 	'S_CREATE_IMAGE'=>			'Skapa bild',
 	'S_WORKING_TIME'=>			'Arbetstid',
-	'S_LATEST_VALUES'=>			'Senaste värden',
 	'S_NO_PERMISSIONS'=>			'Inga rättigheter!',
 	'S_LATEST_DATA_BIG'=>			'SENASTE DATA',
 	'S_ALL_SMALL'=>			'alla',
 	'S_MINUS_ALL_MINUS'=>			'- alla -',
 	'S_MINUS_OTHER_MINUS'=>			'- övriga -',
-	'S_DESCRIPTION_LARGE'=>			'BESKRIVNING',
-	'S_DESCRIPTION_SMALL'=>			'Beskrivning',
 	'S_GRAPH'=>			'Diagram',
-	'S_TREND'=>			'Trend',
-	'S_COMPARE'=>			'Jämför',
 	'S_CONNECTED_AS'=>			'Ansluten som',
-	'S_CONFIGURATION_OF_GRAPH'=>			'Konfiguration av diagram',
-	'S_CONFIGURATION_OF_GRAPH_BIG'=>			'KONFIGURATION AV DIAGRAM',
 	'S_ITEM_ADDED'=>			'Objekt lades till',
 	'S_ITEM_UPDATED'=>			'Objekt uppdaterades',
-	'S_SORT_ORDER_UPDATED'=>			'Sorteringsordning uppdaterades',
-	'S_CANNOT_UPDATE_SORT_ORDER'=>			'Kan inte uppdatera sorteringsordning',
-	'S_DISPLAYED_PARAMETERS_BIG'=>			'VISADE PARAMETRAR',
-	'S_SORT_ORDER'=>			'Sorteringsordning',
 	'S_PARAMETER'=>			'Parameter',
 	'S_COLOR'=>			'Färg',
 	'S_UP'=>			'Uppåt',
 	'S_DOWN'=>			'Nedåt',
 	'S_NEW_ITEM_FOR_THE_GRAPH'=>			'Nytt objekt för diagrammet',
-	'S_SORT_ORDER_1_100'=>			'Sorteringsordning (0->100)',
+	'S_SORT_ORDER_0_100'=>			'Sorteringsordning (0->100)',
 	'S_YAXIS_SIDE'=>			'Y-axel',
 	'S_LEFT'=>			'Vänster',
 	'S_FUNCTION'=>			'Funktion',
@@ -278,7 +184,6 @@
 	'S_ID'=>			'Id',
 	'S_NO_GRAPHS_DEFINED'=>			'Inga diagram har definierats',
 	'S_DELETE_GRAPH_Q'=>			'Ta bort diagram?',
-	'S_YAXIS_TYPE'=>			'Y-axel',
 	'S_YAXIS_MIN_VALUE'=>			'MIN-värde för Y-axel',
 	'S_YAXIS_MAX_VALUE'=>			'MAX-värde för Y-axel',
 	'S_CALCULATED'=>			'Beräknade',
@@ -287,11 +192,7 @@
 	'S_SHOW_WORKING_TIME'=>			'Visa arbetstid',
 	'S_SHOW_TRIGGERS'=>			'Visa utlösare',
 	'S_LAST_HOUR_GRAPH'=>			'Diagram för senaste timmen',
-	'S_VALUES_OF_LAST_HOUR'=>			'Värden för senaste timmen',
 	'S_500_LATEST_VALUES'=>			'500 senaste värdena',
-	'S_GRAPH_OF_SPECIFIED_PERIOD'=>			'Diagram för angiven period',
-	'S_VALUES_OF_SPECIFIED_PERIOD'=>			'Värden för angiven period',
-	'S_VALUES_IN_PLAIN_TEXT_FORMAT'=>			'Värden i rent textformat',
 	'S_TIMESTAMP'=>			'Tidsstämpel',
 	'S_LOCAL'=>			'Lokal',
 	'S_SOURCE'=>			'Källa',
@@ -306,9 +207,6 @@
 	'S_APPLICATIONS'=>			'Program',
 	'S_APPLICATIONS_BIG'=>			'PROGRAM',
 	'S_CREATE_APPLICATION'=>			'Skapa program',
-	'S_DELETE_SELECTED_APPLICATIONS_Q'=>			'Ta bort markerade program?',
-	'S_DISABLE_ITEMS_FROM_SELECTED_APPLICATIONS_Q'=>			'Inaktivera objekt från markerade program?',
-	'S_ACTIVATE_ITEMS_FROM_SELECTED_APPLICATIONS_Q'=>			'Aktivera objekt från markerade program?',
 	'S_APPLICATION_UPDATED'=>			'Program uppdaterat',
 	'S_CANNOT_UPDATE_APPLICATION'=>			'Kan inte uppdatera program',
 	'S_APPLICATION_ADDED'=>			'Program lades till',
@@ -322,26 +220,14 @@
 	'S_GRAPHS'=>			'Diagram',
 	'S_HOST_ADDED'=>			'Värd lades till',
 	'S_CANNOT_ADD_HOST'=>			'Kan inte lägga till värd',
-	'S_ITEMS_ADDED'=>			'Objekt lades till',
-	'S_CANNOT_ADD_ITEMS'=>			'Kan inte lägga till objekt',
 	'S_HOST_UPDATED'=>			'Värd uppdaterades',
 	'S_CANNOT_UPDATE_HOST'=>			'Kan inte uppdatera värd',
 	'S_HOST_STATUS_UPDATED'=>			'Värdstatus uppdaterades',
 	'S_CANNOT_UPDATE_HOST_STATUS'=>			'Kan inte uppdatera värdstatus',
 	'S_HOST_DELETED'=>			'Värd togs bort',
 	'S_CANNOT_DELETE_HOST'=>			'Kan inte ta bort värd',
-	'S_TEMPLATE_LINKAGE_ADDED'=>			'Mallkoppling lades till',
-	'S_CANNOT_ADD_TEMPLATE_LINKAGE'=>			'Kan inte lägga till mallkoppling',
-	'S_TEMPLATE_LINKAGE_UPDATED'=>			'Mallkoppling uppdaterades',
-	'S_CANNOT_UPDATE_TEMPLATE_LINKAGE'=>			'Kan inte uppdatera mallkoppling',
-	'S_TEMPLATE_LINKAGE_DELETED'=>			'Mallkoppling togs bort',
-	'S_CANNOT_DELETE_TEMPLATE_LINKAGE'=>			'Kan inte ta bort mallkoppling',
-	'S_CONFIGURATION_OF_HOSTS_GROUPS_AND_TEMPLATES'=>			'KONFIGURATION AV VÄRDAR, GRUPPER OCH MALLAR',
 	'S_HOST_GROUPS_BIG'=>			'VÄRDGRUPPER',
-	'S_START'=>			'Start',
-	'S_STOP'=>			'Stopp',
 	'S_NO_HOST_GROUPS_DEFINED'=>			'Inga värdgrupper har definierats',
-	'S_NO_LINKAGES_DEFINED'=>			'Inga kopplingar har definierats',
 	'S_NO_HOSTS_DEFINED'=>			'Inga värdar har definierats',
 	'S_HOSTS_BIG'=>			'VÄRDAR',
 	'S_HOST'=>			'Värd',
@@ -349,7 +235,6 @@
 	'S_PORT'=>			'Port',
 	'S_MONITORED'=>			'Övervakad',
 	'S_NOT_MONITORED'=>			'Inte övervakad',
-	'S_UNREACHABLE'=>			'Inte nåbar',
 	'S_TEMPLATE'=>			'Mall',
 	'S_DELETED'=>			'Borttagen',
 	'S_UNKNOWN'=>			'Okänd',
@@ -359,8 +244,6 @@
 	'S_LINK_WITH_TEMPLATE'=>			'Koppla mot mall',
 	'S_USE_PROFILE'=>			'Använd profil',
 	'S_DELETE_SELECTED_HOST_Q'=>			'Ta bort markerad värd?',
-	'S_DELETE_SELECTED_GROUP_Q'=>			'Ta bort markerad grupp?',
-	'S_DELETE_SELECTED_GROUPS_Q'=>			'Ta bort markerade grupper?',
 	'S_GROUP_NAME'=>			'Gruppnamn',
 	'S_HOST_GROUP'=>			'Värdgrupp',
 	'S_HOST_GROUPS'=>			'Värdgrupper',
@@ -379,29 +262,18 @@
 	'S_LOCATION'=>			'Plats',
 	'S_NOTES'=>			'Anteckningar',
 	'S_MACADDRESS'=>			'MAC-adress',
-	'S_PROFILE_ADDED'=>			'Profil lades till',
-	'S_CANNOT_ADD_PROFILE'=>			'Kan inte lägga till profil',
-	'S_PROFILE_UPDATED'=>			'Profil uppdaterad',
-	'S_CANNOT_UPDATE_PROFILE'=>			'Kan inte uppdatera profil',
-	'S_PROFILE_DELETED'=>			'Profil borttagen',
-	'S_CANNOT_DELETE_PROFILE'=>			'Kan inte ta bort profil',
 	'S_ADD_TO_GROUP'=>			'Lägg till i grupp',
 	'S_DELETE_FROM_GROUP'=>			'Ta bort från grupp',
 	'S_UPDATE_IN_GROUP'=>			'Uppdatera i grupp',
 	'S_DELETE_SELECTED_HOSTS_Q'=>			'Ta bort markerade värdar?',
-	'S_DISABLE_SELECTED_HOSTS_Q'=>			'Inaktivera markerade värdar?',
-	'S_ACTIVATE_SELECTED_HOSTS_Q'=>			'Aktivera markerade värdar?',
-	'S_SELECT_HOST_TEMPLATE_FIRST'=>			'Välj värdmall först',
 	'S_CREATE_HOST'=>			'Skapa värd',
 	'S_CREATE_TEMPLATE'=>			'Skapa mall',
 	'S_TEMPLATE_LINKAGE'=>			'Mallkoppling',
-	'S_TEMPLATE_LINKAGE_BIG'=>			'MALLKOPPLING',
-	'S_NO_LINKAGES'=>			'Inga kopplingar',
 	'S_TEMPLATES'=>			'Mallar',
 	'S_TEMPLATES_BIG'=>			'MALLAR',
 	'S_NO_ITEMS_DEFINED'=>			'Inga objekt har definierats',
-	'S_HISTORY_CLEANED'=>			'Historik rensad',
-	'S_CANNOT_CLEAN_HISTORY'=>			'Kan inte rensa historik',
+	'S_HISTORY_CLEARED'=>			'Historik rensad',
+	'S_CANNOT_CLEAR_HISTORY'=>			'Kan inte rensa historik',
 	'S_CONFIGURATION_OF_ITEMS'=>			'Konfiguration av objekt',
 	'S_CONFIGURATION_OF_ITEMS_BIG'=>			'KONFIGURATION AV OBJEKT',
 	'S_CANNOT_UPDATE_ITEM'=>			'Kan inte uppdatera objekt',
@@ -413,16 +285,12 @@
 	'S_ITEMS_DELETED'=>			'Objekt borttagna',
 	'S_CANNOT_DELETE_ITEMS'=>			'Kan inte ta bort objekt',
 	'S_ITEMS_ACTIVATED'=>			'Objekt aktiverade',
-	'S_CANNOT_ACTIVATE_ITEMS'=>			'Kan inte aktivera objekt',
 	'S_ITEMS_DISABLED'=>			'Objekt inaktiverade',
-	'S_CANNOT_DISABLE_ITEMS'=>			'Kan inte inaktivera objekt',
-	'S_SERVERNAME'=>			'Servernamn',
 	'S_KEY'=>			'Nyckel',
 	'S_DESCRIPTION'=>			'Beskrivning',
 	'S_UPDATE_INTERVAL'=>			'Uppdateringsintervall',
 	'S_HISTORY'=>			'Historik',
 	'S_TRENDS'=>			'Trender',
-	'S_SHORT_NAME'=>			'Kortnamn',
 	'S_ZABBIX_AGENT'=>			'ZABBIX-agent',
 	'S_ZABBIX_AGENT_ACTIVE'=>			'ZABBIX-agent (aktiv)',
 	'S_SNMPV1_AGENT'=>			'SNMPv1-agent',
@@ -432,19 +300,13 @@
 	'S_SNMPV3_AGENT'=>			'SNMPv3-agent',
 	'S_ZABBIX_INTERNAL'=>			'ZABBIX internt',
 	'S_ZABBIX_AGGREGATE'=>			'ZABBIX samlat',
-	'S_ZABBIX_UNKNOWN'=>			'Okänd',
 	'S_ACTIVE'=>			'Aktiv',
-	'S_NOT_ACTIVE'=>			'Inte aktiv',
 	'S_NOT_SUPPORTED'=>			'Stöds inte',
-	'S_ACTIVATE_SELECTED_ITEMS_Q'=>			'Aktivera markerade objekt?',
-	'S_DISABLE_SELECTED_ITEMS_Q'=>			'Inaktivera markerade objekt?',
-	'S_DELETE_SELECTED_ITEMS_Q'=>			'Ta bort markerade objekt?',
 	'S_EMAIL'=>			'E-post',
 	'S_SMS'=>			'SMS',
 	'S_SCRIPT'=>			'Skript',
 	'S_GSM_MODEM'=>			'GSM-modem',
 	'S_UNITS'=>			'Enheter',
-	'S_MULTIPLIER'=>			'Faktor',
 	'S_UPDATE_INTERVAL_IN_SEC'=>			'Uppdateringsintervall (i sekunder)',
 	'S_KEEP_HISTORY_IN_DAYS'=>			'Behåll historik (i dagar)',
 	'S_KEEP_TRENDS_IN_DAYS'=>			'Behåll trender (i dagar)',
@@ -474,21 +336,15 @@
 	'S_SELECT_HOST_DOT_DOT_DOT'=>			'Välj värd...',
 	'S_LOG_TIME_FORMAT'=>			'Tidsformat för logg',
 	'S_CREATE_ITEM'=>			'Skapa objekt',
-	'S_ADD_ITEM'=>			'Lägg till objekt',
 	'S_LATEST_EVENTS'=>			'Senaste händelser',
 	'S_HISTORY_OF_EVENTS_BIG'=>			'HÄNDELSEHISTORIK',
 	'S_NO_EVENTS_FOUND'=>			'Inga händelser hittades',
 	'S_LAST_CHECK'=>			'Senaste kontroll',
-	'S_LAST_CHECK_BIG'=>			'SENASTE KONTROLL',
 	'S_LAST_VALUE'=>			'Senaste värde',
 	'S_LINK'=>			'Länk',
 	'S_LABEL'=>			'Etikett',
 	'S_X'=>			'X',
 	'S_Y'=>			'Y',
-	'S_ICON_ON'=>			'Ikon (på)',
-	'S_ICON_OFF'=>			'Ikon (av)',
-	'S_ELEMENT_1'=>			'Element 1',
-	'S_ELEMENT_2'=>			'Element 2',
 	'S_LINK_STATUS_INDICATOR'=>			'Länkstatusindikator',
 	'S_CONFIGURATION_OF_NETWORK_MAPS'=>			'KONFIGURATION AV NÄTVERKSKARTOR',
 	'S_MAPS_BIG'=>			'KARTOR',
@@ -498,13 +354,9 @@
 	'S_BOTTOM'=>			'Nederkant',
 	'S_TOP'=>			'Överkant',
 	'S_OK_BIG'=>			'OK',
-	'S_PROBLEMS_SMALL'=>			'problem',
 	'S_ZABBIX_URL'=>			'http://www.zabbix.com',
 	'S_NETWORK_MAPS'=>			'Nätverkskartor',
 	'S_NETWORK_MAPS_BIG'=>			'NÄTVERKSKARTOR',
-	'S_NO_MAPS_TO_DISPLAY'=>			'Inga kartor att visa',
-	'S_SELECT_MAP_TO_DISPLAY'=>			'Välj karta att visa',
-	'S_SELECT_MAP_DOT_DOT_DOT'=>			'Välj karta...',
 	'S_BACKGROUND_IMAGE'=>			'Bakgrundsbild',
 	'S_ICON_LABEL_TYPE'=>			'Typ av ikonetikett',
 	'S_LABEL_LOCATION'=>			'Etikettposition',
@@ -512,48 +364,15 @@
 	'S_STATUS_ONLY'=>			'Endast status',
 	'S_NOTHING'=>			'Ingenting',
 	'S_MEDIA'=>			'Media',
-	'S_MEDIA_BIG'=>			'MEDIA',
-	'S_MEDIA_ACTIVATED'=>			'Media aktiverat',
-	'S_CANNOT_ACTIVATE_MEDIA'=>			'Kan inte aktivera media',
-	'S_MEDIA_DISABLED'=>			'Media inaktiverat',
-	'S_CANNOT_DISABLE_MEDIA'=>			'Kan inte inaktivera media',
-	'S_MEDIA_ADDED'=>			'Media lades till',
-	'S_CANNOT_ADD_MEDIA'=>			'Kan inte lägga till media',
-	'S_MEDIA_UPDATED'=>			'Media updaterat',
-	'S_CANNOT_UPDATE_MEDIA'=>			'Kan inte uppdatera media',
-	'S_MEDIA_DELETED'=>			'Media togs bort',
-	'S_CANNOT_DELETE_MEDIA'=>			'Kan inte ta bort media',
 	'S_SEND_TO'=>			'Skicka till',
 	'S_WHEN_ACTIVE'=>			'När aktiv',
 	'S_NO_MEDIA_DEFINED'=>			'Inget media har definierats',
 	'S_NEW_MEDIA'=>			'Nytt media',
 	'S_USE_IF_SEVERITY'=>			'Använd om allvarlighetsgrad',
-	'S_DELETE_SELECTED_MEDIA_Q'=>			'Ta bort markerat media?',
-	'S_CREATE_MEDIA'=>			'Skapa media',
 	'S_SAVE'=>			'Spara',
 	'S_CANCEL'=>			'Avbryt',
-	'S_MENU_LATEST_VALUES'=>			'SENASTE VÄRDEN',
-	'S_MENU_TRIGGERS'=>			'UTLÖSARE',
-	'S_MENU_QUEUE'=>			'K',
-	'S_MENU_ALARMS'=>			'ALARM',
-	'S_MENU_ALERTS'=>			'LARM',
-	'S_MENU_NETWORK_MAPS'=>			'NÄTVERKSKARTOR',
-	'S_MENU_GRAPHS'=>			'DIAGRAM',
-	'S_MENU_SCREENS'=>			'SKÄRMAR',
-	'S_MENU_IT_SERVICES'=>			'IT-TJÄNSTER',
-	'S_MENU_HOME'=>			'HEM',
-	'S_MENU_ABOUT'=>			'OM',
-	'S_MENU_STATUS_OF_ZABBIX'=>			'STATUS FÖR ZABBIX',
-	'S_MENU_AVAILABILITY_REPORT'=>			'TILLGÄNGLIGHETSRAPPORT',
-	'S_MENU_CONFIG'=>			'KONFIGURATION',
-	'S_MENU_USERS'=>			'ANVÄNDARE',
-	'S_MENU_HOSTS'=>			'VÄRDAR',
-	'S_MENU_ITEMS'=>			'OBJEKT',
-	'S_MENU_AUDIT'=>			'GRANSKNING',
-	'S_SELECT_GROUP_DOT_DOT_DOT'=>			'Välj grupp ...',
 	'S_OVERVIEW'=>			'Översikt',
 	'S_OVERVIEW_BIG'=>			'ÖVERSIKT',
-	'S_EXCL'=>			'!',
 	'S_DATA'=>			'Data',
 	'S_QUEUE_BIG'=>			'K',
 	'S_QUEUE_OF_ITEMS_TO_BE_UPDATED_BIG'=>			'UPPDATERINGSKÖ FÖR OBJEKT',
@@ -566,14 +385,11 @@
 	'S_30_SECONDS'=>			'30 sekunder',
 	'S_1_MINUTE'=>			'1 minut',
 	'S_5_MINUTES'=>			'5 minuter',
-	'S_MORE_THAN_5_MINUTES'=>			'Mer än 5 minuter',
 	'S_STATUS_OF_ZABBIX'=>			'Status för ZABBIX',
 	'S_STATUS_OF_ZABBIX_BIG'=>			'STATUS FÖR ZABBIX',
 	'S_VALUE'=>			'Värde',
 	'S_ZABBIX_SERVER_IS_RUNNING'=>			'ZABBIX-server kör',
-	'S_NUMBER_OF_VALUES_STORED'=>			'Antal lagrade värden',
 	'S_VALUES_STORED'=>			'Lagrade värden',
-	'S_NUMBER_OF_TRENDS_STORED'=>			'Antal lagrade trender',
 	'S_TRENDS_STORED'=>			'Lagrade trender',
 	'S_NUMBER_OF_ALERTS'=>			'Antal larm',
 	'S_NUMBER_OF_TRIGGERS'=>			'Antal utlösare (aktiverade/inaktiverade)[sant/okänt/falskt]',
@@ -591,8 +407,6 @@
 	'S_AVAILABILITY_REPORT'=>			'Tillgänglighetsrapport',
 	'S_AVAILABILITY_REPORT_BIG'=>			'TILLGÄNGLIGHETSRAPPORT',
 	'S_SHOW'=>			'Visa',
-	'S_TRUE'=>			'Sant',
-	'S_FALSE'=>			'Falskt',
 	'S_IT_SERVICES_AVAILABILITY_REPORT'=>			'Tillgänglighetsrapport för IT-tjänster',
 	'S_IT_SERVICES_AVAILABILITY_REPORT_BIG'=>			'TILLGÄNGLIGHETSRAPPOR FÖR IT-TJÄNSTER',
 	'S_FROM'=>			'Från',
@@ -659,86 +473,49 @@
 	'S_LOCAL_TIME'=>			'Lokal tid',
 	'S_STYLE'=>			'Stil',
 	'S_VERTICAL'=>			'Vertikal',
-	'S_HORISONTAL'=>			'Horisontell',
-	'S_HORISONTAL_ALIGN'=>			'Horisontell justering',
-	'S_CENTER'=>			'Centrera',
+	'S_HORIZONTAL'=>			'Horisontell',
+	'S_HORIZONTAL_ALIGN'=>			'Horisontell justering',
+	'S_CENTRE'=>			'Centrera',
 	'S_RIGHT'=>			'Rättighet',
 	'S_VERTICAL_ALIGN'=>			'Vertikal justering',
 	'S_MIDDLE'=>			'Mitten',
 	'S_CUSTOM_SCREENS'=>			'Anpassade skärmar',
 	'S_SCREENS_BIG'=>			'SKÄRMAR',
-	'S_NO_SCREENS_TO_DISPLAY'=>			'Inga skärmar att visa',
-	'S_SELECT_SCREEN_TO_DISPLAY'=>			'Välj skärm att visa',
-	'S_SELECT_SCREEN_DOT_DOT_DOT'=>			'Välj skärm ...',
 	'S_IT_SERVICES'=>			'IT-tjänster',
 	'S_SERVICE_UPDATED'=>			'Tjänst uppdaterad',
 	'S_CANNOT_UPDATE_SERVICE'=>			'Kan inte uppdatera tjänst',
 	'S_SERVICE_ADDED'=>			'Tjänst lades till',
 	'S_CANNOT_ADD_SERVICE'=>			'Kan inte lägga till tjänst',
-	'S_LINK_ADDED'=>			'Länk lades till',
-	'S_CANNOT_ADD_LINK'=>			'Kan inte lägga till länk',
 	'S_SERVICE_DELETED'=>			'Tjänst togs bort',
 	'S_CANNOT_DELETE_SERVICE'=>			'Kan inte ta bort tjänst',
-	'S_LINK_DELETED'=>			'Länk togs bort',
-	'S_CANNOT_DELETE_LINK'=>			'Kan inte ta bort länk',
 	'S_STATUS_CALCULATION'=>			'Statusberäkning',
 	'S_STATUS_CALCULATION_ALGORITHM'=>			'Algoritm för statusberäkning',
 	'S_NONE'=>			'Ingen',
-	'S_MAX_OF_CHILDS'=>			'MAX av barn',
-	'S_MIN_OF_CHILDS'=>			'MIN av barn',
-	'S_SERVICE_1'=>			'Tjänst 1',
-	'S_SERVICE_2'=>			'Tjänst 2',
-	'S_SOFT_HARD_LINK'=>			'Mjuk/hård länk',
 	'S_SOFT'=>			'Mjuk',
-	'S_HARD'=>			'Hård',
 	'S_DO_NOT_CALCULATE'=>			'Beräkna inte',
-	'S_MAX_BIG'=>			'MAX',
-	'S_MIN_BIG'=>			'MIN',
-	'S_SHOW_SLA'=>			'Visa SLA',
 	'S_ACCEPTABLE_SLA_IN_PERCENT'=>			'Acceptabel SLA (i %)',
 	'S_LINK_TO_TRIGGER_Q'=>			'Länk till utlösare?',
 	'S_SORT_ORDER_0_999'=>			'Sorteringsordning (0->999)',
-	'S_DELETE_SERVICE_Q'=>			'S_DELETE_SERVICE_Q',
-	'S_LINK_TO'=>			'Länka till',
-	'S_SOFT_LINK_Q'=>			'Mjuk länk?',
-	'S_ADD_SERVER_DETAILS'=>			'Lägg till serverdetaljer',
 	'S_TRIGGER'=>			'Utlösare',
 	'S_SERVER'=>			'Server',
 	'S_DELETE'=>			'Ta bort',
-	'S_DELETE_SELECTED_SERVICES'=>			'Ta bort markerade tjänster?',
-	'S_DELETE_SELECTED_LINKS'=>			'Ta bort markerade länkar?',
-	'S_SERVICES_DELETED'=>			'Tjänster togs bort',
-	'S_CANNOT_DELETE_SERVICES'=>			'Kan inte ta bort tjänster',
 	'S_DEPENDS_ON'=>			'Beroende av',
 	'S_IT_SERVICES_BIG'=>			'IT-TJÄNSTER',
 	'S_SERVICE'=>			'Tjänst',
 	'S_REASON'=>			'Anledning',
-	'S_SLA_LAST_7_DAYS'=>			'SLA (senaste 7 dagarna)',
-	'S_PLANNED_CURRENT_SLA'=>			'Planerat/aktuellt SLA',
-	'S_TRIGGER_BIG'=>			'UTLÖSARE',
 	'S_NO_TRIGGERS_DEFINED'=>			'Inga utlösare har definierats',
 	'S_CONFIGURATION_OF_TRIGGERS'=>			'Konfiguration av utlösare',
 	'S_CONFIGURATION_OF_TRIGGERS_BIG'=>			'KONFIGURATION AV UTLÖSARE',
-	'S_DEPENDENCY_ADDED'=>			'Beroende lades till',
-	'S_CANNOT_ADD_DEPENDENCY'=>			'Kan inte lägga till beroende',
-	'S_TRIGGERS_UPDATED'=>			'Utlösare uppdaterades',
-	'S_CANNOT_UPDATE_TRIGGERS'=>			'Kan inte uppdatera utlösare',
-	'S_TRIGGERS_DISABLED'=>			'Utlösare inaktiverades',
-	'S_CANNOT_DISABLE_TRIGGERS'=>			'Kan inte inaktivera utlösare',
 	'S_TRIGGERS_DELETED'=>			'Utlösare togs bort',
 	'S_CANNOT_DELETE_TRIGGERS'=>			'Kan inte ta bort utlösare',
 	'S_TRIGGER_DELETED'=>			'Utlösare togs bort',
 	'S_CANNOT_DELETE_TRIGGER'=>			'Kan inte ta bort utlösare',
-	'S_INVALID_TRIGGER_EXPRESSION'=>			'Ogiltigt uttryck för utlösare',
 	'S_TRIGGER_ADDED'=>			'Utlösare lades till',
 	'S_CANNOT_ADD_TRIGGER'=>			'Kan inte lägga till utlösare',
 	'S_SEVERITY'=>			'Allvarlighetsgrad',
 	'S_EXPRESSION'=>			'Uttryck',
 	'S_DISABLED'=>			'Inaktiverad',
 	'S_ENABLED'=>			'Aktiverad',
-	'S_ENABLE_SELECTED_TRIGGERS_Q'=>			'Aktivera markerade utlösare?',
-	'S_DISABLE_SELECTED_TRIGGERS_Q'=>			'Inaktivera markerade utlösare?',
-	'S_DELETE_SELECTED_TRIGGERS_Q'=>			'Ta bort markerade utlösare?',
 	'S_CHANGE'=>			'Ändra',
 	'S_TRIGGER_UPDATED'=>			'Utlösare uppdaterades',
 	'S_CANNOT_UPDATE_TRIGGER'=>			'Kan inte uppdatera utlösare',
@@ -751,17 +528,9 @@
 	'S_ADD'=>			'Lägg till',
 	'S_STATUS_OF_TRIGGERS'=>			'Status för utlösare',
 	'S_STATUS_OF_TRIGGERS_BIG'=>			'STATUS FÖR UTLÖSARE',
-	'S_SHOW_ONLY_TRUE'=>			'Visa endast sanna',
-	'S_HIDE_ACTIONS'=>			'Dölj åtgärder',
-	'S_SHOW_ACTIONS'=>			'Visa åtgärder',
-	'S_HIDE_DETAILS'=>			'Dölj detaljer',
 	'S_SHOW_DETAILS'=>			'Visa detaljer',
 	'S_SELECT'=>			'Välj',
-	'S_HIDE_SELECT'=>			'Dölj markerade',
 	'S_TRIGGERS_BIG'=>			'UTLÖSARE',
-	'S_NAME_BIG'=>			'NAMN',
-	'S_SEVERITY_BIG'=>			'ALLVARLIGHETSGRAD',
-	'S_LAST_CHANGE_BIG'=>			'SENASTE ÄNDRING',
 	'S_LAST_CHANGE'=>			'Senaste ändring',
 	'S_COMMENTS'=>			'Kommentarer',
 	'S_ACKNOWLEDGED'=>			'Bekräftade',
@@ -772,10 +541,6 @@
 	'S_CANNOT_ADD_USER_BOTH_PASSWORDS_MUST'=>			'Kan inte lägga till användare. Båda lösenorden måste vara samma.',
 	'S_USER_DELETED'=>			'Användare togs bort',
 	'S_CANNOT_DELETE_USER'=>			'Kan inte ta bort användare',
-	'S_PERMISSION_DELETED'=>			'Rättighet togs bort',
-	'S_CANNOT_DELETE_PERMISSION'=>			'Kan inte ta bort rättighet',
-	'S_PERMISSION_ADDED'=>			'Rättighet lades till',
-	'S_CANNOT_ADD_PERMISSION'=>			'Kan inte lägga till rättighet',
 	'S_USER_UPDATED'=>			'Användare uppdaterades',
 	'S_CANNOT_UPDATE_USER'=>			'Kan inte uppdatera användare',
 	'S_CANNOT_UPDATE_USER_BOTH_PASSWORDS'=>			'Kan inte uppdatera användare. Båda lösenorden måste vara samma.',
@@ -790,36 +555,26 @@
 	'S_USERS_BIG'=>			'ANVÄNDARE',
 	'S_USER_GROUPS'=>			'Användargrupper',
 	'S_MEMBERS'=>			'Medlemmar',
-	'S_HOSTS_TEMPLATES_LINKAGE'=>			'Värdar-/mallkoppling',
-	'S_CONFIGURATION_OF_TEMPLATES_LINKAGE'=>			'KONFIGURATION AV MALLKOPPLING',
-	'S_LINKED_TEMPLATES_BIG'=>			'KOPPLINGAR FÖR MALLAR',
 	'S_NO_USER_GROUPS_DEFINED'=>			'Inga användargrupper har definierats',
 	'S_ALIAS'=>			'Alias',
 	'S_NAME'=>			'Namn',
 	'S_SURNAME'=>			'Efternamn',
 	'S_IS_ONLINE_Q'=>			'Är ansluten?',
 	'S_NO_USERS_DEFINED'=>			'Inga användare har definierats',
-	'S_PERMISSION'=>			'Behörighet',
-	'S_RESOURCE_NAME'=>			'Resursnamn',
 	'S_READ_ONLY'=>			'Endast läs',
 	'S_READ_WRITE'=>			'Läs-skriv',
 	'S_HIDE'=>			'Dölj',
 	'S_PASSWORD'=>			'Lösenord',
 	'S_PASSWORD_ONCE_AGAIN'=>			'Lösenord (en gång till)',
 	'S_URL_AFTER_LOGIN'=>			'URL (efter inloggning)',
-	'S_AUTO_LOGOUT_IN_SEC'=>			'Automatisk utloggning (i sekunder=>0 - inaktivera)',
 	'S_SCREEN_REFRESH'=>			'Uppdatera (i sekunder)',
 	'S_CREATE_USER'=>			'Skapa användare',
 	'S_CREATE_GROUP'=>			'Skapa grupp',
-	'S_AUDIT_LOG'=>			'Granskningslogg',
-	'S_AUDIT_LOG_BIG'=>			'GRANSKNINGSLOGG',
 	'S_ACTION'=>			'Åtgärd',
 	'S_DETAILS'=>			'Detaljer',
 	'S_UNKNOWN_ACTION'=>			'Okänd åtgärd',
 	'S_ADDED'=>			'Lades till',
 	'S_UPDATED'=>			'Uppdaterad',
-	'S_LOGGED_IN'=>			'Loggade in',
-	'S_LOGGED_OUT'=>			'Loggade ut',
 	'S_MEDIA_TYPE'=>			'Mediatyp',
 	'S_GRAPH_ELEMENT'=>			'Diagramelement',
 	'S_UNKNOWN_RESOURCE'=>			'Okänd resurs',
@@ -854,6 +609,6 @@
 	'S_LOGIN'=>			'Inloggning',
 	'S_LATEST_DATA'=>			'Senaste data',
 	'S_INCORRECT_DESCRIPTION'=>			'Felaktig beskrivning',
-	
+
 	);
-?>
\ No newline at end of file
+?>
