@@ -23,9 +23,9 @@
 function zbx_session_start($userid, $name, $password){
 	$sessionid = md5(time().$password.$name.rand(0,10000000));
 	zbx_setcookie('zbx_sessionid',$sessionid);
-	
+
 	DBexecute('INSERT INTO sessions (sessionid,userid,lastaccess,status) VALUES ('.zbx_dbstr($sessionid).','.$userid.','.time().','.ZBX_SESSION_ACTIVE.')');
-	
+
 return $sessionid;
 }
 
@@ -45,134 +45,19 @@ function permission2str($group_permission){
 *****************************************/
 
 function check_authorisation(){
-	global	$DB;
-	global	$page;
-	global	$PHP_AUTH_USER,$PHP_AUTH_PW;
-	global	$USER_DETAILS;
-	global	$ZBX_LOCALNODEID;
-
-	$USER_DETAILS = NULL;
-	$login = FALSE;
-
 	$sessionid = get_cookie('zbx_sessionid');
-	if(!is_null($sessionid)){
-		$sql = 'SELECT u.*,s.* '.
-				' FROM sessions s,users u'.
-				' WHERE s.sessionid='.zbx_dbstr($sessionid).
-					' AND s.status='.ZBX_SESSION_ACTIVE.
-					' AND s.userid=u.userid'.
-					' AND ((s.lastaccess+u.autologout>'.time().') OR (u.autologout=0))'.
-					' AND '.DBin_node('u.userid', $ZBX_LOCALNODEID);
 
-		$login = $USER_DETAILS = DBfetch(DBselect($sql));
-		if(!$USER_DETAILS){
-			$incorrect_session = true;
-		}
-		else if($login['attempt_failed']){
-			error(new CScript(array(
-						bold($login['attempt_failed']),
-						'failed login attempts logged. Last failed attempt was from ',
-						bold($login['attempt_ip']),
-						' on ',
-						bold(date('d.m.Y H:i',$login['attempt_clock'])),
-						'.')));
-			
-			DBexecute('UPDATE users SET attempt_failed=0 WHERE userid='.$login['userid']);
-		}
-	}
-
-	if(!$USER_DETAILS && !isset($_SERVER['PHP_AUTH_USER'])){
-		$sql = 'SELECT u.* '.
-				' FROM users u '.
-				' WHERE u.alias='.zbx_dbstr(ZBX_GUEST_USER).
-					' AND '.DBin_node('u.userid', $ZBX_LOCALNODEID);
-		$login = $USER_DETAILS = DBfetch(DBselect($sql));
-		if(!$USER_DETAILS){
-			$missed_user_guest = true;
-		}
-		else{
-			$sessionid = zbx_session_start($USER_DETAILS['userid'], ZBX_GUEST_USER, '');
-		}
-	}
-
-	if($login){
-		$login = (check_perm2login($USER_DETAILS['userid']) && check_perm2system($USER_DETAILS['userid']));
-	}
-	
-	if(!$login){
-		$USER_DETAILS = NULL;
-	}
-	
-	if($login && !isset($incorrect_session)){
-		zbx_setcookie('zbx_sessionid',$sessionid,$USER_DETAILS['autologin']?(time()+86400*31):0);	//1 month
-		DBexecute('UPDATE sessions SET lastaccess='.time().' WHERE sessionid='.zbx_dbstr($sessionid));
-	}
-	else{
-		zbx_unsetcookie('zbx_sessionid');
-		DBexecute('UPDATE sessions SET status='.ZBX_SESSION_PASSIVE.' WHERE sessionid='.zbx_dbstr($sessionid));
-		unset($sessionid);
-	}
-
-	if($USER_DETAILS){
-		$USER_DETAILS['node'] = DBfetch(DBselect('SELECT * FROM nodes WHERE nodeid='.id2nodeid($USER_DETAILS['userid'])));
+	$user = array('sessionid'=>$sessionid);
+	if(!$auth = CUser::checkAuthentication($user)){
 		
-		if(empty($USER_DETAILS['node'])){
-			$USER_DETAILS['node']['name'] = '- unknown -';
-			$USER_DETAILS['node']['nodeid'] = $ZBX_LOCALNODEID;
-		}
-	}
-	else{
-		$USER_DETAILS = array(
-			'alias'	=>ZBX_GUEST_USER,
-			'userid'=>0,
-			'lang'	=>'en_gb',
-			'type'	=>'0',
-			'node'	=>array(
-				'name'	=>'- unknown -',
-				'nodeid'=>0));
-	}
+		include_once('include/locales/en_gb.inc.php');
+		process_locales();
 
-	if(!$login || isset($incorrect_session) || isset($missed_user_guest)){
-
-		if(isset($incorrect_session))	$message = 'Session was ended, please relogin!';
-		else if(isset($missed_user_guest)){
-			$row = DBfetch(DBselect('SELECT count(u.userid) as user_cnt FROM users u'));
-			if(!$row || $row['user_cnt'] == 0){
-				$message = 'Table users is empty. Possible database corruption.';
-			}
-		}
-
-		if(!isset($_REQUEST['message']) && isset($message)) $_REQUEST['message'] = $message;
-		
 		include('index.php');
-		exit;
-	}
-}
-	
-/*****************************************
-	LDAP AUTHENTICATION
-*****************************************/
-function ldap_authentication($user,$passwd,$cnf=NULL){
-	if(is_null($cnf)){
-		$config = select_config();
-		foreach($config as $id => $value){
-			if(strpos($id,'ldap_') !== false){
-				$cnf[str_replace('ldap_','',$id)] = $config[$id];
-			}
-		}
+		exit();
 	}
 
-	if(!function_exists('ldap_connect')){
-		info('Probably php-ldap module is missing.');
-		return false;
-	}
-	
-	$ldap = new CLdap($cnf);
-	$ldap->connect();
-
-	$result = $ldap->checkPass($user,$passwd);
-
-return $result;
+return $auth;
 }
 
 
@@ -183,7 +68,7 @@ return $result;
  *
  * Description:
  * 		Checking user permissions to access system (affects server side: no notification will be sent)
- * 
+ *
  * Comments:
  *		return true if permission is positive
  *
@@ -205,10 +90,10 @@ return true;
  *
  * Description:
  * 		Checking user permissions to Login in frontend
- * 
+ *
  * Comments:
  *		return true if permission is positive
- * 
+ *
  * Author: Aly
  */
 
@@ -222,41 +107,71 @@ return (GROUP_GUI_ACCESS_DISABLED == $res)?false:true;
  *
  * Description:
  * 		Returns user authentication type
- * 
+ *
  * Comments:
  *		default is SYSTEM auth
- *	
+ *
  * Author: Aly
  */
 function get_user_auth($userid){
-	$result = GROUP_GUI_ACCESS_SYSTEM;
-	
+	global $USER_DETAILS;
+
+	if(($userid == $USER_DETAILS['userid']) && isset($USER_DETAILS['gui_access'])) return $USER_DETAILS['gui_access'];
+	else $result = GROUP_GUI_ACCESS_SYSTEM;
+
 	$sql = 'SELECT MAX(g.gui_access) as gui_access '.
 		' FROM usrgrp g, users_groups ug '.
 		' WHERE ug.userid='.$userid.
 			' AND g.usrgrpid=ug.usrgrpid ';
 	$acc = DBfetch(DBselect($sql));
 
-	if(!zbx_empty($acc['gui_access'])) $result=$acc['gui_access'];
-	
+	if(!zbx_empty($acc['gui_access'])){
+		$result = $acc['gui_access'];
+		$USER_DETAILS['gui_access'] = $acc['gui_access'];
+	}
+
 return $result;
 }
 
+function get_user_api_access($userid){
+	$sql = 'SELECT g.usrgrpid '.
+			' FROM usrgrp g, users_groups ug '.
+			' WHERE ug.userid = '.$userid.
+				' AND g.usrgrpid = ug.usrgrpid '.
+				' AND g.api_access = '.GROUP_API_ACCESS_ENABLED;
+	if($res = DBfetch(DBselect($sql,1))){
+		return true;
+	}
+return false;
+}
+
+function get_user_debug_mode($userid){
+	$sql = 'SELECT g.usrgrpid '.
+			' FROM usrgrp g, users_groups ug '.
+			' WHERE ug.userid = '.$userid.
+				' AND g.usrgrpid = ug.usrgrpid '.
+				' AND g.debug_mode = '.GROUP_DEBUG_MODE_ENABLED;
+	if($res = DBfetch(DBselect($sql,1))){
+		return true;
+	}
+return false;
+}
+
 /* Function: get_user_system_auth()
  *
  * Description:
  * 		Returns overal user authentication type in system
- * 
+ *
  * Comments:
  *		default is INTERNAL auth
- *	
+ *
  * Author: Aly
  */
 function get_user_system_auth($userid){
 	$result = ZBX_AUTH_INTERNAL;
-	
+
 	$user_auth = get_user_auth($userid);
-	
+
 	switch($user_auth){
 		case GROUP_GUI_ACCESS_SYSTEM:
 			$config = select_config();
@@ -267,7 +182,7 @@ function get_user_system_auth($userid){
 		default:
 			break;
 	}
-	
+
 return $result;
 }
 
@@ -275,13 +190,52 @@ return $result;
 	GET ACCESSIBLE RESOURCES BY USERID
 ************************************************/
 
+function available_groups($groupids, $editable=null){
+	$options = array();
+	$options['groupids'] = $groupids;
+	$options['editable'] = $editable;
+
+	$groups = CHostGroup::get($options);
+return zbx_objectValues($groups, 'groupid');
+}
+function available_hosts($hostids, $editable=null){
+	$options = array();
+	$options['hostids'] = $hostids;
+	$options['editable'] = $editable;
+	$options['templated_hosts'] = 1;
+
+	$hosts = CHost::get($options);
+
+return zbx_objectValues($hosts, 'hostid');
+}
+
+function available_triggers($triggerids, $editable=null){
+	$options = array();
+	$options['triggerids'] = $triggerids;
+	$options['editable'] = $editable;
+	$options['nodes'] = get_current_nodeid(true);
+
+	$triggers = CTrigger::get($options);
+return zbx_objectValues($triggers, 'triggerid');
+}
+
+function available_graphs($graphids, $editable=null){
+	$options = array();
+	$options['graphids'] = $graphids;
+	$options['editable'] = $editable;
+	$options['nodes'] = get_current_nodeid(true);
+
+	$graphs = CGraph::get($options);
+return zbx_objectValues($graphs, 'graphid');
+}
+
 function get_accessible_hosts_by_user(&$user_data,$perm,$perm_res=null,$nodeid=null,$cache=1){
 //		global $DB;
 	static $available_hosts;
-	
+
 	if(is_null($perm_res)) $perm_res = PERM_RES_IDS_ARRAY;
 	if($perm == PERM_READ_LIST)	$perm = PERM_READ_ONLY;
-	
+
 	$result = array();
 
 	$userid =& $user_data['userid'];
@@ -303,13 +257,13 @@ COpt::counter_up('perm');
 	$where = array();
 
 	if(!is_null($nodeid))
-		array_push($where, DBin_node('h.hostid', $nodeid));	
-		
+		array_push($where, DBin_node('h.hostid', $nodeid));
+
 	if(count($where))
 		$where = ' WHERE '.implode(' AND ',$where);
 	else
 		$where = '';
-		
+
 //		$sortorder = (isset($DB['TYPE']) && (($DB['TYPE'] == 'MYSQL') || ($DB['TYPE'] == 'SQLITE3')))?' DESC ':'';
 //SDI($sql);
 	$sql = 'SELECT DISTINCT n.nodeid, n.name as node_name, h.hostid, h.host, min(r.permission) as permission, ug.userid '.
@@ -335,7 +289,7 @@ COpt::counter_up('perm');
 		}
 		else{
 			if(zbx_empty($host_data['permission']) || zbx_empty($host_data['userid'])) continue;
-			
+
 			if(isset($processed[$host_data['hostid']])){
 				if(PERM_DENY == $host_data['permission']){
 					unset($result[$host_data['hostid']]);
@@ -350,21 +304,21 @@ COpt::counter_up('perm');
 		}
 
 		$processed[$host_data['hostid']] = $host_data['permission'];
-		if($host_data['permission']<$perm)	continue; 
+		if($host_data['permission']<$perm)	continue;
 
 		switch($perm_res){
-			case PERM_RES_DATA_ARRAY:	
-				$result[$host_data['hostid']] = $host_data; 
+			case PERM_RES_DATA_ARRAY:
+				$result[$host_data['hostid']] = $host_data;
 				break;
 			default:
-				$result[$host_data['hostid']] = $host_data['hostid']; 
+				$result[$host_data['hostid']] = $host_data['hostid'];
 		}
 	}
 
 	unset($processed, $host_data, $db_hosts);
 
 	if(PERM_RES_STRING_LINE == $perm_res){
-		if(count($result) == 0) 
+		if(count($result) == 0)
 			$result = '-1';
 		else
 			$result = implode(',',$result);
@@ -382,7 +336,7 @@ function get_accessible_groups_by_user($user_data,$perm,$perm_res=null,$nodeid=n
 	if(is_null($nodeid)) $nodeid = get_current_nodeid();
 
 	$result = array();
-	
+
 	$userid =& $user_data['userid'];
 	if(!isset($userid)) fatal_error('Incorrect user data in "get_accessible_groups_by_user"');
 	$user_type =& $user_data['type'];
@@ -417,7 +371,7 @@ COpt::counter_up('perm');
 		}
 		else{
 			if(zbx_empty($group_data['permission']) || zbx_empty($group_data['userid'])) continue;
-			
+
 			if(isset($processed[$group_data['groupid']])){
 				if(PERM_DENY == $group_data['permission']){
 					unset($result[$group_data['groupid']]);
@@ -432,14 +386,14 @@ COpt::counter_up('perm');
 		}
 
 		$processed[$group_data['groupid']] = $group_data['permission'];
-		if($group_data['permission'] < $perm) continue;	
+		if($group_data['permission'] < $perm) continue;
 
 		switch($perm_res){
 			case PERM_RES_DATA_ARRAY:
-				$result[$group_data['groupid']] = $group_data; 
+				$result[$group_data['groupid']] = $group_data;
 				break;
 			default:
-				$result[$group_data['groupid']] = $group_data["groupid"]; 
+				$result[$group_data['groupid']] = $group_data["groupid"];
 				break;
 		}
 	}
@@ -447,7 +401,7 @@ COpt::counter_up('perm');
 	unset($processed, $group_data, $db_groups);
 
 	if($perm_res == PERM_RES_STRING_LINE) {
-		if(count($result) == 0) 
+		if(count($result) == 0)
 			$result = '-1';
 		else
 			$result = implode(',',$result);
@@ -458,6 +412,7 @@ return $result;
 
 function get_accessible_nodes_by_user(&$user_data,$perm,$perm_res=null,$nodeid=null,$cache=1){
 	global $ZBX_LOCALNODEID, $ZBX_NODES_IDS;
+	static $available_nodes;
 
 	if(is_null($perm_res)) $perm_res = PERM_RES_IDS_ARRAY;
 	if(is_null($nodeid)) $nodeid = $ZBX_NODES_IDS;
@@ -467,12 +422,20 @@ function get_accessible_nodes_by_user(&$user_data,$perm,$perm_res=null,$nodeid=n
 	$user_type	=& $user_data['type'];
 	if(!isset($userid)) fatal_error('Incorrect user data in "get_accessible_nodes_by_user"');
 
+
+	$nodeid_str =(is_array($nodeid))?md5(implode('',$nodeid)):strval($nodeid);
+
+	if($cache && isset($available_nodes[$userid][$perm][$perm_res][$nodeid_str])){
+//SDI('Cache!!! '."[$userid][$perm][$perm_res]");
+		return $available_nodes[$userid][$perm][$perm_res][$nodeid_str];
+	}
+
 	$node_data = array();
 	$result = array();
 
 //COpt::counter_up('perm');
 	if(USER_TYPE_SUPER_ADMIN == $user_type){
-		$nodes = DBselect('SELECT nodeid FROM nodes');// WHERE '.DBcondition('nodeid',$ZBX_NODES_IDS));
+		$nodes = DBselect('SELECT nodeid FROM nodes');
 		while($node = DBfetch($nodes)){
 			$node_data[$node['nodeid']] = $node;
 			$node_data[$node['nodeid']]['permission'] = PERM_READ_WRITE;
@@ -480,7 +443,7 @@ function get_accessible_nodes_by_user(&$user_data,$perm,$perm_res=null,$nodeid=n
 		if(empty($node_data)) $node_data[0]['nodeid'] = 0;
 	}
 	else{
-		$available_groups = get_accessible_groups_by_user($user_data,$perm,PERM_RES_DATA_ARRAY,$nodeid,$cache);	
+		$available_groups = get_accessible_groups_by_user($user_data,$perm,PERM_RES_DATA_ARRAY,$nodeid,$cache);
 
 		foreach($available_groups as $id => $group){
 			$nodeid = id2nodeid($group['groupid']);
@@ -494,8 +457,8 @@ function get_accessible_nodes_by_user(&$user_data,$perm,$perm_res=null,$nodeid=n
 	foreach($node_data as $nodeid => $node){
 		switch($perm_res){
 			case PERM_RES_DATA_ARRAY:
-				$db_node = DBfetch(DBselect('SELECT * FROM nodes WHERE nodeid='.$nodeid));
-				
+				$db_node = DBfetch(DBselect('SELECT * FROM nodes WHERE nodeid='.$nodeid.' ORDER BY name'));
+
 				if(!ZBX_DISTRIBUTED){
 					if(!$node){
 						$db_node = array(
@@ -509,8 +472,8 @@ function get_accessible_nodes_by_user(&$user_data,$perm,$perm_res=null,$nodeid=n
 						continue;
 					}
 				}
-				
-				$result[$nodeid] = array_merge($db_node,$node);
+
+				$result[$nodeid] = zbx_array_merge($db_node,$node);
 
 				break;
 			default:
@@ -520,12 +483,14 @@ function get_accessible_nodes_by_user(&$user_data,$perm,$perm_res=null,$nodeid=n
 	}
 
 	if($perm_res == PERM_RES_STRING_LINE) {
-		if(count($result) == 0) 
+		if(count($result) == 0)
 			$result = '-1';
 		else
 			$result = implode(',',$result);
 	}
 
+	$available_nodes[$userid][$perm][$perm_res][$nodeid_str] = $result;
+
 return $result;
 }
 
@@ -537,7 +502,7 @@ return $result;
 		$rights[i]['type']	= type of resource
 		$rights[i]['permission']= permission for resource
 		$rights[i]['id']	= resource id
-		
+
 	*/
 
 function get_accessible_hosts_by_rights(&$rights,$user_type,$perm,$perm_res=null,$nodeid=null){
@@ -546,7 +511,7 @@ function get_accessible_hosts_by_rights(&$rights,$user_type,$perm,$perm_res=null
 
 	$result = array();
 	$res_perm = array();
-	
+
 	foreach($rights as $id => $right){
 		$res_perm[$right['id']] = $right['permission'];
 	}
@@ -569,17 +534,17 @@ function get_accessible_hosts_by_rights(&$rights,$user_type,$perm,$perm_res=null
 	while($host_data = DBfetch($db_hosts)){
 		if(isset($host_data['groupid']) && isset($res_perm[$host_data['groupid']])){
 			if(!isset($perm_by_host[$host_data['hostid']])) $perm_by_host[$host_data['hostid']] = array();
-			
+
 			$perm_by_host[$host_data['hostid']][] = $res_perm[$host_data['groupid']];
-			
+
 			$host_perm[$host_data['hostid']][$host_data['groupid']] = $res_perm[$host_data['groupid']];
-		}		
+		}
 		$host_perm[$host_data['hostid']]['data'] = $host_data;
 	}
 
 	foreach($host_perm as $hostid => $host_data){
 		$host_data = $host_data['data'];
-		
+
 // Select Min rights from groups
 		if(USER_TYPE_SUPER_ADMIN == $user_type){
 			$host_data['permission'] = PERM_MAX;
@@ -590,23 +555,23 @@ function get_accessible_hosts_by_rights(&$rights,$user_type,$perm,$perm_res=null
 			}
 			else{
 				if(is_null($host_data['nodeid'])) $host_data['nodeid'] = id2nodeid($host_data['groupid']);
-					
+
 				$host_data['permission'] = PERM_DENY;
 			}
 		}
 
 		if($host_data['permission']<$perm) continue;
 		switch($perm_res){
-			case PERM_RES_DATA_ARRAY:	
+			case PERM_RES_DATA_ARRAY:
 				$result[$host_data['hostid']] = $host_data;
 				break;
 			default:
-				$result[$host_data['hostid']] = $host_data['hostid']; 
+				$result[$host_data['hostid']] = $host_data['hostid'];
 		}
 	}
 
 	if($perm_res == PERM_RES_STRING_LINE) {
-		if(count($result) == 0) 
+		if(count($result) == 0)
 			$result = '-1';
 		else
 			$result = implode(',',$result);
@@ -654,20 +619,20 @@ function get_accessible_groups_by_rights(&$rights,$user_type,$perm,$perm_res=nul
 				$group_data['permission'] = PERM_DENY;
 			}
 		}
-					
+
 		if($group_data['permission']<$perm) continue;
 
 		switch($perm_res){
-			case PERM_RES_DATA_ARRAY:	
+			case PERM_RES_DATA_ARRAY:
 				$result[$group_data['groupid']] = $group_data;
 				break;
 			default:
-				$result[$group_data['groupid']] = $group_data['groupid']; 
+				$result[$group_data['groupid']] = $group_data['groupid'];
 		}
 	}
 
 	if($perm_res == PERM_RES_STRING_LINE) {
-		if(count($result) == 0) 
+		if(count($result) == 0)
 			$result = '-1';
 		else
 			$result = implode(',',$result);
@@ -678,7 +643,7 @@ return $result;
 
 function get_accessible_nodes_by_rights(&$rights,$user_type,$perm,$perm_res=null){
 	global $ZBX_LOCALNODEID;
-	
+
 	$nodeid = get_current_nodeid(true);
 
 	if(is_null($perm_res))	$perm_res=PERM_RES_STRING_LINE;
@@ -686,30 +651,31 @@ function get_accessible_nodes_by_rights(&$rights,$user_type,$perm,$perm_res=null
 
 	$node_data = array();
 	$result = array();
-	
+
+//COpt::counter_up('perm_nodes['.$userid.','.$perm.','.$perm_mode.','.$perm_res.','.$nodeid.']');
 //COpt::counter_up('perm');
 //SDI(get_accessible_groups_by_rights($rights,$user_type,$perm,PERM_RES_DATA_ARRAY,$nodeid));
 	$available_groups = get_accessible_groups_by_rights($rights,$user_type,$perm,PERM_RES_DATA_ARRAY,$nodeid);
 	foreach($available_groups as $id => $group){
 		$nodeid = id2nodeid($group['groupid']);
 		$permission = $group['permission'];
-		
+
 		if(isset($node_data[$nodeid]) && ($permission < $node_data[$nodeid]['permission'])){
 			$permission = $node_data[$nodeid]['permission'];
-		} 
+		}
 
 		$node_data[$nodeid]['nodeid'] = $nodeid;
 		$node_data[$nodeid]['permission'] = $permission;
 	}
-	
-	$available_hosts = get_accessible_hosts_by_rights($rights,$user_type,$perm,PERM_RES_DATA_ARRAY,$nodeid);	
+
+	$available_hosts = get_accessible_hosts_by_rights($rights,$user_type,$perm,PERM_RES_DATA_ARRAY,$nodeid);
 	foreach($available_hosts as $id => $host){
 		$nodeid = id2nodeid($host['hostid']);
 		$permission = $host['permission'];
 
 		if(isset($node_data[$nodeid]) && ($permission < $node_data[$nodeid]['permission'])){
 			$permission = $node_data[$nodeid]['permission'];
-		} 
+		}
 
 		$node_data[$nodeid]['nodeid'] = $nodeid;
 		$node_data[$nodeid]['permission'] = $permission;
@@ -719,7 +685,7 @@ function get_accessible_nodes_by_rights(&$rights,$user_type,$perm,$perm_res=null
 		switch($perm_res){
 			case PERM_RES_DATA_ARRAY:
 				$db_node = DBfetch(DBselect('SELECT * FROM nodes WHERE nodeid='.$nodeid));
-				
+
 				if(!ZBX_DISTRIBUTED){
 					if(!$node){
 						$db_node = array(
@@ -733,8 +699,8 @@ function get_accessible_nodes_by_rights(&$rights,$user_type,$perm,$perm_res=null
 						continue;
 					}
 				}
-				
-				$result[$nodeid] = array_merge($db_node,$node);
+
+				$result[$nodeid] = zbx_array_merge($db_node,$node);
 
 				break;
 			default:
@@ -742,9 +708,9 @@ function get_accessible_nodes_by_rights(&$rights,$user_type,$perm,$perm_res=null
 				break;
 		}
 	}
-	
+
 	if($perm_res == PERM_RES_STRING_LINE) {
-		if(count($result) == 0) 
+		if(count($result) == 0)
 			$result = '-1';
 		else
 			$result = implode(',',$result);
@@ -752,4 +718,4 @@ function get_accessible_nodes_by_rights(&$rights,$user_type,$perm,$perm_res=null
 
 return $result;
 }
-?>
\ No newline at end of file
+?>
