@@ -23,105 +23,95 @@
 
 //---------- GET USER VALUE -------------
 
-function get_profile($idx,$default_value=null,$type=PROFILE_TYPE_UNKNOWN,$idx2=null,$source=null){
+function get_profile($idx,$default_value=null,$idx2=0,$source=null,$nocache=false){
 	global $USER_DETAILS;
+	static $profiles;
 
-	$result = $default_value;
-
-	if($USER_DETAILS["alias"]!=ZBX_GUEST_USER){
-		$sql_cond = '';
-		if(profile_type($type,'id'))	$sql_cond.= ' AND '.DBin_node('value_id');
-		if(zbx_numeric($idx2)) 			$sql_cond.= ' AND idx2='.$idx2.' AND '.DBin_node('idx2');
-		if(!is_null($source)) 			$sql_cond.= ' AND source='.zbx_dbstr($source);
-		
-		$sql = 'SELECT value_id, value_int, value_str, type '.
-				' FROM profiles '.
-				' WHERE userid='.$USER_DETAILS["userid"].
-					' AND idx='.zbx_dbstr($idx).
-					$sql_cond.
-				' ORDER BY profileid ASC';
-
-		$db_profiles = DBselect($sql);
-		if($profile=DBfetch($db_profiles)){
-		
-			if(profile_type($type,'unknown')) $type = $profile['type'];
-			$value_type = profile_field_by_type($type);
-
-			if(profile_type($type,'array')){
-				$result[] = $profile[$value_type];
-				while($profile=DBfetch($db_profiles)){
-					$result[] = $profile[$value_type];
-				}
-			}
-			else{
-				$result = $profile[$value_type];
+	if(!is_null($profiles) && !$nocache){
+		if(isset($profiles[$idx]) && !empty($profiles[$idx])){
+//SDI($idx); SDII($profiles[$idx]);
+			if(!is_null($source))
+				return $profiles[$idx][$source];
+			else if(!isset($profiles[$idx][$idx2])){
+				return $default_value;
 			}
+			else
+				return $profiles[$idx][$idx2];
+		}
+		else{
+			return $default_value;
 		}
 	}
+	else{
+		$profiles = array();
 
-return $result;
-}
-
-
-// multi value
-function get_source_profile($idx,$default_value=array(),$type=PROFILE_TYPE_UNKNOWN,$idx2=null,$source=null){
-	global $USER_DETAILS;
-
-	$result = array();
-
-	if($USER_DETAILS["alias"]!=ZBX_GUEST_USER){
-		$sql_cond = '';
-		if(profile_type($type,'id'))	$sql_cond.= ' AND '.DBin_node('value_id');
-		if(zbx_numeric($idx2)) 			$sql_cond.= ' AND idx2='.$idx2.' AND '.DBin_node('idx2');
-		if(!is_null($source)) 			$sql_cond.= ' AND source='.zbx_dbstr($source);
-		
-		$sql = 'SELECT value_id,value_int,value_str,source,type '.
+		$sql = 'SELECT * '.
 				' FROM profiles '.
-				' WHERE userid='.$USER_DETAILS["userid"].
-					' AND idx='.zbx_dbstr($idx).
-					$sql_cond.
-				' ORDER BY profileid ASC';
-
+				' WHERE userid='.$USER_DETAILS['userid'].
+					' AND '.DBin_node('profileid', false).
+				' ORDER BY userid ASC, profileid ASC';
 		$db_profiles = DBselect($sql);
-		if($profile=DBfetch($db_profiles)){
-			if(profile_type($type,'unknown')) $type = $profile['type'];
-			$value_type = profile_field_by_type($type);
-			
-			if(profile_type($type,'array')){
-				$result[] = array('value'=>$profile[$value_type], 'source'=>$profile['source']);
-				
-				while($profile=DBfetch($db_profiles)){
-					$result[] = array('value'=>$profile[$value_type], 'source'=>$profile['source']);
+		while($profile=DBfetch($db_profiles)){
+			if(!isset($profiles[$profile['idx']])) $profiles[$profile['idx']] = array();
+
+			$value_type = profile_field_by_type($profile['type']);
+
+			if(zbx_empty($source)){
+				if(profile_type($profile['type'],'array')){
+					if(!isset($profiles[$profile['idx']][$profile['idx2']])) $profiles[$profile['idx']][$profile['idx2']] = array();
+					$profiles[$profile['idx']][$profile['idx2']][] = $profile[$value_type];
+				}
+				else{
+					$profiles[$profile['idx']][$profile['idx2']] = $profile[$value_type];
 				}
 			}
 			else{
-				$result = array('value'=>$profile[$value_type], 'source'=>$profile['source']);
+				if(profile_type($profile['type'],'array')){
+					if(!isset($profiles[$profile['idx']][$source])) $profiles[$profile['idx']][$source] = array();
+					$profiles[$profile['idx']][$source][] = $profile[$value_type];
+				}
+				else{
+					$profiles[$profile['idx']][$source] = $profile[$value_type];
+				}
 			}
 
 		}
 	}
-	$result = count($result)?$result:$default_value;
-	
-return $result;
+
+	if(isset($profiles[$idx]) && !empty($profiles[$idx])){
+		if(!is_null($source))
+			return $profiles[$idx][$source];
+		else if(isset($profiles[$idx][$idx2]))
+			return $profiles[$idx][$idx2];
+		else
+			return $default_value;
+	}
+
+return $default_value;
 }
 
 //----------- ADD/EDIT USERPROFILE -------------
 function update_profile($idx,$value,$type=PROFILE_TYPE_UNKNOWN,$idx2=null,$source=null){
 	global $USER_DETAILS;
-	if($USER_DETAILS["alias"]==ZBX_GUEST_USER) return false;
+	if($USER_DETAILS['alias']==ZBX_GUEST_USER) return false;
 
 	if(profile_type($type,'unknown')) $type = profile_type_by_value($value);
 	else $value = profile_value_by_type($value,$type);
 
+//if($idx == 'web.history') SDI('PROF: v='.$value.'  t='.$type);
+
 	if($value === false) return false;
 
 	$sql_cond = '';
-	if(zbx_numeric($idx2)) 	$sql_cond = ' AND idx2='.$idx2.' AND '.DBin_node('idx2');
+ // dirty fix, but havn't figureout something better
+	if($idx != 'web.nodes.switch_node') $sql_cond.= ' AND '.DBin_node('profileid', false);
+// ---
+	if(zbx_numeric($idx2)) $sql_cond.= ' AND idx2='.$idx2.' AND '.DBin_node('idx2', false);
+
 
 	if(profile_type($type,'array')){
-		
 		$sql='DELETE FROM profiles '.
-			' WHERE userid='.$USER_DETAILS["userid"].
+			' WHERE userid='.$USER_DETAILS['userid'].
 				' AND idx='.zbx_dbstr($idx).
 				$sql_cond;
 
@@ -133,26 +123,20 @@ function update_profile($idx,$value,$type=PROFILE_TYPE_UNKNOWN,$idx2=null,$sourc
 		$result = DBend();
 	}
 	else{
-		$sql = 'SELECT profileid '.
-				' FROM profiles '.
-				' WHERE userid='.$USER_DETAILS['userid'].
-					' AND idx='.zbx_dbstr($idx).
-					$sql_cond;
-					
-		$row = DBfetch(DBselect($sql));
+		$prof = get_profile($idx, false, is_null($idx2)?0:$idx2);
 
-		if(!$row){
+		if($prof === false){
 			$result = insert_profile($idx,$value,$type,$idx2,$source);
 		}
 		else{
 			$val = array();
 			$value_type = profile_field_by_type($type);
-			
+
 			$val['value_id'] = 0;
 			$val['value_int'] = 0;
 			$val['value_str'] = '';
-			
-			$val[$value_type] = $value;	
+
+			$val[$value_type] = $value;
 
 			$idx2 = zbx_numeric($idx2)?$idx2:0;
 			$src = is_null($source)?'':$source;
@@ -169,15 +153,14 @@ function update_profile($idx,$value,$type=PROFILE_TYPE_UNKNOWN,$idx2=null,$sourc
 					' value_str='.zbx_dbstr($val['value_str']).','.
 					' type='.$type.','.
 					' source='.zbx_dbstr($src).
-				' WHERE userid='.$USER_DETAILS["userid"].
+				' WHERE userid='.$USER_DETAILS['userid'].
 					' AND idx='.zbx_dbstr($idx).
 					$sql_cond;
-					
 			$result = DBexecute($sql);
 		}
 	}
 
-	
+
 return $result;
 }
 
@@ -188,13 +171,13 @@ function insert_profile($idx,$value,$type,$idx2,$source){
 
 	$profileid = get_dbid('profiles', 'profileid');
 	$value_type = profile_field_by_type($type);
-	
+
 	$val['value_id'] = 0;
 	$val['value_int'] = 0;
 	$val['value_str'] = '';
-	
-	$val[$value_type] = $value;	
-	
+
+	$val[$value_type] = $value;
+
 	$idx2 = zbx_numeric($idx2)?$idx2:0;
 	$src = is_null($source)?'':$source;
 
@@ -202,9 +185,9 @@ function insert_profile($idx,$value,$type,$idx2,$source){
 		$val[$value_type] = isset($value['value'])?$value['value']:'';
 		$src = isset($value['source'])?$value['source']:$src;
 	}
-	
+
 	if(is_null($val[$value_type])) return false;
-	
+
 	$sql='INSERT INTO profiles (profileid,userid,idx,idx2,value_id,value_int,value_str,source,type)'.
 		' VALUES ('.$profileid.','.
 					$USER_DETAILS['userid'].','.
@@ -217,7 +200,7 @@ function insert_profile($idx,$value,$type,$idx2,$source){
 					$type.')';
 
 	$result = DBexecute($sql);
-	
+
 return $result;
 }
 
@@ -247,7 +230,7 @@ return $result;
 }
 
 function profile_field_by_type($type){
-	switch($type){	
+	switch($type){
 		case PROFILE_TYPE_INT:
 		case PROFILE_TYPE_ARRAY_INT:
 			$field = 'value_int';
@@ -268,9 +251,9 @@ return $field;
 function profile_type_by_value($value,$type=PROFILE_TYPE_UNKNOWN){
 	if(is_array($value)){
 		$value = $value[0];
-		
+
 		if(is_array($value)){
-			if(isset($value['value'])) 
+			if(isset($value['value']))
 				$type=zbx_numeric($value['value'])?PROFILE_TYPE_ARRAY_ID:PROFILE_TYPE_ARRAY_STR;
 		}
 		else{
@@ -278,7 +261,8 @@ function profile_type_by_value($value,$type=PROFILE_TYPE_UNKNOWN){
 		}
 	}
 	else{
-		if(zbx_numeric($value)) $type = PROFILE_TYPE_ID;
+		if(zbx_ctype_digit($value)) $type = PROFILE_TYPE_ID;
+		else if(zbx_numeric($value)) $type = PROFILE_TYPE_INT;
 		else $type = PROFILE_TYPE_STR;
 	}
 return $type;
@@ -290,9 +274,9 @@ function profile_value_by_type(&$value,$type){
 	}
 	else if(is_array($value)){
 		if(!isset($value['value'])) return false;
-		
+
 		$result = $value;
-		switch($type){	
+		switch($type){
 			case PROFILE_TYPE_ID:
 			case PROFILE_TYPE_INT:
 				if(zbx_numeric($value['value'])){
@@ -310,7 +294,7 @@ function profile_value_by_type(&$value,$type){
 		}
 	}
 	else{
-		switch($type){	
+		switch($type){
 			case PROFILE_TYPE_ID:
 				$result = zbx_ctype_digit($value)?$value:false;
 				break;
@@ -332,25 +316,30 @@ return $result;
 
 /************ CONFIG **************/
 
-function select_config(){
+function select_config($cache = true){
 	global $page;
-	
-	$row=DBfetch(DBselect('SELECT * FROM config WHERE '.DBin_node('configid', get_current_nodeid(false))));
+	static $config;
+
+	if($cache && isset($config)) return $config;
+
+	$row = DBfetch(DBselect('SELECT * FROM config WHERE '.DBin_node('configid', get_current_nodeid(false))));
+
 	if($row){
-		return	$row;
+		$config = $row;
+		return $row;
 	}
-	else if($page['title'] != S_INSTALLATION){
-			error('Unable to select configuration');
+	elseif($page['title'] != S_INSTALLATION){
+		error('Unable to select configuration');
 	}
-return	$row;
+return $row;
 }
 
 function update_config($configs){
 	$update = array();
-	
+
 	if(isset($configs['work_period']) && !is_null($configs['work_period'])){
 		if(!validate_period($configs['work_period'])){
-			error(S_ICORRECT_WORK_PERIOD);
+			error(S_INCORRECT_WORK_PERIOD);
 			return NULL;
 		}
 	}
@@ -360,9 +349,9 @@ function update_config($configs){
 			return NULL;
 		}
 	}
-	
+
 	foreach($configs as $key => $value){
-		if(!is_null($value)) 
+		if(!is_null($value))
 			$update[] = $key.'='.zbx_dbstr($value);
 	}
 
@@ -371,93 +360,92 @@ function update_config($configs){
 		return NULL;
 	}
 
-return	DBexecute('update config set '.implode(',',$update).' where '.DBin_node('configid', get_current_nodeid(false)));
+return	DBexecute('update config set '.implode(',',$update).' where '.DBin_node('configid', false));
 }
 /************ END CONFIG **************/
 
 /************ HISTORY **************/
-// Author: Aly
 function get_user_history(){
-	$history=array();
+	global $USER_DETAILS;
+
+	$result = array();
 	$delimiter = new CSpan('&raquo;','delimiter');
-	for($i = 0; $i < ZBX_HISTORY_COUNT; $i++){
-		if($rows = get_source_profile('web.history.'.$i,false)){
-			if($i>0){
-				array_push($history,$delimiter);
-			}
-			$url = new CLink($rows['source'],$rows['value'],'history');
-			array_push($history,array(SPACE,$url,SPACE));
+
+	$sql = 'SELECT title1, url1, title2, url2, title3, url3, title4, url4, title5, url5
+			FROM user_history WHERE userid='.$USER_DETAILS['userid'];
+	$history = DBfetch(DBSelect($sql));
+
+	if($history)
+		$USER_DETAILS['last_page'] = array('title' => $history['title4'], 'url' => $history['url4']);
+	else
+		$USER_DETAILS['last_page'] = false;
+
+	for($i = 1; $i<6; $i++){
+		if(defined($history['title'.$i])){
+			$url = new CLink(constant($history['title'.$i]), $history['url'.$i], 'history');
+			array_push($result, array(SPACE, $url, SPACE));
+			array_push($result, $delimiter);
 		}
 	}
-return $history;
+	array_pop($result);
+
+	return $result;
 }
 
-function get_last_history_page($same_page=false){
-	global $page;
-	$title = explode('[',$page['title']);
-	$title = $title[0];
-	
-	$rows=false;
-	for($i = 0; $i < ZBX_HISTORY_COUNT; $i++){
-		$new_rows = get_source_profile('web.history.'.$i,false);
-		
-		if(!$same_page && ($title == $new_rows['source'])) continue;
-		$rows = $new_rows;
-	}
-	
-	if(is_array($rows)){
-		$rows['page'] = $rows['source'];
-		$rows['url'] = $rows['value'];
-	}
-	
-return $rows;
-}
-
-// Author: Aly
 function add_user_history($page){
+	global $USER_DETAILS;
 
-	$title = explode('[',$page['title']);
-	$title = $title[0];
+	$userid = $USER_DETAILS['userid'];
+	$title = $page['title'];
 
-	if(!(isset($page['hist_arg']) && is_array($page['hist_arg']))){
-		return FALSE;
-	}
-	
-	$url = '';
-	foreach($page['hist_arg'] as $key => $arg){
-		if(isset($_REQUEST[$arg]) && !empty($_REQUEST[$arg])){
-			$url.=((empty($url))?('?'):('&')).$arg.'='.$_REQUEST[$arg];
-		}
-	}
-	$url = $page['file'].$url;
-
-
-	$curr = 0;
-	$profile = array();
-	for($i = 0; $i < ZBX_HISTORY_COUNT; $i++){
-		if($history = get_source_profile('web.history.'.$i,false)){
-			if($history['source'] != $title){
-				$profile[$curr] = $history;
-				$curr++;
+	if(isset($page['hist_arg']) && is_array($page['hist_arg'])){
+		$url = '';
+		foreach($page['hist_arg'] as $arg){
+			if(isset($_REQUEST[$arg])){
+				$url .= ((empty($url))? '?' : '&').$arg.'='.$_REQUEST[$arg];
 			}
 		}
+		$url = $page['file'].$url;
+	}
+	else{
+		$url = $page['file'];
 	}
 
-	$history = array('source' => $title, 
-					'value' => $url);
-				
-	if($curr < ZBX_HISTORY_COUNT){
-		for($i = 0; $i < $curr; $i++){
-			update_profile('web.history.'.$i,$profile[$i], PROFILE_TYPE_STR);
+	$sql = 'SELECT title5, url5
+			FROM user_history WHERE userid='.$userid;
+	$history5 = DBfetch(DBSelect($sql));
+
+	if($history5 && ($history5['title5'] == $title)){ //title is same
+		if($history5['url5'] != $url){ // title same, url isnt, change only url
+			$sql = 'UPDATE user_history '.
+					' SET url5='.zbx_dbstr($url).
+					' WHERE userid='.$userid;
 		}
-		$result = update_profile('web.history.'.$curr,$history, PROFILE_TYPE_STR);
-	} 
-	else {
-		for($i = 1; $i < ZBX_HISTORY_COUNT; $i++){
-			update_profile('web.history.'.($i-1),$profile[$i], PROFILE_TYPE_STR);
-		}
-		$result = update_profile('web.history.'.(ZBX_HISTORY_COUNT-1),$history, PROFILE_TYPE_STR);
+		else
+			return; // no need to change anything;
 	}
+	else{ // new page with new title is added
+		if(!$USER_DETAILS['last_page']){
+			$userhistoryid = get_dbid('user_history', 'userhistoryid');
+			$sql = 'INSERT INTO user_history (userhistoryid, userid, title5, url5)'.
+					' VALUES('.$userhistoryid.', '.$userid.', '.zbx_dbstr($title).', '.zbx_dbstr($url).')';
+		}
+		else{
+			$sql = 'UPDATE user_history '.
+					' SET title1=title2, '.
+						' url1=url2, '.
+						' title2=title3, '.
+						' url2=url3, '.
+						' title3=title4, '.
+						' url3=url4, '.
+						' title4=title5, '.
+						' url4=url5, '.
+						' title5='.zbx_dbstr($title).', '.
+						' url5='.zbx_dbstr($url).
+					' WHERE userid='.$userid;
+		}
+	}
+	$result = DBexecute($sql);
 
 return $result;
 }
@@ -465,9 +453,30 @@ return $result;
 
 /********** USER FAVORITES ***********/
 // Author: Aly
-function get_favorites($favobj,$nodeid=null){
-	$fav = get_source_profile($favobj,array(),PROFILE_TYPE_ARRAY_ID);
-return $fav;
+function get_favorites($idx,$nodeid=null){
+	global $USER_DETAILS;
+
+	$result = array();
+	if($USER_DETAILS['alias']!=ZBX_GUEST_USER){
+		$sql = 'SELECT value_id,value_int,value_str,source,type '.
+				' FROM profiles '.
+				' WHERE userid='.$USER_DETAILS['userid'].
+					' AND idx='.zbx_dbstr($idx).
+				' ORDER BY profileid ASC';
+		$db_profiles = DBselect($sql);
+		if($profile=DBfetch($db_profiles)){
+			$value_type = profile_field_by_type($profile['type']);
+
+			$result[] = array('value'=>$profile[$value_type], 'source'=>$profile['source']);
+			while($profile=DBfetch($db_profiles)){
+				$result[] = array('value'=>$profile[$value_type], 'source'=>$profile['source']);
+			}
+		}
+	}
+
+	$result = count($result)?$result:array();
+
+return $result;
 }
 
 // Author: Aly
@@ -479,9 +488,9 @@ function add2favorites($favobj,$favid,$source=null){
 			return true;
 		}
 	}
-	 
+
 	$favorites[] = array('value' => $favid);
-	
+
 	$result = update_profile($favobj,$favorites,PROFILE_TYPE_ARRAY_ID,null,$source);
 return $result;
 }
@@ -490,7 +499,7 @@ return $result;
 function rm4favorites($favobj,$favid,$favcnt=null,$source=null){
 	$favorites = get_favorites($favobj,get_current_nodeid(true));
 
-	$favcnt = (is_null($favcnt))?0:$favcnt;		
+	$favcnt = (is_null($favcnt))?0:$favcnt;
 	if($favid == 0) $favcnt = ZBX_FAVORITES_ALL;
 
 	foreach($favorites as $key => $favorite){
@@ -522,4 +531,4 @@ function infavorites($favobj,$favid,$source=null){
 return false;
 }
 /********** END USER FAVORITES ***********/
-?>
\ No newline at end of file
+?>
