@@ -1,5 +1,5 @@
 <?php
-/* 
+/*
 ** ZABBIX
 ** Copyright (C) 2000-2005 SIA Zabbix
 **
@@ -23,20 +23,20 @@
 	require_once 'include/hosts.inc.php';
 	require_once 'include/items.inc.php';
 
-	$page['title'] = "S_LATEST_DATA";
+	$page['title'] = S_LATEST_DATA;
 	$page['file'] = 'latest.php';
 	$page['hist_arg'] = array('groupid','hostid','show','select','open','applicationid');
-//	$page['scripts'] = array('updater.js');
-	
+	$page['scripts'] = array('scriptaculous.js?load=effects');
+
 	$page['type'] = detect_page_type(PAGE_TYPE_HTML);
-	
+
 	define('ZBX_PAGE_MAIN_HAT','hat_latest');
-	
+
 	if(PAGE_TYPE_HTML == $page['type']){
 		define('ZBX_PAGE_DO_REFRESH', 1);
 	}
 //	define('ZBX_PAGE_DO_JS_REFRESH', 1);
-	
+
 include_once 'include/page_header.php';
 ?>
 <?php
@@ -44,21 +44,26 @@ include_once 'include/page_header.php';
 	$fields=array(
 		'applications'=>	array(T_ZBX_INT, O_OPT,	NULL,	DB_ID,		NULL),
 		'applicationid'=>	array(T_ZBX_INT, O_OPT,	NULL,	DB_ID,		NULL),
-		'close'=>		array(T_ZBX_INT, O_OPT,	NULL,	IN('1'),	NULL),
-		'open'=>		array(T_ZBX_INT, O_OPT,	NULL,	IN('1'),	NULL),
+		'close'=>			array(T_ZBX_INT, O_OPT,	NULL,	IN('1'),	NULL),
+		'open'=>			array(T_ZBX_INT, O_OPT,	NULL,	IN('1'),	NULL),
 		'groupbyapp'=>		array(T_ZBX_INT, O_OPT,	NULL,	IN('1'),	NULL),
 
 		'groupid'=>		array(T_ZBX_INT, O_OPT,	P_SYS,	DB_ID,		NULL),
 		'hostid'=>		array(T_ZBX_INT, O_OPT,	P_SYS,	DB_ID,		NULL),
-		'select'=>		array(T_ZBX_STR, O_OPT, NULL,	NULL,		NULL),
 
-		'show'=>		array(T_ZBX_STR, O_OPT, NULL,   NULL,		NULL),
+
 		'fullscreen'=>	array(T_ZBX_INT, O_OPT,	P_SYS,	IN('0,1'),		NULL),
-		
+
+// filter
+		'select'=>			array(T_ZBX_STR, O_OPT, NULL,	NULL,		NULL),
+
+		'filter_rst'=>		array(T_ZBX_INT, O_OPT,	P_SYS,	IN(array(0,1)),	NULL),
+		'filter_set'=>		array(T_ZBX_STR, O_OPT,	P_SYS,	null,	NULL),
+
 //ajax
 		'favobj'=>		array(T_ZBX_STR, O_OPT, P_ACT,	NULL,			'isset({favid})'),
 		'favid'=>		array(T_ZBX_STR, O_OPT, P_ACT,  NOT_EMPTY,		NULL),
-		'state'=>		array(T_ZBX_INT, O_OPT, P_ACT,  NOT_EMPTY,		'isset({favobj}) && ("hat"=={favobj})'),
+		'state'=>		array(T_ZBX_INT, O_OPT, P_ACT,  NOT_EMPTY,		'isset({favobj})'),
 	);
 
 	check_fields($fields);
@@ -68,8 +73,8 @@ include_once 'include/page_header.php';
 	update_profile('web.latest.filter.select', $_REQUEST['select'], PROFILE_TYPE_STR);
 
 	$options = array('allow_all_hosts','monitored_hosts','with_historical_items');
-	if(!$ZBX_WITH_SUBNODES)	array_push($options,'only_current_node');
-	
+	//if(!$ZBX_WITH_ALL_NODES)	array_push($options,'only_current_node');
+
 //SDI($_REQUEST['groupid'].' : '.$_REQUEST['hostid']);
 	$params = array();
 	foreach($options as  $option) $params[$option] = 1;
@@ -82,10 +87,10 @@ include_once 'include/page_header.php';
 //----------------
 ?>
 <?php
-/* AJAX	*/
+/* AJAX */
 	if(isset($_REQUEST['favobj'])){
-		if('hat' == $_REQUEST['favobj']){
-			update_profile('web.latest.hats.'.$_REQUEST['favid'].'.state',$_REQUEST['state'], PROFILE_TYPE_INT);
+		if('filter' == $_REQUEST['favobj']){
+			update_profile('web.latest.filter.state',$_REQUEST['state'], PROFILE_TYPE_INT);
 		}
 /*
 		else if('refresh' == $_REQUEST['favobj']){
@@ -96,20 +101,43 @@ include_once 'include/page_header.php';
 			}
 		}
 //*/
-	}	
+	}
 
 	if((PAGE_TYPE_JS == $page['type']) || (PAGE_TYPE_HTML_BLOCK == $page['type'])){
 		exit();
 	}
 //--------
-	$p_elements = array();
+
+/* FILTER */
+	if(isset($_REQUEST['filter_rst'])){
+		$_REQUEST['select'] = '';
+	}
+
+	$_REQUEST['select'] = get_request('select',get_profile('web.latest.filter.select',''));
+
+	if(isset($_REQUEST['filter_set']) || isset($_REQUEST['filter_rst'])){
+		update_profile('web.latest.filter.select',$_REQUEST['select'], PROFILE_TYPE_STR);
+	}
+// --------------
+
+	$latest_wdgt = new CWidget();
 // Header
+
+	$url = '?fullscreen='.($_REQUEST['fullscreen']?'0':'1');
+
+	$fs_icon = new CDiv(SPACE,'fullscreen');
+	$fs_icon->setAttribute('title',$_REQUEST['fullscreen']?S_NORMAL.' '.S_VIEW:S_FULLSCREEN);
+	$fs_icon->addAction('onclick',new CJSscript("javascript: document.location = '".$url."';"));
+
+	$latest_wdgt->addPageHeader(S_LATEST_DATA_BIG,$fs_icon);
+
+// 2nd header
 	$r_form = new CForm();
-	$r_form->SetMethod('get');
+	$r_form->setMethod('get');
 
 //	$cmbGroup = new CComboBox('groupid',$_REQUEST['groupid'],"javascript: return updater.onetime_update('".ZBX_PAGE_MAIN_HAT."',this.form);");
 //	$cmbHosts = new CComboBox('hostid',$_REQUEST['hostid'],"javascript: return updater.onetime_update('".ZBX_PAGE_MAIN_HAT."',this.form);");
-	
+
 	$available_groups = $PAGE_GROUPS['groupids'];
 	$available_hosts = $PAGE_HOSTS['hostids'];
 
@@ -117,40 +145,43 @@ include_once 'include/page_header.php';
 	$cmbHosts = new CComboBox('hostid',$PAGE_HOSTS['selected'],'javascript: submit();');
 
 	foreach($PAGE_GROUPS['groups'] as $groupid => $name){
-		$cmbGroup->addItem($groupid, get_node_name_by_elid($groupid).$name);
+		$cmbGroup->addItem($groupid, get_node_name_by_elid($groupid, null, ': ').$name);
 	}
 	foreach($PAGE_HOSTS['hosts'] as $hostid => $name){
-		$cmbHosts->addItem($hostid, get_node_name_by_elid($hostid).$name);
+		$cmbHosts->addItem($hostid, get_node_name_by_elid($hostid, null, ': ').$name);
 	}
-	
-	$r_form->addItem(array(S_GROUP.SPACE,$cmbGroup));
-	$r_form->addItem(array(SPACE.S_HOST.SPACE,$cmbHosts));	
-	
-	$sql_from = '';
-	$sql_where = '';
-	if($_REQUEST['groupid'] > 0){
-		$sql_from .= ',hosts_groups hg ';
-		$sql_where.= ' AND hg.hostid=h.hostid AND hg.groupid='.$_REQUEST['groupid'];
-	}
-//---
-	
-	$l_form = new CForm();
-	$l_form->SetMethod('get');
-	$l_form->addVar('groupid',$_REQUEST['groupid']);
-	$l_form->addVar('hostid',$_REQUEST['hostid']);
-	$l_form->AddItem(array(S_SHOW_ITEMS_WITH_DESCRIPTION_LIKE, new CTextBox('select',$_REQUEST['select'],20)));
-	$l_form->AddItem(array(SPACE, new CButton('show',S_SHOW,'javascript: submit();')));
-//	$l_form->AddItem(array(SPACE, new CButton('show',S_SHOW,"javascript: return updater.onetime_update('".ZBX_PAGE_MAIN_HAT."',this.form);")));
 
-	$p_elements[] = get_table_header($l_form,$r_form);
+	$r_form->addItem(array(S_GROUP.SPACE,$cmbGroup));
+	$r_form->addItem(array(SPACE.S_HOST.SPACE,$cmbHosts));
+
+	$latest_wdgt->addHeader(S_ITEMS_BIG,$r_form);
+//	show_table_header(S_LATEST_DATA_BIG,$r_form);
 //-------------
 
+/************************* FILTER **************************/
+/***********************************************************/
+	$filterForm = new CFormTable();
+	$filterForm->setAttribute('name','zbx_filter');
+	$filterForm->setAttribute('id','zbx_filter');
+
+	$filterForm->addRow(S_SHOW_ITEMS_WITH_DESCRIPTION_LIKE, new CTextBox('select',$_REQUEST['select'],20));
+
+	$reset = new CButton("filter_rst",S_RESET);
+	$reset->setType('button');
+	$reset->setAction('javascript: var uri = new Curl(location.href); uri.setArgument("filter_rst",1); location.href = uri.getUrl();');
+
+	$filterForm->addItemToBottomRow(new CButton("filter_set",S_FILTER));
+	$filterForm->addItemToBottomRow($reset);
+
+	$latest_wdgt->addFlicker($filterForm, get_profile('web.latest.filter.state',1));
+//-------
+
 	validate_sort_and_sortorder('i.description',ZBX_SORT_UP);
-	
+
 	$_REQUEST['groupbyapp'] = get_request('groupbyapp',get_profile('web.latest.groupbyapp',1));
 	update_profile('web.latest.groupbyapp',$_REQUEST['groupbyapp'],PROFILE_TYPE_INT);
 
-	$_REQUEST['applications'] = get_request('applications',get_profile('web.latest.applications',array(),PROFILE_TYPE_ARRAY_ID));
+	$_REQUEST['applications'] = get_request('applications',get_profile('web.latest.applications',array()));
 
 	if(isset($_REQUEST['open'])){
 		if(!isset($_REQUEST['applicationid'])){
@@ -160,8 +191,8 @@ include_once 'include/page_header.php';
 		else if(!uint_in_array($_REQUEST['applicationid'],$_REQUEST['applications'])){
 			array_push($_REQUEST['applications'],$_REQUEST['applicationid']);
 		}
-		
-	} 
+
+	}
 	else if(isset($_REQUEST['close'])){
 		if(!isset($_REQUEST['applicationid'])){
 			$_REQUEST['applications'] = array();
@@ -197,24 +228,33 @@ include_once 'include/page_header.php';
 		$link = new CLink(new CImg('images/general/closed.gif'),$url);
 //		$link = new CLink(new CImg('images/general/closed.gif'),$url,null,"javascript: return updater.onetime_update('".ZBX_PAGE_MAIN_HAT."','".$url."');");
 	}
-	
+
 	$table=new CTableInfo();
-	$table->SetHeader(array(
-		is_show_subnodes()?make_sorting_link(S_NODE,'h.hostid') : null,
+	$table->setHeader(array(
+		is_show_all_nodes()?make_sorting_link(S_NODE,'h.hostid') : null,
 		($_REQUEST['hostid'] ==0)?make_sorting_link(S_HOST,'h.host') : NULL,
 		array($link,SPACE,make_sorting_link(S_DESCRIPTION,'i.description')),
 		make_sorting_link(S_LAST_CHECK,'i.lastclock'),
 		S_LAST_VALUE,
 		S_CHANGE,
 		S_HISTORY));
-		
+
 //	$table->ShowStart();
 
 	$db_apps = array();
 	$db_appids = array();
-	
-	$sql_where.=($_REQUEST['hostid']>0)?' AND h.hostid='.$_REQUEST['hostid']:'';
-	
+
+	$sql_from = '';
+	$sql_where = '';
+	if($_REQUEST['groupid'] > 0){
+		$sql_from .= ',hosts_groups hg ';
+		$sql_where.= ' AND hg.hostid=h.hostid AND hg.groupid='.$_REQUEST['groupid'];
+	}
+
+	if($_REQUEST['hostid']>0){
+		$sql_where.= ' AND h.hostid='.$_REQUEST['hostid'];
+	}
+
 	$sql = 'SELECT DISTINCT h.host,h.hostid, a.* '.
 			' FROM applications a, hosts h '.$sql_from.
 			' WHERE a.hostid=h.hostid'.
@@ -226,7 +266,7 @@ include_once 'include/page_header.php';
 	$db_app_res = DBselect($sql);
 	while($db_app = DBfetch($db_app_res)){
 		$db_app['item_cnt'] = 0;
-		
+
 		$db_apps[$db_app['applicationid']] = $db_app;
 		$db_appids[$db_app['applicationid']] = $db_app['applicationid'];
 	}
@@ -245,14 +285,14 @@ include_once 'include/page_header.php';
 		$description = item_description($db_item);
 
 		if(!empty($_REQUEST['select']) && !zbx_stristr($description, $_REQUEST['select']) ) continue;
-		
+
 		$db_app = &$db_apps[$db_item['applicationid']];
 
 		if(!isset($tab_rows[$db_app['applicationid']])) $tab_rows[$db_app['applicationid']] = array();
 		$app_rows = &$tab_rows[$db_app['applicationid']];
 
 		$db_app['item_cnt']++;
-		
+
 		if(!uint_in_array($db_app['applicationid'],$_REQUEST['applications']) && !isset($show_all_apps)) continue;
 
 		if(isset($db_item['lastclock']))
@@ -274,18 +314,18 @@ include_once 'include/page_header.php';
 		else{
 			$change = ' - ';
 		}
-		
+
 		if(($db_item['value_type']==ITEM_VALUE_TYPE_FLOAT) || ($db_item['value_type']==ITEM_VALUE_TYPE_UINT64)){
-			$actions=new CLink(S_GRAPH,'history.php?action=showgraph&itemid='.$db_item['itemid'],'action');
+			$actions = new CLink(S_GRAPH,'history.php?action=showgraph&itemid='.$db_item['itemid']);
 		}
 		else{
-			$actions=new CLink(S_HISTORY,'history.php?action=showvalues&period=3600&itemid='.$db_item['itemid'],'action');
+			$actions = new CLink(S_HISTORY,'history.php?action=showvalues&period=3600&itemid='.$db_item['itemid']);
 		}
-		
+
 		$item_status = $db_item['status']==3?'unknown': null;
-		
+
 		array_push($app_rows, new CRow(array(
-			is_show_subnodes()?SPACE:null,
+			is_show_all_nodes()?SPACE:null,
 			($_REQUEST['hostid']>0)?NULL:SPACE,
 			new CCol(str_repeat(SPACE,6).$description, $item_status),
 			new CCol($lastclock, $item_status),
@@ -302,11 +342,11 @@ include_once 'include/page_header.php';
 
 		$app_rows = $tab_rows[$appid];
 
-		if(uint_in_array($db_app['applicationid'],$_REQUEST['applications']) || isset($show_all_apps)){					
+		if(uint_in_array($db_app['applicationid'],$_REQUEST['applications']) || isset($show_all_apps)){
 			$url = '?close=1&applicationid='.$db_app['applicationid'].
 				url_param('groupid').url_param('hostid').url_param('applications').
 				url_param('fullscreen').url_param('select');
-				
+
 			$link = new CLink(new CImg('images/general/opened.gif'),$url);
 //			$link = new CLink(new CImg('images/general/opened.gif'),$url,null,"javascript: return updater.onetime_update('".ZBX_PAGE_MAIN_HAT."','".$url."');");
 		}
@@ -319,22 +359,22 @@ include_once 'include/page_header.php';
 		}
 
 		$col = new CCol(array($link,SPACE,bold($db_app['name']),SPACE.'('.$db_app['item_cnt'].SPACE.S_ITEMS.')'));
-		$col->SetColSpan(5);
+		$col->setColSpan(5);
 
-		$table->AddRow(array(
+		$table->addRow(array(
 				get_node_name_by_elid($db_app['applicationid']),
 				($_REQUEST['hostid'] > 0)?NULL:$db_app['host'],
 				$col
 			));
 
 		foreach($app_rows as $row)
-			$table->AddRow($row);
+			$table->addRow($row);
 	}
 
 // OTHER ITEMS (which doesn't linked to application)
 	$db_hosts = array();
 	$db_hostids = array();
-	
+
 	$sql = 'SELECT DISTINCT h.host,h.hostid '.
 			' FROM hosts h'.$sql_from.', items i '.
 				' LEFT JOIN items_applications ia ON ia.itemid=i.itemid'.
@@ -349,7 +389,7 @@ include_once 'include/page_header.php';
 	$db_host_res = DBselect($sql);
 	while($db_host = DBfetch($db_host_res)){
 		$db_host['item_cnt'] = 0;
-		
+
 		$db_hosts[$db_host['hostid']] = $db_host;
 		$db_hostids[$db_host['hostid']] = $db_host['hostid'];
 	}
@@ -368,13 +408,13 @@ include_once 'include/page_header.php';
 			' ORDER BY i.description,i.itemid';
 	$db_items = DBselect($sql);
 	while($db_item = DBfetch($db_items)){
-		
+
 		$description = item_description($db_item);
 
-		if(!empty($_REQUEST['select']) && !zbx_stristr($description, $_REQUEST['select']) ) continue;		
+		if(!empty($_REQUEST['select']) && !zbx_stristr($description, $_REQUEST['select']) ) continue;
 
 		$db_host = &$db_hosts[$db_item['hostid']];
-		
+
 		if(!isset($tab_rows[$db_host['hostid']])) $tab_rows[$db_host['hostid']] = array();
 		$app_rows = &$tab_rows[$db_host['hostid']];
 
@@ -394,28 +434,28 @@ include_once 'include/page_header.php';
 			($db_item['value_type'] == ITEM_VALUE_TYPE_FLOAT || $db_item['value_type'] == ITEM_VALUE_TYPE_UINT64) &&
 			($db_item['lastvalue']-$db_item['prevvalue'] != 0) )
 		{
-			if($db_item['lastvalue']-$db_item['prevvalue']<0){
-				$change=convert_units($db_item['lastvalue']-$db_item['prevvalue'],$db_item['units']);
-				$change=nbsp($change);
-			}
-			else{
-				$change='+'.convert_units($db_item['lastvalue']-$db_item['prevvalue'],$db_item['units']);
-				$change=nbsp($change);
+			$change = '';
+			if($db_item['lastvalue']-$db_item['prevvalue']>0){
+				$change = '+';
 			}
+
+			$digits = ($db_item['value_type'] == ITEM_VALUE_TYPE_FLOAT) ? 2 : 0;
+			$change = $change . convert_units(bcsub($db_item['lastvalue'], $db_item['prevvalue'], $digits), $db_item['units']);
+			$change = nbsp($change);
 		}
 		else{
-			$change=new CCol(' - ');
+			$change = new CCol(' - ');
 		}
-		
+
 		if(($db_item['value_type']==ITEM_VALUE_TYPE_FLOAT) || ($db_item['value_type']==ITEM_VALUE_TYPE_UINT64)){
-			$actions=new CLink(S_GRAPH,'history.php?action=showgraph&itemid='.$db_item['itemid'],'action');
+			$actions=new CLink(S_GRAPH,'history.php?action=showgraph&itemid='.$db_item['itemid']);
 		}
 		else{
-			$actions=new CLink(S_HISTORY,'history.php?action=showvalues&period=3600&itemid='.$db_item['itemid'],'action');
+			$actions=new CLink(S_HISTORY,'history.php?action=showvalues&period=3600&itemid='.$db_item['itemid']);
 		}
-		
+
 		array_push($app_rows, new CRow(array(
-			is_show_subnodes()?($db_host['item_cnt']?SPACE:get_node_name_by_elid($db_item['itemid'])):null,
+			is_show_all_nodes()?($db_host['item_cnt']?SPACE:get_node_name_by_elid($db_item['itemid'])):null,
 			$_REQUEST['hostid']?NULL:($db_host['item_cnt']?SPACE:$db_item['host']),
 			str_repeat(SPACE, 6).$description,
 			$lastclock,
@@ -437,7 +477,7 @@ include_once 'include/page_header.php';
 				url_param('groupid').url_param('hostid').
 				url_param('applications').url_param('select');
 			$link = new CLink(new CImg('images/general/opened.gif'),$url);
-//			$link = new CLink(new CImg('images/general/opened.gif'),$url,null,"javascript: return updater.onetime_update('".ZBX_PAGE_MAIN_HAT."','".$url."');");				
+//			$link = new CLink(new CImg('images/general/opened.gif'),$url,null,"javascript: return updater.onetime_update('".ZBX_PAGE_MAIN_HAT."','".$url."');");
 		}
 		else{
 			$url = '?open=1&applicationid=0'.
@@ -448,20 +488,18 @@ include_once 'include/page_header.php';
 		}
 
 		$col = new CCol(array($link,SPACE,bold(S_MINUS_OTHER_MINUS),SPACE.'('.$db_host['item_cnt'].SPACE.S_ITEMS.')'));
-		$col->SetColSpan(5);
-		
-		$table->AddRow(array(
+		$col->setColSpan(5);
+
+		$table->addRow(array(
 				get_node_name_by_elid($db_host['hostid']),
 				($_REQUEST['hostid'] > 0)?NULL:$db_host['host'],
 				$col
-				));	
+				));
 
 		foreach($app_rows as $row)
-			$table->AddRow($row);
+			$table->addRow($row);
 	}
 
-	$p_elements[] = $table;
-
 /*
 // Refresh tab
 	$refresh_tab = array(
@@ -472,23 +510,9 @@ include_once 'include/page_header.php';
 	);
 //*/
 
-	$url = '?fullscreen='.($_REQUEST['fullscreen']?'0':'1');
+	$latest_wdgt->addItem($table);
+	$latest_wdgt->show();
 
-	$fs_icon = new CDiv(SPACE,'fullscreen');
-	$fs_icon->AddOption('title',$_REQUEST['fullscreen']?S_NORMAL.' '.S_VIEW:S_FULLSCREEN);
-	$fs_icon->AddAction('onclick',new CScript("javascript: document.location = '".$url."';"));
-
-
-	$latest_hat = create_hat(
-			S_LATEST_DATA_BIG,
-			$p_elements,//new CSpan(S_LOADING_P,'textcolorstyles'),
-			array($fs_icon),
-			ZBX_PAGE_MAIN_HAT,
-			get_profile('web.latest.hats.hat_latest.state',1)
-	);
-
-	$latest_hat->Show();
-	
 //	add_refresh_objects($refresh_tab);
 ?>
 <?php
