@@ -1,5 +1,5 @@
 <?php
-/* 
+/*
 ** ZABBIX
 ** Copyright (C) 2000-2005 SIA Zabbix
 **
@@ -25,7 +25,7 @@
 	$page["title"] = "S_QUEUE_BIG";
 	$page["file"] = "queue.php";
 	$page['hist_arg'] = array('config');
-	
+
 	define('ZBX_PAGE_DO_REFRESH', 1);
 
 include_once "include/page_header.php";
@@ -38,7 +38,7 @@ include_once "include/page_header.php";
 	);
 
 	check_fields($fields);
-	
+
 	$available_hosts = get_accessible_hosts_by_user($USER_DETAILS,PERM_READ_ONLY,PERM_RES_IDS_ARRAY);
 ?>
 
@@ -48,7 +48,7 @@ include_once "include/page_header.php";
 
 	$form = new CForm();
 	$form->SetMethod('get');
-	
+
 	$cmbMode = new CComboBox("config", $_REQUEST["config"], "submit();");
 	$cmbMode->AddItem(0, S_OVERVIEW);
 	$cmbMode->AddItem(1, S_OVERVIEW_BY_PROXY);
@@ -61,34 +61,59 @@ include_once "include/page_header.php";
 <?php
 	$now = time();
 
+	$norm_item_types = array(
+			ITEM_TYPE_ZABBIX_ACTIVE,
+			ITEM_TYPE_SSH,
+			ITEM_TYPE_TELNET,
+			ITEM_TYPE_SIMPLE,
+			ITEM_TYPE_INTERNAL,
+			ITEM_TYPE_AGGREGATE,
+			ITEM_TYPE_EXTERNAL,
+			ITEM_TYPE_CALCULATED);
+	$zbx_item_types = array(
+			ITEM_TYPE_ZABBIX);
+	$snmp_item_types = array(
+			ITEM_TYPE_SNMPV1,
+			ITEM_TYPE_SNMPV2C,
+			ITEM_TYPE_SNMPV3);
+	$ipmi_item_types = array(
+			ITEM_TYPE_IPMI);
+
 	$item_types = array(
 			ITEM_TYPE_ZABBIX,
 			ITEM_TYPE_ZABBIX_ACTIVE,
 			ITEM_TYPE_SNMPV1,
-			//ITEM_TYPE_TRAPPER,
 			ITEM_TYPE_SNMPV2C,
 			ITEM_TYPE_SNMPV3,
+			ITEM_TYPE_IPMI,
+			ITEM_TYPE_SSH,
+			ITEM_TYPE_TELNET,
 			ITEM_TYPE_SIMPLE,
 			ITEM_TYPE_INTERNAL,
 			ITEM_TYPE_AGGREGATE,
-			//ITEM_TYPE_HTTPTEST,
-			ITEM_TYPE_EXTERNAL);
+			ITEM_TYPE_EXTERNAL,
+			ITEM_TYPE_CALCULATED);
 
-	$result = DBselect('SELECT i.itemid,i.lastclock,i.description,i.key_,i.type,h.host,h.hostid,h.proxy_hostid,i.delay,i.delay_flex '.
-		' FROM items i,hosts h '.
-		' WHERE i.status='.ITEM_STATUS_ACTIVE.
-			' AND i.type in ('.implode(',',$item_types).') '.
-			' AND ((h.status='.HOST_STATUS_MONITORED.' AND h.available != '.HOST_AVAILABLE_FALSE.') '.
-				' OR (h.status='.HOST_STATUS_MONITORED.' AND h.available='.HOST_AVAILABLE_FALSE.' AND h.disable_until<='.$now.')) '.
-			' AND i.hostid=h.hostid '.
-/*			' AND i.nextcheck + 5 <'.$now.*/
-			' AND i.key_ NOT IN ('.zbx_dbstr('status').','.zbx_dbstr('icmpping').','.zbx_dbstr('icmppingsec').','.zbx_dbstr('zabbix[log]').') '.
-			' AND i.value_type not in ('.ITEM_VALUE_TYPE_LOG.') '.
+	$result = DBselect('SELECT i.itemid,i.lastclock,i.description,i.key_,i.type,h.host,h.hostid,h.proxy_hostid,i.delay,i.delay_flex'.
+		' FROM items i,hosts h'.
+		' WHERE i.hostid=h.hostid'.
+			' AND h.status='.HOST_STATUS_MONITORED.
+			' AND i.status='.ITEM_STATUS_ACTIVE.
+			' AND i.value_type not in ('.ITEM_VALUE_TYPE_LOG.')'.
+			' AND i.key_ NOT IN ('.zbx_dbstr('status').','.zbx_dbstr('zabbix[log]').')'.
+			' AND NOT i.lastclock IS NULL'.
+			' AND ('.
+				' i.type in ('.implode(',',$norm_item_types).')'.
+				' OR (h.available<>'.HOST_AVAILABLE_FALSE.' AND i.type in ('.implode(',',$zbx_item_types).'))'.
+				' OR (h.snmp_available<>'.HOST_AVAILABLE_FALSE.' AND i.type in ('.implode(',',$snmp_item_types).'))'.
+				' OR (h.ipmi_available<>'.HOST_AVAILABLE_FALSE.' AND i.type in ('.implode(',',$ipmi_item_types).'))'.
+				')'.
 			' AND '.DBcondition('h.hostid',$available_hosts).
 			' AND '.DBin_node('h.hostid', get_current_nodeid()).
 		' ORDER BY i.lastclock,h.host,i.description,i.key_');
 
 	$table = new CTableInfo(S_THE_QUEUE_IS_EMPTY);
+	$truncated = 0;
 
 	if($_REQUEST["config"]==0){
 
@@ -102,9 +127,11 @@ include_once "include/page_header.php";
 		}
 
 		while($row=DBfetch($result)){
-			$nextcheck = is_null($row['lastclock']) ? 0 : calculate_item_nextcheck($row['itemid'], $row['type'],
-					$row['delay'], $row['delay_flex'], $row['lastclock']);
-			$diff = $now - $nextcheck;
+			$res = calculate_item_nextcheck($row['itemid'], $row['type'], $row['delay'], $row['delay_flex'], $row['lastclock']);
+			if (0 != $row['proxy_hostid'])
+				$res['nextcheck'] = $row['lastclock'] + $res['delay'];
+
+			$diff = $now - $res['nextcheck'];
 			if ($diff <= 5)
 				continue;
 
@@ -116,7 +143,7 @@ include_once "include/page_header.php";
 			else	$sec_rest[$row['type']]++;
 
 		}
-		
+
 		$table->setHeader(array(S_ITEMS,S_5_SECONDS,S_10_SECONDS,S_30_SECONDS,S_1_MINUTE,S_5_MINUTES,S_MORE_THAN_10_MINUTES));
 		foreach($item_types as $type){
 			$elements=array(
@@ -128,7 +155,7 @@ include_once "include/page_header.php";
 				new CCol($sec_600[$type],($sec_600[$type])?"high":"normal"),
 				new CCol($sec_rest[$type],($sec_rest[$type])?"disaster":"normal")
 			);
-			
+
 			$table->addRow($elements);
 		}
 	}
@@ -154,9 +181,11 @@ include_once "include/page_header.php";
 
 		while ($row = DBfetch($result))
 		{
-			$nextcheck = is_null($row['lastclock']) ? 0 : calculate_item_nextcheck($row['itemid'], $row['type'],
-					$row['delay'], $row['delay_flex'], $row['lastclock']);
-			$diff = $now - $nextcheck;
+			$res = calculate_item_nextcheck($row['itemid'], $row['type'], $row['delay'], $row['delay_flex'], $row['lastclock']);
+			if (0 != $row['proxy_hostid'])
+				$res['nextcheck'] = $row['lastclock'] + $res['delay'];
+
+			$diff = $now - $res['nextcheck'];
 			if ($diff <= 5)
 				continue;
 
@@ -202,25 +231,37 @@ include_once "include/page_header.php";
 
 		$table->SetHeader(array(
 				S_NEXT_CHECK,
-				is_show_subnodes() ? S_NODE : null,
+				S_DELAYED_BY,
+				is_show_all_nodes() ? S_NODE : null,
 				S_HOST,
 				S_DESCRIPTION
 				));
 		while($row=DBfetch($result)){
-			$nextcheck = is_null($row['lastclock']) ? 0 : calculate_item_nextcheck($row['itemid'], $row['type'],
-					$row['delay'], $row['delay_flex'], $row['lastclock']);
-			$diff = $now - $nextcheck;
+			$res = calculate_item_nextcheck($row['itemid'], $row['type'], $row['delay'], $row['delay_flex'], $row['lastclock']);
+			if (0 != $row['proxy_hostid'])
+				$res['nextcheck'] = $row['lastclock'] + $res['delay'];
+
+			$diff = $now - $res['nextcheck'];
 			if ($diff <= 5)
 				continue;
 
-			array_push($arr, array($nextcheck, $row['hostid'], $row['host'], item_description($row)));
+			array_push($arr, array($res['nextcheck'], $row['hostid'], $row['host'], item_description($row)));
 		}
 
+		$rows = 0;
 		sort($arr);
 		foreach($arr as $r){
+			$rows++;
+			if ($rows > 500)
+			{
+				$truncated = 1;
+				break;
+			}
+
 			$table->AddRow(array(
-				date("m.d.Y H:i:s",
+				date(S_DATE_FORMAT_YMDHMS,
 					$r[0]),
+				zbx_date2age($r[0]),
 				get_node_name_by_elid($r[1]),
 				$r[2],
 				$r[3]
@@ -231,7 +272,7 @@ include_once "include/page_header.php";
 	$table->Show();
 
 	if($_REQUEST["config"]!=0){
-		show_table_header(S_TOTAL.": ".$table->GetNumRows());
+		show_table_header(S_TOTAL.": ".$table->GetNumRows().($truncated ? ' ('.S_TRUNCATED.')' : ''));
 	}
 ?>
 <?php
