@@ -1,4 +1,4 @@
-/* 
+/*
 ** ZABBIX
 ** Copyright (C) 2000-2005 SIA Zabbix
 **
@@ -40,13 +40,11 @@
 // Performance Countername structure
 //
 
-#define MAX_PERFCOUNTER_NAME_LEN      (108)	/* old naming <MAX_COUNTER_NAME> */
-
 struct perfcounter
 {
 	struct perfcounter *next;
 	unsigned long	pdhIndex;
-	char		name[MAX_PERFCOUNTER_NAME_LEN];	
+	TCHAR		name[PDH_MAX_COUNTER_NAME];
 	/* must be caracter array! if you want to rewrite */
 	/* to dinacal memory allocation CHECK for usage   */
 	/* of sizeof function                             */
@@ -56,7 +54,7 @@ typedef struct perfcounter PERFCOUNTER;
 
 extern PERFCOUNTER *PerfCounterList;
 
-char *GetCounterName(unsigned long index);
-int check_counter_path(char *counterPath);
+LPTSTR	GetCounterName(DWORD pdhIndex);
+int	check_counter_path(char *counterPath);
 
 #endif /* ZABBIX_PERFMON_H */
