@@ -1,4 +1,4 @@
-/* 
+/*
 ** ZABBIX
 ** Copyright (C) 2000-2005 SIA Zabbix
 **
@@ -41,6 +41,14 @@
 #	include <ws2tcpip.h>
 #endif
 
+#ifdef HAVE_WSPIAPI_H
+#	include "Wspiapi.h"
+#endif
+
+#ifdef HAVE_IPHLPAPI_H
+#	include <Iphlpapi.h>
+#endif
+
 #ifdef HAVE_WINDOWS_H
 #	include <windows.h>
 #endif
@@ -101,6 +109,10 @@
 #	include <linux/kernel.h>
 #endif
 
+#ifdef HAVE_ARPA_NAMESER_COMPAT_H
+#	include <arpa/nameser_compat.h>
+#endif
+
 #ifdef HAVE_ARPA_NAMESER_H
 #	include <arpa/nameser.h>
 #endif
@@ -381,4 +393,25 @@
 #	include <ucd-snmp/keytools.h>
 #endif
 
+/* Required for advanced sigaction */
+#ifdef HAVE_SYS_UCONTEXT_H
+#	include <sys/ucontext.h>
+#endif
+
+#ifdef HAVE_ICONV
+#	include <iconv.h>
+#endif
+
+#ifdef HAVE_SSH2
+#	include <libssh2.h>
+#endif
+
+#ifdef HAVE_IO_H
+#	include <io.h>
+#endif
+
+#ifdef HAVE_FCNTL_H
+#	include <fcntl.h>
+#endif
+
 #endif
