@@ -1,4 +1,4 @@
-/* 
+/*
 ** ZABBIX
 ** Copyright (C) 2000-2005 SIA Zabbix
 **
@@ -92,7 +92,7 @@ double	zbx_time(void)
 
 	_ftime(&current);
 
-	return (((double)current.time) + 1.0e-6 * ((double)current.millitm));
+	return (((double)current.time) + 1.0e-3 * ((double)current.millitm));
 
 #else /* not _WINDOWS */
 
@@ -110,7 +110,7 @@ double	zbx_time(void)
  *                                                                            *
  * Function: zbx_current_time                                                 *
  *                                                                            *
- * Purpose: Gets the current time include UTC offset                          *
+ * Purpose: Gets the current time including UTC offset                        *
  *                                                                            *
  * Parameters:                                                                *
  *                                                                            *
@@ -296,7 +296,7 @@ static time_t	get_next_flexible_interval(char *delay_flex, time_t now)
  *                                                                            *
  * Function: calculate_item_nextcheck                                         *
  *                                                                            *
- * Purpose: calculate nextcheck timespamp for item                            *
+ * Purpose: calculate nextcheck timestamp for item                            *
  *                                                                            *
  * Parameters: delay - item's refresh rate in sec                             *
  *             now - current timestamp                                        *
@@ -316,7 +316,7 @@ int	calculate_item_nextcheck(zbx_uint64_t itemid, int item_type, int delay, char
 	time_t	next;
 
 	zabbix_log(LOG_LEVEL_DEBUG, "In calculate_item_nextcheck (" ZBX_FS_UI64 ",%d,\"%s\",%d)",
-			itemid, delay, delay_flex, now);
+			itemid, delay, NULL == delay_flex ? "" : delay_flex, now);
 
 	if (0 == delay)
 	{
@@ -368,7 +368,7 @@ int	calculate_item_nextcheck(zbx_uint64_t itemid, int item_type, int delay, char
  *                                                                            *
  * Parameters: ip - string                                                    *
  *                                                                            *
- * Return value: SUCCEED - is IPv4 address                                    * 
+ * Return value: SUCCEED - is IPv4 address                                    *
  *               FAIL - otherwise                                             *
  *                                                                            *
  * Author: Alexei Vladishev, Aleksander Vladishev                             *
@@ -418,7 +418,7 @@ static int	is_ip4(const char *ip)
  *                                                                            *
  * Parameters: ip - string                                                    *
  *                                                                            *
- * Return value: SUCCEED - is IPv6 address                                    * 
+ * Return value: SUCCEED - is IPv6 address                                    *
  *               FAIL - otherwise                                             *
  *                                                                            *
  * Author: Aleksader Vladishev                                                *
@@ -473,7 +473,7 @@ static int	is_ip6(const char *ip)
  *                                                                            *
  * Parameters: ip - string                                                    *
  *                                                                            *
- * Return value: SUCCEED - is IP address                                      * 
+ * Return value: SUCCEED - is IP address                                      *
  *               FAIL - otherwise                                             *
  *                                                                            *
  * Author: Aleksader Vladishev                                                *
@@ -505,7 +505,7 @@ int	is_ip(const char *ip)
  * Parameters: ip - IPv6 IPs [12fc::2]                                        *
  *             buf - result value [12fc:0000:0000:0000:0000:0000:0000:0002]   *
  *                                                                            *
- * Return value: FAIL - invlid IP address, SUCCEED - conversion OK            *
+ * Return value: FAIL - invalid IP address, SUCCEED - conversion OK           *
  *                                                                            *
  * Author: Alksander Vladishev                                                *
  *                                                                            *
@@ -516,9 +516,7 @@ int	expand_ipv6(const char *ip, char *str, size_t str_len )
 {
 	unsigned int	i[8]; /* x:x:x:x:x:x:x:x */
 	char		buf[5], *ptr;
-	int		c, dc, pos = 0, j, len, ip_len, ret = FAIL;
-
-	zabbix_log(LOG_LEVEL_DEBUG, "In expand_ipv6(ip:%s)", ip);
+	int		c, dc, pos = 0, j, len, ip_len;
 
 	c = 0; /* colons count */
 	for(ptr = strchr(ip, ':'); ptr != NULL; ptr = strchr(ptr + 1, ':'))
@@ -528,13 +526,13 @@ int	expand_ipv6(const char *ip, char *str, size_t str_len )
 
 	if(c < 2 || c > 7)
 	{
-		goto out;
+		return FAIL;
 	}
 
 	ip_len = strlen(ip);
 	if((ip[0] == ':' && ip[1] != ':') || (ip[ip_len - 1] == ':' && ip[ip_len - 2] != ':'))
 	{
-		goto out;
+		return FAIL;
 	}
 
 	memset(i, 0x00, sizeof(i));
@@ -546,15 +544,11 @@ int	expand_ipv6(const char *ip, char *str, size_t str_len )
 		if((ip[j] >= '0' && ip[j] <= '9') || (ip[j] >= 'A' && ip[j] <= 'F') || (ip[j] >= 'a' && ip[j] <= 'f'))
 		{
 			if(len > 3)
-			{
-				goto out;
-			}
+				return FAIL;
 			buf[len ++] = ip[j];
 		}
 		else if(ip[j] != ':')
-		{
-			goto out;
-		}
+			return FAIL;
 
 		if(ip[j] == ':' || ip[j + 1] == '\0')
 		{
@@ -574,23 +568,85 @@ int	expand_ipv6(const char *ip, char *str, size_t str_len )
 					pos = ( 8 - c ) + pos + (j == 0 ? 1 : 0);
 				}
 				else
-				{
-					goto out;
-				}
+					return FAIL;
 			}
 		}
 	}
-	zbx_snprintf(str, str_len, "%04x:%04x:%04x:%04x:%04x:%04x:%04x:%04x", i[0], i[1], i[2], i[3], i[4], i[5], i[6], i[7]);
-	ret = SUCCEED;
-out:
-	zabbix_log(LOG_LEVEL_DEBUG, "End expand_ipv6(ip:%s):%s", ip, ret == SUCCEED ? "SUCCEED" : "FAIL");
 
-	return ret;
+	zbx_snprintf(str, str_len, "%04x:%04x:%04x:%04x:%04x:%04x:%04x:%04x", i[0], i[1], i[2], i[3], i[4], i[5], i[6], i[7]);
+
+	return SUCCEED;
 }
 
 /******************************************************************************
  *                                                                            *
- * Function: ip_in_list_ipv6                                                  *
+ * Function: collapse_ipv6                                                    *
+ *                                                                            *
+ * Purpose: convert array to IPv6 collapsed type                              *
+ *                                                                            *
+ * Parameters: ip - [IN] full IPv6 address [12fc:0:0:0:0:0:0:2]               *
+ *                  [OUT] short IPv6 address [12fc::0]                        *
+ *             ip_len - [IN] ip buffer len                                    *
+ *                                                                            *
+ * Return value: pointer to result buffer                                     *
+ *                                                                            *
+ * Author: Alksander Vladishev                                                *
+ *                                                                            *
+ * Comments:                                                                  *
+ *                                                                            *
+ ******************************************************************************/
+char	*collapse_ipv6(char *str, size_t str_len)
+{
+	int		i, c = 0, m = 0, idx = -1, idx2 = -1, offset = 0;
+	unsigned int	j[8];
+
+	if (8 != sscanf(str, "%x:%x:%x:%x:%x:%x:%x:%x", &j[0], &j[1], &j[2], &j[3], &j[4], &j[5], &j[6], &j[7]))
+		return str;
+
+	for (i = 0; i <= 8; i++)
+	{
+		if (i < 8 && j[i] == 0)
+		{
+			if (idx2 == -1)
+				idx2 = i;
+			c++;
+		}
+		else
+		{
+			if (c != 0 && c > m)
+			{
+				m = c;
+				idx = idx2;
+			}
+			c = 0;
+			idx2 = -1;
+		}
+	}
+
+	for (i = 0; i < 8; i++)
+	{
+		if (j[i] != 0 || idx == -1 || i < idx)
+		{
+			offset += zbx_snprintf(str + offset, str_len - offset, "%x", j[i]);
+			if (i > idx)
+				idx = -1;
+			if (i < 7)
+				offset += zbx_snprintf(str + offset, str_len - offset, ":");
+		}
+		else if (idx == i)
+		{
+			offset += zbx_snprintf(str + offset, str_len - offset, ":");
+			if (idx == 0)
+				offset += zbx_snprintf(str + offset, str_len - offset, ":");
+		}
+	}
+
+	return str;
+}
+
+/******************************************************************************
+ *                                                                            *
+ * Function: ip6_in_list                                                      *
  *                                                                            *
  * Purpose: check if ip matches range of ip addresses                         *
  *                                                                            *
@@ -603,12 +659,12 @@ out:
  * Comments:                                                                  *
  *                                                                            *
  ******************************************************************************/
-int	ip_in_list_ipv6(char *list, char *ip)
+static int	ip6_in_list(char *list, char *ip)
 {
 	char	*start, *comma = NULL, *dash = NULL, buffer[MAX_STRING_LEN];
 	int	i[8], j[9], ret = FAIL;
 
-	zabbix_log(LOG_LEVEL_DEBUG, "In ip_in_list(list:%s,ip:%s)", list, ip);
+	zabbix_log(LOG_LEVEL_DEBUG, "In ip6_in_list(list:%s,ip:%s)", list, ip);
 
 	if(FAIL == expand_ipv6(ip, buffer, sizeof(buffer)))
 	{
@@ -652,9 +708,9 @@ int	ip_in_list_ipv6(char *list, char *ip)
 			j[8] = j[7];
 		}
 
-		if(i[0] == j[0] && i[1] == j[1] && i[2] == j[2] && i[3] == j[3] && 
-		   i[4] == j[4] && i[5] == j[5] && i[6] == j[6] && 
-		   i[7] >= j[7] && i[7] <= j[8])
+		if(i[0] == j[0] && i[1] == j[1] && i[2] == j[2] && i[3] == j[3] &&
+			i[4] == j[4] && i[5] == j[5] && i[6] == j[6] &&
+			i[7] >= j[7] && i[7] <= j[8])
 		{
 			ret = SUCCEED;
 			break;
@@ -688,7 +744,9 @@ out:
 		comma[0] = ',';
 	}
 
-	zabbix_log(LOG_LEVEL_DEBUG, "End ip_in_list(ret:%s)", ret == SUCCEED ? "SUCCEED" : "FAIL");
+	zabbix_log(LOG_LEVEL_DEBUG, "End of ip6_in_list():%s",
+			zbx_result_string(ret));
+
 	return ret;
 }
 #endif /*HAVE_IPV6*/
@@ -718,7 +776,7 @@ int	ip_in_list(char *list, char *ip)
 	if(sscanf(ip, "%d.%d.%d.%d", &i[0], &i[1], &i[2], &i[3]) != 4)
 	{
 #if defined(HAVE_IPV6)
-		ret = ip_in_list_ipv6(list, ip);
+		ret = ip6_in_list(list, ip);
 #endif /*HAVE_IPV6*/
 		goto out;
 	}
@@ -784,7 +842,9 @@ out:
 		comma[0] = ',';
 	}
 
-	zabbix_log( LOG_LEVEL_DEBUG, "End ip_in_list(ret:%s)", ret == SUCCEED ? "SUCCEED" : "FAIL");
+	zabbix_log(LOG_LEVEL_DEBUG, "End of ip_in_list():%s",
+			zbx_result_string(ret));
+
 	return ret;
 }
 
@@ -818,11 +878,11 @@ int	int_in_list(char *list, int value)
 		end=strchr(start, ',');
 
 		if(end != NULL)
-		{	
+		{
 			c=end[0];
 			end[0]='\0';
 		}
-		
+
 		if(sscanf(start,"%d-%d",&i1,&i2) == 2)
 		{
 			if(value>=i1 && value<=i2)
@@ -856,7 +916,8 @@ int	int_in_list(char *list, int value)
 		end[0]=c;
 	}
 
-	zabbix_log( LOG_LEVEL_DEBUG, "End int_in_list(ret:%s)", ret == SUCCEED?"SUCCEED":"FAIL");
+	zabbix_log(LOG_LEVEL_DEBUG, "End of int_in_list():%s",
+			zbx_result_string(ret));
 
 	return ret;
 }
@@ -868,7 +929,7 @@ int	int_in_list(char *list, int value)
  * Purpose: check if current time is within given period                      *
  *                                                                            *
  * Parameters: period - time period in format [d1-d2,hh:mm-hh:mm]*            *
- *             now    - timestamp for comporation                             *
+ *             now    - timestamp for comparison                             *
  *                      if NULL - use current timestamp.                      *
  *                                                                            *
  * Return value: 0 - out of period, 1 - within the period                     *
@@ -891,7 +952,7 @@ int	check_time_period(char *period, time_t now)
 
 	if (now == (time_t)NULL)
 		now = time(NULL);
-	
+
 	tm = localtime(&now);
 
 	day = tm->tm_wday;
@@ -976,7 +1037,7 @@ int	cmp_double(double a,double b)
  *                                                                            *
  * Author: Alexei Vladishev                                                   *
  *                                                                            *
- * Comments: the functions support prefixes K,M,G                             *
+ * Comments: the functions supports prefixes K,M,G                            *
  *                                                                            *
  ******************************************************************************/
 int	is_double_prefix(char *c)
@@ -1034,7 +1095,7 @@ int	is_double_prefix(char *c)
 	const char *endstr = str + strlen(str);
 	char *endptr = NULL;
 	double x;
-       
+
 	x = strtod(str, &endptr);
 
 	if(endptr == str || errno != 0)
@@ -1074,13 +1135,13 @@ int	is_double(char *c)
 		if(c[i]==' ') /* check right spaces */
 		{
 			for( ; c[i]==' ' && c[i]!=0;i++); /* trim right spaces */
-			
+
 			if(c[i]==0) break; /* SUCCEED */
 		}
 
 		return FAIL;
 	}
-	
+
 	if(len <= 0) return FAIL;
 
 	if(len == 1 && dot!=-1) return FAIL;
@@ -1110,27 +1171,49 @@ int	is_uint(char *c)
 	int	len;
 
 	for(i=0; c[i]==' ' && c[i]!=0;i++); /* trim left spaces */
-	
+
 	for(len=0; c[i]!=0; i++,len++)
 	{
 		if((c[i]>='0')&&(c[i]<='9'))
 		{
 			continue;
 		}
-		
+
 		if(c[i]==' ') /* check right spaces */
 		{
 			for( ; c[i]==' ' && c[i]!=0;i++); /* trim right spaces */
-			
+
 			if(c[i]==0) break; /* SUCCEED */
 		}
 		return FAIL;
 	}
 
 	if(len <= 0) return FAIL;
+
+	return SUCCEED;
+}
+
+#if defined(_WINDOWS)
+int	_wis_uint(const wchar_t *wide_string)
+{	
+	const wchar_t	*wide_char = wide_string;
+	
+	if (L'\0' == *wide_char)
+		return FAIL;
+		
+	while (L'\0' != *wide_char)
+	{
+		if (0 != iswdigit(*wide_char))
+		{
+			wide_char ++;
+			continue;
+		}
+		return FAIL;
+	}
 	
 	return SUCCEED;
 }
+#endif
 
 /******************************************************************************
  *                                                                            *
@@ -1174,6 +1257,86 @@ int	is_uint64(register char *str, zbx_uint64_t *value)
 	return SUCCEED;
 }
 
+/******************************************************************************
+ *                                                                            *
+ * Function: is_uoct                                                          *
+ *                                                                            *
+ * Purpose: check if the string is unsigned octal                             *
+ *                                                                            *
+ * Parameters: c - string to check                                            *
+ *                                                                            *
+ * Return value:  SUCCEED - the string is unsigned octal                      *
+ *                FAIL - otherwise                                            *
+ *                                                                            *
+ * Author: Aleksander Vladishev                                               *
+ *                                                                            *
+ * Comments:                                                                  *
+ *                                                                            *
+ ******************************************************************************/
+int	is_uoct(char *str)
+{
+	int	res = FAIL;
+
+	while (' ' == *str)	/* trim left spaces */
+		str++;
+
+	for (; '\0' != *str; str++)
+	{
+		if (*str < '0' || *str > '7')
+			break;
+
+		res = SUCCEED;
+	}
+
+	while (' ' == *str)	/* check right spaces */
+		str++;
+
+	if ('\0' != *str)
+		return FAIL;
+
+	return res;
+}
+
+/******************************************************************************
+ *                                                                            *
+ * Function: is_uhex                                                          *
+ *                                                                            *
+ * Purpose: check if the string is unsigned hexadecimal                       *
+ *                                                                            *
+ * Parameters: c - string to check                                            *
+ *                                                                            *
+ * Return value:  SUCCEED - the string is unsigned hexadecimal                *
+ *                FAIL - otherwise                                            *
+ *                                                                            *
+ * Author: Aleksander Vladishev                                               *
+ *                                                                            *
+ * Comments:                                                                  *
+ *                                                                            *
+ ******************************************************************************/
+int	is_uhex(char *str)
+{
+	int	res = FAIL;
+
+	while (' ' == *str)	/* trim left spaces */
+		str++;
+
+	for (; '\0' != *str; str++)
+	{
+		if ((*str < '0' || *str > '9') && (*str < 'a' || *str > 'f') && (*str < 'A' || *str > 'F'))
+			break;
+
+		res = SUCCEED;
+	}
+
+	while (' ' == *str)	/* check right spaces */
+		str++;
+
+	if ('\0' != *str)
+		return FAIL;
+
+	return res;
+}
+
 /******************************************************************************
  *                                                                            *
  * Function: uint64_in_list                                                   *
@@ -1204,11 +1367,11 @@ int	uint64_in_list(char *list, zbx_uint64_t value)
 		end=strchr(start, ',');
 
 		if(end != NULL)
-		{	
+		{
 			c=end[0];
 			end[0]='\0';
 		}
-		
+
 		if(sscanf(start,ZBX_FS_UI64 "-" ZBX_FS_UI64,&i1,&i2) == 2)
 		{
 			if(value>=i1 && value<=i2)
@@ -1243,29 +1406,22 @@ int	uint64_in_list(char *list, zbx_uint64_t value)
 		end[0]=c;
 	}
 
-	zabbix_log( LOG_LEVEL_DEBUG, "End int_in_list(ret:%s)", ret == SUCCEED?"SUCCEED":"FAIL");
+	zabbix_log(LOG_LEVEL_DEBUG, "End of int_in_list():%s",
+			zbx_result_string(ret));
 
 	return ret;
 }
 
-/******************************************************************************
- *                                                                            *
- * Function: get_nearestindex                                                 *
- *                                                                            *
- * Purpose:                                                                   *
- *                                                                            *
- * Parameters:                                                                *
- *                                                                            *
- * Return value:                                                              *
- *                                                                            *
- * Author: Alekasander Vladishev                                              *
- *                                                                            *
- * Comments:                                                                  *
- *                                                                            *
- ******************************************************************************/
-static int	get_nearestindex(zbx_uint64_t *values, int num, zbx_uint64_t value)
+/*
+ * Get nearest index of sorted elements in array.
+ *     p - pointer to array of elements
+ *     sz - size of one element in array
+ *     num - number of elements
+ */
+int	get_nearestindex(void *p, size_t sz, int num, zbx_uint64_t id)
 {
-	int	first_index, last_index, index;
+	int		first_index, last_index, index;
+	zbx_uint64_t	element_id;
 
 	if (num == 0)
 		return 0;
@@ -1276,15 +1432,16 @@ static int	get_nearestindex(zbx_uint64_t *values, int num, zbx_uint64_t value)
 	{
 		index = first_index + (last_index - first_index) / 2;
 
-		if (values[index] == value)
+		element_id = *(zbx_uint64_t *)((char *)p + index * sz);
+		if (element_id == id)
 			return index;
 		else if (last_index == first_index)
 		{
-			if (values[index] < value)
+			if (element_id < id)
 				index++;
 			return index;
 		}
-		else if (values[index] < value)
+		else if (element_id < id)
 			first_index = index + 1;
 		else
 			last_index = index;
@@ -1306,17 +1463,17 @@ static int	get_nearestindex(zbx_uint64_t *values, int num, zbx_uint64_t value)
  * Comments:                                                                  *
  *                                                                            *
  ******************************************************************************/
-int	uint64_array_add(zbx_uint64_t **values, int *alloc, int *num, zbx_uint64_t value)
+int	uint64_array_add(zbx_uint64_t **values, int *alloc, int *num, zbx_uint64_t value, int alloc_step)
 {
 	int	index;
 
-	index = get_nearestindex(*values, *num, value);
+	index = get_nearestindex(*values, sizeof(zbx_uint64_t), *num, value);
 	if (index < (*num) && (*values)[index] == value)
 		return index;
 
 	if (*alloc == *num)
 	{
-		*alloc += 100;
+		*alloc += alloc_step;
 		*values = zbx_realloc(*values, *alloc * sizeof(zbx_uint64_t));
 	}
 
@@ -1328,6 +1485,29 @@ int	uint64_array_add(zbx_uint64_t **values, int *alloc, int *num, zbx_uint64_t v
 	return index;
 }
 
+/******************************************************************************
+ *                                                                            *
+ * Function: uint64_array_merge                                               *
+ *                                                                            *
+ * Purpose: merge two uint64 arrays                                           *
+ *                                                                            *
+ * Parameters:                                                                *
+ *                                                                            *
+ * Return value:                                                              *
+ *                                                                            *
+ * Author: Aleksander Vladishev                                               *
+ *                                                                            *
+ * Comments:                                                                  *
+ *                                                                            *
+ ******************************************************************************/
+void	uint64_array_merge(zbx_uint64_t **values, int *alloc, int *num, zbx_uint64_t *value, int value_num, int alloc_step)
+{
+	int	i;
+
+	for (i = 0; i < value_num; i++)
+		uint64_array_add(values, alloc, num, value[i], alloc_step);
+}
+
 /******************************************************************************
  *                                                                            *
  * Function: uint64_array_exists                                              *
@@ -1347,7 +1527,7 @@ int	uint64_array_exists(zbx_uint64_t *values, int num, zbx_uint64_t value)
 {
 	int	index;
 
-	index = get_nearestindex(values, num, value);
+	index = get_nearestindex(values, sizeof(zbx_uint64_t), num, value);
 	if (index < num && values[index] == value)
 		return SUCCEED;
 
@@ -1375,7 +1555,7 @@ void	uint64_array_rm(zbx_uint64_t *values, int *num, zbx_uint64_t *rm_values, in
 
 	for (rindex = 0; rindex < rm_num; rindex++)
 	{
-		index = get_nearestindex(values, *num, rm_values[rindex]);
+		index = get_nearestindex(values, sizeof(zbx_uint64_t), *num, rm_values[rindex]);
 		if (index == *num || values[index] != rm_values[rindex])
 			continue;
 
@@ -1383,3 +1563,159 @@ void	uint64_array_rm(zbx_uint64_t *values, int *num, zbx_uint64_t *rm_values, in
 		(*num)--;
 	}
 }
+
+/******************************************************************************
+ *                                                                            *
+ * Function: str2uint64                                                       *
+ *                                                                            *
+ * Purpose: convert string to 64bit unsigned integer                          *
+ *                                                                            *
+ * Parameters: str - string to convert                                        *
+ *             value - pointer to retirned value                              *
+ *                                                                            *
+ * Return value:  SUCCEED - the string is unsigned integer                    *
+ *                FAIL - otherwise                                            *
+ *                                                                            *
+ * Author: Aleksander Vladishev                                               *
+ *                                                                            *
+ * Comments: the function automatically processes prefixes 'K','M','G'        *
+ *                                                                            *
+ ******************************************************************************/
+int	str2uint64(char *str, zbx_uint64_t *value)
+{
+	size_t	sz;
+	int	factor = 1, ret;
+	char	c = '\0';
+
+	sz = strlen(str) - 1;
+
+	if (str[sz] == 'K')
+	{
+		c = str[sz];
+		factor = 1024;
+	}
+	else if (str[sz] == 'M')
+	{
+		c = str[sz];
+		factor = 1024 * 1024;
+	}
+	else if (str[sz] == 'G')
+	{
+		c = str[sz];
+		factor = 1024 * 1024 * 1024;
+	}
+
+	if ('\0' != c)
+		str[sz] = '\0';
+
+	if (SUCCEED == (ret = is_uint64(str, value)))
+		*value *= factor;
+
+	if ('\0' != c)
+		str[sz] = c;
+
+	return ret;
+}
+
+/******************************************************************************
+ *                                                                            *
+ * Function: is_hostname_char                                                 *
+ *                                                                            *
+ * Purpose:                                                                   *
+ *                                                                            *
+ * Parameters:                                                                *
+ *                                                                            *
+ * Return value:  SUCCEED - the char is allowed in the host name              *
+ *                FAIL - otherwise                                            *
+ *                                                                            *
+ * Author: Aleksander Vladishev                                               *
+ *                                                                            *
+ * Comments: in host name allowed characters: '0-9a-zA-Z_. -]'                *
+ *           !!! Don't forget sync code with PHP !!!                          *
+ *                                                                            *
+ ******************************************************************************/
+int	is_hostname_char(const char c)
+{
+	if (c >= 'a' && c <= 'z')
+		return SUCCEED;
+
+	if (c == '.' || c == '_' || c == '-' || c == ' ')
+		return SUCCEED;
+
+	if (c >= 'A' && c <= 'Z')
+		return SUCCEED;
+
+	if (c >= '0' && c <= '9')
+		return SUCCEED;
+
+	return FAIL;
+}
+
+/******************************************************************************
+ *                                                                            *
+ * Function: is_key_char                                                      *
+ *                                                                            *
+ * Purpose:                                                                   *
+ *                                                                            *
+ * Parameters:                                                                *
+ *                                                                            *
+ * Return value:  SUCCEED - the char is allowed in the item key               *
+ *                FAIL - otherwise                                            *
+ *                                                                            *
+ * Author: Aleksander Vladishev                                               *
+ *                                                                            *
+ * Comments: in host name allowed characters: '0-9a-zA-Z_.,]'                 *
+ *           !!! Don't forget sync code with PHP !!!                          *
+ *                                                                            *
+ ******************************************************************************/
+int	is_key_char(const char c)
+{
+	if (c >= 'a' && c <= 'z')
+		return SUCCEED;
+
+	if (c == '.' || c == ',' || c == '_')
+		return SUCCEED;
+
+	if (c >= 'A' && c <= 'Z')
+		return SUCCEED;
+
+	if (c >= '0' && c <= '9')
+		return SUCCEED;
+
+	return FAIL;
+}
+
+/******************************************************************************
+ *                                                                            *
+ * Function: is_function_char                                                 *
+ *                                                                            *
+ * Purpose:                                                                   *
+ *                                                                            *
+ * Parameters:                                                                *
+ *                                                                            *
+ * Return value:  SUCCEED - the char is allowed in the trigger function       *
+ *                FAIL - otherwise                                            *
+ *                                                                            *
+ * Author: Aleksander Vladishev                                               *
+ *                                                                            *
+ * Comments: in host name allowed characters: '0-9a-zA-Z_. -]'                *
+ *           !!! Don't forget sync code with PHP !!!                          *
+ *                                                                            *
+ ******************************************************************************/
+int	is_function_char(const char c)
+{
+	if (c >= 'a' && c <= 'z')
+		return SUCCEED;
+
+	if (c == '_')
+		return SUCCEED;
+
+	if (c >= 'A' && c <= 'Z')
+		return SUCCEED;
+
+	if (c >= '0' && c <= '9')
+		return SUCCEED;
+
+	return FAIL;
+}
+
