@@ -24,6 +24,10 @@
 #include "log.h"
 #include "zlog.h"
 
+/* Transaction level. Must be 1 for all queries. */
+int	txn_level = 0;
+int	txn_init = 0;
+
 #ifdef	HAVE_SQLITE3
 	int		sqlite_transaction_started = 0;
 	sqlite3		*conn = NULL;
@@ -40,8 +44,8 @@
 #endif
 
 #ifdef	HAVE_ORACLE
-	sqlo_db_handle_t oracle;
-#endif
+	zbx_oracle_db_handle_t oracle;
+#endif /* HAVE_ORACLE */
 
 void	zbx_db_close(void)
 {
@@ -54,9 +58,22 @@ void	zbx_db_close(void)
 	conn = NULL;
 #endif
 #ifdef	HAVE_ORACLE
-	if (SQLO_SUCCESS != sqlo_finish(oracle))
-		zabbix_errlog(ERR_Z3004, 0, "sqlo_finish");
-#endif
+	if (oracle.svchp)
+	{
+		(void) OCILogoff(oracle.svchp, oracle.errhp);
+		oracle.svchp = NULL;
+	}
+
+	if (oracle.errhp) {
+		(void) OCIHandleFree (oracle.errhp, OCI_HTYPE_ERROR);
+		oracle.errhp = NULL;
+	}
+
+	if (oracle.envhp) {
+		(void) OCIHandleFree((dvoid *) oracle.envhp, OCI_HTYPE_ENV);
+		oracle.envhp = NULL;
+	}
+#endif /* HAVE_ORACLE */
 #ifdef	HAVE_SQLITE3
 	sqlite_transaction_started = 0;
 	sqlite3_close(conn);
@@ -64,18 +81,52 @@ void	zbx_db_close(void)
 /*	php_sem_remove(&sqlite_access);*/
 #endif
 }
+#if HAVE_ORACLE
+char* zbx_oci_error(sword status)
+{
+	/* NOTE: do not thread safe, be carefully */
+	static char errbuf[512];
+	sb4 errcode = 0;
 
+	errbuf[0] = '\0';
+	switch (status)
+	{
+		case OCI_SUCCESS_WITH_INFO:
+			(void) zbx_snprintf (errbuf, sizeof(errbuf), "%s", "OCI_SUCCESS_WITH_INFO");
+			break;
+		case OCI_NEED_DATA:
+			(void) zbx_snprintf (errbuf, sizeof(errbuf), "%s", "OCI_NEED_DATA");
+			break;
+		case OCI_NO_DATA:
+			(void) zbx_snprintf (errbuf, sizeof(errbuf), "%s", "OCI_NODATA");
+			break;
+		case OCI_ERROR:
+			(void) OCIErrorGet((dvoid *)oracle.errhp, (ub4) 1, (text *) NULL, &errcode,
+				(text *)errbuf, (ub4) sizeof(errbuf), OCI_HTYPE_ERROR);
+			break;
+		case OCI_INVALID_HANDLE:
+			(void) zbx_snprintf (errbuf, sizeof(errbuf), "%s", "OCI_INVALID_HANDLE");
+			break;
+		case OCI_STILL_EXECUTING:
+			(void) zbx_snprintf (errbuf, sizeof(errbuf), "%s", "OCI_STILL_EXECUTE");
+			break;
+		case OCI_CONTINUE:
+			(void) zbx_snprintf (errbuf, sizeof(errbuf), "%s", "OCI_CONTINUE");
+			break;
+	}
+	return errbuf;
+}
+#endif /* HAVE_ORACLE */
 
 /*
  * Connect to the database.
  * If fails, program terminates.
- */ 
+ */
 int	zbx_db_connect(char *host, char *user, char *password, char *dbname, char *dbsocket, int port)
 {
 	int	ret = ZBX_DB_OK;
-#ifdef	HAVE_SQLITE3
-	char	*p, *path;
-#endif /* HAVE_SQLITE3 */
+
+	txn_init = 1;
 
 #ifdef	HAVE_MYSQL
 	/* For MySQL >3.22.00 */
@@ -99,15 +150,22 @@ int	zbx_db_connect(char *host, char *user, char *password, char *dbname, char *d
 	}
 
 	if (ZBX_DB_OK == ret)
+	{
+		DBexecute("SET NAMES utf8");
 		DBexecute("SET CHARACTER SET utf8");
+	}
 
 	if (ZBX_DB_FAIL == ret)
 	{
 		switch (mysql_errno(conn)) {
+		case CR_CONN_HOST_ERROR:
 		case CR_SERVER_GONE_ERROR:
 		case CR_CONNECTION_ERROR:
 		case CR_SERVER_LOST:
 		case ER_SERVER_SHUTDOWN:
+		case ER_ACCESS_DENIED_ERROR: /* wrong user or password */
+		case ER_ILLEGAL_GRANT_FOR_TABLE: /* user without any privileges */
+		case ER_TABLEACCESS_DENIED_ERROR:/* user without some privilege */
 		case ER_UNKNOWN_ERROR:
 			ret = ZBX_DB_DOWN;
 			break;
@@ -115,8 +173,6 @@ int	zbx_db_connect(char *host, char *user, char *password, char *dbname, char *d
 			break;
 		}
 	}
-
-	return ret;
 #endif
 #ifdef	HAVE_POSTGRESQL
 	char		*cport = NULL;
@@ -157,43 +213,68 @@ int	zbx_db_connect(char *host, char *user, char *password, char *dbname, char *d
 		/* disable "nonstandard use of \' in a string literal" warning */
 		DBexecute("set escape_string_warning to off");
 	}
-
-	return ret;
 #endif
 #ifdef	HAVE_ORACLE
-	char	connect[MAX_STRING_LEN];
+	char *connect = NULL;
+	sword err = OCI_SUCCESS;
 
-	zbx_strlcpy(connect, user, sizeof(connect));
+#if defined(HAVE_GETENV) && defined(HAVE_PUTENV)
+	if (NULL == getenv ("NLS_LANG")) {
+		putenv ("NLS_LANG=.UTF8");
+	}
+#endif /* defined(HAVE_GETENV) && defined(HAVE_PUTENV) */
 
-	if (password && *password) {
-		zbx_strlcat(connect, "/", sizeof(connect));
-		zbx_strlcat(connect, password, sizeof(connect));
+	memset (&oracle, 0, sizeof (oracle));
 
-		if (dbname && *dbname) {
-			zbx_strlcat(connect, "@", sizeof(connect));
-			zbx_strlcat(connect, dbname, sizeof(connect));
-		}
+	if (host && *host) {
+		connect = zbx_strdcatf(connect, "//%s", host);
+
+		if (port)
+			connect = zbx_strdcatf(connect, ":%d", port);
 	}
 
-	if (SQLO_SUCCESS != sqlo_init(SQLO_OFF, 1, 100)) {
-		zabbix_errlog(ERR_Z3001, connect, 0, "Failed to init libsqlora8");
+	if (dbname && *dbname && connect) {
+		if (connect)
+			connect = zbx_strdcat(connect, "/");
+		connect = zbx_strdcatf(connect, "%s", dbname);
+	}
+
+	/* initialize environment */
+	err = OCIEnvCreate((OCIEnv **) &oracle.envhp, (ub4) OCI_DEFAULT,
+			(dvoid *) 0, (dvoid * (*)(dvoid *,size_t)) 0,
+			(dvoid * (*)(dvoid *, dvoid *, size_t)) 0,
+			(void (*)(dvoid *, dvoid *)) 0, (size_t) 0, (dvoid **) 0);
+	if (OCI_SUCCESS != err) {
+		zabbix_errlog(ERR_Z3001, connect, err, zbx_oci_error(err));
 		ret = ZBX_DB_FAIL;
 	}
 
 	if (ZBX_DB_OK == ret) {
-		/* login */ /* TODO: how to use port??? */
-		if (SQLO_SUCCESS != sqlo_connect(&oracle, connect)) {
-			zabbix_errlog(ERR_Z3001, connect, 0, "sqlo_connect");
+		/* allocate an error handle */
+		(void) OCIHandleAlloc((dvoid *) oracle.envhp, (dvoid **) &oracle.errhp, OCI_HTYPE_ERROR,
+			(size_t) 0, (dvoid **) 0);
+
+		/* get the session */
+		err = OCILogon2(oracle.envhp, oracle.errhp, &oracle.svchp,
+				(text *)user, (ub4)strlen(user),
+				(text *)password, (ub4)strlen(password),
+				(text *)connect, (ub4)strlen(connect),
+				OCI_DEFAULT);
+		if (OCI_SUCCESS != err) {
+			zabbix_errlog(ERR_Z3001, connect, err, zbx_oci_error(err));
 			ret = ZBX_DB_FAIL;
 		}
 	}
 
-	if (ZBX_DB_OK == ret)
-		sqlo_autocommit_off(oracle);
+	zbx_free(connect);
 
-	return ret;
+	if (ZBX_DB_OK != ret) {
+		zbx_db_close ();
+	}
 #endif
 #ifdef	HAVE_SQLITE3
+	char	*p, *path;
+
 	/* check to see that the backend connection was successfully made */
 	if (SQLITE_OK != (ret = sqlite3_open(dbname, &conn))) {
 		zabbix_errlog(ERR_Z3001, dbname, 0, sqlite3_errmsg(conn));
@@ -216,9 +297,10 @@ int	zbx_db_connect(char *host, char *user, char *password, char *dbname, char *d
 	DBexecute("PRAGMA temp_store_directory = '%s'", path);
 
 	zbx_free(path);
+#endif
+	txn_init = 0;
 
 	return ret;
-#endif
 }
 
 void	zbx_db_init(char *host, char *user, char *password, char *dbname, char *dbsocket, int port)
@@ -287,11 +369,17 @@ static DB_RESULT __zbx_zbx_db_select(const char *fmt, ...)
  *                                                                            *
  * Author: Eugene Grigorjev                                                   *
  *                                                                            *
- * Comments: Do nothing of DB does not support transactions                   *
+ * Comments: Do nothing if DB does not support transactions                   *
  *                                                                            *
  ******************************************************************************/
 void	zbx_db_begin(void)
 {
+	if (txn_level > 0)
+	{
+		zabbix_log( LOG_LEVEL_CRIT, "ERROR: nested transaction detected. Please report it to Zabbix Team.");
+		assert(0);
+	}
+	txn_level++;
 #ifdef	HAVE_MYSQL
 	zbx_db_execute("%s","begin;");
 #endif
@@ -300,10 +388,14 @@ void	zbx_db_begin(void)
 #endif
 #ifdef	HAVE_SQLITE3
 	sqlite_transaction_started++;
-	
+
 	if(sqlite_transaction_started == 1)
 	{
-		php_sem_acquire(&sqlite_access);
+		if(PHP_MUTEX_OK != php_sem_acquire(&sqlite_access))
+		{
+			zabbix_log( LOG_LEVEL_CRIT, "ERROR: Unable to create lock on SQLite database.");
+			exit(-1);
+		}
 
 		zbx_db_execute("%s","begin;");
 	}
@@ -326,11 +418,16 @@ void	zbx_db_begin(void)
  *                                                                            *
  * Author: Eugene Grigorjev                                                   *
  *                                                                            *
- * Comments: Do nothing of DB does not support transactions                   *
+ * Comments: Do nothing if DB does not support transactions                   *
  *                                                                            *
  ******************************************************************************/
 void zbx_db_commit(void)
 {
+	if (0 == txn_level)
+	{
+		zabbix_log( LOG_LEVEL_CRIT, "ERROR: commit without transaction. Please report it to Zabbix Team.");
+		assert(0);
+	}
 #ifdef	HAVE_MYSQL
 	zbx_db_execute("%s","commit;");
 #endif
@@ -338,15 +435,15 @@ void zbx_db_commit(void)
 	zbx_db_execute("%s","commit;");
 #endif
 #ifdef	HAVE_ORACLE
-	zbx_db_execute("%s","commit");
-#endif
+	(void) OCITransCommit (oracle.svchp, oracle.errhp, OCI_DEFAULT);
+#endif /* HAVE_ORACLE */
 #ifdef	HAVE_SQLITE3
 
 	if(sqlite_transaction_started > 1)
 	{
 		sqlite_transaction_started--;
 	}
-	
+
 	if(sqlite_transaction_started == 1)
 	{
 		zbx_db_execute("%s","commit;");
@@ -357,6 +454,7 @@ void zbx_db_commit(void)
 	}
 
 #endif
+	txn_level--;
 }
 
 /******************************************************************************
@@ -371,11 +469,16 @@ void zbx_db_commit(void)
  *                                                                            *
  * Author: Eugene Grigorjev                                                   *
  *                                                                            *
- * Comments: Do nothing of DB does not support transactions                   *
+ * Comments: Do nothing if DB does not support transactions                   *
  *                                                                            *
  ******************************************************************************/
 void zbx_db_rollback(void)
 {
+	if (0 == txn_level)
+	{
+		zabbix_log( LOG_LEVEL_CRIT, "ERROR: rollback without transaction. Please report it to Zabbix Team.");
+		assert(0);
+	}
 #ifdef	HAVE_MYSQL
 	zbx_db_execute("rollback;");
 #endif
@@ -383,8 +486,8 @@ void zbx_db_rollback(void)
 	zbx_db_execute("rollback;");
 #endif
 #ifdef	HAVE_ORACLE
-	zbx_db_execute("rollback");
-#endif
+	(void) OCITransRollback (oracle.svchp, oracle.errhp, OCI_DEFAULT);
+#endif /* HAVE_ORACLE */
 #ifdef	HAVE_SQLITE3
 
 	if(sqlite_transaction_started > 1)
@@ -402,12 +505,13 @@ void zbx_db_rollback(void)
 	}
 
 #endif
+	txn_level--;
 }
 
 /*
  * Execute SQL statement. For non-select statements only.
  * If fails, program terminates.
- */ 
+ */
 int zbx_db_vexecute(const char *fmt, va_list args)
 {
 	char	*sql = NULL;
@@ -430,7 +534,11 @@ int zbx_db_vexecute(const char *fmt, va_list args)
 
 	sql = zbx_dvsprintf(sql, fmt, args);
 
-	zabbix_log( LOG_LEVEL_DEBUG, "Query [%s]", sql);
+	if (0 == txn_init && 0 == txn_level)
+	{
+		zabbix_log(LOG_LEVEL_DEBUG, "Query without transaction detected [%s]", sql);
+	}
+	zabbix_log( LOG_LEVEL_DEBUG, "Query [txnlev:%d] [%s]", txn_level, sql);
 #ifdef	HAVE_MYSQL
 	if(!conn)
 	{
@@ -443,10 +551,14 @@ int zbx_db_vexecute(const char *fmt, va_list args)
 		{
 			zabbix_errlog(ERR_Z3005, mysql_errno(conn), mysql_error(conn), sql);
 			switch(mysql_errno(conn)) {
+				case	CR_CONN_HOST_ERROR:
 				case	CR_SERVER_GONE_ERROR:
 				case	CR_CONNECTION_ERROR:
 				case	CR_SERVER_LOST:
 				case	ER_SERVER_SHUTDOWN:
+				case	ER_ACCESS_DENIED_ERROR: /* wrong user or password */
+				case	ER_ILLEGAL_GRANT_FOR_TABLE: /* user without any privileges */
+				case	ER_TABLEACCESS_DENIED_ERROR:/* user without some privilege */
 				case	ER_UNKNOWN_ERROR:
 					ret = ZBX_DB_DOWN;
 					break;
@@ -471,7 +583,7 @@ int zbx_db_vexecute(const char *fmt, va_list args)
 				}
 
 				/* more results? -1 = no, >0 = error, 0 = yes (keep looping) */
-			        if ((status = mysql_next_result(conn)) > 0)
+				if ((status = mysql_next_result(conn)) > 0)
 					zabbix_errlog(ERR_Z3005, mysql_errno(conn), mysql_error(conn), sql);
 			} while (status == 0);
 		}
@@ -497,23 +609,60 @@ int zbx_db_vexecute(const char *fmt, va_list args)
 
 	if(ret == ZBX_DB_OK)
 	{
-		ret = PQntuples(result);
+		ret = atoi(PQcmdTuples(result));
 	}
 	PQclear(result);
 #endif
 #ifdef	HAVE_ORACLE
-	if ((ret = sqlo_exec(oracle, sql))<0)
-	{
-		zabbix_errlog(ERR_Z3005, 0, sqlo_geterror(oracle), sql);
+	sword err = OCI_SUCCESS;
+
+	OCIStmt *stmthp = NULL;
+
+	err = OCIHandleAlloc( (dvoid *) oracle.envhp, (dvoid **) &stmthp,
+		OCI_HTYPE_STMT, (size_t) 0, (dvoid **) 0);
+
+	if (err == OCI_SUCCESS) {
+		err = OCIStmtPrepare(stmthp, oracle.errhp, (text *)sql,
+			(ub4) strlen((char *) sql),
+			(ub4) OCI_NTV_SYNTAX, (ub4) OCI_DEFAULT);
+	}
+
+	if (err == OCI_SUCCESS) {
+		err = OCIStmtExecute(oracle.svchp, stmthp, oracle.errhp, (ub4) 1, (ub4) 0,
+			(CONST OCISnapshot *) NULL, (OCISnapshot *) NULL, OCI_COMMIT_ON_SUCCESS);
+
+		if (err != 1)
+		{
+			ub4 nrows = 0;
+
+			err = OCIAttrGet((void *)stmthp, OCI_HTYPE_STMT, (ub4 *)&nrows,
+					  (ub4 *)0, OCI_ATTR_ROW_COUNT, oracle.errhp);
+
+			ret = nrows;
+		}
+	}
+
+	if (err != OCI_SUCCESS) {
+		zabbix_errlog(ERR_Z3005, err, zbx_oci_error(err), sql);
 		ret = ZBX_DB_FAIL;
 	}
-#endif
+
+	if (stmthp)
+	{
+		(void) OCIHandleFree((dvoid *) stmthp, OCI_HTYPE_STMT);
+		stmthp = NULL;
+	}
+#endif /* HAVE_ORACLE */
 #ifdef	HAVE_SQLITE3
 	if (!sqlite_transaction_started)
 	{
-		php_sem_acquire(&sqlite_access);
+		if(PHP_MUTEX_OK != php_sem_acquire(&sqlite_access))
+		{
+			zabbix_log( LOG_LEVEL_CRIT, "ERROR: Unable to create lock on SQLite database.");
+			exit(-1);
+		}
 	}
-	
+
 lbl_exec:
 	if (SQLITE_OK != (ret = sqlite3_exec(conn, sql, NULL, 0, &error)))
 	{
@@ -536,7 +685,7 @@ lbl_exec:
 	}
 #endif
 
-/*	sec = zbx_time() - sec;	
+/*	sec = zbx_time() - sec;
 	if(sec > 0.1)
 		zabbix_log( LOG_LEVEL_WARNING, "Long query: " ZBX_FS_DBL " sec, \"%s\"", sec, sql);*/
 
@@ -553,7 +702,7 @@ int	zbx_db_is_null(char *field)
 	if(field == NULL)	ret = SUCCEED;
 #ifdef HAVE_ORACLE
 	else if(field[0] == 0)	ret = SUCCEED;
-#endif
+#endif /* HAVE_ORACLE */
 	return ret;
 }
 
@@ -580,7 +729,7 @@ void	PG_DBfree_result(DB_RESULT result)
 void	SQ_DBfree_result(DB_RESULT result)
 {
 	if(!result) return;
-	
+
 	if(result->data)
 	{
 		sqlite3_free_table(result->data);
@@ -589,6 +738,30 @@ void	SQ_DBfree_result(DB_RESULT result)
 	zbx_free(result);
 }
 #endif
+#ifdef  HAVE_ORACLE
+/* in db.h - #define DBfree_result   OCI_DBfree_result */
+void	OCI_DBfree_result(DB_RESULT result)
+{
+	if(!result) return;
+
+	if (result->values) {
+		int i;
+		for (i = 0; i < result->ncolumn; i++) {
+			if (result->values[i]) {
+				zbx_free (result->values[i]);
+				result->values[i] = NULL;
+			}
+		}
+		zbx_free (result->values);
+		result->values = NULL;
+	}
+
+	if (result->stmthp)
+		(void) OCIHandleFree((dvoid *) result->stmthp, OCI_HTYPE_STMT);
+
+	zbx_free (result);
+}
+#endif
 
 DB_ROW	zbx_db_fetch(DB_RESULT result)
 {
@@ -603,18 +776,18 @@ DB_ROW	zbx_db_fetch(DB_RESULT result)
 
 	/* EOF */
 	if(!result)	return NULL;
-		
+
 	/* free old data */
 	if(result->values)
 	{
 		zbx_free(result->values);
 		result->values = NULL;
 	}
-	
+
 	/* EOF */
 	if(result->cursor == result->row_num) return NULL;
 
-	/* init result */	
+	/* init result */
 	result->fld_num = PQnfields(result->pg_result);
 
 	if(result->fld_num > 0)
@@ -637,31 +810,27 @@ DB_ROW	zbx_db_fetch(DB_RESULT result)
 
 	result->cursor++;
 
-	return result->values;	
+	return result->values;
 #endif
 #ifdef	HAVE_ORACLE
-	int res;
+	sword err = OCI_SUCCESS;
 
-	res = sqlo_fetch(result, 1);
+	/* EOF */
+	if(!result)	return NULL;
 
-	if(SQLO_SUCCESS == res)
-	{
-		return (DB_ROW)sqlo_values(result, NULL, 1);
-	}
-	else if(SQLO_NO_DATA == res)
-	{
+	err = OCIStmtFetch(result->stmthp, oracle.errhp, 1, OCI_FETCH_NEXT, OCI_DEFAULT);
+	if (OCI_NO_DATA == err)	{
 		return NULL;
 	}
 
-	zabbix_errlog(ERR_Z3006, 0, sqlo_geterror(oracle));
-	exit(FAIL);
-	return NULL;
-#endif
+	return result->values;
+
+#endif /* HAVE_ORACLE */
 #ifdef HAVE_SQLITE3
-	
+
 	/* EOF */
 	if(!result)	return NULL;
-		
+
 	/* EOF */
 	if(result->curow >= result->nrow) return NULL;
 
@@ -669,7 +838,7 @@ DB_ROW	zbx_db_fetch(DB_RESULT result)
 
 	result->curow++; /* NOTE: First row == header row */
 
-	return &(result->data[result->curow * result->ncolumn]);	
+	return &(result->data[result->curow * result->ncolumn]);
 #endif
 
 	return NULL;
@@ -678,7 +847,7 @@ DB_ROW	zbx_db_fetch(DB_RESULT result)
 /*
  * Execute SQL statement. For select statements only.
  * If fails, program terminates.
- */ 
+ */
 DB_RESULT zbx_db_vselect(const char *fmt, va_list args)
 {
 	char	*sql = NULL;
@@ -687,8 +856,9 @@ DB_RESULT zbx_db_vselect(const char *fmt, va_list args)
 /*	double	sec;*/
 
 #ifdef	HAVE_ORACLE
-	sqlo_stmt_handle_t sth;
-#endif
+	sword err = OCI_SUCCESS;
+	ub4 counter;
+#endif /* HAVE_ORACLE */
 #ifdef	HAVE_SQLITE3
 	int ret = FAIL;
 	char *error=NULL;
@@ -701,7 +871,7 @@ DB_RESULT zbx_db_vselect(const char *fmt, va_list args)
 
 	sql = zbx_dvsprintf(sql, fmt, args);
 
-	zabbix_log( LOG_LEVEL_DEBUG, "Query [%s]", sql);
+	zabbix_log( LOG_LEVEL_DEBUG, "Query [txnlev:%d] [%s]", txn_level, sql);
 
 #ifdef	HAVE_MYSQL
 	if(!conn)
@@ -715,10 +885,14 @@ DB_RESULT zbx_db_vselect(const char *fmt, va_list args)
 		{
 			zabbix_errlog(ERR_Z3005, mysql_errno(conn), mysql_error(conn), sql);
 			switch(mysql_errno(conn)) {
+				case 	CR_CONN_HOST_ERROR:
 				case	CR_SERVER_GONE_ERROR:
 				case	CR_CONNECTION_ERROR:
 				case	CR_SERVER_LOST:
 				case	ER_SERVER_SHUTDOWN:
+				case	ER_ACCESS_DENIED_ERROR: /* wrong user or password */
+				case	ER_ILLEGAL_GRANT_FOR_TABLE: /* user without any privileges */
+				case	ER_TABLEACCESS_DENIED_ERROR:/* user without some privilege */
 				case	ER_UNKNOWN_ERROR:
 					result = (DB_RESULT)ZBX_DB_DOWN;
 					break;
@@ -748,7 +922,7 @@ DB_RESULT zbx_db_vselect(const char *fmt, va_list args)
 	{
 		error = zbx_dsprintf(error, "%s:%s",
 				PQresStatus(PQresultStatus(result->pg_result)),
-			 	PQresultErrorMessage(result->pg_result));
+				PQresultErrorMessage(result->pg_result));
 		zabbix_errlog(ERR_Z3005, 0, error, sql);
 		zbx_free(error);
 	}
@@ -757,17 +931,109 @@ DB_RESULT zbx_db_vselect(const char *fmt, va_list args)
 
 #endif
 #ifdef	HAVE_ORACLE
-	if(0 > (sth = (sqlo_open(oracle, sql,0,NULL))))
-	{
-		zabbix_errlog(ERR_Z3005, 0, sqlo_geterror(oracle), sql);
+	result = zbx_malloc(NULL, sizeof(ZBX_OCI_DB_RESULT));
+	memset (result, 0, sizeof(ZBX_OCI_DB_RESULT));
+
+	err = OCIHandleAlloc( (dvoid *) oracle.envhp, (dvoid **) &result->stmthp,
+		OCI_HTYPE_STMT, (size_t) 0, (dvoid **) 0);
+
+	if (err == OCI_SUCCESS) {
+		err = OCIStmtPrepare(result->stmthp, oracle.errhp, (text *)sql,
+			(ub4) strlen((char *) sql),
+			(ub4) OCI_NTV_SYNTAX, (ub4) OCI_DEFAULT);
+	}
+
+	if (err == OCI_SUCCESS) {
+		err = OCIStmtExecute(oracle.svchp, result->stmthp, oracle.errhp, (ub4) 0, (ub4) 0,
+			(CONST OCISnapshot *) NULL, (OCISnapshot *) NULL, OCI_COMMIT_ON_SUCCESS);
+		if (err == OCI_NO_DATA) {
+			OCI_DBfree_result (result);
+			result = NULL;
+			err = OCI_SUCCESS;
+		}
+	}
+
+	if (err == OCI_SUCCESS) {
+		/* Get the number of columns in the query */
+		err = OCIAttrGet((void *)result->stmthp, OCI_HTYPE_STMT, (void *)&result->ncolumn,
+				  (ub4 *)0, OCI_ATTR_PARAM_COUNT, oracle.errhp);
+	}
+
+	if (err != OCI_SUCCESS) {
+		zabbix_errlog(ERR_Z3005, err, zbx_oci_error(err), sql);
 		exit(FAIL);
 	}
-	result = sth;
-#endif
+
+	assert(result->ncolumn > 0);
+
+	result->values = zbx_malloc (NULL, result->ncolumn * sizeof (char *));
+	memset (result->values, 0, result->ncolumn * sizeof (char *));
+
+	for (counter = 1; (err == OCI_SUCCESS) && (counter <= result->ncolumn); counter++)
+	{
+		OCIParam *parmdp = NULL;
+		OCIDefine *defnp = NULL;
+		ub4 char_semantics;
+		ub2 col_width;
+
+		/* Request a parameter descriptor in the select-list */
+		err = OCIParamGet((void *)result->stmthp, OCI_HTYPE_STMT, oracle.errhp,
+			(void **)&parmdp, (ub4) counter);
+
+		if (err == OCI_SUCCESS) {
+			/* Retrieve the length semantics for the column */
+			char_semantics = 0;
+			err = OCIAttrGet((void*) parmdp, (ub4) OCI_DTYPE_PARAM,
+				(void*) &char_semantics,(ub4 *) 0, (ub4) OCI_ATTR_CHAR_USED,
+				(OCIError *) oracle.errhp  );
+		}
+
+		if (err == OCI_SUCCESS) {
+			col_width = 0;
+			if (char_semantics) {
+				/* Retrieve the column width in characters */
+				err = OCIAttrGet((void*) parmdp, (ub4) OCI_DTYPE_PARAM,
+					(void*) &col_width, (ub4 *) 0, (ub4) OCI_ATTR_CHAR_SIZE,
+					(OCIError *) oracle.errhp  );
+			}
+			else {
+				/* Retrieve the column width in bytes */
+				err = OCIAttrGet((void*) parmdp, (ub4) OCI_DTYPE_PARAM,
+					(void*) &col_width,(ub4 *) 0, (ub4) OCI_ATTR_DATA_SIZE,
+					(OCIError *) oracle.errhp  );
+			}
+		}
+		col_width++;
+
+		result->values[counter - 1] = zbx_malloc (NULL, col_width);
+		memset (result->values[counter - 1], 0, col_width);
+
+		if (err == OCI_SUCCESS) {
+			/* represent any data as characters */
+			err = OCIDefineByPos(result->stmthp, &defnp, oracle.errhp, counter,
+				(dvoid *) result->values[counter - 1], col_width, SQLT_STR,
+				(dvoid *) 0, (ub2 *)0, (ub2 *)0, OCI_DEFAULT);
+		}
+
+		/* free cell descriptor */
+		OCIDescriptorFree(parmdp, OCI_DTYPE_PARAM);
+		parmdp = NULL;
+	}
+
+	if (err != OCI_SUCCESS) {
+		zabbix_errlog(ERR_Z3005, err, zbx_oci_error(err), sql);
+		exit(FAIL);
+	}
+
+#endif /* HAVE_ORACLE */
 #ifdef HAVE_SQLITE3
 	if(!sqlite_transaction_started)
 	{
-		php_sem_acquire(&sqlite_access);
+		if(PHP_MUTEX_OK != php_sem_acquire(&sqlite_access))
+		{
+			zabbix_log( LOG_LEVEL_CRIT, "ERROR: Unable to create lock on SQLite database.");
+			exit(-1);
+		}
 	}
 
 	result = zbx_malloc(NULL, sizeof(ZBX_SQ_DB_RESULT));
@@ -793,7 +1059,7 @@ lbl_get_table:
 	}
 #endif
 
-/*	sec = zbx_time() - sec;	
+/*	sec = zbx_time() - sec;
 	if(sec > 0.1)
 		zabbix_log( LOG_LEVEL_WARNING, "Long query: " ZBX_FS_DBL " sec, \"%s\"", sec, sql);*/
 
@@ -803,14 +1069,14 @@ lbl_get_table:
 
 /*
  * Get value of autoincrement field for last insert or update statement
- */ 
+ */
 zbx_uint64_t	zbx_db_insert_id(int exec_result, const char *table, const char *field)
 {
 #ifdef	HAVE_MYSQL
 	zabbix_log(LOG_LEVEL_DEBUG, "In DBinsert_id()" );
-	
+
 	if(exec_result == FAIL) return 0;
-	
+
 	return mysql_insert_id(conn);
 #endif
 
@@ -819,18 +1085,18 @@ zbx_uint64_t	zbx_db_insert_id(int exec_result, const char *table, const char *fi
 	zbx_uint64_t	id_res = FAIL;
 
 	zabbix_log(LOG_LEVEL_DEBUG, "In DBinsert_id()" );
-	
+
 	if(exec_result < 0) return 0;
 	if(exec_result == FAIL) return 0;
 	if((Oid)exec_result == InvalidOid) return 0;
-	
+
 	tmp_res = zbx_db_select("select %s from %s where oid=%i", field, table, exec_result);
 
 	ZBX_STR2UINT64(id_res, PQgetvalue(tmp_res->pg_result, 0, 0));
 /*	id_res = atoi(PQgetvalue(tmp_res->pg_result, 0, 0));*/
-	
+
 	DBfree_result(tmp_res);
-	
+
 	return id_res;
 #endif
 
@@ -839,7 +1105,7 @@ zbx_uint64_t	zbx_db_insert_id(int exec_result, const char *table, const char *fi
 	char    sql[MAX_STRING_LEN];
 	DB_RESULT       result;
 	zbx_uint64_t	id;
-	
+
 	zabbix_log(LOG_LEVEL_DEBUG, "In DBinsert_id()" );
 
 	if(exec_result == FAIL) return 0;
@@ -847,7 +1113,7 @@ zbx_uint64_t	zbx_db_insert_id(int exec_result, const char *table, const char *fi
 	zbx_snprintf(sql, sizeof(sql), "select %s_%s.currval from dual", table, field);
 
 	result=DBselect("%s", sql);
-	
+
 	row = DBfetch(result);
 
 	ZBX_STR2UINT64(id, row[0]);
@@ -855,7 +1121,7 @@ zbx_uint64_t	zbx_db_insert_id(int exec_result, const char *table, const char *fi
 	DBfree_result(result);
 
 	return id;
-#endif
+#endif /* HAVE_ORACLE */
 #ifdef	HAVE_SQLITE3
 	return (zbx_uint64_t)sqlite3_last_insert_rowid(conn);
 #endif
@@ -864,7 +1130,7 @@ zbx_uint64_t	zbx_db_insert_id(int exec_result, const char *table, const char *fi
 /*
  * Execute SQL statement. For select statements only.
  * If fails, program terminates.
- */ 
+ */
 DB_RESULT zbx_db_select_n(char *query, int n)
 {
 #ifdef	HAVE_MYSQL
@@ -875,9 +1141,8 @@ DB_RESULT zbx_db_select_n(char *query, int n)
 #endif
 #ifdef	HAVE_ORACLE
 	return zbx_db_select("select * from (%s) where rownum<=%d", query, n);
-#endif
+#endif /* HAVE_ORACLE */
 #ifdef	HAVE_SQLITE3
 	return zbx_db_select("%s limit %d", query, n);
 #endif
 }
-
