@@ -1,4 +1,4 @@
-/* 
+/*
 ** ZABBIX
 ** Copyright (C) 2000-2005 SIA Zabbix
 **
@@ -44,12 +44,12 @@
 /*
  * smtp_readln reads a until a 0x0a
  */
-ssize_t smtp_readln(int fd, char *buf, int buf_len) 
+ssize_t smtp_readln(int fd, char *buf, int buf_len)
 {
 	ssize_t	nbytes, read_bytes = 0;
 
 	buf_len --;	/* '\0' */
-	do 
+	do
 	{
 		if (-1 == (nbytes = read(fd, &((char*)buf)[read_bytes], 1)))
 			return nbytes;				/* Error */
@@ -67,7 +67,7 @@ ssize_t smtp_readln(int fd, char *buf, int buf_len)
 
 /*
  * Send email
- */ 
+ */
 int	send_email(char *smtp_server,char *smtp_helo,char *smtp_email,char *mailto,char *mailsubject,char *mailbody, char *error, int max_error_len)
 {
 	int		ret = FAIL;
@@ -109,13 +109,13 @@ int	send_email(char *smtp_server,char *smtp_helo,char *smtp_email,char *mailto,c
 	{
 		memset(c,0,MAX_STRING_LEN);
 		zbx_snprintf(c,sizeof(c),"HELO %s\r\n",smtp_helo);
-		e=write(s.socket,c,strlen(c)); 
+		e=write(s.socket,c,strlen(c));
 		if(e == -1)
 		{
 			zbx_snprintf(error,max_error_len,"Error sending HELO to mailserver [%s]", strerror(errno));
 			goto out;
 		}
-				
+
 		if (-1 == smtp_readln(s.socket, c, sizeof(c)))
 		{
 			zbx_snprintf(error,max_error_len,"Error receiving answer on HELO request [%s]", strerror(errno));
@@ -132,7 +132,7 @@ int	send_email(char *smtp_server,char *smtp_helo,char *smtp_email,char *mailto,c
 
 	zbx_snprintf(c,sizeof(c),"MAIL FROM: <%s>\r\n",smtp_email);
 
-	e=write(s.socket,c,strlen(c)); 
+	e=write(s.socket,c,strlen(c));
 	if(e == -1)
 	{
 		zbx_snprintf(error,max_error_len,"Error sending MAIL FROM to mailserver [%s]", strerror(errno));
@@ -149,10 +149,10 @@ int	send_email(char *smtp_server,char *smtp_helo,char *smtp_email,char *mailto,c
 		zbx_snprintf(error,max_error_len,"Wrong answer on MAIL FROM [%s]", c);
 		goto out;
 	}
-			
+
 	memset(c,0,MAX_STRING_LEN);
 	zbx_snprintf(c,sizeof(c),"RCPT TO: <%s>\r\n",mailto);
-	e=write(s.socket,c,strlen(c)); 
+	e=write(s.socket,c,strlen(c));
 	if(e == -1)
 	{
 		zbx_snprintf(error,max_error_len,"Error sending RCPT TO to mailserver [%s]", strerror(errno));
@@ -169,10 +169,10 @@ int	send_email(char *smtp_server,char *smtp_helo,char *smtp_email,char *mailto,c
 		zbx_snprintf(error,max_error_len,"Wrong answer on RCPT TO [%s]", c);
 		goto out;
 	}
-	
+
 	memset(c,0,MAX_STRING_LEN);
 	zbx_snprintf(c,sizeof(c),"DATA\r\n");
-	e=write(s.socket,c,strlen(c)); 
+	e=write(s.socket,c,strlen(c));
 	if(e == -1)
 	{
 		zbx_snprintf(error,max_error_len,"Error sending DATA to mailserver [%s]", strerror(errno));
@@ -180,7 +180,7 @@ int	send_email(char *smtp_server,char *smtp_helo,char *smtp_email,char *mailto,c
 	}
 	if (-1 == smtp_readln(s.socket, c, sizeof(c)))
 	{
-		zbx_snprintf(error,max_error_len,"Error receivng answer on DATA request [%s]", strerror(errno));
+		zbx_snprintf(error,max_error_len,"Error receiving answer on DATA request [%s]", strerror(errno));
 		goto out;
 	}
 	if(strncmp(OK_354,c,strlen(OK_354)) != 0)
@@ -204,7 +204,7 @@ int	send_email(char *smtp_server,char *smtp_helo,char *smtp_email,char *mailto,c
 	cp = zbx_dsprintf(cp, "From:<%s>\r\nTo:<%s>\r\nDate: %s\r\nSubject: %s\r\n"
 			"Content-Type: text/plain; charset=\"UTF-8\"\r\n\r\n%s",
 			smtp_email, mailto, str_time, mailsubject, mailbody);
-	e=write(s.socket,cp,strlen(cp)); 
+	e=write(s.socket,cp,strlen(cp));
 	zbx_free(cp);
 	zbx_free(mailsubject);
 	zbx_free(mailbody);
@@ -216,7 +216,7 @@ int	send_email(char *smtp_server,char *smtp_helo,char *smtp_email,char *mailto,c
 
 	memset(c,0,MAX_STRING_LEN);
 	zbx_snprintf(c,sizeof(c),"\r\n.\r\n");
-	e=write(s.socket,c,strlen(c)); 
+	e=write(s.socket,c,strlen(c));
 	if(e == -1)
 	{
 		zbx_snprintf(error,max_error_len,"Error sending . to mailserver [%s]", strerror(errno));
@@ -224,7 +224,7 @@ int	send_email(char *smtp_server,char *smtp_helo,char *smtp_email,char *mailto,c
 	}
 	if (-1 == smtp_readln(s.socket, c, sizeof(c)))
 	{
-		zbx_snprintf(error,max_error_len,"Error receivng answer on . request [%s]", strerror(errno));
+		zbx_snprintf(error,max_error_len,"Error receiving answer on . request [%s]", strerror(errno));
 		goto out;
 	}
 	if(strncmp(OK_250,c,strlen(OK_250)) != 0)
@@ -232,17 +232,17 @@ int	send_email(char *smtp_server,char *smtp_helo,char *smtp_email,char *mailto,c
 		zbx_snprintf(error,max_error_len,"Wrong answer on end of data [%s]", c);
 		goto out;
 	}
-	
+
 	memset(c,0,MAX_STRING_LEN);
 	zbx_snprintf(c,sizeof(c),"QUIT\r\n");
-	e=write(s.socket,c,strlen(c)); 
+	e=write(s.socket,c,strlen(c));
 	if(e == -1)
 	{
 		zbx_snprintf(error,max_error_len,"Error sending QUIT to mailserver [%s]", strerror(errno));
 		goto out;
 	}
 	ret = SUCCEED;
-out:	
+out:
 	zbx_tcp_close(&s);
 
 	if ('\0' != *error)
