@@ -1,4 +1,4 @@
-/* 
+/*
 ** ZABBIX
 ** Copyright (C) 2000-2005 SIA Zabbix
 **
@@ -26,7 +26,7 @@
  *                                                                            *
  * Function: zbx_json_strerror                                                *
  *                                                                            *
- * Purpose: return string describing of json error                            *
+ * Purpose: return string describing json error                               *
  *                                                                            *
  * Parameters:                                                                *
  *                                                                            *
@@ -43,7 +43,7 @@ static char zbx_json_strerror_message[ZBX_JSON_MAX_STRERROR];
 
 char	*zbx_json_strerror(void)
 {
-	zbx_json_strerror_message[ZBX_JSON_MAX_STRERROR - 1] = '\0'; /* forse terminate string */
+	zbx_json_strerror_message[ZBX_JSON_MAX_STRERROR - 1] = '\0'; /* force terminate string */
 	return (&zbx_json_strerror_message[0]);
 }
 
@@ -71,7 +71,7 @@ static void __zbx_zbx_set_json_strerror(const char *fmt, ...)
  *                                                                            *
  * Parameters:                                                                *
  *                                                                            *
- * Return value: -                                                            * 
+ * Return value: -                                                            *
  *                                                                            *
  * Author: Aleksander Vladishev                                               *
  *                                                                            *
@@ -92,7 +92,7 @@ static void	__zbx_json_realloc(struct zbx_json *j, size_t need)
 		}
 		return;
 	}
-			
+
 	while (need > j->buffer_allocated) {
 		if (0 == j->buffer_allocated)
 			j->buffer_allocated = 1024;
@@ -157,7 +157,7 @@ static size_t	__zbx_json_stringsize(const char *string, zbx_json_type_t type)
 	len = 0;
 	for (sptr = (NULL != string) ? string : buffer; *sptr != '\0'; sptr++) {
 		switch (*sptr) {
-		case '"':  /* quatation mark */
+		case '"':  /* quotation mark */
 		case '\\': /* reverse solidus */
 		case '/':  /* solidus */
 		case '\b': /* backspace */
@@ -177,7 +177,7 @@ static size_t	__zbx_json_stringsize(const char *string, zbx_json_type_t type)
 
 	if (NULL != string && type == ZBX_JSON_TYPE_STRING)
 		len += 2; /* "" */
-	
+
 	return len;
 }
 
@@ -188,10 +188,10 @@ static char	*__zbx_json_insstring(char *p, const char *string, zbx_json_type_t t
 
 	if (NULL != string && type == ZBX_JSON_TYPE_STRING)
 		*p++ = '"';
-	
+
 	for (sptr = (NULL != string) ? string : buffer; *sptr != '\0'; sptr++) {
 		switch (*sptr) {
-		case '"': *p++ = '\\'; *p++ = '"'; break; /* quatation mark */
+		case '"': *p++ = '\\'; *p++ = '"'; break; /* quotation mark */
 		case '\\': *p++ = '\\'; *p++ = '\\'; break; /* reverse solidus */
 		case '/': *p++ = '\\'; *p++ = '/'; break; /* solidus */
 		case '\b': *p++ = '\\'; *p++ = 'b'; break; /* backspace */
@@ -241,7 +241,7 @@ static void	__zbx_json_addobject(struct zbx_json *j, const char *name, int objec
 		len += __zbx_json_stringsize(name, 1);
 		len += 1; /* : */
 	}
-	
+
 	__zbx_json_realloc(j, j->buffer_size + len + 1/*'\0'*/);
 
 	psrc = j->buffer + j->buffer_offset;
@@ -305,7 +305,7 @@ void	zbx_json_addstring(struct zbx_json *j, const char *name, const char *string
 #endif
 	}
 	len += __zbx_json_stringsize(string, type);
-	
+
 	__zbx_json_realloc(j, j->buffer_size + len + 1/*'\0'*/);
 
 	psrc = j->buffer + j->buffer_offset;
@@ -365,7 +365,7 @@ int	zbx_json_close(struct zbx_json *j)
  *                                                                            *
  * Parameters:                                                                *
  *                                                                            *
- * Return value: position of right bracket                                    * 
+ * Return value: position of right bracket                                    *
  *               NULL - an error occured                                      *
  *                                                                            *
  * Author: Aleksander Vladishev                                               *
@@ -424,7 +424,7 @@ static const char	*__zbx_json_rbracket(const char *p)
  *                                                                            *
  * Parameters:                                                                *
  *                                                                            *
- * Return value: SUCCESS - processed succesfully                              * 
+ * Return value: SUCCESS - processed succesfully                              *
  *               FAIL - an error occured                                      *
  *                                                                            *
  * Author: Aleksander Vladishev                                               *
@@ -447,7 +447,7 @@ fprintf(stderr, "----- [%zd] [%s]\n", strlen(buffer), buffer);
 		jp->start = buffer;
 	else
 		goto error;
-	
+
 #ifdef ZBX_JSON_READABLE
 	o = buffer;
 	i = buffer;
@@ -456,7 +456,7 @@ fprintf(stderr, "----- [%zd] [%s]\n", strlen(buffer), buffer);
 			*o++ = *i;
 	} while(*i++ != '\0');
 #endif
-/*	
+/*
 fprintf(stderr, "----- [%zd] [%s]\n",  strlen(buffer), buffer);
 */
 	if (NULL == (jp->end = __zbx_json_rbracket(buffer)))
@@ -478,7 +478,7 @@ error:
  *                                                                            *
  * Parameters:                                                                *
  *                                                                            *
- * Return value: NULL - no more values                                        * 
+ * Return value: NULL - no more values                                        *
  *               NOT NULL - pointer to pair or element                        *
  *      {"name",...    or  "array":["name", ... ,1,null]                      *
  * p =   ^                                         ^                          *
@@ -493,7 +493,7 @@ const char	*zbx_json_next(struct zbx_json_parse *jp, const char *p)
 	int	level = 0;
 	int	state = 0; /* o - outside string; 1 - inside string */
 
-	if (jp->end - jp->start == 1) /* empty object or arraj */
+	if (jp->end - jp->start == 1) /* empty object or array */
 		return NULL;
 
 	if (NULL == p)
@@ -561,8 +561,8 @@ static const char	*zbx_json_decodestring(const char *p, char *string, size_t len
 		} else if (state == 1 && (size_t)(o - string) < len - 1/*'\0'*/) {
 			if (*p == '\\') {
 				switch (*++p) {
-				case '"': 
-				case '\\': 
+				case '"':
+				case '\\':
 				case '/': *o++ = *p; break;
 				case 'b': *o++ = '\b'; break;
 				case 'f': *o++ = '\f'; break;
@@ -627,12 +627,12 @@ const char	*zbx_json_pair_next(struct zbx_json_parse *jp, const char *p, char *n
 
 	if (NULL == (p = zbx_json_decodestring(p, name, len)))
 		goto error;
-	
+
 	if (*p != ':')
 		goto error;
 
 	return ++p;
-error:	       
+error:
 	return NULL;
 }
 
@@ -644,7 +644,7 @@ error:
  *                                                                            *
  * Parameters:                                                                *
  *                                                                            *
- * Return value: pointer to value                                             * 
+ * Return value: pointer to value                                             *
  *        {"name":["a","b",...]}                                              *
  *                ^ - returned pointer                                        *
  *                                                                            *
@@ -679,7 +679,7 @@ const char	*zbx_json_pair_by_name(struct zbx_json_parse *jp, const char *name)
  *                                                                            *
  * Parameters:                                                                *
  *                                                                            *
- * Return value: pointer to value                                             * 
+ * Return value: pointer to value                                             *
  *        {"name":["a","b",...]}                                              *
  *                ^ - returned pointer                                        *
  *                                                                            *
@@ -709,7 +709,7 @@ int	zbx_json_value_by_name(struct zbx_json_parse *jp, const char *name, char *st
  *                                                                            *
  * Parameters:                                                                *
  *                                                                            *
- * Return value: SUCCESS - processed succesfully                              * 
+ * Return value: SUCCESS - processed succesfully                              *
  *               FAIL - an error occured                                      *
  *                                                                            *
  * Author: Aleksander Vladishev                                               *
@@ -738,7 +738,7 @@ int	zbx_json_brackets_open(const char *p, struct zbx_json_parse *jp)
  *                                                                            *
  * Parameters:                                                                *
  *                                                                            *
- * Return value: SUCCESS - processed succesfully                              * 
+ * Return value: SUCCESS - processed succesfully                              *
  *               FAIL - an error occured                                      *
  *                                                                            *
  * Author: Aleksander Vladishev                                               *
@@ -767,7 +767,7 @@ int	zbx_json_brackets_by_name(struct zbx_json_parse *jp, const char *name, struc
  *                                                                            *
  * Parameters:                                                                *
  *                                                                            *
- * Return value: type of pointed value                                        * 
+ * Return value: type of pointed value                                        *
  *                                                                            *
  * Author: Aleksander Vladishev                                               *
  *                                                                            *
