@@ -1,4 +1,4 @@
-/* 
+/*
 ** ZABBIX
 ** Copyright (C) 2000-2005 SIA Zabbix
 **
@@ -54,14 +54,15 @@ ZBX_METRIC	parameters_common[]=
 	{"web.page.regexp",	CF_USEUPARAM,	WEB_PAGE_REGEXP,	0,	"localhost,,80,OK"},
 
 	{"vfs.file.exists",	CF_USEUPARAM,	VFS_FILE_EXISTS,	0,	VFS_TEST_FILE},
-	{"vfs.file.time",       CF_USEUPARAM,   VFS_FILE_TIME,          0,      VFS_TEST_FILE ",modify"},
+	{"vfs.file.time",	CF_USEUPARAM,	VFS_FILE_TIME,		0,	VFS_TEST_FILE ",modify"},
 	{"vfs.file.size",	CF_USEUPARAM,	VFS_FILE_SIZE, 		0,	VFS_TEST_FILE},
 	{"vfs.file.regexp",	CF_USEUPARAM,	VFS_FILE_REGEXP,	0,	VFS_TEST_FILE "," VFS_TEST_REGEXP},
 	{"vfs.file.regmatch",	CF_USEUPARAM,	VFS_FILE_REGMATCH, 	0,	VFS_TEST_FILE "," VFS_TEST_REGEXP},
 	{"vfs.file.cksum",	CF_USEUPARAM,	VFS_FILE_CKSUM,		0,	VFS_TEST_FILE},
 	{"vfs.file.md5sum",	CF_USEUPARAM,	VFS_FILE_MD5SUM,	0,	VFS_TEST_FILE},
 
-	{"net.tcp.dns",		CF_USEUPARAM,	CHECK_DNS,		0,	"127.0.0.1,localhost"},
+	{"net.tcp.dns",		CF_USEUPARAM,	CHECK_DNS,		0,	",localhost"},
+	{"net.tcp.dns.query",	CF_USEUPARAM,	CHECK_DNS_QUERY,	0,	",localhost"},
 	{"net.tcp.port",	CF_USEUPARAM,	CHECK_PORT,		0,	",80"},
 
 	{"system.hostname",	0,		SYSTEM_HOSTNAME,	0,	0},
@@ -69,6 +70,7 @@ ZBX_METRIC	parameters_common[]=
 
 	{"system.users.num",	0,		SYSTEM_UNUM, 		0,	0},
 	{"log",			CF_USEUPARAM,	ONLY_ACTIVE, 		0,	"logfile"},
+	{"logrt",		CF_USEUPARAM,	ONLY_ACTIVE,		0,	"logfile"},
 	{"eventlog",		CF_USEUPARAM,	ONLY_ACTIVE, 		0,	"system"},
 
 	{0}
@@ -78,8 +80,10 @@ static int	ONLY_ACTIVE(const char *cmd, const char *param, unsigned flags, AGENT
 {
 	assert(result);
 
-        init_result(result);	
+	init_result(result);
+
 	SET_MSG_RESULT(result, strdup("Accessible only as active check!"));
+
 	return SYSINFO_RET_FAIL;
 }
 
@@ -91,18 +95,18 @@ int	getPROC(char *file, int lineno, int fieldno, unsigned flags, AGENT_RESULT *r
 	char	c[MAX_STRING_LEN];
 	int	i;
 	double	value = 0;
-        
+
 	assert(result);
 
-        init_result(result);	
-		
+	init_result(result);
+
 	if(NULL == (f = fopen(file,"r")))
 	{
 		return	SYSINFO_RET_FAIL;
 	}
 
 	for(i=1; i<=lineno; i++)
-	{	
+	{
 		if(NULL == fgets(c,MAX_STRING_LEN,f))
 		{
 			zbx_fclose(f);
@@ -129,27 +133,27 @@ int	getPROC(char *file, int lineno, int fieldno, unsigned flags, AGENT_RESULT *r
 
 static int	AGENT_PING(const char *cmd, const char *param, unsigned flags, AGENT_RESULT *result)
 {
-        assert(result);
+	assert(result);
+
+	init_result(result);
 
-        init_result(result);	
-	
 	SET_UI64_RESULT(result, 1);
+
 	return SYSINFO_RET_OK;
 }
 
 static int	AGENT_VERSION(const char *cmd, const char *param, unsigned flags, AGENT_RESULT *result)
 {
-	static	char	version[]=ZABBIX_VERSION;
+	static char	version[] = ZABBIX_VERSION;
 
 	assert(result);
 
-        init_result(result);
-		
-	SET_STR_RESULT(result, strdup(version));
-	
-	return	SYSINFO_RET_OK;
-}
+	init_result(result);
 
+	SET_STR_RESULT(result, strdup(version));
+
+	return SYSINFO_RET_OK;
+}
 
 int	EXECUTE_STR(const char *cmd, const char *param, unsigned flags, AGENT_RESULT *result)
 {
@@ -160,6 +164,7 @@ int	EXECUTE_STR(const char *cmd, const char *param, unsigned flags, AGENT_RESULT
 	PROCESS_INFORMATION pi = {0};
 	SECURITY_ATTRIBUTES sa;
 	HANDLE hWrite=NULL, hRead=NULL;
+	LPTSTR	wcommand;
 
 #else /* not _WINDOWS */
 
@@ -174,9 +179,9 @@ int	EXECUTE_STR(const char *cmd, const char *param, unsigned flags, AGENT_RESULT
 	char	*command=NULL;
 	int	len;
 
-        assert(result);
+	assert(result);
 
-        init_result(result);
+	init_result(result);
 
 	cmd_result = zbx_dsprintf(cmd_result,"");
 	memset(stat_buf, 0, sizeof(stat_buf));
@@ -184,12 +189,12 @@ int	EXECUTE_STR(const char *cmd, const char *param, unsigned flags, AGENT_RESULT
 #if defined(_WINDOWS)
 
 	/* Set the bInheritHandle flag so pipe handles are inherited */
-	sa.nLength = sizeof(SECURITY_ATTRIBUTES); 
-	sa.bInheritHandle = TRUE; 
-	sa.lpSecurityDescriptor = NULL; 
+	sa.nLength = sizeof(SECURITY_ATTRIBUTES);
+	sa.bInheritHandle = TRUE;
+	sa.lpSecurityDescriptor = NULL;
 
 	/* Create a pipe for the child process's STDOUT */
-	if (! CreatePipe(&hRead, &hWrite, &sa, sizeof(cmd_result))) 
+	if (! CreatePipe(&hRead, &hWrite, &sa, sizeof(cmd_result)))
 	{
 		zabbix_log(LOG_LEVEL_DEBUG, "Unable to create pipe [%s]", strerror_from_system(GetLastError()));
 		ret = SYSINFO_RET_FAIL;
@@ -206,14 +211,18 @@ int	EXECUTE_STR(const char *cmd, const char *param, unsigned flags, AGENT_RESULT
 
 	command = zbx_dsprintf(command, "cmd /C \"%s\"", param);
 
+	wcommand = zbx_utf8_to_unicode(command);
+
 	/* Create new process */
-	if (!CreateProcess(NULL,command,NULL,NULL,TRUE,0,NULL,NULL,&si,&pi))
+	if (!CreateProcess(NULL,wcommand,NULL,NULL,TRUE,0,NULL,NULL,&si,&pi))
 	{
 		zabbix_log(LOG_LEVEL_DEBUG, "Unable to create process: '%s' [%s]", command, strerror_from_system(GetLastError()));
 
 		ret = SYSINFO_RET_FAIL;
+		zbx_free(wcommand);
 		goto lbl_exit;
 	}
+	zbx_free(wcommand);
 	CloseHandle(hWrite);	hWrite = NULL;
 
 	/* Read process output */
@@ -233,7 +242,7 @@ int	EXECUTE_STR(const char *cmd, const char *param, unsigned flags, AGENT_RESULT
 	CloseHandle(pi.hThread);
 
 	CloseHandle(hRead);	hRead = NULL;
-		
+
 
 #else /* not _WINDOWS */
 	command = zbx_dsprintf(command, "%s", param);
@@ -355,11 +364,13 @@ int	RUN_COMMAND(const char *cmd, const char *param, unsigned flags, AGENT_RESULT
 	PROCESS_INFORMATION  pi;
 
 	char	full_command[MAX_STRING_LEN];
+	LPTSTR	wcommand;
+	int	ret = SYSINFO_RET_FAIL;
 #else /* not _WINDOWS */
 	pid_t	pid;
 #endif
 
-        assert(result);
+	assert(result);
 
 	init_result(result);
 
@@ -369,16 +380,19 @@ int	RUN_COMMAND(const char *cmd, const char *param, unsigned flags, AGENT_RESULT
 		return SYSINFO_RET_FAIL;
 	}
 
-        if (num_param(param) > 2)
-                return SYSINFO_RET_FAIL;
+	if (num_param(param) > 2)
+		return SYSINFO_RET_FAIL;
 
 	if (0 != get_param(param, 1, command, sizeof(command)))
-                return SYSINFO_RET_FAIL;
+		return SYSINFO_RET_FAIL;
 
 	if (*command == '\0')
 		return SYSINFO_RET_FAIL;
 
-	zabbix_log(LOG_LEVEL_DEBUG, "Run command '%s'", command);
+	if (CONFIG_LOG_REMOTE_COMMANDS == 1)
+		zabbix_log(LOG_LEVEL_WARNING, "Executing command '%s'", command);
+	else
+		zabbix_log(LOG_LEVEL_DEBUG, "Executing command '%s'", command);
 
 	if (0 != get_param(param, 2, flag, sizeof(flag)))
 		*flag = '\0';
@@ -390,7 +404,7 @@ int	RUN_COMMAND(const char *cmd, const char *param, unsigned flags, AGENT_RESULT
 		return EXECUTE_STR(cmd,command,flags,result);
 	else if(0 != strcmp(flag,"nowait"))
 		return SYSINFO_RET_FAIL;
-	
+
 #if defined(_WINDOWS)
 
 	zbx_snprintf(full_command, sizeof(full_command), "cmd /C \"%s\"", command);
@@ -399,9 +413,11 @@ int	RUN_COMMAND(const char *cmd, const char *param, unsigned flags, AGENT_RESULT
 
 	zabbix_log(LOG_LEVEL_DEBUG, "Execute command '%s'",full_command);
 
+	wcommand = zbx_utf8_to_unicode(full_command);
+
 	if(!CreateProcess(
 		NULL,	/* No module name (use command line) */
-		full_command,/* Name of app to launch */
+		wcommand,/* Name of app to launch */
 		NULL,	/* Default process security attributes */
 		NULL,	/* Default thread security attributes */
 		FALSE,	/* Don't inherit handles from the parent */
@@ -411,9 +427,17 @@ int	RUN_COMMAND(const char *cmd, const char *param, unsigned flags, AGENT_RESULT
 		&si,	/* Startup Information */
 		&pi))	/* Process information stored upon return */
 	{
-		return SYSINFO_RET_FAIL;
+		goto lbl_exit;
 	}
 
+	ret = SYSINFO_RET_OK;
+
+	SET_UI64_RESULT(result, 1);
+lbl_exit:
+	zbx_free(wcommand);
+
+	return ret;
+
 #else /* not _WINDOWS */
 
 	pid = zbx_fork(); /* run new thread 1 */
@@ -430,13 +454,13 @@ int	RUN_COMMAND(const char *cmd, const char *param, unsigned flags, AGENT_RESULT
 			zabbix_log(LOG_LEVEL_WARNING, "fork2 failed for '%s'",command);
 			return SYSINFO_RET_FAIL;
 		case 0:
-			/* 
+			/*
 			 * DON'T REMOVE SLEEP
 			 * sleep needed to return server result as "1"
 			 * then we can run "execl"
 			 * otherwise command print result into socket with STDOUT id
 			 */
-			sleep(3); 
+			sleep(3);
 			/**/
 
 			/* replace thread 2 by the execution of command */
@@ -456,9 +480,8 @@ int	RUN_COMMAND(const char *cmd, const char *param, unsigned flags, AGENT_RESULT
 		break;
 	}
 
-#endif /* _WINDOWS */
-
 	SET_UI64_RESULT(result, 1);
 
 	return SYSINFO_RET_OK;
+#endif /* _WINDOWS */
 }
