@@ -1,4 +1,4 @@
-/* 
+/*
 ** ZABBIX
 ** Copyright (C) 2000-2005 SIA Zabbix
 **
@@ -17,9 +17,8 @@
 ** Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 **/
 
-#include "config.h"
-
 #include "common.h"
+
 #include "sysinfo.h"
 
 int	KERNEL_MAXFILES(const char *cmd, const char *param, unsigned flags, AGENT_RESULT *result)
@@ -28,17 +27,16 @@ int	KERNEL_MAXFILES(const char *cmd, const char *param, unsigned flags, AGENT_RE
 	char line[MAX_STRING_LEN];
 
 	zbx_uint64_t value = 0;
-	
+
 	FILE 	*f;
 
 	assert(result);
 
-        init_result(result);	
+        init_result(result);
 
-	f=fopen("/proc/sys/fs/file-max","r");
-	if(f)
+	if(NULL != ( f = fopen("/proc/sys/fs/file-max","r") ))
 	{
-		if(fgets(line,MAX_STRING_LEN,f) != NULL);
+		if (NULL != fgets(line, sizeof(line), f))
 		{
 			if(sscanf(line,ZBX_FS_UI64 "\n", &value) == 1)
 			{
@@ -46,7 +44,7 @@ int	KERNEL_MAXFILES(const char *cmd, const char *param, unsigned flags, AGENT_RE
 				ret = SYSINFO_RET_OK;
 			}
 		}
-		fclose(f);
+		zbx_fclose(f);
 	}
 
 	return ret;
@@ -54,29 +52,24 @@ int	KERNEL_MAXFILES(const char *cmd, const char *param, unsigned flags, AGENT_RE
 
 int	KERNEL_MAXPROC(const char *cmd, const char *param, unsigned flags, AGENT_RESULT *result)
 {
-#ifdef HAVE_FUNCTION_SYSCTL_KERN_MAXPROC
-	int	mib[2],len;
-	int	maxproc;
+#ifdef HAVE_FUNCTION_SYSCTL_KERN_PIDMAX
+	size_t	sz;
+	int	maxproc, mib[2] = {CTL_KERN, KERN_PIDMAX};
 
 	assert(result);
 
-        init_result(result);	
-	
-	mib[0]=CTL_KERN;
-	mib[1]=KERN_MAXPROC;
+	init_result(result);
 
-	len=sizeof(maxproc);
+	sz = sizeof(maxproc);
 
-	if(sysctl(mib,2,&maxproc,(size_t *)&len,NULL,0) != 0)
-	{
-		return	SYSINFO_RET_FAIL;
-/*		printf("Errno [%m]");*/
-	}
+	if (0 != sysctl(mib, 2, &maxproc, &sz, NULL, 0))
+		return SYSINFO_RET_FAIL;
 
 	SET_UI64_RESULT(result, maxproc);
+
 	return SYSINFO_RET_OK;
 #else
-	return	SYSINFO_RET_FAIL;
+	return SYSINFO_RET_FAIL;
 #endif
 }
 
@@ -87,7 +80,7 @@ int     OLD_KERNEL(const char *cmd, const char *param, unsigned flags, AGENT_RES
 
         assert(result);
 
-        init_result(result);	
+        init_result(result);
 
         if(num_param(param) > 1)
         {
@@ -114,4 +107,3 @@ int     OLD_KERNEL(const char *cmd, const char *param, unsigned flags, AGENT_RES
 
         return ret;
 }
-
