@@ -1,4 +1,4 @@
-/* 
+/*
 ** ZABBIX
 ** Copyright (C) 2000-2005 SIA Zabbix
 **
@@ -21,20 +21,29 @@
 
 #include "sysinfo.h"
 
+void	refresh_diskdevices()
+{
+}
+
+int	get_diskstat(const char *devname, zbx_uint64_t *dstat)
+{
+	return FAIL;
+}
+
 int	VFS_DEV_WRITE(const char *cmd, const char *param, unsigned flags, AGENT_RESULT *result)
 {
 #ifndef TODO
-	return SYSINFO_RET_FAIL; 
+	return SYSINFO_RET_FAIL;
 #else
 	/* !!!TODO!!! */
 	char devname[MAX_STRING_LEN];
 	char type[MAX_STRING_LEN];
 	char mode[MAX_STRING_LEN];
-	
+
         assert(result);
 
         init_result(result);
-	
+
         if(num_param(param) > 3)
         {
                 return SYSINFO_RET_FAIL;
@@ -44,7 +53,7 @@ int	VFS_DEV_WRITE(const char *cmd, const char *param, unsigned flags, AGENT_RESU
         {
                 return SYSINFO_RET_FAIL;
         }
-	
+
 	if(get_param(param, 2, type, sizeof(type)) != 0)
         {
                 type[0] = '\0';
@@ -54,12 +63,12 @@ int	VFS_DEV_WRITE(const char *cmd, const char *param, unsigned flags, AGENT_RESU
 		/* default parameter */
 		zbx_snprintf(type, sizeof(type), "bps");
 	}
-	
+
 	if(get_param(param, 3, mode, sizeof(mode)) != 0)
         {
                 mode[0] = '\0';
         }
-	
+
         if(mode[0] == '\0')
 	{
 		/* default parameter */
@@ -100,17 +109,17 @@ int	VFS_DEV_WRITE(const char *cmd, const char *param, unsigned flags, AGENT_RESU
 int	VFS_DEV_READ(const char *cmd, const char *param, unsigned flags, AGENT_RESULT *result)
 {
 #ifndef TODO
-	return SYSINFO_RET_FAIL; 
+	return SYSINFO_RET_FAIL;
 #else
 	/* !!!TODO!!! */
 	char devname[MAX_STRING_LEN];
 	char type[MAX_STRING_LEN];
 	char mode[MAX_STRING_LEN];
-	
+
         assert(result);
 
         init_result(result);
-	
+
         if(num_param(param) > 3)
         {
                 return SYSINFO_RET_FAIL;
@@ -120,7 +129,7 @@ int	VFS_DEV_READ(const char *cmd, const char *param, unsigned flags, AGENT_RESUL
         {
                 return SYSINFO_RET_FAIL;
         }
-	
+
 	if(get_param(param, 2, type, sizeof(type)) != 0)
         {
                 type[0] = '\0';
@@ -130,12 +139,12 @@ int	VFS_DEV_READ(const char *cmd, const char *param, unsigned flags, AGENT_RESUL
 		/* default parameter */
 		zbx_snprintf(type, sizeof(type), "bps");
 	}
-	
+
 	if(get_param(param, 3, mode, sizeof(mode)) != 0)
         {
                 mode[0] = '\0';
         }
-	
+
         if(mode[0] == '\0')
 	{
 		/* default parameter */
@@ -261,7 +270,6 @@ int	OLD_IO(const char *cmd, const char *param, unsigned flags, AGENT_RESULT *res
 	{
 		ret = SYSINFO_RET_FAIL;
 	}
-    
+
 	return ret;
 }
-
