@@ -25,17 +25,37 @@
 #include "log.h"
 
 #define MAX_PROCESSES		4096
-#define MAX_MODULES		512
+/*#define MAX_MODULES		512*/
 #define MAX_NAME		256
 
-/* function 'GetProcessUsername' require 'userName' with size 'MAX_NAME' */
-static int GetProcessUsername(HANDLE hProcess, char *userName)
+/* function 'zbx_get_processname' require 'baseName' with size 'MAX_NAME' */
+static int	zbx_get_processname(HANDLE hProcess, char *baseName)
+{
+	HMODULE	hMod;
+	DWORD	dwSize;
+	TCHAR	name[MAX_NAME];
+/*			if (0 != EnumProcessModules(hProcess, modList, sizeof(HMODULE) * MAX_MODULES, &dwSize))
+				if (0 != GetModuleBaseName(hProcess,modList[0],baseName,sizeof(baseName)))*/
+
+	if (0 == EnumProcessModules(hProcess, &hMod, sizeof(hMod), &dwSize))
+		return FAIL;
+
+	if (0 == GetModuleBaseName(hProcess, hMod, name, sizeof(name)))
+		return FAIL;
+
+	zbx_unicode_to_utf8_static(name, baseName, MAX_NAME);
+
+	return SUCCEED;
+}
+
+/* function 'zbx_get_process_username' require 'userName' with size 'MAX_NAME' */
+static int	zbx_get_process_username(HANDLE hProcess, char *userName)
 {
 	HANDLE		tok;
 	TOKEN_USER	*ptu = NULL;
 	DWORD		sz = 0, nlen, dlen;
-	char		name[MAX_NAME], dom[MAX_NAME];
-	int		iUse, res = 0;
+	TCHAR		name[MAX_NAME], dom[MAX_NAME];
+	int		iUse, res = FAIL;
 
 	assert(userName);
 
@@ -47,26 +67,26 @@ static int GetProcessUsername(HANDLE hProcess, char *userName)
 		return res;
 
 	// Get required buffer size and allocate the TOKEN_USER buffer
-	if (0 == GetTokenInformation(tok, (TOKEN_INFORMATION_CLASS)1, (LPVOID)ptu, 0, &sz)) 
+	if (0 == GetTokenInformation(tok, (TOKEN_INFORMATION_CLASS)1, (LPVOID)ptu, 0, &sz))
 	{
-		if (GetLastError() != ERROR_INSUFFICIENT_BUFFER) 
+		if (GetLastError() != ERROR_INSUFFICIENT_BUFFER)
 			goto lbl_err;
 		ptu = (PTOKEN_USER)zbx_malloc(ptu, sz);
 	}
 
 	// Get the token user information from the access token.
-	if (0 == GetTokenInformation(tok, (TOKEN_INFORMATION_CLASS)1, (LPVOID)ptu, sz, &sz)) 
+	if (0 == GetTokenInformation(tok, (TOKEN_INFORMATION_CLASS)1, (LPVOID)ptu, sz, &sz))
 		goto lbl_err;
 
 	//get the account/domain name of the SID
-	nlen = sizeof(name);
-	dlen = sizeof(dom);
+	nlen = MAX_NAME;
+	dlen = MAX_NAME;
 	if (0 == LookupAccountSid(NULL, ptu->User.Sid, name, &nlen, dom, &dlen, (PSID_NAME_USE)&iUse))
 		goto lbl_err;
 
-	zbx_strlcpy(userName, name, MAX_NAME);
+	zbx_unicode_to_utf8_static(name, userName, MAX_NAME);
 
-	res = 1;
+	res = SUCCEED;
 lbl_err:
 	zbx_free(ptu);
 
@@ -87,14 +107,13 @@ int     PROC_MEMORY(const char *cmd, const char *param, unsigned flags, AGENT_RE
 int	    PROC_NUM(const char *cmd, const char *param, unsigned flags, AGENT_RESULT *result)
 { /* usage: <function name>[ <process name>, <user name>] */
 	HANDLE	hProcess;
-	HMODULE	hMod;
 	DWORD	procList[MAX_PROCESSES], dwSize;
 	int	i, proccount, max_proc_cnt,
 		proc_ok = 0,
 		user_ok = 0;
 	char	procName[MAX_PATH],
 		userName[MAX_PATH],
-		baseName[MAX_PATH], 
+		baseName[MAX_PATH],
 		uname[MAX_NAME];
 
 	if (num_param(param) > 2)
@@ -119,19 +138,18 @@ int	    PROC_NUM(const char *cmd, const char *param, unsigned flags, AGENT_RESUL
 
 		if (NULL != (hProcess = OpenProcess(PROCESS_QUERY_INFORMATION | PROCESS_VM_READ, FALSE, procList[i])))
 		{
-			if ('\0' != *procName) 
+			if ('\0' != *procName)
 			{
-				if (0 != EnumProcessModules(hProcess, &hMod, sizeof(hMod), &dwSize))
-					if (0 != GetModuleBaseName(hProcess, hMod, baseName, sizeof(baseName)))
-						if (0 == stricmp(baseName, procName))
-							proc_ok = 1;
+				if (SUCCEED == zbx_get_processname(hProcess, baseName))
+					if (0 == stricmp(baseName, procName))
+						proc_ok = 1;
 			}
 			else
 				proc_ok = 1;
 
 			if (0 != proc_ok && '\0' != *userName)
 			{
-				if (0 != GetProcessUsername(hProcess, uname))
+				if (SUCCEED == zbx_get_process_username(hProcess, uname))
 					if (0 == stricmp(uname, userName))
 						user_ok = 1;
 			}
@@ -169,9 +187,9 @@ static double ConvertProcessTime(FILETIME *lpft)
  * Get specific process attribute
  */
 
-static double GetProcessAttribute(HANDLE hProcess,int attr,int type,int count,double *lastValue)
+static int	GetProcessAttribute(HANDLE hProcess,int attr,int type,int count,double *lastValue)
 {
-   double value;  
+   double value;
    PROCESS_MEMORY_COUNTERS mc;
    IO_COUNTERS ioCounters;
    FILETIME ftCreate,ftExit,ftKernel,ftUser;
@@ -252,31 +270,27 @@ static double GetProcessAttribute(HANDLE hProcess,int attr,int type,int count,do
          return SYSINFO_RET_FAIL;
    }
 
-   /* Recalculate final value according to selected type */
-   if (count==1)     /* First instance */
-   {
-      *lastValue = value;
-   }
+	/* Recalculate final value according to selected type */
+	switch (type) {
+	case 0:	/* min */
+		if (count == 0 || value < *lastValue)
+			*lastValue = value;
+		break;
+	case 1:	/* max */
+		if (count == 0 || value > *lastValue)
+			*lastValue = value;
+		break;
+	case 2:	/* avg */
+		*lastValue = (*lastValue * count + value) / (count + 1);
+		break;
+	case 3:	/* sum */
+		*lastValue += value;
+		break;
+	default:
+		return SYSINFO_RET_FAIL;
+	}
 
-   switch(type)
-   {
-      case 0:     /* min */
-         *lastValue = min((*lastValue),value);
-	 break;
-      case 1:     /* max */
-         *lastValue = max((*lastValue),value);
-	 break;
-      case 2:     /* avg */
-         *lastValue = ((*lastValue) * (count-1) + value) / count;
-	 break;
-      case 3:     /* sum */
-         *lastValue = (*lastValue) + value;
-	 break;
-      default:
-         return SYSINFO_RET_FAIL;
-   }
-
-   return SYSINFO_RET_OK;
+	return SYSINFO_RET_OK;
 }
 
 
@@ -299,7 +313,6 @@ static double GetProcessAttribute(HANDLE hProcess,int attr,int type,int count,do
 int	PROC_INFO(const char *cmd, const char *param, unsigned flags, AGENT_RESULT *result)
 {
 	DWORD		*procList, dwSize;
-	HMODULE		*modList;
 	HANDLE		hProcess;
 	char		proc_name[MAX_PATH],
 			attr[MAX_PATH],
@@ -347,7 +360,6 @@ int	PROC_INFO(const char *cmd, const char *param, unsigned flags, AGENT_RESULT *
 		return SYSINFO_RET_FAIL;     /* Unsupported type */
 
 	procList = (DWORD *)malloc(MAX_PROCESSES * sizeof(DWORD));
-	modList = (HMODULE *)malloc(MAX_MODULES * sizeof(HMODULE));
 
 	EnumProcesses(procList, sizeof(DWORD) * MAX_PROCESSES, &dwSize);
 
@@ -359,17 +371,15 @@ int	PROC_INFO(const char *cmd, const char *param, unsigned flags, AGENT_RESULT *
 	{
 		if (NULL != (hProcess = OpenProcess(PROCESS_QUERY_INFORMATION | PROCESS_VM_READ,FALSE, procList[i])))
 		{
-			if (0 != EnumProcessModules(hProcess, modList, sizeof(HMODULE) * MAX_MODULES, &dwSize))
-				if (0 != GetModuleBaseName(hProcess,modList[0],baseName,sizeof(baseName)))
-					if (0 == stricmp(baseName, proc_name))
-						if (SYSINFO_RET_OK != (ret = GetProcessAttribute(hProcess, attr_id, type_id, ++counter, &value)))
-							break;
+			if (SUCCEED == zbx_get_processname(hProcess, baseName))
+				if (0 == stricmp(baseName, proc_name))
+					if (SYSINFO_RET_OK != (ret = GetProcessAttribute(hProcess, attr_id, type_id, counter++, &value)))
+						break;
 			CloseHandle(hProcess);
 		}
 	}
 
 	free(procList);
-	free(modList);
 
 	if (SYSINFO_RET_OK == ret)
 		SET_DBL_RESULT(result, value)
