@@ -1,4 +1,4 @@
-/* 
+/*
 ** ZABBIX
 ** Copyright (C) 2000-2005 SIA Zabbix
 **
@@ -24,7 +24,9 @@
 #include "log.h"
 #include "sysinfo.h"
 #include "logfiles.h"
+#if defined (_WINDOWS)
 #include "eventlog.h"
+#endif
 #include "comms.h"
 #include "threads.h"
 #include "zbxjson.h"
@@ -37,103 +39,80 @@
 
 static ZBX_ACTIVE_METRIC *active_metrics = NULL;
 static ZBX_ACTIVE_BUFFER buffer;
+static ZBX_REGEXP	*regexps = NULL;
+static int		regexps_alloc = 0, regexps_num = 0;
 
 static void	init_active_metrics()
 {
-	zabbix_log( LOG_LEVEL_DEBUG, "In init_active_metrics()");
+	zabbix_log(LOG_LEVEL_DEBUG, "In init_active_metrics()");
 
-	if(NULL == active_metrics)
-	{
-		active_metrics = calloc(sizeof(ZBX_ACTIVE_METRIC), 1);
-	}
-	else
-	{
-		zabbix_log(LOG_LEVEL_WARNING, "Metrics are already initialised.");
-	}
+	active_metrics = zbx_malloc(active_metrics, sizeof(ZBX_ACTIVE_METRIC));
+	active_metrics->key = NULL;
 }
 
 static void	disable_all_metrics()
 {
-	int i;
+	int	i;
 
- 	zabbix_log( LOG_LEVEL_DEBUG, "In disable_all_metrics()");
+	zabbix_log(LOG_LEVEL_DEBUG, "In disable_all_metrics()");
 
-	if(NULL == active_metrics) 
-	{
-		zabbix_log(LOG_LEVEL_DEBUG, "No meters to desabling.");
-		return;
-	}
-
-	for(i=0; NULL != active_metrics[i].key; i++)
-	{
+	for (i = 0; NULL != active_metrics[i].key; i++)
 		active_metrics[i].status = ITEM_STATUS_NOTSUPPORTED;
-	}
 }
 
-
-static void	free_active_metrics(void)
+static void	free_active_metrics()
 {
-	int i;
+	int	i;
 
-	zabbix_log( LOG_LEVEL_DEBUG, "In free_active_metrics()");
+	zabbix_log(LOG_LEVEL_DEBUG, "In free_active_metrics()");
 
-	if(NULL == active_metrics)
-	{
-		zabbix_log(LOG_LEVEL_WARNING, "Metrics are already freed.");
-		return;
-	}
-
-	for(i = 0; NULL != active_metrics[i].key;i++)
-	{
+	for (i = 0; NULL != active_metrics[i].key; i++)
 		zbx_free(active_metrics[i].key);
-		active_metrics[i].status = ITEM_STATUS_NOTSUPPORTED;
-	}
 
 	zbx_free(active_metrics);
-	active_metrics = NULL;
+
+	clean_regexps_ex(regexps, &regexps_num);
+
+	zbx_free(regexps);
 }
 
 static int	get_min_nextcheck()
 {
-	int i;
-	int min = -1;
+	int	i, min = -1;
 
 	zabbix_log( LOG_LEVEL_DEBUG, "In get_min_nextcheck()");
 
-	for(i = 0; NULL != active_metrics[i].key; i++)
+	for (i = 0; NULL != active_metrics[i].key; i++)
 	{
-		if(ITEM_STATUS_ACTIVE != active_metrics[i].status)
+		if (ITEM_STATUS_ACTIVE != active_metrics[i].status)
 			continue;
 
-		if(active_metrics[i].nextcheck < min || ((-1) == min))
+		if (active_metrics[i].nextcheck < min || (-1) == min)
 			min = active_metrics[i].nextcheck;
 	}
 
-	if((-1) == min)
-		return	FAIL;
+	if ((-1) == min)
+		return FAIL;
 
 	return min;
 }
 
-static void	add_check(const char *key, const char *key_orig, int refresh, long lastlogsize)
+static void	add_check(const char *key, const char *key_orig, int refresh, long lastlogsize, int mtime)
 {
-	int i;
+	int	i;
 
-	zabbix_log( LOG_LEVEL_DEBUG, "In add_check('%s', %i, %li)", key, refresh, lastlogsize);
+	zabbix_log( LOG_LEVEL_DEBUG, "In add_check('%s', %i, %li, %i)", key, refresh, lastlogsize, mtime);
 
-	for(i=0; NULL != active_metrics[i].key; i++)
+	for (i = 0; NULL != active_metrics[i].key; i++)
 	{
-		if(strcmp(active_metrics[i].key,key) != 0)
+		if (0 != strcmp(active_metrics[i].key, key))
 			continue;
 
 		/* replace metric */
-		if(active_metrics[i].refresh != refresh)
-		{
+		if (active_metrics[i].refresh != refresh)
 			active_metrics[i].nextcheck = 0;
-		}
-		active_metrics[i].refresh	= refresh;
-		/* active_metrics[i].lastlogsize	= lastlogsize; *//* don't update lastlogsize for exsted items */
-		active_metrics[i].status	= ITEM_STATUS_ACTIVE;
+		active_metrics[i].refresh = refresh;
+		active_metrics[i].status = ITEM_STATUS_ACTIVE;
 
 		return;
 	}
@@ -145,15 +124,16 @@ static void	add_check(const char *key, const char *key_orig, int refresh, long l
 	active_metrics[i].nextcheck	= 0;
 	active_metrics[i].status	= ITEM_STATUS_ACTIVE;
 	active_metrics[i].lastlogsize	= lastlogsize;
+	active_metrics[i].mtime		= mtime;
 
 	/* move to the last metric */
 	i++;
 
 	/* allocate memory for last metric */
-	active_metrics	= zbx_realloc(active_metrics, (i+1) * sizeof(ZBX_ACTIVE_METRIC));
+	active_metrics	= zbx_realloc(active_metrics, (i + 1) * sizeof(ZBX_ACTIVE_METRIC));
 
-	/* inicialize last metric */
-	memset(&active_metrics[i], 0, sizeof(ZBX_ACTIVE_METRIC));
+	/* initialize last metric */
+	active_metrics[i].key = NULL;
 }
 
 /******************************************************************************
@@ -164,131 +144,175 @@ static void	add_check(const char *key, const char *key_orig, int refresh, long l
  *                                                                            *
  * Parameters: str - NULL terminated string received from server              *
  *                                                                            *
- * Return value: returns SUCCEED on succesfull parsing,                       *
- *               FAIL on an incoorrect format of string                       *
+ * Return value: returns SUCCEED on succesful parsing,                        *
+ *               FAIL on an incorrect format of string                        *
  *                                                                            *
  * Author: Eugene Grigorjev, Alexei Vladishev (new json protocol)             *
  *                                                                            *
  * Comments:                                                                  *
- *    String reprents as "ZBX_EOF" termination list                           *
+ *    String represented as "ZBX_EOF" termination list                        *
  *    With '\n' delimeter between elements.                                   *
- *    Each element represents as:                                             *
- *           <key>:<refresh time>:<last log size>                             *
+ *    Each element represented as:                                            *
+ *           <key>:<refresh time>:<last log size>:<modification time>         *
  *                                                                            *
  ******************************************************************************/
 static int	parse_list_of_checks(char *str)
 {
-	const char	*p;
-	char	key[MAX_STRING_LEN], key_orig[MAX_STRING_LEN], delay[MAX_STRING_LEN], lastlogsize[MAX_STRING_LEN];
-	char	result[MAX_STRING_LEN];
-	int	ret = SUCCEED;
+	const char		*p;
+	char			name[MAX_STRING_LEN], key_orig[MAX_STRING_LEN], expression[MAX_STRING_LEN], tmp[MAX_STRING_LEN],
+				exp_delimiter;
+	int			delay, lastlogsize, mtime, expression_type, case_sensitive;
+	struct zbx_json_parse	jp;
+	struct zbx_json_parse	jp_data, jp_row;
 
-	struct	zbx_json_parse jp;
-	struct	zbx_json_parse   jp_data, jp_row;
-
-	zabbix_log(LOG_LEVEL_DEBUG, "In parse_list_of_checks() [%s]",
-		str);
+	zabbix_log(LOG_LEVEL_DEBUG, "In parse_list_of_checks()");
 
 	disable_all_metrics();
 
-	if (SUCCEED == ret && SUCCEED != zbx_json_open(str, &jp))
-	{
-		zabbix_log(LOG_LEVEL_WARNING, "Can't open jason object");
-		ret = FAIL;
-	}
+	if (SUCCEED != zbx_json_open(str, &jp))
+		goto json_error;
 
-	if (SUCCEED == ret && SUCCEED != zbx_json_value_by_name(&jp, ZBX_PROTO_TAG_RESPONSE, result, sizeof(result)))
-	{
-		zabbix_log(LOG_LEVEL_WARNING, "%s",
-			zbx_json_strerror());
-		ret = FAIL;
-	}
+	if (SUCCEED != zbx_json_value_by_name(&jp, ZBX_PROTO_TAG_RESPONSE, tmp, sizeof(tmp)))
+		goto json_error;
 
-	if (SUCCEED == ret && 0 != strcmp(result, ZBX_PROTO_VALUE_SUCCESS))
+	if (0 != strcmp(tmp, ZBX_PROTO_VALUE_SUCCESS))
 	{
-		if (SUCCEED == zbx_json_value_by_name(&jp, ZBX_PROTO_TAG_INFO, result, sizeof(result)))
+		if (SUCCEED == zbx_json_value_by_name(&jp, ZBX_PROTO_TAG_INFO, tmp, sizeof(tmp)))
 			zabbix_log(LOG_LEVEL_WARNING, "No active checks on server: %s",
-					result);
+					tmp);
 		else
 			zabbix_log(LOG_LEVEL_WARNING, "No active checks on server");
-		ret = FAIL;
+		return FAIL;
 	}
 
-	if (SUCCEED == ret && NULL == (p = zbx_json_pair_by_name(&jp, ZBX_PROTO_TAG_DATA)))
+	if (SUCCEED != zbx_json_brackets_by_name(&jp, ZBX_PROTO_TAG_DATA, &jp_data))
+		goto json_error;
+
+ 	p = NULL;
+	while (NULL != (p = zbx_json_next(&jp_data, p)))
 	{
-		zabbix_log(LOG_LEVEL_WARNING, "Can't find \"%s\" tag",
-			ZBX_PROTO_TAG_DATA);
-		ret = FAIL;
+/* {"data":[{"key":"system.cpu.num",...,...},{...},...]}
+ *          ^------------------------------^
+ */ 		if (SUCCEED != zbx_json_brackets_open(p, &jp_row))
+			goto json_error;
+
+		if (SUCCEED != zbx_json_value_by_name(&jp_row, ZBX_PROTO_TAG_KEY, name, sizeof(name)) || *name == '\0')
+		{
+			zabbix_log(LOG_LEVEL_WARNING, "Unable to retrieve value of tag \"%s\"",
+					ZBX_PROTO_TAG_KEY);
+			continue;
+		}
+
+		if (SUCCEED != zbx_json_value_by_name(&jp_row, ZBX_PROTO_TAG_KEY_ORIG, key_orig, sizeof(key_orig)) || *key_orig == '\0')
+			zbx_strlcpy(key_orig, name, sizeof(key_orig));
+
+		if (SUCCEED != zbx_json_value_by_name(&jp_row, ZBX_PROTO_TAG_DELAY, tmp, sizeof(tmp)) || *tmp == '\0')
+		{
+			zabbix_log(LOG_LEVEL_WARNING, "Unable to retrieve value of tag \"%s\"",
+					ZBX_PROTO_TAG_DELAY);
+			continue;
+		}
+
+		delay = atoi(tmp);
+
+		if (SUCCEED != zbx_json_value_by_name(&jp_row, ZBX_PROTO_TAG_LOGLASTSIZE, tmp, sizeof(tmp)) || *tmp == '\0')
+		{
+			zabbix_log(LOG_LEVEL_WARNING, "Unable to retrieve value of tag \"%s\"",
+					ZBX_PROTO_TAG_LOGLASTSIZE);
+			continue;
+		}
+
+		lastlogsize = atoi(tmp);
+
+		if (SUCCEED != zbx_json_value_by_name(&jp_row, ZBX_PROTO_TAG_MTIME, tmp, sizeof(tmp)) || *tmp == '\0')
+		{
+			zabbix_log(LOG_LEVEL_WARNING, "Unable to retrieve value of tag \"%s\"",
+					ZBX_PROTO_TAG_MTIME);
+			mtime = 0;
+		}
+		else
+		{
+			mtime = atoi(tmp);
+		}
+
+		add_check(name, key_orig, delay, lastlogsize, mtime);
 	}
 
-	if (SUCCEED == ret && FAIL == zbx_json_brackets_open(p, &jp_data))
-	{
-		zabbix_log(LOG_LEVEL_WARNING, "Can't proceed jason request. %s",
-				zbx_json_strerror());
-		ret = FAIL;
-	}
+	clean_regexps_ex(regexps, &regexps_num);
 
-	if (SUCCEED == ret)
+	if (SUCCEED == zbx_json_brackets_by_name(&jp, ZBX_PROTO_TAG_REGEXP, &jp_data))
 	{
 	 	p = NULL;
-		while (SUCCEED == ret && NULL != (p = zbx_json_next(&jp_data, p)))
+		while (NULL != (p = zbx_json_next(&jp_data, p)))
 		{
-/* {"request":"ZBX_SENDER_DATA","data":[{"key":"system.cpu.num",...,...},{...},...]} 
- *                                      ^------------------------------^
- */ 			if (FAIL == (ret = zbx_json_brackets_open(p, &jp_row)))
-			{
-				zabbix_log(LOG_LEVEL_WARNING, "%s",
-					zbx_json_strerror());
-				ret = FAIL;
-				break;
-			}
+/* {"regexp":[{"name":"regexp1",...,...},{...},...]}
+ *            ^------------------------^
+ */			if (SUCCEED != zbx_json_brackets_open(p, &jp_row))
+				goto json_error;
 
-			*delay = '\0';
-			*key = '\0';
-			*lastlogsize = '\0';
-
-			if (FAIL == zbx_json_value_by_name(&jp_row, ZBX_PROTO_TAG_KEY, key, sizeof(key)))
+			if (SUCCEED != zbx_json_value_by_name(&jp_row, "name", name, sizeof(name)))
 			{
 				zabbix_log(LOG_LEVEL_WARNING, "Unable to retrieve value of tag \"%s\"",
-					ZBX_PROTO_TAG_KEY);
+						"name");
 				continue;
 			}
 
-			if (SUCCEED != zbx_json_value_by_name(&jp_row, ZBX_PROTO_TAG_KEY_ORIG, key_orig, sizeof(key_orig)) || *key_orig == '\0')
-				zbx_strlcpy(key_orig, key, sizeof(key_orig));
-
-			if (FAIL == zbx_json_value_by_name(&jp_row, ZBX_PROTO_TAG_DELAY, delay, sizeof(delay)))
+			if (SUCCEED != zbx_json_value_by_name(&jp_row, "expression", expression, sizeof(expression)) || *expression == '\0')
 			{
 				zabbix_log(LOG_LEVEL_WARNING, "Unable to retrieve value of tag \"%s\"",
-					ZBX_PROTO_TAG_DELAY);
+						"expression");
 				continue;
 			}
 
-			if (FAIL == zbx_json_value_by_name(&jp_row, ZBX_PROTO_TAG_LOGLASTSIZE, lastlogsize, sizeof(lastlogsize)))
+			if (SUCCEED != zbx_json_value_by_name(&jp_row, "expression_type", tmp, sizeof(tmp)) || *tmp == '\0')
 			{
 				zabbix_log(LOG_LEVEL_WARNING, "Unable to retrieve value of tag \"%s\"",
-					ZBX_PROTO_TAG_LOGLASTSIZE);
+						"expression_type");
 				continue;
 			}
 
-			if (*key && *delay && *lastlogsize)
-				add_check(key, key_orig, atoi(delay), atoi(lastlogsize));
+			expression_type = atoi(tmp);
+
+			if (SUCCEED != zbx_json_value_by_name(&jp_row, "exp_delimiter", tmp, sizeof(tmp)))
+			{
+				zabbix_log(LOG_LEVEL_WARNING, "Unable to retrieve value of tag \"%s\"",
+						"exp_delimiter");
+				continue;
+			}
+
+			exp_delimiter = tmp[0];
+
+			if (SUCCEED != zbx_json_value_by_name(&jp_row, "case_sensitive", tmp, sizeof(tmp)) || *tmp == '\0')
+			{
+				zabbix_log(LOG_LEVEL_WARNING, "Unable to retrieve value of tag \"%s\"",
+						"case_sensitive");
+				continue;
+			}
+
+			case_sensitive = atoi(tmp);
+
+			add_regexp_ex(&regexps, &regexps_alloc, &regexps_num,
+					name, expression, expression_type, exp_delimiter, case_sensitive);
 		}
 	}
 
 	return SUCCEED;
+json_error:
+	zabbix_log(LOG_LEVEL_ERR, "Can't parse list of active checks. %s",
+			zbx_json_strerror());
+	return FAIL;
 }
 
 /******************************************************************************
  *                                                                            *
  * Function: refresh_active_checks                                            *
  *                                                                            *
- * Purpose: Retrive from ZABBIX server list of active checks                  *
+ * Purpose: Retrieve from ZABBIX server list of active checks                 *
  *                                                                            *
  * Parameters: host - IP or Hostname of ZABBIX server                         *
  *             port - port of ZABBIX server                                   *
  *                                                                            *
- * Return value: returns SUCCEED on succesfull parsing,                       *
+ * Return value: returns SUCCEED on succesful parsing,                        *
  *               FAIL on other cases                                          *
  *                                                                            *
  * Author: Eugene Grigorjev, Alexei Vladishev (new json protocol)             *
@@ -296,35 +320,29 @@ static int	parse_list_of_checks(char *str)
  * Comments:                                                                  *
  *                                                                            *
  ******************************************************************************/
-static int	refresh_active_checks(
-	const char		*host, 
-	unsigned short	port
-	)
+static int	refresh_active_checks(const char *host, unsigned short port)
 {
-
 	zbx_sock_t	s;
+	char		*buf;
+	int		ret;
+	struct zbx_json	json;
 
-	char	*buf;
-
-	int	ret;
-
-	struct zbx_json json;
-
-	zabbix_log( LOG_LEVEL_DEBUG, "refresh_active_checks('%s',%u)", host, port);
+	zabbix_log(LOG_LEVEL_DEBUG, "refresh_active_checks('%s',%u)", host, port);
 
 	zbx_json_init(&json, ZBX_JSON_STAT_BUF_LEN);
 
 	zbx_json_addstring(&json, ZBX_PROTO_TAG_REQUEST, ZBX_PROTO_VALUE_GET_ACTIVE_CHECKS, ZBX_JSON_TYPE_STRING);
 	zbx_json_addstring(&json, ZBX_PROTO_TAG_HOST, CONFIG_HOSTNAME, ZBX_JSON_TYPE_STRING);
 
-	if (SUCCEED == (ret = zbx_tcp_connect(&s, CONFIG_SOURCE_IP, host, port, CONFIG_TIMEOUT))) {
+	if (SUCCEED == (ret = zbx_tcp_connect(&s, CONFIG_SOURCE_IP, host, port, CONFIG_TIMEOUT)))
+	{
 		zabbix_log(LOG_LEVEL_DEBUG, "Sending [%s]", json.buffer);
 
-		if( SUCCEED == (ret = zbx_tcp_send(&s, json.buffer)) )
+		if (SUCCEED == (ret = zbx_tcp_send(&s, json.buffer)))
 		{
 			zabbix_log(LOG_LEVEL_DEBUG, "Before read");
 
-			if( SUCCEED == (ret = zbx_tcp_recv_ext(&s, &buf, ZBX_TCP_READ_UNTIL_CLOSE)) )
+			if (SUCCEED == (ret = zbx_tcp_recv_ext(&s, &buf, ZBX_TCP_READ_UNTIL_CLOSE)))
 			{
 				zabbix_log(LOG_LEVEL_DEBUG, "Got [%s]", buf);
 				parse_list_of_checks(buf);
@@ -333,10 +351,8 @@ static int	refresh_active_checks(
 		zbx_tcp_close(&s);
 	}
 
-	if( FAIL == ret )
-	{
+	if (SUCCEED != ret)
 		zabbix_log(LOG_LEVEL_DEBUG, "Get active checks error: %s", zbx_tcp_strerror());
-	}
 
 	zbx_json_free(&json);
 
@@ -400,12 +416,12 @@ static int	check_response(char *response)
  *                                                                            *
  * Function: send_buffer                                                      *
  *                                                                            *
- * Purpose: Send value stgored in the buffer to ZABBIX server                 *
+ * Purpose: Send value stored in the buffer to ZABBIX server                  *
  *                                                                            *
  * Parameters: host - IP or Hostname of ZABBIX server                         *
  *             port - port number                                             *
  *                                                                            *
- * Return value: returns SUCCEED on succesfull parsing,                       *
+ * Return value: returns SUCCEED on succesful parsing,                        *
  *               FAIL on other cases                                          *
  *                                                                            *
  * Author: Alexei Vladishev                                                   *
@@ -462,12 +478,16 @@ static int	send_buffer(
 		zbx_json_addstring(&json, ZBX_PROTO_TAG_VALUE, buffer.data[i].value, ZBX_JSON_TYPE_STRING);
 		if (buffer.data[i].lastlogsize)
 			zbx_json_adduint64(&json, ZBX_PROTO_TAG_LOGLASTSIZE, buffer.data[i].lastlogsize);
+		if (buffer.data[i].mtime)
+			zbx_json_adduint64(&json, ZBX_PROTO_TAG_MTIME, buffer.data[i].mtime);
 		if (buffer.data[i].timestamp)
 			zbx_json_adduint64(&json, ZBX_PROTO_TAG_LOGTIMESTAMP, buffer.data[i].timestamp);
 		if (buffer.data[i].source)
 			zbx_json_addstring(&json, ZBX_PROTO_TAG_LOGSOURCE, buffer.data[i].source, ZBX_JSON_TYPE_STRING);
 		if (buffer.data[i].severity)
 			zbx_json_adduint64(&json, ZBX_PROTO_TAG_LOGSEVERITY, buffer.data[i].severity);
+		if (buffer.data[i].logeventid)
+			zbx_json_adduint64(&json, ZBX_PROTO_TAG_LOGEVENTID, buffer.data[i].logeventid);
 		zbx_json_adduint64(&json, ZBX_PROTO_TAG_CLOCK, buffer.data[i].clock);
 		zbx_json_close(&json);
 	}
@@ -537,12 +557,13 @@ static int	send_buffer(
  *             hostname - name of host in ZABBIX database                     *
  *             key - name of metric                                           *
  *             value - string version os key value                            *
- *             lastlogsize - size of readed logfile                           *
- *             timestamp - timestamp of readed value                          *
+ *             lastlogsize - size of read logfile                             *
+ *             mtime - time of last file modification                         *
+ *             timestamp - timestamp of read value                            *
  *             source - name of logged data source                            *
  *             severity - severity of logged data sources                     *
  *                                                                            *
- * Return value: returns SUCCEED on succesfull parsing,                       *
+ * Return value: returns SUCCEED on succesful parsing,                        *
  *               FAIL on other cases                                          *
  *                                                                            *
  * Author: Alexei Vladishev                                                   *
@@ -551,15 +572,17 @@ static int	send_buffer(
  *                                                                            *
  ******************************************************************************/
 static int	process_value(
-		const char		*server,
+		const char	*server,
 		unsigned short	port,
-		const char		*host,
-		const char		*key,
-		const char		*value,
-		long			*lastlogsize,
+		const char	*host,
+		const char	*key,
+		const char	*value,
+		long		*lastlogsize,
+		int		*mtime,
 		unsigned long	*timestamp,
-		const char		*source, 
-		unsigned short	*severity
+		const char	*source,
+		unsigned short	*severity,
+		unsigned long	*logeventid
 )
 {
 	ZBX_ACTIVE_BUFFER_ELEMENT	*el;
@@ -610,8 +633,12 @@ static int	process_value(
 		el->severity	= *severity;
 	if (lastlogsize)
 		el->lastlogsize	= *lastlogsize;
+	if (mtime)/* will be NULL for "eventlog" and "log" and the value will be 0, only "logrt" matters */
+		el->mtime	= *mtime;
 	if (timestamp)
 		el->timestamp	= *timestamp;
+	if (logeventid)
+		el->logeventid	= (int)*logeventid;
 	el->clock	= (int)time(NULL);
 
 /*	zabbix_log(LOG_LEVEL_DEBUG, "BUFFER");
@@ -623,20 +650,29 @@ static int	process_value(
 	return ret;
 }
 
-
 static void	process_active_checks(char *server, unsigned short port)
 {
 	register int	i, s_count, p_count;
 	char		**pvalue;
 	int		now, send_err = SUCCEED, ret;
-	unsigned long	timestamp;
-	char		*source = NULL;
 	char		*value = NULL;
-	unsigned short	severity;
 	long		lastlogsize;
+	int		mtime;
 	char		params[MAX_STRING_LEN];
 	char		filename[MAX_STRING_LEN];
 	char		pattern[MAX_STRING_LEN];
+	/*checks `log', `eventlog', `logrt' may contain parameter,*/
+	/*which overrides CONFIG_MAX_LINES_PER_SECOND*/
+	char		maxlines_persec_str[16];
+	int		maxlines_persec;
+#ifdef	_WINDOWS
+	unsigned long	timestamp, logeventid;
+	unsigned short	severity;
+	char		key_severity[MAX_STRING_LEN], str_severity[32]/*for `regex_match_ex'*/;
+	char		key_source[MAX_STRING_LEN], *source = NULL;
+	char		key_logeventid[MAX_STRING_LEN], str_logeventid[8]/*for `regex_match_ex'*/;
+#endif
+	char		encoding[32];
 
 	AGENT_RESULT	result;
 
@@ -646,19 +682,24 @@ static void	process_active_checks(char *server, unsigned short port)
 
 	now = (int)time(NULL);
 
-	for(i=0; NULL != active_metrics[i].key && SUCCEED == send_err; i++)
+	for (i = 0; NULL != active_metrics[i].key && SUCCEED == send_err; i++)
 	{
-		if(active_metrics[i].nextcheck > now)			continue;
-		if(active_metrics[i].status != ITEM_STATUS_ACTIVE)	continue;
+		if (active_metrics[i].nextcheck > now)
+			continue;
 
-		/* Special processing for log files */
-		if(strncmp(active_metrics[i].key,"log[",4) == 0)
+		if (active_metrics[i].status != ITEM_STATUS_ACTIVE)
+			continue;
+
+		/* special processing for log files WITHOUT rotation */
+		if (0 == strncmp(active_metrics[i].key, "log[", 4))
 		{
-			do{ /* simple try realization */
+			ret = FAIL;
+
+			do { /* simple try realization */
 				if (parse_command(active_metrics[i].key, NULL, 0, params, MAX_STRING_LEN) != 2)
 					break;
-				
-				if (num_param(params) > 2)
+
+				if (num_param( params ) > 4)
 					break;
 
 				if (get_param(params, 1, filename, sizeof(filename)) != 0)
@@ -667,14 +708,30 @@ static void	process_active_checks(char *server, unsigned short port)
 				if (get_param(params, 2, pattern, sizeof(pattern)) != 0)
 					*pattern = '\0';
 
-				s_count = 0;
-				p_count = 0;
-				lastlogsize = active_metrics[i].lastlogsize;
-				while (SUCCEED == (ret = process_log(filename, &lastlogsize, &value))) {
-					if (!value) /* EOF */
-						break;
+				if (get_param(params, 3, encoding, sizeof(encoding)) != 0)
+					*encoding = '\0';
 
-					if ('\0' == *pattern || NULL != zbx_regexp_match(value, pattern, NULL)) {
+				zbx_strupper(encoding);
+
+				if (get_param(params, 4, maxlines_persec_str, sizeof(maxlines_persec_str)) != 0 ||
+						*maxlines_persec_str == '\0')
+					maxlines_persec = CONFIG_MAX_LINES_PER_SECOND;
+				else if ((maxlines_persec = atoi(maxlines_persec_str)) < MIN_VALUE_LINES ||
+						maxlines_persec > MAX_VALUE_LINES)
+					break;
+
+				s_count = p_count = 0;
+				lastlogsize = active_metrics[i].lastlogsize;
+
+				while (SUCCEED == (ret = process_log(filename, &lastlogsize, &value, encoding))) {
+					if (!value) /* EOF */
+					{
+						/*the file could become empty, must save `lastlogsize'*/
+						active_metrics[i].lastlogsize = lastlogsize;
+						break;
+					}
+
+					if (SUCCEED == regexp_match_ex(regexps, regexps_num, value, pattern, ZBX_CASE_SENSITIVE)) {
 						send_err = process_value(
 									server,
 									port,
@@ -682,6 +739,8 @@ static void	process_active_checks(char *server, unsigned short port)
 									active_metrics[i].key_orig,
 									value,
 									&lastlogsize,
+									NULL,/* "mtime" is not used */
+									NULL,
 									NULL,
 									NULL,
 									NULL
@@ -693,46 +752,55 @@ static void	process_active_checks(char *server, unsigned short port)
 					zbx_free(value);
 
 					if (SUCCEED == send_err)
+					{
 						active_metrics[i].lastlogsize = lastlogsize;
-					else
+					}
+					else/* this branch is not neccessary, historically redundant */
+					{
 						lastlogsize = active_metrics[i].lastlogsize;
+					}
 
-					/* Do not flood ZABBIX server if file grows too fast */
-					if(s_count >= (MAX_LINES_PER_SECOND * active_metrics[i].refresh))	break;
+					/* do not flood ZABBIX server if file grows too fast */
+					if (s_count >= (maxlines_persec * active_metrics[i].refresh))
+						break;
 
-					/* Do not flood local system if file grows too fast */
-					if(p_count >= (4 * MAX_LINES_PER_SECOND * active_metrics[i].refresh))	break;
-				}
+					/* do not flood local system if file grows too fast */
+					if (p_count >= (4 * maxlines_persec * active_metrics[i].refresh))
+						break;
+				} //while processing a log
 
-				if( FAIL == ret )
-				{
-					active_metrics[i].status = ITEM_STATUS_NOTSUPPORTED;
-					zabbix_log( LOG_LEVEL_WARNING, "Active check [%s] is not supported. Disabled.",
-						active_metrics[i].key);
+			} while(0); /* simple try realization */
 
-					send_err = process_value(
-								server,
-								port,
-								CONFIG_HOSTNAME,
-								active_metrics[i].key_orig,
-								"ZBX_NOTSUPPORTED",
-								&active_metrics[i].lastlogsize,
-								NULL,
-								NULL,
-								NULL
-							);
-				}
+			if (FAIL == ret) {
+				active_metrics[i].status = ITEM_STATUS_NOTSUPPORTED;
+				zabbix_log( LOG_LEVEL_WARNING, "Active check [%s] is not supported. Disabled.",
+					active_metrics[i].key);
 
-			}while(0); /* simple try realization */
+				send_err = process_value(
+					server,
+					port,
+					CONFIG_HOSTNAME,
+					active_metrics[i].key_orig,
+					"ZBX_NOTSUPPORTED",
+					&active_metrics[i].lastlogsize,
+					NULL,/* "mtime" is not used */
+					NULL,
+					NULL,
+					NULL,
+					NULL
+				);
+			}
 		}
-		/* Special processing for eventlog */
-		else if(strncmp(active_metrics[i].key,"eventlog[",9) == 0)
+		/* special processing for log files WITH rotation */
+		else if (0 == strncmp(active_metrics[i].key, "logrt[", 6))
 		{
-			do{ /* simple try realization */
+			ret = FAIL;
+
+			do { /* simple try realization */
 				if (parse_command(active_metrics[i].key, NULL, 0, params, MAX_STRING_LEN) != 2)
 					break;
-				
-				if (num_param(params) > 2)
+
+				if (num_param( params ) > 4)
 					break;
 
 				if (get_param(params, 1, filename, sizeof(filename)) != 0)
@@ -741,16 +809,32 @@ static void	process_active_checks(char *server, unsigned short port)
 				if (get_param(params, 2, pattern, sizeof(pattern)) != 0)
 					*pattern = '\0';
 
-				s_count = 0;
-				p_count = 0;
-				lastlogsize = active_metrics[i].lastlogsize;
-				while (SUCCEED == (ret = process_eventlog(filename, &lastlogsize,
-					&timestamp, &source, &severity, &value)))
-				{
-					if (!value) /* EOF */
-						break;
+				if (get_param(params, 3, encoding, sizeof(encoding)) != 0)
+					*encoding = '\0';
 
-					if ('\0' == *pattern || NULL != zbx_regexp_match(value, pattern, NULL)) {
+				zbx_strupper(encoding);
+
+				if (get_param(params, 4, maxlines_persec_str, sizeof(maxlines_persec_str)) != 0 ||
+						*maxlines_persec_str == '\0')
+					maxlines_persec = CONFIG_MAX_LINES_PER_SECOND;
+				else if ((maxlines_persec = atoi(maxlines_persec_str)) < MIN_VALUE_LINES ||
+						maxlines_persec > MAX_VALUE_LINES)
+					break;
+
+				s_count = p_count = 0;
+				lastlogsize = active_metrics[i].lastlogsize;
+				mtime = active_metrics[i].mtime;
+
+				while (SUCCEED == (ret = process_logrt(filename, &lastlogsize, &mtime, &value, encoding))) {
+					if (!value) /* EOF */
+					{
+						/*the file could become empty, must save `lastlogsize' and `mtime'*/
+						active_metrics[i].lastlogsize = lastlogsize;
+						active_metrics[i].mtime	= mtime;
+						break;
+					}
+
+					if (SUCCEED == regexp_match_ex(regexps, regexps_num, value, pattern, ZBX_CASE_SENSITIVE)) {
 						send_err = process_value(
 									server,
 									port,
@@ -758,9 +842,163 @@ static void	process_active_checks(char *server, unsigned short port)
 									active_metrics[i].key_orig,
 									value,
 									&lastlogsize,
+									&mtime,
+									NULL,
+									NULL,
+									NULL,
+									NULL
+								);
+						s_count++;
+					}
+					p_count++;
+
+					zbx_free(value);
+
+					if (SUCCEED == send_err)
+					{
+						active_metrics[i].lastlogsize = lastlogsize;
+						active_metrics[i].mtime = mtime;
+					}
+					else/*this branch is not neccessary, historically redundant*/
+					{
+						lastlogsize = active_metrics[i].lastlogsize;
+						mtime = active_metrics[i].mtime;
+					}
+
+					/* Do not flood ZABBIX server if file grows too fast */
+					if (s_count >= (maxlines_persec * active_metrics[i].refresh))
+						break;
+
+					/* Do not flood local system if file grows too fast */
+					if (p_count >= (4 * maxlines_persec * active_metrics[i].refresh))
+						break;
+				} //while processing a log
+
+			} while(0); /* simple try realization */
+
+			if (FAIL == ret) {
+				active_metrics[i].status = ITEM_STATUS_NOTSUPPORTED;
+				zabbix_log( LOG_LEVEL_WARNING, "Active check [%s] is not supported. Disabled.",
+					active_metrics[i].key);
+
+				send_err = process_value(
+					server,
+					port,
+					CONFIG_HOSTNAME,
+					active_metrics[i].key_orig,
+					"ZBX_NOTSUPPORTED",
+					&active_metrics[i].lastlogsize,
+					&active_metrics[i].mtime,
+					NULL,
+					NULL,
+					NULL,
+					NULL
+				);
+			}
+		}
+		/* special processing for eventlog */
+		else if(strncmp(active_metrics[i].key,"eventlog[",9) == 0)
+		{
+			ret = FAIL;
+
+#if defined(_WINDOWS)
+			do{ /* simple try realization */
+				if (parse_command(active_metrics[i].key, NULL, 0, params, MAX_STRING_LEN) != 2) {
+					ret = FAIL;
+					break;
+				}
+
+				if (num_param(params) > 6) {
+					ret = FAIL;
+					break;
+				}
+
+				if (get_param(params, 1, filename, sizeof(filename)) != 0) {
+					ret = FAIL;
+					break;
+				}
+
+				if (get_param(params, 2, pattern, sizeof(pattern)) != 0)
+					*pattern = '\0';
+
+				if (get_param(params, 3, key_severity, sizeof(key_severity)) != 0)
+					*key_severity = '\0';
+
+				if (get_param(params, 4, key_source, sizeof(key_source)) != 0)
+					*key_source = '\0';
+
+				if (get_param(params, 5, key_logeventid, sizeof(key_logeventid)) != 0)
+					*key_logeventid = '\0';
+
+				if (get_param(params, 6, maxlines_persec_str, sizeof(maxlines_persec_str)) != 0 ||
+						*maxlines_persec_str == '\0')
+					maxlines_persec = CONFIG_MAX_LINES_PER_SECOND;
+				else if ((maxlines_persec = atoi(maxlines_persec_str)) < MIN_VALUE_LINES ||
+						maxlines_persec > MAX_VALUE_LINES) {
+					ret = FAIL;
+					break;
+				}
+
+				s_count = 0;
+				p_count = 0;
+				lastlogsize = active_metrics[i].lastlogsize;
+				/* "mtime" parameter is not used by "eventlog" checks */
+
+				while (SUCCEED == (ret = process_eventlog(filename, &lastlogsize,
+					&timestamp, &source, &severity, &value, &logeventid)))
+				{
+					if (!value) /* EOF */
+					{
+						/*the eventlog could become empty, must save `lastlogsize'*/
+						active_metrics[i].lastlogsize = lastlogsize;
+						break;
+					}
+
+					switch ( severity )
+					{
+						case EVENTLOG_INFORMATION_TYPE:
+							severity = 1;
+							zbx_snprintf(str_severity, sizeof(str_severity), INFORMATION_TYPE);
+							break;
+						case EVENTLOG_WARNING_TYPE:
+							severity = 2;
+							zbx_snprintf(str_severity, sizeof(str_severity), WARNING_TYPE);
+							break;
+						case EVENTLOG_ERROR_TYPE:
+							severity = 4;
+							zbx_snprintf(str_severity, sizeof(str_severity), ERROR_TYPE);
+							break;
+						case EVENTLOG_AUDIT_FAILURE:
+							severity = 7;
+							zbx_snprintf(str_severity, sizeof(str_severity), AUDIT_FAILURE);
+							break;
+						case EVENTLOG_AUDIT_SUCCESS:
+							severity = 8;
+							zbx_snprintf(str_severity, sizeof(str_severity), AUDIT_SUCCESS);
+							break;
+					}
+
+					zbx_snprintf(str_logeventid, sizeof(str_logeventid), "%lu", logeventid);
+
+					if (SUCCEED == regexp_match_ex(regexps, regexps_num, value, pattern, ZBX_CASE_SENSITIVE) &&
+							SUCCEED == regexp_match_ex(regexps, regexps_num, str_severity,
+									key_severity, ZBX_IGNORE_CASE) &&
+							(('\0' == *key_source) ? 1 : (0 == strcmp(key_source, source))) &&
+							SUCCEED == regexp_match_ex(regexps, regexps_num, str_logeventid,
+									key_logeventid, ZBX_CASE_SENSITIVE))
+					{
+						send_err = process_value(
+									server,
+									port,
+									CONFIG_HOSTNAME,
+									active_metrics[i].key_orig,
+									value,
+									&lastlogsize,
+									NULL,/* "mtime" is not used */
 									&timestamp,
 									source,
-									&severity
+									&severity,
+									&logeventid
 								);
 						s_count++;
 					}
@@ -775,35 +1013,42 @@ static void	process_active_checks(char *server, unsigned short port)
 						lastlogsize = active_metrics[i].lastlogsize;
 
 					/* Do not flood ZABBIX server if file grows too fast */
-					if(s_count >= (MAX_LINES_PER_SECOND * active_metrics[i].refresh))	break;
+					if (s_count >= (maxlines_persec * active_metrics[i].refresh))
+						break;
 
 					/* Do not flood local system if file grows too fast */
-					if(p_count >= (4 * MAX_LINES_PER_SECOND * active_metrics[i].refresh))	break;
-				}
+					if (p_count >= (4 * maxlines_persec * active_metrics[i].refresh))
+						break;
+				} //while processing an eventlog
 
-				if( FAIL == ret )
-				{
-					active_metrics[i].status = ITEM_STATUS_NOTSUPPORTED;
-					zabbix_log( LOG_LEVEL_WARNING, "Active check [%s] is not supported. Disabled.",
-						active_metrics[i].key);
+				break;
 
-					send_err = process_value(
-								server,
-								port,
-								CONFIG_HOSTNAME,
-								active_metrics[i].key_orig,
-								"ZBX_NOTSUPPORTED",
-								&active_metrics[i].lastlogsize,
-								NULL,
-								NULL,
-								NULL
-							);
-				}
 			}while(0); /* simple try realization NOTE: never loop */
+#endif	/* if defined (_WINDOWS) */
+
+			if( FAIL == ret ) {
+				active_metrics[i].status = ITEM_STATUS_NOTSUPPORTED;
+				zabbix_log( LOG_LEVEL_WARNING, "Active check [%s] is not supported. Disabled.",
+					active_metrics[i].key);
+
+				send_err = process_value(
+					server,
+					port,
+					CONFIG_HOSTNAME,
+					active_metrics[i].key_orig,
+					"ZBX_NOTSUPPORTED",
+					&active_metrics[i].lastlogsize,
+					NULL,/* "mtime" is not used */
+					NULL,
+					NULL,
+					NULL,
+					NULL
+				);
+			}
 		}
 		else
 		{
-			
+
 			process(active_metrics[i].key, 0, &result);
 
 			if( NULL == (pvalue = GET_TEXT_RESULT(&result)) )
@@ -822,9 +1067,11 @@ static void	process_active_checks(char *server, unsigned short port)
 						NULL,
 						NULL,
 						NULL,
+						NULL,
+						NULL,
 						NULL
 					);
-				
+
 				if( 0 == strcmp(*pvalue,"ZBX_NOTSUPPORTED") )
 				{
 					active_metrics[i].status = ITEM_STATUS_NOTSUPPORTED;
@@ -849,9 +1096,9 @@ ZBX_THREAD_ENTRY(active_checks_thread, args)
 	char	*p = NULL;
 
 #if defined(ZABBIX_DAEMON)
-	phan.sa_handler = child_signal_handler;
+	phan.sa_sigaction = child_signal_handler;
 	sigemptyset(&phan.sa_mask);
-	phan.sa_flags = 0;
+	phan.sa_flags = SA_SIGINFO;
 	sigaction(SIGALRM, &phan, NULL);
 #endif /* ZABBIX_DAEMON */
 
@@ -859,7 +1106,7 @@ ZBX_THREAD_ENTRY(active_checks_thread, args)
 	activechk_args.port = ((ZBX_THREAD_ACTIVECHK_ARGS *)args)->port;
 
 	assert(activechk_args.host);
-	
+
 	p = strchr(activechk_args.host,',');
 	if(p) *p = '\0';
 
@@ -895,7 +1142,8 @@ ZBX_THREAD_ENTRY(active_checks_thread, args)
 
 			process_active_checks(activechk_args.host, activechk_args.port);
 			nextcheck = get_min_nextcheck();
-			if(FAIL == nextcheck)	nextcheck = (int)time(NULL) + 60;
+			if(FAIL == nextcheck)
+				nextcheck = (int)time(NULL) + 60;
 		}
 		else
 		{
@@ -915,4 +1163,3 @@ ZBX_THREAD_ENTRY(active_checks_thread, args)
 	zbx_tread_exit(0);
 
 }
-
