@@ -1,4 +1,4 @@
-/* 
+/*
 ** ZABBIX
 ** Copyright (C) 2000-2005 SIA Zabbix
 **
@@ -34,6 +34,7 @@
 #include "daemon.h"
 
 #include "../zabbix_server/dbsyncer/dbsyncer.h"
+#include "../zabbix_server/dbconfig/dbconfig.h"
 #include "../zabbix_server/discoverer/discoverer.h"
 #include "../zabbix_server/httppoller/httppoller.h"
 #include "housekeeper/housekeeper.h"
@@ -46,7 +47,7 @@
 #include "heart/heart.h"
 
 char *progname = NULL;
-char title_message[] = "ZABBIX Proxy (daemon)";
+char title_message[] = "Zabbix Proxy (daemon)";
 char usage_message[] = "[-hV] [-c <file>]";
 
 #ifndef HAVE_GETOPT_LONG
@@ -92,7 +93,7 @@ static struct zbx_option longopts[] =
 
 /* short options */
 
-static char	shortopts[] = 
+static char	shortopts[] =
 	"c:n:hV"
 #if defined (_WINDOWS)
 	"idsx"
@@ -105,7 +106,6 @@ pid_t	*threads=NULL;
 
 int	CONFIG_CONFSYNCER_FORKS		= 1;
 int	CONFIG_DATASENDER_FORKS		= 1;
-int	CONFIG_DBSYNCER_FORKS		= 0;
 int	CONFIG_DISCOVERER_FORKS		= 1;
 int	CONFIG_HOUSEKEEPER_FORKS	= 1;
 int	CONFIG_PINGER_FORKS		= 1;
@@ -133,8 +133,14 @@ int	CONFIG_PROXYCONFIG_FREQUENCY    = 3600; /* 1h */
 int	CONFIG_DATASENDER_FREQUENCY     = 1;
 
 int	CONFIG_SENDER_FREQUENCY		= 30;
+int	CONFIG_DBSYNCER_FORKS		= 1;
 int	CONFIG_DBSYNCER_FREQUENCY	= 5;
-int	CONFIG_PINGER_FREQUENCY		= 60;
+int	CONFIG_DBCONFIG_FORKS		= 1;
+int	CONFIG_DBCONFIG_FREQUENCY	= 60;
+int	CONFIG_DBCONFIG_SIZE		= 8388608;	/* 8MB */
+int	CONFIG_HISTORY_CACHE_SIZE	= 8388608;	/* 8MB */
+int	CONFIG_TRENDS_CACHE_SIZE	= 4194304;	/* 4MB */
+int	CONFIG_TEXT_CACHE_SIZE		= 16777216;	/* 16MB */
 int	CONFIG_UNREACHABLE_PERIOD	= 45;
 int	CONFIG_UNREACHABLE_DELAY	= 15;
 int	CONFIG_UNAVAILABLE_DELAY	= 60;
@@ -153,6 +159,7 @@ char	*CONFIG_DBPASSWORD		= NULL;
 char	*CONFIG_DBSOCKET		= NULL;
 int	CONFIG_DBPORT			= 0;
 int	CONFIG_ENABLE_REMOTE_COMMANDS	= 0;
+int	CONFIG_LOG_REMOTE_COMMANDS	= 0;
 
 char	*CONFIG_SERVER			= NULL;
 int	CONFIG_SERVER_PORT		= 10051;
@@ -161,12 +168,14 @@ int	CONFIG_NODEID			= -1;
 int	CONFIG_MASTER_NODEID		= 0;
 int	CONFIG_NODE_NOHISTORY		= 0;
 
+char	*CONFIG_SSH_KEY_LOCATION	= NULL;
+
 /* Global variable to control if we should write warnings to log[] */
 int	CONFIG_ENABLE_LOG		= 1;
 
 int	CONFIG_REFRESH_UNSUPPORTED	= 600;
 
-/* Zabbix server sturtup time */
+/* Zabbix server startup time */
 int     CONFIG_SERVER_STARTUP_TIME      = 0;
 
 /* Mutex for node syncs */
@@ -196,10 +205,9 @@ void	init_config(void)
 	{
 /*		 PARAMETER	,VAR	,FUNC,	TYPE(0i,1s),MANDATORY,MIN,MAX	*/
 		{"Server",&CONFIG_SERVER,0,TYPE_STRING,PARM_MAND,0,0},
-		{"ServerPort",&CONFIG_SERVER_PORT,0,TYPE_INT,PARM_OPT,1024,32768},
+		{"ServerPort",&CONFIG_SERVER_PORT,0,TYPE_INT,PARM_OPT,1024,32767},
 		{"Hostname",&CONFIG_HOSTNAME,0,TYPE_STRING,PARM_OPT,0,0},
 
-		{"StartDBSyncers",&CONFIG_DBSYNCER_FORKS,0,TYPE_INT,PARM_OPT,0,16},
 		{"StartDiscoverers",&CONFIG_DISCOVERER_FORKS,0,TYPE_INT,PARM_OPT,0,255},
 		{"StartHTTPPollers",&CONFIG_HTTPPOLLER_FORKS,0,TYPE_INT,PARM_OPT,0,255},
 		{"StartPingers",&CONFIG_PINGER_FORKS,0,TYPE_INT,PARM_OPT,0,255},
@@ -208,6 +216,12 @@ void	init_config(void)
 		{"StartPollersUnreachable",&CONFIG_UNREACHABLE_POLLER_FORKS,0,TYPE_INT,PARM_OPT,0,255},
 		{"StartTrappers",&CONFIG_TRAPPERD_FORKS,0,TYPE_INT,PARM_OPT,0,255},
 
+		{"CacheSize",&CONFIG_DBCONFIG_SIZE,0,TYPE_INT,PARM_OPT,128*1024,1024*1024*1024},
+		{"HistoryCacheSize",&CONFIG_HISTORY_CACHE_SIZE,0,TYPE_INT,PARM_OPT,128*1024,1024*1024*1024},
+		{"TrendCacheSize",&CONFIG_TRENDS_CACHE_SIZE,0,TYPE_INT,PARM_OPT,128*1024,1024*1024*1024},
+		{"HistoryTextCacheSize",&CONFIG_TEXT_CACHE_SIZE,0,TYPE_INT,PARM_OPT,128*1024,1024*1024*1024},
+		{"CacheUpdateFrequency",&CONFIG_DBCONFIG_FREQUENCY,0,TYPE_INT,PARM_OPT,1,3600},
+
 		{"HousekeepingFrequency",&CONFIG_HOUSEKEEPING_FREQUENCY,0,TYPE_INT,PARM_OPT,1,24},
 		{"ProxyLocalBuffer",&CONFIG_PROXY_LOCAL_BUFFER,0,TYPE_INT,PARM_OPT,0,720},
 		{"ProxyOfflineBuffer",&CONFIG_PROXY_OFFLINE_BUFFER,0,TYPE_INT,PARM_OPT,1,720},
@@ -217,7 +231,6 @@ void	init_config(void)
 		{"DataSenderFrequency",&CONFIG_DATASENDER_FREQUENCY,0,TYPE_INT,PARM_OPT,1,3600},
 
 /*		{"SenderFrequency",&CONFIG_SENDER_FREQUENCY,0,TYPE_INT,PARM_OPT,5,3600},*/
-		{"PingerFrequency",&CONFIG_PINGER_FREQUENCY,0,TYPE_INT,PARM_OPT,1,3600},
 		{"TmpDir",&CONFIG_TMPDIR,0,TYPE_STRING,PARM_OPT,0,0},
 		{"FpingLocation",&CONFIG_FPING_LOCATION,0,TYPE_STRING,PARM_OPT,0,0},
 #ifdef HAVE_IPV6
@@ -229,7 +242,7 @@ void	init_config(void)
 		{"UnreachableDelay",&CONFIG_UNREACHABLE_DELAY,0,TYPE_INT,PARM_OPT,1,3600},
 		{"UnavailableDelay",&CONFIG_UNAVAILABLE_DELAY,0,TYPE_INT,PARM_OPT,1,3600},
 		{"ListenIP",&CONFIG_LISTEN_IP,0,TYPE_STRING,PARM_OPT,0,0},
-		{"ListenPort",&CONFIG_LISTEN_PORT,0,TYPE_INT,PARM_OPT,1024,32768},
+		{"ListenPort",&CONFIG_LISTEN_PORT,0,TYPE_INT,PARM_OPT,1024,32767},
 		{"SourceIP",&CONFIG_SOURCE_IP,0,TYPE_STRING,PARM_OPT,0,0},
 /*		{"NoTimeWait",&CONFIG_NOTIMEWAIT,0,TYPE_INT,PARM_OPT,0,1},*/
 /*		{"DisablePinger",&CONFIG_DISABLE_PINGER,0,TYPE_INT,PARM_OPT,0,1},*/
@@ -245,6 +258,7 @@ void	init_config(void)
 		{"DBPassword",&CONFIG_DBPASSWORD,0,TYPE_STRING,PARM_OPT,0,0},
 		{"DBSocket",&CONFIG_DBSOCKET,0,TYPE_STRING,PARM_OPT,0,0},
 		{"DBPort",&CONFIG_DBPORT,0,TYPE_INT,PARM_OPT,1024,65535},
+		{"SSHKeyLocation",&CONFIG_SSH_KEY_LOCATION,0,TYPE_STRING,PARM_OPT,0,0},
 		{0}
 	};
 
@@ -276,7 +290,7 @@ void	init_config(void)
 	}
 	if(APP_PID_FILE == NULL)
 	{
-		APP_PID_FILE=strdup("/tmp/zabbix_server.pid");
+		APP_PID_FILE=strdup("/tmp/zabbix_proxy.pid");
 	}
 	if(CONFIG_ALERT_SCRIPTS_PATH == NULL)
 	{
@@ -303,9 +317,6 @@ void	init_config(void)
 #ifndef	HAVE_LIBCURL
 	CONFIG_HTTPPOLLER_FORKS = 0;
 #endif
-#ifndef	HAVE_OPENIPMI
-	CONFIG_IPMIPOLLER_FORKS = 0;
-#endif
 }
 
 /******************************************************************************
@@ -389,6 +400,11 @@ int MAIN_ZABBIX_ENTRY(void)
 #else
 #	define SNMP_FEATURE_STATUS " NO"
 #endif
+#ifdef	HAVE_OPENIPMI
+#	define IPMI_FEATURE_STATUS "YES"
+#else
+#	define IPMI_FEATURE_STATUS " NO"
+#endif
 #ifdef  HAVE_LIBCURL
 #	define LIBCURL_FEATURE_STATUS "YES"
 #else
@@ -399,20 +415,27 @@ int MAIN_ZABBIX_ENTRY(void)
 #else
 #	define ODBC_FEATURE_STATUS " NO"
 #endif
+#ifdef	HAVE_SSH2
+#	define SSH2_FEATURE_STATUS "YES"
+#else
+#	define SSH2_FEATURE_STATUS " NO"
+#endif
 #ifdef  HAVE_IPV6
 #       define IPV6_FEATURE_STATUS "YES"
 #else
 #       define IPV6_FEATURE_STATUS " NO"
 #endif
 
-	zabbix_log( LOG_LEVEL_WARNING, "Starting zabbix_proxy. ZABBIX %s (revision %s).",
+	zabbix_log( LOG_LEVEL_WARNING, "Starting zabbix_proxy. Zabbix %s (revision %s).",
 			ZABBIX_VERSION,
 			ZABBIX_REVISION);
 
 	zabbix_log( LOG_LEVEL_WARNING, "**** Enabled features ****");
 	zabbix_log( LOG_LEVEL_WARNING, "SNMP monitoring:       " SNMP_FEATURE_STATUS	);
+	zabbix_log( LOG_LEVEL_WARNING, "IPMI monitoring:       " IPMI_FEATURE_STATUS	);
 	zabbix_log( LOG_LEVEL_WARNING, "WEB monitoring:        " LIBCURL_FEATURE_STATUS	);
 	zabbix_log( LOG_LEVEL_WARNING, "ODBC:                  " ODBC_FEATURE_STATUS	);
+	zabbix_log( LOG_LEVEL_WARNING, "SSH2 support:          " SSH2_FEATURE_STATUS	);
 	zabbix_log( LOG_LEVEL_WARNING, "IPv6 support:          " IPV6_FEATURE_STATUS	);
 	zabbix_log( LOG_LEVEL_WARNING, "**************************");
 
@@ -427,11 +450,13 @@ int MAIN_ZABBIX_ENTRY(void)
 	DBinit();
 
 	init_database_cache(ZBX_PROCESS_PROXY);
+	init_configuration_cache();
 
-	threads = calloc(1 + CONFIG_CONFSYNCER_FORKS + CONFIG_DATASENDER_FORKS + CONFIG_POLLER_FORKS
-			+ CONFIG_TRAPPERD_FORKS + CONFIG_PINGER_FORKS + CONFIG_HOUSEKEEPER_FORKS
-			+ CONFIG_UNREACHABLE_POLLER_FORKS + CONFIG_HTTPPOLLER_FORKS + CONFIG_DISCOVERER_FORKS
-			+ CONFIG_DBSYNCER_FORKS + CONFIG_IPMIPOLLER_FORKS, sizeof(pid_t));
+	threads = calloc(1 + CONFIG_DBCONFIG_FORKS + CONFIG_CONFSYNCER_FORKS + CONFIG_DATASENDER_FORKS
+			+ CONFIG_POLLER_FORKS + CONFIG_TRAPPERD_FORKS + CONFIG_PINGER_FORKS
+			+ CONFIG_HOUSEKEEPER_FORKS + CONFIG_UNREACHABLE_POLLER_FORKS
+			+ CONFIG_HTTPPOLLER_FORKS + CONFIG_DISCOVERER_FORKS + CONFIG_DBSYNCER_FORKS
+			+ CONFIG_IPMIPOLLER_FORKS, sizeof(pid_t));
 
 	if (CONFIG_TRAPPERD_FORKS > 0) {
 		if (FAIL == zbx_tcp_listen(&listen_sock, CONFIG_LISTEN_IP, (unsigned short)CONFIG_LISTEN_PORT)) {
@@ -440,16 +465,16 @@ int MAIN_ZABBIX_ENTRY(void)
 		}
 	}
 
-	for (	i = 1;
-		i <= CONFIG_CONFSYNCER_FORKS + CONFIG_DATASENDER_FORKS + CONFIG_POLLER_FORKS
-			+ CONFIG_TRAPPERD_FORKS + CONFIG_PINGER_FORKS + CONFIG_HOUSEKEEPER_FORKS
-			+ CONFIG_UNREACHABLE_POLLER_FORKS + CONFIG_HTTPPOLLER_FORKS + CONFIG_DISCOVERER_FORKS
-			+ CONFIG_DBSYNCER_FORKS + CONFIG_IPMIPOLLER_FORKS; 
+	for (i = 1; i <= CONFIG_DBCONFIG_FORKS + CONFIG_CONFSYNCER_FORKS + CONFIG_DATASENDER_FORKS
+			+ CONFIG_POLLER_FORKS + CONFIG_TRAPPERD_FORKS + CONFIG_PINGER_FORKS
+			+ CONFIG_HOUSEKEEPER_FORKS + CONFIG_UNREACHABLE_POLLER_FORKS
+			+ CONFIG_HTTPPOLLER_FORKS + CONFIG_DISCOVERER_FORKS + CONFIG_DBSYNCER_FORKS
+			+ CONFIG_IPMIPOLLER_FORKS;
 		i++)
 	{
 		if ((pid = zbx_fork()) == 0) {
 			server_num = i;
-			break; 
+			break;
 		} else
 			threads[i] = pid;
 	}
@@ -462,26 +487,33 @@ int MAIN_ZABBIX_ENTRY(void)
 				server_num);
 
 		main_heart_loop();
-		
+
 		for (;;)
 			zbx_sleep(3600);
 	}
+	else if (server_num <= CONFIG_DBCONFIG_FORKS)
+	{
+		zabbix_log(LOG_LEVEL_WARNING, "server #%d started [DB Cache]",
+				server_num);
 
-	if (server_num <= CONFIG_CONFSYNCER_FORKS)
+		main_dbconfig_loop();
+	}
+	else if (server_num <= CONFIG_DBCONFIG_FORKS + CONFIG_CONFSYNCER_FORKS)
 	{
 		zabbix_log(LOG_LEVEL_WARNING, "server #%d started [Configuration syncer]",
 				server_num);
 
-		main_proxyconfig_loop(server_num);
+		main_proxyconfig_loop(server_num - CONFIG_DBCONFIG_FORKS);
 	}
-	else if (server_num <= CONFIG_CONFSYNCER_FORKS + CONFIG_DATASENDER_FORKS)
+	else if (server_num <= CONFIG_DBCONFIG_FORKS + CONFIG_CONFSYNCER_FORKS + CONFIG_DATASENDER_FORKS)
 	{
 		zabbix_log(LOG_LEVEL_WARNING, "server #%d started [Datasender]",
 				server_num);
 
 		main_datasender_loop();
 	}
-	else if (server_num <= CONFIG_CONFSYNCER_FORKS + CONFIG_DATASENDER_FORKS + CONFIG_POLLER_FORKS)
+	else if (server_num <= CONFIG_DBCONFIG_FORKS + CONFIG_CONFSYNCER_FORKS + CONFIG_DATASENDER_FORKS
+			+ CONFIG_POLLER_FORKS)
 	{
 #ifdef HAVE_SNMP
 		init_snmp("zabbix_server");
@@ -490,37 +522,39 @@ int MAIN_ZABBIX_ENTRY(void)
 		zabbix_log(LOG_LEVEL_WARNING, "server #%d started [Poller. SNMP:"SNMP_FEATURE_STATUS"]",
 				server_num);
 
-		main_poller_loop(ZBX_PROCESS_PROXY, ZBX_POLLER_TYPE_NORMAL, server_num - (CONFIG_CONFSYNCER_FORKS
-				+ CONFIG_DATASENDER_FORKS));
+		main_poller_loop(ZBX_PROCESS_PROXY, ZBX_POLLER_TYPE_NORMAL, server_num
+				- CONFIG_DBCONFIG_FORKS - CONFIG_CONFSYNCER_FORKS
+				- CONFIG_DATASENDER_FORKS);
 	}
-	else if (server_num <= CONFIG_CONFSYNCER_FORKS + CONFIG_DATASENDER_FORKS + CONFIG_POLLER_FORKS
-			+ CONFIG_TRAPPERD_FORKS)
+	else if (server_num <= CONFIG_DBCONFIG_FORKS + CONFIG_CONFSYNCER_FORKS + CONFIG_DATASENDER_FORKS
+			+ CONFIG_POLLER_FORKS + CONFIG_TRAPPERD_FORKS)
 	{
 		zabbix_log(LOG_LEVEL_WARNING, "server #%d started [Trapper]",
 				server_num);
 
 		child_trapper_main(ZBX_PROCESS_PROXY, &listen_sock);
 	}
-	else if(server_num <= CONFIG_CONFSYNCER_FORKS + CONFIG_DATASENDER_FORKS + CONFIG_POLLER_FORKS
-			+ CONFIG_TRAPPERD_FORKS + CONFIG_PINGER_FORKS)
+	else if (server_num <= CONFIG_DBCONFIG_FORKS + CONFIG_CONFSYNCER_FORKS + CONFIG_DATASENDER_FORKS
+			+ CONFIG_POLLER_FORKS + CONFIG_TRAPPERD_FORKS + CONFIG_PINGER_FORKS)
 	{
 		zabbix_log(LOG_LEVEL_WARNING, "server #%d started [ICMP pinger]",
 				server_num);
 
-		main_pinger_loop(ZBX_PROCESS_PROXY, server_num - (CONFIG_CONFSYNCER_FORKS + CONFIG_DATASENDER_FORKS
-				+ CONFIG_POLLER_FORKS + CONFIG_TRAPPERD_FORKS));
+		main_pinger_loop(server_num - CONFIG_DBCONFIG_FORKS - CONFIG_CONFSYNCER_FORKS
+				- CONFIG_DATASENDER_FORKS - CONFIG_POLLER_FORKS - CONFIG_TRAPPERD_FORKS);
 	}
-	else if(server_num <= CONFIG_CONFSYNCER_FORKS + CONFIG_DATASENDER_FORKS + CONFIG_POLLER_FORKS
-			+ CONFIG_TRAPPERD_FORKS + CONFIG_PINGER_FORKS + CONFIG_HOUSEKEEPER_FORKS)
+	else if (server_num <= CONFIG_DBCONFIG_FORKS + CONFIG_CONFSYNCER_FORKS + CONFIG_DATASENDER_FORKS
+			+ CONFIG_POLLER_FORKS + CONFIG_TRAPPERD_FORKS + CONFIG_PINGER_FORKS
+			+ CONFIG_HOUSEKEEPER_FORKS)
 	{
 		zabbix_log(LOG_LEVEL_WARNING, "server #%d started [Housekeeper]",
 				server_num);
 
 		main_housekeeper_loop();
 	}
-	else if(server_num <= CONFIG_CONFSYNCER_FORKS + CONFIG_DATASENDER_FORKS + CONFIG_POLLER_FORKS
-			+ CONFIG_TRAPPERD_FORKS + CONFIG_PINGER_FORKS + CONFIG_HOUSEKEEPER_FORKS
-			+ CONFIG_UNREACHABLE_POLLER_FORKS)
+	else if (server_num <= CONFIG_DBCONFIG_FORKS + CONFIG_CONFSYNCER_FORKS + CONFIG_DATASENDER_FORKS
+			+ CONFIG_POLLER_FORKS + CONFIG_TRAPPERD_FORKS + CONFIG_PINGER_FORKS
+			+ CONFIG_HOUSEKEEPER_FORKS + CONFIG_UNREACHABLE_POLLER_FORKS)
 	{
 #ifdef HAVE_SNMP
 		init_snmp("zabbix_server");
@@ -530,24 +564,28 @@ int MAIN_ZABBIX_ENTRY(void)
 				server_num);
 
 		main_poller_loop(ZBX_PROCESS_PROXY, ZBX_POLLER_TYPE_UNREACHABLE, server_num
-				- (CONFIG_CONFSYNCER_FORKS + CONFIG_DATASENDER_FORKS + CONFIG_POLLER_FORKS
-				+ CONFIG_TRAPPERD_FORKS + CONFIG_PINGER_FORKS + CONFIG_HOUSEKEEPER_FORKS));
+				- CONFIG_DBCONFIG_FORKS - CONFIG_CONFSYNCER_FORKS
+				- CONFIG_DATASENDER_FORKS - CONFIG_POLLER_FORKS
+				- CONFIG_TRAPPERD_FORKS - CONFIG_PINGER_FORKS
+				- CONFIG_HOUSEKEEPER_FORKS);
 	}
-	else if (server_num <= CONFIG_CONFSYNCER_FORKS + CONFIG_DATASENDER_FORKS + CONFIG_POLLER_FORKS
-			+ CONFIG_TRAPPERD_FORKS + CONFIG_PINGER_FORKS + CONFIG_HOUSEKEEPER_FORKS
-			+ CONFIG_UNREACHABLE_POLLER_FORKS + CONFIG_HTTPPOLLER_FORKS)
+	else if (server_num <= CONFIG_DBCONFIG_FORKS + CONFIG_CONFSYNCER_FORKS + CONFIG_DATASENDER_FORKS
+			+ CONFIG_POLLER_FORKS + CONFIG_TRAPPERD_FORKS + CONFIG_PINGER_FORKS
+			+ CONFIG_HOUSEKEEPER_FORKS + CONFIG_UNREACHABLE_POLLER_FORKS
+			+ CONFIG_HTTPPOLLER_FORKS)
 	{
 		zabbix_log(LOG_LEVEL_WARNING, "server #%d started [HTTP Poller]",
 				server_num);
 
-		main_httppoller_loop(ZBX_PROCESS_PROXY, server_num - (CONFIG_CONFSYNCER_FORKS
-				+ CONFIG_DATASENDER_FORKS + CONFIG_POLLER_FORKS + CONFIG_TRAPPERD_FORKS
-				+ CONFIG_PINGER_FORKS + CONFIG_HOUSEKEEPER_FORKS
-				+ CONFIG_UNREACHABLE_POLLER_FORKS));
+		main_httppoller_loop(server_num - CONFIG_DBCONFIG_FORKS - CONFIG_CONFSYNCER_FORKS
+				- CONFIG_DATASENDER_FORKS - CONFIG_POLLER_FORKS - CONFIG_TRAPPERD_FORKS
+				- CONFIG_PINGER_FORKS - CONFIG_HOUSEKEEPER_FORKS
+				- CONFIG_UNREACHABLE_POLLER_FORKS);
 	}
-	else if (server_num <= CONFIG_CONFSYNCER_FORKS + CONFIG_DATASENDER_FORKS + CONFIG_POLLER_FORKS
-			+ CONFIG_TRAPPERD_FORKS + CONFIG_PINGER_FORKS + CONFIG_HOUSEKEEPER_FORKS
-			+ CONFIG_UNREACHABLE_POLLER_FORKS + CONFIG_HTTPPOLLER_FORKS + CONFIG_DISCOVERER_FORKS)
+	else if (server_num <= CONFIG_DBCONFIG_FORKS + CONFIG_CONFSYNCER_FORKS + CONFIG_DATASENDER_FORKS
+			+ CONFIG_POLLER_FORKS + CONFIG_TRAPPERD_FORKS + CONFIG_PINGER_FORKS
+			+ CONFIG_HOUSEKEEPER_FORKS + CONFIG_UNREACHABLE_POLLER_FORKS
+			+ CONFIG_HTTPPOLLER_FORKS + CONFIG_DISCOVERER_FORKS)
 	{
 #ifdef HAVE_SNMP
 		init_snmp("zabbix_server");
@@ -556,34 +594,37 @@ int MAIN_ZABBIX_ENTRY(void)
 		zabbix_log(LOG_LEVEL_WARNING, "server #%d started [Discoverer. SNMP:"SNMP_FEATURE_STATUS"]",
 				server_num);
 
-		main_discoverer_loop(ZBX_PROCESS_PROXY, server_num - (CONFIG_CONFSYNCER_FORKS
-				+ CONFIG_DATASENDER_FORKS + CONFIG_POLLER_FORKS + CONFIG_TRAPPERD_FORKS
-				+ CONFIG_PINGER_FORKS + CONFIG_HOUSEKEEPER_FORKS + CONFIG_UNREACHABLE_POLLER_FORKS
-				+ CONFIG_HTTPPOLLER_FORKS));
+		main_discoverer_loop(ZBX_PROCESS_PROXY, server_num - CONFIG_DBCONFIG_FORKS
+				- CONFIG_CONFSYNCER_FORKS - CONFIG_DATASENDER_FORKS - CONFIG_POLLER_FORKS
+				- CONFIG_TRAPPERD_FORKS - CONFIG_PINGER_FORKS - CONFIG_HOUSEKEEPER_FORKS
+				- CONFIG_UNREACHABLE_POLLER_FORKS - CONFIG_HTTPPOLLER_FORKS);
 	}
-	else if (server_num <= CONFIG_CONFSYNCER_FORKS + CONFIG_DATASENDER_FORKS + CONFIG_POLLER_FORKS
-			+ CONFIG_TRAPPERD_FORKS + CONFIG_PINGER_FORKS + CONFIG_HOUSEKEEPER_FORKS
-			+ CONFIG_UNREACHABLE_POLLER_FORKS + CONFIG_HTTPPOLLER_FORKS + CONFIG_DISCOVERER_FORKS
-			+ CONFIG_DBSYNCER_FORKS)
+	else if (server_num <= CONFIG_DBCONFIG_FORKS + CONFIG_CONFSYNCER_FORKS + CONFIG_DATASENDER_FORKS
+			+ CONFIG_POLLER_FORKS + CONFIG_TRAPPERD_FORKS + CONFIG_PINGER_FORKS
+			+ CONFIG_HOUSEKEEPER_FORKS + CONFIG_UNREACHABLE_POLLER_FORKS
+			+ CONFIG_HTTPPOLLER_FORKS + CONFIG_DISCOVERER_FORKS + CONFIG_DBSYNCER_FORKS)
 	{
 		zabbix_log(LOG_LEVEL_WARNING, "server #%d started [DB Syncer]",
 				server_num);
 
 		main_dbsyncer_loop();
 	}
-	else if (server_num <= CONFIG_CONFSYNCER_FORKS + CONFIG_DATASENDER_FORKS + CONFIG_POLLER_FORKS
-			+ CONFIG_TRAPPERD_FORKS + CONFIG_PINGER_FORKS + CONFIG_HOUSEKEEPER_FORKS
-			+ CONFIG_UNREACHABLE_POLLER_FORKS + CONFIG_HTTPPOLLER_FORKS + CONFIG_DISCOVERER_FORKS
-			+ CONFIG_DBSYNCER_FORKS + CONFIG_IPMIPOLLER_FORKS)
+	else if (server_num <= CONFIG_DBCONFIG_FORKS + CONFIG_CONFSYNCER_FORKS + CONFIG_DATASENDER_FORKS
+			+ CONFIG_POLLER_FORKS + CONFIG_TRAPPERD_FORKS + CONFIG_PINGER_FORKS
+			+ CONFIG_HOUSEKEEPER_FORKS + CONFIG_UNREACHABLE_POLLER_FORKS
+			+ CONFIG_HTTPPOLLER_FORKS + CONFIG_DISCOVERER_FORKS + CONFIG_DBSYNCER_FORKS
+			+ CONFIG_IPMIPOLLER_FORKS)
 	{
 		zabbix_log(LOG_LEVEL_WARNING, "server #%d started [IPMI Poller]",
 				server_num);
 
 		main_poller_loop(ZBX_PROCESS_PROXY, ZBX_POLLER_TYPE_IPMI, server_num
-				- (CONFIG_CONFSYNCER_FORKS + CONFIG_DATASENDER_FORKS + CONFIG_POLLER_FORKS
-				+ CONFIG_TRAPPERD_FORKS + CONFIG_PINGER_FORKS + CONFIG_HOUSEKEEPER_FORKS
-				+ CONFIG_UNREACHABLE_POLLER_FORKS + CONFIG_HTTPPOLLER_FORKS + CONFIG_DISCOVERER_FORKS
-				+ CONFIG_DBSYNCER_FORKS));
+				- CONFIG_DBCONFIG_FORKS - CONFIG_CONFSYNCER_FORKS
+				- CONFIG_DATASENDER_FORKS - CONFIG_POLLER_FORKS
+				- CONFIG_TRAPPERD_FORKS - CONFIG_PINGER_FORKS
+				- CONFIG_HOUSEKEEPER_FORKS - CONFIG_UNREACHABLE_POLLER_FORKS
+				- CONFIG_HTTPPOLLER_FORKS - CONFIG_DISCOVERER_FORKS
+				- CONFIG_DBSYNCER_FORKS);
 	}
 
 	return SUCCEED;
@@ -593,24 +634,24 @@ void	zbx_on_exit()
 {
 	zabbix_log(LOG_LEVEL_INFORMATION, "zbx_on_exit()");
 #if !defined(_WINDOWS)
-	
+
 	int i = 0;
 
 	if (threads != NULL) {
-		for (	i = 1;
-			i <= CONFIG_CONFSYNCER_FORKS + CONFIG_DATASENDER_FORKS + CONFIG_POLLER_FORKS
-				+ CONFIG_TRAPPERD_FORKS + CONFIG_PINGER_FORKS + CONFIG_HOUSEKEEPER_FORKS
-				+ CONFIG_UNREACHABLE_POLLER_FORKS + CONFIG_HTTPPOLLER_FORKS
-				+ CONFIG_DISCOVERER_FORKS + CONFIG_DBSYNCER_FORKS + CONFIG_IPMIPOLLER_FORKS; i ++)
+		for (i = 1; i <= CONFIG_DBCONFIG_FORKS + CONFIG_CONFSYNCER_FORKS + CONFIG_DATASENDER_FORKS
+				+ CONFIG_POLLER_FORKS + CONFIG_TRAPPERD_FORKS + CONFIG_PINGER_FORKS
+				+ CONFIG_HOUSEKEEPER_FORKS + CONFIG_UNREACHABLE_POLLER_FORKS
+				+ CONFIG_HTTPPOLLER_FORKS + CONFIG_DISCOVERER_FORKS
+				+ CONFIG_DBSYNCER_FORKS + CONFIG_IPMIPOLLER_FORKS; i++)
 		{
 			if (threads[i]) {
 				kill(threads[i], SIGTERM);
-				threads[i] = (ZBX_THREAD_HANDLE)0;
+				threads[i] = (ZBX_THREAD_HANDLE)NULL;
 			}
 		}
 		zbx_free(threads);
 	}
-	
+
 #endif /* not _WINDOWS */
 
 #ifdef USE_PID_FILE
@@ -625,6 +666,7 @@ void	zbx_on_exit()
 
 	DBconnect(ZBX_DB_CONNECT_EXIT);
 	free_database_cache();
+	free_configuration_cache();
 	DBclose();
 /*	zbx_mutex_destroy(&node_sync_access);*/
 
@@ -633,15 +675,14 @@ void	zbx_on_exit()
 #endif
 
 	zabbix_close_log();
-	
+
 #ifdef  HAVE_SQLITE3
 	php_sem_remove(&sqlite_access);
 #endif /* HAVE_SQLITE3 */
 
-	zabbix_log(LOG_LEVEL_INFORMATION, "ZABBIX Proxy stopped. ZABBIX %s (revision %s).",
+	zabbix_log(LOG_LEVEL_INFORMATION, "Zabbix Proxy stopped. Zabbix %s (revision %s).",
 		ZABBIX_VERSION,
 		ZABBIX_REVISION);
 
 	exit(SUCCEED);
 }
-
