@@ -1,4 +1,4 @@
-/* 
+/*
 ** ZABBIX
 ** Copyright (C) 2000-2006 SIA Zabbix
 **
@@ -36,8 +36,8 @@
  *                                                                            *
  * Parameters:                                                                *
  *                                                                            *
- * Return value: SUCCESS - processed succesfully                              * 
- *               FAIL - an error occured                                      *
+ * Return value: SUCCESS - processed successfully                             *
+ *               FAIL - an error occurred                                     *
  *                                                                            *
  * Author: Aleksander Vladishev                                               *
  *                                                                            *
@@ -79,10 +79,13 @@ static int	process_proxyconfig_table(struct zbx_json_parse *jp, const char *tabl
 
 	result = DBselect("select %s from %s", table->recid, table->table);
 	while (NULL != (row = DBfetch(result)))
-		uint64_array_add(&old, &old_alloc, &old_num, zbx_atoui64(row[0]));
+	{
+		ZBX_STR2UINT64(recid, row[0]);
+		uint64_array_add(&old, &old_alloc, &old_num, recid, 64);
+	}
 	DBfree_result(result);
 
-/* {"hosts":{"fields":["hostid","host",...],"data":[[1,"zbx01",...],[2,"zbx02",...],...]},"items":{...},...} 
+/* {"hosts":{"fields":["hostid","host",...],"data":[[1,"zbx01",...],[2,"zbx02",...],...]},"items":{...},...}
  *                    ^-------------------^
  */	if (FAIL == zbx_json_brackets_by_name(jp_obj, "fields", &jp_data))
 		goto json_error;
@@ -111,7 +114,7 @@ static int	process_proxyconfig_table(struct zbx_json_parse *jp, const char *tabl
 		field_count++;
 	}
 
-/* {"hosts":{"fields":["hostid","host",...],"data":[[1,"zbx01",...],[2,"zbx02",...],...]},"items":{...},...} 
+/* {"hosts":{"fields":["hostid","host",...],"data":[[1,"zbx01",...],[2,"zbx02",...],...]},"items":{...},...}
  *                                                 ^-----------------------------------^
  */	if (FAIL == zbx_json_brackets_by_name(jp_obj, "data", &jp_data))
 		goto json_error;
@@ -135,11 +138,11 @@ static int	process_proxyconfig_table(struct zbx_json_parse *jp, const char *tabl
 	zbx_snprintf_alloc(&sql, &sql_alloc, &sql_offset, 8, "begin\n");
 #endif
 
-/* {"hosts":{"fields":["hostid","host",...],"data":[[1,"zbx01",...],[2,"zbx02",...],...]},"items":{...},...} 
+/* {"hosts":{"fields":["hostid","host",...],"data":[[1,"zbx01",...],[2,"zbx02",...],...]},"items":{...},...}
  *                                                  ^
  */	while (NULL != (p = zbx_json_next(&jp_data, p)))
 	{
-/* {"hosts":{"fields":["hostid","host",...],"data":[[1,"zbx01",...],[2,"zbx02",...],...]},"items":{...},...} 
+/* {"hosts":{"fields":["hostid","host",...],"data":[[1,"zbx01",...],[2,"zbx02",...],...]},"items":{...},...}
  *                                                  ^-------------^
  */		if (FAIL == zbx_json_brackets_open(p, &jp_row))
 			goto json_error;
@@ -148,7 +151,7 @@ static int	process_proxyconfig_table(struct zbx_json_parse *jp, const char *tabl
 		if (NULL == (pf = zbx_json_next_value(&jp_row, pf, buf, sizeof(buf))))
 			goto json_error;
 
-		recid = zbx_atoui64(buf);
+		ZBX_STR2UINT64(recid, buf);
 
 		insert = (SUCCEED == uint64_array_exists(old, old_num, recid)) ? 0 : 1;
 
@@ -167,7 +170,7 @@ static int	process_proxyconfig_table(struct zbx_json_parse *jp, const char *tabl
 			zbx_snprintf_alloc(&sql, &sql_alloc, &sql_offset, 128, "update %s set ",
 					table->table);
 
-/* {"hosts":{"fields":["hostid","host",...],"data":[[1,"zbx01",...],[2,"zbx02",...],...]},"items":{...},...} 
+/* {"hosts":{"fields":["hostid","host",...],"data":[[1,"zbx01",...],[2,"zbx02",...],...]},"items":{...},...}
  *                                                   ^
  */		f = 1;
 		while (NULL != (pf = zbx_json_next_value(&jp_row, pf, buf, sizeof(buf))))
@@ -230,7 +233,7 @@ static int	process_proxyconfig_table(struct zbx_json_parse *jp, const char *tabl
 #endif
 		}
 
-		uint64_array_add(&new, &new_alloc, &new_num, recid);
+		uint64_array_add(&new, &new_alloc, &new_num, recid, 64);
 	}
 
 #ifdef HAVE_ORACLE
@@ -281,8 +284,8 @@ db_error:
  *                                                                            *
  * Parameters:                                                                *
  *                                                                            *
- * Return value: SUCCESS - processed succesfully                              * 
- *               FAIL - an error occured                                      *
+ * Return value: SUCCESS - processed successfully                             *
+ *               FAIL - an error occurred                                     *
  *                                                                            *
  * Author: Aleksander Vladishev                                               *
  *                                                                            *
@@ -301,11 +304,11 @@ static void	process_proxyconfig(struct zbx_json_parse *jp)
 
 	DBbegin();
 /*
- * {"hosts":{"fields":["hostid","host",...],"data":[[1,"zbx01",...],[2,"zbx02",...],...]},"items":{...},...} 
+ * {"hosts":{"fields":["hostid","host",...],"data":[[1,"zbx01",...],[2,"zbx02",...],...]},"items":{...},...}
  *          ^
  */	while (NULL != (p = zbx_json_pair_next(jp, p, buf, len)) && res == SUCCEED)
 	{
-/* {"items":{"fields":["itemid","hostid",...],"data":[[1,1,...],[2,1,...],...]},...} 
+/* {"items":{"fields":["itemid","hostid",...],"data":[[1,1,...],[2,1,...],...]},...}
  *          ^-----------------------------------------------------------------^
  */		if (FAIL == zbx_json_brackets_open(p, &jp_obj))
 		{
@@ -328,11 +331,11 @@ static void	process_proxyconfig(struct zbx_json_parse *jp)
  *                                                                            *
  * Function: process_configuration_sync                                       *
  *                                                                            *
- * Purpose: calculates checks sum of config data                              *
+ * Purpose: calculates checksum of config data                                *
  *                                                                            *
  * Parameters:                                                                *
  *                                                                            *
- * Return value:                                                              * 
+ * Return value:                                                              *
  *                                                                            *
  * Author: Aleksander Vladishev                                               *
  *                                                                            *
@@ -344,7 +347,7 @@ static void	process_configuration_sync()
 	zbx_sock_t	sock;
 	char		*data;
 	struct		zbx_json_parse jp;
-	
+
 	zabbix_log(LOG_LEVEL_DEBUG, "In process_configuration_sync()");
 
 	while (FAIL == connect_to_server(&sock, 600)) { /* alarm */
@@ -373,7 +376,7 @@ exit:
  *                                                                            *
  * Parameters:                                                                *
  *                                                                            *
- * Return value:                                                              * 
+ * Return value:                                                              *
  *                                                                            *
  * Author: Aleksander Vladishev                                               *
  *                                                                            *
@@ -386,9 +389,10 @@ void	main_proxyconfig_loop()
 
 	zabbix_log(LOG_LEVEL_DEBUG, "In main_proxyconfig_loop()");
 
-	phan.sa_handler = child_signal_handler;
+/*	phan.sa_handler = child_signal_handler;*/
+	phan.sa_sigaction = child_signal_handler;
 	sigemptyset(&phan.sa_mask);
-	phan.sa_flags = 0;
+	phan.sa_flags = SA_SIGINFO;
 	sigaction(SIGALRM, &phan, NULL);
 
 	for (;;) {
