@@ -1,4 +1,4 @@
-/* 
+/*
 ** ZABBIX
 ** Copyright (C) 2000-2005 SIA Zabbix
 **
@@ -28,16 +28,16 @@
 
 char *progname = NULL;
 
-char title_message[] = "ZABBIX send";
+char title_message[] = "Zabbix Sender";
 
-char usage_message[] = "[-Vhv] {[-zpsI] -ko | [-zpI] -i <file>} [-c <file>]";
+char usage_message[] = "[-Vhv] {[-zpsI] -ko | [-zpI] -T -i <file>} [-c <file>]";
 
 #ifdef HAVE_GETOPT_LONG
 char *help_message[] = {
 	"Options:",
 	"  -c --config <File>                   Specify configuration file",
 	"",
-	"  -z --zabbix-server <Server>          Hostname or IP address of ZABBIX Server",
+	"  -z --zabbix-server <Server>          Hostname or IP address of Zabbix Server",
 	"  -p --port <Server port>              Specify port number of server trapper running on the server. Default is 10051",
 	"  -s --host <Hostname>                 Specify host name. Host IP address and DNS name will not work.",
 	"  -I --source-address <ip address>     Specify source IP address",
@@ -47,20 +47,22 @@ char *help_message[] = {
 	"",
 	"  -i --input-file <input_file>         Load values from input file",
 	"                                       Each line of file contains space delimited: <hostname> <key> <value>",
+	"  -T --with-timestamps                 Each line of file contains space delimited: <hostname> <key> <timestamp> <value>",
+	"                                       This can be used with --input-file option",
 	"",
 	"  -v --verbose                         Verbose mode, -vv for more details",
 	"",
 	" Other options:",
 	"  -h --help                            Give this help",
 	"  -V --version                         Display version number",
-        0 /* end of text */
+	0 /* end of text */
 };
 #else
 char *help_message[] = {
 	"Options:",
 	"  -c <File>                    Specify configuration file",
 	"",
-	"  -z <Server>                  Hostname or IP address of ZABBIX Server.",
+	"  -z <Server>                  Hostname or IP address of Zabbix Server.",
 	"  -p <Server port>             Specify port number of server trapper running on the server. Default is 10051.",
 	"  -s <Hostname>                Specify hostname or IP address of a host.",
 	"  -I <ip address>              Specify source IP address",
@@ -69,14 +71,16 @@ char *help_message[] = {
 	"  -o <Key value>               Specify value of the key.",
 	"",
 	"  -i <Input file>              Load values from input file.",
-	"                               Each line of file contains: <zabbix_server> <hostname> <port> <key> <value>.",
+	"                               Each line of file contains space delimited: <hostname> <key> <value>.",
+	"  -T                           Each line of file contains space delimited: <hostname> <key> <timestamp> <value>",
+	"                               This can be used with -i option",
 	"",
 	"  -v                           Verbose mode",
 	"",
 	" Other options:",
 	"  -h                           Give this help.",
 	"  -V                           Display version number.",
-        0 /* end of text */
+	0 /* end of text */
 };
 #endif
 
@@ -94,21 +98,23 @@ static struct zbx_option longopts[] =
 	{"key",			1,	NULL,	'k'},
 	{"value",		1,	NULL,	'o'},
 	{"input-file",		1,	NULL,	'i'},
-	{"verbose",        	0,      NULL,	'v'},
-	{"help",        	0,      NULL,	'h'},
-	{"version",     	0,      NULL,	'V'},
+	{"with-timestamps",	0,	NULL,	'T'},
+	{"verbose",		0,	NULL,	'v'},
+	{"help",		0,	NULL,	'h'},
+	{"version",		0,	NULL,	'V'},
 	{0,0,0,0}
 };
 
 /* short options */
 
-static char     shortopts[] = "c:I:z:p:s:k:o:i:vhV";
+static char	shortopts[] = "c:I:z:p:s:k:o:Ti:vhV";
 
 /* end of COMMAND LINE OPTIONS*/
 
 static int	CONFIG_LOG_LEVEL = LOG_LEVEL_CRIT;
 
 static char*	INPUT_FILE = NULL;
+static int	WITH_TIMESTAMPS = 0;
 
 static char*	CONFIG_SOURCE_IP = NULL;
 static char*	ZABBIX_SERVER = NULL;
@@ -119,14 +125,14 @@ static char*	ZABBIX_KEY_VALUE = NULL;
 
 #if !defined(_WINDOWS)
 
-static void    send_signal_handler( int sig )
+static void	send_signal_handler( int sig )
 {
 	if( SIGALRM == sig )
 	{
 		signal( SIGALRM, send_signal_handler );
 		zabbix_log( LOG_LEVEL_WARNING, "Timeout while executing operation");
 	}
- 
+
 	if( SIGQUIT == sig || SIGINT == sig || SIGTERM == sig )
 	{
 /*		fprintf(stderr,"\nGot QUIT or INT or TERM signal. Exiting..." ); */
@@ -152,7 +158,7 @@ typedef struct zbx_active_metric_type
  * Parameters: result SUCCEED or FAIL                                         *
  *                                                                            *
  * Return value:  SUCCEED - processed successfully                            *
- *                FAIL - an error occured                                     *
+ *                FAIL - an error occurred                                    *
  *                                                                            *
  * Author: Alexei Vladishev                                                   *
  *                                                                            *
@@ -161,7 +167,7 @@ typedef struct zbx_active_metric_type
  ******************************************************************************/
 static int	check_response(char *response)
 {
-	struct 		zbx_json_parse jp;
+	struct		zbx_json_parse jp;
 	const char 	*p;
 	char		value[MAX_STRING_LEN];
 	char		info[MAX_STRING_LEN];
@@ -272,7 +278,7 @@ static void    init_config(const char* config_file)
 
 		if (NULL != config_source_ip_from_conf)
 		{
-			if (NULL == CONFIG_SOURCE_IP)	/* apply parameter only if unsetted */
+			if (NULL == CONFIG_SOURCE_IP)	/* apply parameter only if unset */
 			{
 				CONFIG_SOURCE_IP = strdup(config_source_ip_from_conf);
 			}
@@ -282,7 +288,7 @@ static void    init_config(const char* config_file)
 		if( zabbix_server_from_conf )
 		{
 			if( !ZABBIX_SERVER )
-			{ /* apply parameter only if unsetted */
+			{ /* apply parameter only if unset */
 				if( (c = strchr(zabbix_server_from_conf, ',')) )
 				{ /* get only first server */
 					*c = '\0';
@@ -293,14 +299,14 @@ static void    init_config(const char* config_file)
 		}
 
 		if( !ZABBIX_SERVER_PORT && zabbix_server_port_from_conf )
-		{ /* apply parameter only if unsetted */
+		{ /* apply parameter only if unset */
 			ZABBIX_SERVER_PORT = zabbix_server_port_from_conf;
 		}
 
 		if( zabbix_hostname_from_conf )
 		{
 			if( !ZABBIX_HOSTNAME )
-			{ /* apply parameter only if unsetted */
+			{ /* apply parameter only if unset */
 				ZABBIX_HOSTNAME = strdup(zabbix_hostname_from_conf);
 			}
 			zbx_free(zabbix_hostname_from_conf);
@@ -327,10 +333,10 @@ static zbx_task_t parse_commandline(int argc, char **argv)
 				version();
 				exit(-1);
 				break;
-			case 'I': 
+			case 'I':
 				CONFIG_SOURCE_IP = strdup(zbx_optarg);
 				break;
-			case 'z': 
+			case 'z':
 				ZABBIX_SERVER = strdup(zbx_optarg);
 				break;
 			case 'p':
@@ -348,6 +354,9 @@ static zbx_task_t parse_commandline(int argc, char **argv)
 			case 'i':
 				INPUT_FILE = strdup(zbx_optarg);
 				break;
+			case 'T':
+				WITH_TIMESTAMPS = 1;
+				break;
 			case 'v':
 				if(CONFIG_LOG_LEVEL == LOG_LEVEL_WARNING)
 					CONFIG_LOG_LEVEL = LOG_LEVEL_DEBUG;
@@ -371,17 +380,19 @@ static zbx_task_t parse_commandline(int argc, char **argv)
 
 int main(int argc, char **argv)
 {
+#define VALUES_MAX	250
 	FILE	*in;
 
-	char	in_line[MAX_STRING_LEN],
-		*s,
+	char	in_line[MAX_BUF_LEN],
 		*hostname,
 		*key,
-		*key_value;
+		*key_value,
+		*clock;
 
 	int	task = ZBX_TASK_START,
 		total_count = 0,
 		succeed_count = 0,
+		buffer_count = 0,
 		ret = SUCCEED;
 
 	ZBX_THREAD_SENDVAL_ARGS sentdval_args;
@@ -421,13 +432,16 @@ int main(int argc, char **argv)
 		if (NULL == (in = fopen(INPUT_FILE, "r")) )
 		{
 			zabbix_log(LOG_LEVEL_WARNING, "Cannot open [%s] [%s]", INPUT_FILE, strerror(errno));
-			return FAIL;
+			ret = FAIL;
+			goto exit;
 		}
 
-		while (NULL != fgets(in_line, sizeof(in_line), in))	/* <hostname> <key> <value> */
+		while (NULL != fgets(in_line, sizeof(in_line), in) && SUCCEED == ret)	/* <hostname> <key> <value> */
 		{
 			total_count++; /* also used as inputline */
 
+			zbx_rtrim(in_line, "\r\n");
+
 			hostname = in_line;
 
 			if (NULL == (key = strchr(hostname, ' ')))
@@ -438,30 +452,63 @@ int main(int argc, char **argv)
 
 			*key++ = '\0';
 
-			if (NULL == (key_value = strchr(key, ' ')))
+			if (1 == WITH_TIMESTAMPS)
+			{
+				if (NULL == (clock = strchr(key, ' ')))
+				{
+					zabbix_log(LOG_LEVEL_WARNING, "[line %d] 'Timestamp' required", total_count);
+					continue;
+				}
+
+				*clock++ = '\0';
+			}
+			else
+				clock = key;
+
+			if (NULL == (key_value = strchr(clock, ' ')))
 			{
 				zabbix_log(LOG_LEVEL_WARNING, "[line %d] 'Key value' required", total_count);
 				continue;
 			}
-
 			*key_value++ = '\0';
 
-			for (s = key_value; s && *s; s++)
-			{
-				if(*s == '\r' || *s == '\n' )
-				{
-					*s = '\0';
-					break;
-				}
-			}
+			zbx_rtrim(key_value, "\r\n");
 
 			zbx_json_addobject(&sentdval_args.json, NULL);
 			zbx_json_addstring(&sentdval_args.json, ZBX_PROTO_TAG_HOST, hostname, ZBX_JSON_TYPE_STRING);
 			zbx_json_addstring(&sentdval_args.json, ZBX_PROTO_TAG_KEY, key, ZBX_JSON_TYPE_STRING);
 			zbx_json_addstring(&sentdval_args.json, ZBX_PROTO_TAG_VALUE, key_value, ZBX_JSON_TYPE_STRING);
+			if (1 == WITH_TIMESTAMPS)
+				zbx_json_adduint64(&sentdval_args.json, ZBX_PROTO_TAG_CLOCK, atoi(clock));
 			zbx_json_close(&sentdval_args.json);
 
 			succeed_count++;
+			buffer_count++;
+
+			if (VALUES_MAX == buffer_count)
+			{
+				zbx_json_close(&sentdval_args.json);
+
+				if (1 == WITH_TIMESTAMPS)
+					zbx_json_adduint64(&sentdval_args.json, ZBX_PROTO_TAG_CLOCK, (int)time(NULL));
+
+				ret = zbx_thread_wait(zbx_thread_start(send_value, &sentdval_args));
+
+				buffer_count = 0;
+				zbx_json_clean(&sentdval_args.json);
+				zbx_json_addstring(&sentdval_args.json, ZBX_PROTO_TAG_REQUEST, ZBX_PROTO_VALUE_SENDER_DATA,
+						ZBX_JSON_TYPE_STRING);
+				zbx_json_addarray(&sentdval_args.json, ZBX_PROTO_TAG_DATA);
+			}
+		}
+		zbx_json_close(&sentdval_args.json);
+
+		if (0 != buffer_count)
+		{
+			if (1 == WITH_TIMESTAMPS)
+				zbx_json_adduint64(&sentdval_args.json, ZBX_PROTO_TAG_CLOCK, (int)time(NULL));
+
+			ret = zbx_thread_wait(zbx_thread_start(send_value, &sentdval_args));
 		}
 
 		fclose(in);
@@ -499,26 +546,20 @@ int main(int argc, char **argv)
 			zbx_json_close(&sentdval_args.json);
 
 			succeed_count++;
+
+			ret = zbx_thread_wait(zbx_thread_start(send_value, &sentdval_args));
 		}
 		while(0); /* try block simulation */
 	}
 
-	if (succeed_count > 0)
-	{
-		if (SUCCEED == zbx_thread_wait(zbx_thread_start(send_value, &sentdval_args)))
-		{
-			printf("sent: %d; skipped: %d; total: %d\n", succeed_count, (total_count - succeed_count), total_count);
-		}
-		else
-		{
-			printf("Sending failed. Use option -vv for more detailed output.\n");
-		}
-	}
-
 	zbx_json_free(&sentdval_args.json);
+
+	if (SUCCEED == ret)
+		printf("sent: %d; skipped: %d; total: %d\n", succeed_count, (total_count - succeed_count), total_count);
+	else
+		printf("Sending failed. Use option -vv for more detailed output.\n");
 exit:
 	zabbix_close_log();
 
 	return ret;
 }
-
