@@ -1,4 +1,4 @@
-/* 
+/*
 ** ZABBIX
 ** Copyright (C) 2000-2005 SIA Zabbix
 **
@@ -35,6 +35,7 @@
 ZBX_USER_MSG
 {
 	zbx_uint64_t	userid;
+	zbx_uint64_t	mediatypeid;
 	char		*subject;
 	char		*message;
 	void		*next;
@@ -48,7 +49,7 @@ ZBX_USER_MSG
  *                                                                            *
  * Parameters: userid - user ID                                               *
  *                                                                            *
- * Return value: SUCCEED - prermitions is positive, FAIL - otherwise          *
+ * Return value: SUCCEED - prermission is positive, FAIL - otherwise          *
  *                                                                            *
  * Author:                                                                    *
  *                                                                            *
@@ -163,7 +164,7 @@ static int	get_trigger_permision(zbx_uint64_t userid, zbx_uint64_t triggerid)
 
 	while (NULL != (row = DBfetch(result)))
 	{
-		hostid = zbx_atoui64(row[0]);
+		ZBX_STR2UINT64(hostid, row[0]);
 		host_perm = get_host_permision(userid, hostid);
 
 		if (perm < host_perm)
@@ -178,7 +179,8 @@ static int	get_trigger_permision(zbx_uint64_t userid, zbx_uint64_t triggerid)
 	return perm;
 }
 
-static void	add_user_msg(zbx_uint64_t userid, zbx_uint64_t triggerid, ZBX_USER_MSG **user_msg, char *subject, char *message)
+static void	add_user_msg(int source, zbx_uint64_t userid, zbx_uint64_t mediatypeid, zbx_uint64_t triggerid, ZBX_USER_MSG **user_msg,
+		char *subject, char *message)
 {
 	ZBX_USER_MSG	*p;
 
@@ -187,7 +189,7 @@ static void	add_user_msg(zbx_uint64_t userid, zbx_uint64_t triggerid, ZBX_USER_M
 	if (SUCCEED != check_perm2system(userid))
 		return;
 
-	if (PERM_READ_ONLY > get_trigger_permision(userid, triggerid))
+	if (EVENT_SOURCE_TRIGGERS == source && PERM_READ_ONLY > get_trigger_permision(userid, triggerid))
 		return;
 
 	p = *user_msg;
@@ -203,6 +205,7 @@ static void	add_user_msg(zbx_uint64_t userid, zbx_uint64_t triggerid, ZBX_USER_M
 		p = zbx_malloc(p, sizeof(ZBX_USER_MSG));
 
 		p->userid = userid;
+		p->mediatypeid = mediatypeid;
 		p->subject = strdup(subject);
 		p->message = strdup(message);
 		p->next = *user_msg;
@@ -211,14 +214,24 @@ static void	add_user_msg(zbx_uint64_t userid, zbx_uint64_t triggerid, ZBX_USER_M
 	}
 }
 
-static void	add_object_msg(zbx_uint64_t triggerid, DB_OPERATION *operation, ZBX_USER_MSG **user_msg, char *subject, char *message)
+static void	add_object_msg(int source, zbx_uint64_t triggerid, DB_OPERATION *operation, ZBX_USER_MSG **user_msg,
+		char *subject, char *message)
 {
 	DB_RESULT	result;
 	DB_ROW		row;
+	zbx_uint64_t	mediatypeid = 0, userid;
+
+	result = DBselect("select mediatypeid from opmediatypes where operationid=" ZBX_FS_UI64,
+			operation->operationid);
+
+	if (NULL != (row = DBfetch(result)))
+		ZBX_STR2UINT64(mediatypeid, row[0]);
+
+	DBfree_result(result);
 
 	switch (operation->object) {
 		case OPERATION_OBJECT_USER:
-			add_user_msg(operation->objectid, triggerid, user_msg, subject, message);
+			add_user_msg(source, operation->objectid, mediatypeid, triggerid, user_msg, subject, message);
 			break;
 		case OPERATION_OBJECT_GROUP:
 			result = DBselect("select ug.userid from users_groups ug,usrgrp g"
@@ -227,7 +240,10 @@ static void	add_object_msg(zbx_uint64_t triggerid, DB_OPERATION *operation, ZBX_
 					GROUP_STATUS_ACTIVE);
 
 			while (NULL != (row = DBfetch(result)))
-				add_user_msg(zbx_atoui64(row[0]), triggerid, user_msg, subject, message);
+			{
+				ZBX_STR2UINT64(userid, row[0]);
+				add_user_msg(source, userid, mediatypeid, triggerid, user_msg, subject, message);
+			}
 
 			DBfree_result(result);
 			break;
@@ -270,11 +286,12 @@ static void	add_command_alert(DB_ESCALATION *escalation, DB_EVENT *event, DB_ACT
 	zbx_free(command_esc);
 }
 
-static void	add_message_alert(DB_ESCALATION *escalation, DB_EVENT *event, DB_ACTION *action, zbx_uint64_t userid, char *subject, char *message)
+static void	add_message_alert(DB_ESCALATION *escalation, DB_EVENT *event, DB_ACTION *action,
+		zbx_uint64_t userid, zbx_uint64_t mediatypeid, char *subject, char *message)
 {
 	DB_RESULT	result;
 	DB_ROW		row;
-	zbx_uint64_t	alertid, mediatypeid;
+	zbx_uint64_t	alertid;
 	int		now, severity, medias = 0;
 	char		*sendto_esc, *subject_esc, *message_esc, *error_esc;
 	char		error[MAX_STRING_LEN];
@@ -286,15 +303,26 @@ static void	add_message_alert(DB_ESCALATION *escalation, DB_EVENT *event, DB_ACT
 	subject_esc	= DBdyn_escape_string_len(subject, ALERT_SUBJECT_LEN);
 	message_esc	= DBdyn_escape_string(message);
 
-	result = DBselect("select mediatypeid,sendto,severity,period from media"
-			" where active=%d and userid=" ZBX_FS_UI64,
-			MEDIA_STATUS_ACTIVE,
-			userid);
+	if (0 == mediatypeid)
+	{
+		result = DBselect("select mediatypeid,sendto,severity,period from media"
+				" where active=%d and userid=" ZBX_FS_UI64,
+				MEDIA_STATUS_ACTIVE,
+				userid);
+	}
+	else
+	{
+		result = DBselect("select mediatypeid,sendto,severity,period from media"
+				" where active=%d and userid=" ZBX_FS_UI64 " and mediatypeid=" ZBX_FS_UI64,
+				MEDIA_STATUS_ACTIVE,
+				userid,
+				mediatypeid);
+	}
 
 	while (NULL != (row = DBfetch(result))) {
 		medias		= 1;
 
-		mediatypeid	= zbx_atoui64(row[0]);
+		ZBX_STR2UINT64(mediatypeid, row[0]);
 		severity	= atoi(row[2]);
 
 		zabbix_log( LOG_LEVEL_DEBUG, "Trigger severity [%d] Media severity [%d] Period [%s]",
@@ -338,18 +366,8 @@ static void	add_message_alert(DB_ESCALATION *escalation, DB_EVENT *event, DB_ACT
 	DBfree_result(result);
 
 	if (0 == medias) {
-		result = DBselect("select name,surname,alias from users where userid=" ZBX_FS_UI64,
-				userid);
-
-		if (NULL != (row = DBfetch(result))) {
-			zbx_snprintf(error, sizeof(error), "No media defined for user %s %s (%s)",
-					row[0],
-					row[1],
-					row[2]);
-		} else
-			zbx_snprintf(error, sizeof(error), "No media defined");
-
-		DBfree_result(result);
+		zbx_snprintf(error, sizeof(error), "No media defined for user \"%s\"",
+				zbx_user_string(userid));
 
 		alertid		= DBget_maxid("alerts", "alertid");
 		error_esc	= DBdyn_escape_string(error);
@@ -400,7 +418,7 @@ static int	check_operation_conditions(DB_EVENT *event, DB_OPERATION *operation)
 	DB_ROW		row;
 	DB_CONDITION	condition;
 
-	/* SUCCEED required for ACTION_EVAL_TYPE_AND_OR */	
+	/* SUCCEED required for ACTION_EVAL_TYPE_AND_OR */
 	int	ret = SUCCEED;
 	int	old_type = -1;
 	int	cond;
@@ -433,7 +451,7 @@ static int	check_operation_conditions(DB_EVENT *event, DB_OPERATION *operation)
 					else if (FAIL == check_action_condition(event, &condition))
 						ret	= FAIL;
 				}
-		
+
 				old_type = condition.conditiontype;
 				break;
 			case ACTION_EVAL_TYPE_AND:
@@ -501,11 +519,11 @@ static void	execute_operations(DB_ESCALATION *escalation, DB_EVENT *event, DB_AC
 
 	while (NULL != (row = DBfetch(result))) {
 		memset(&operation, 0, sizeof(operation));
-		operation.operationid	= zbx_atoui64(row[0]);
+		ZBX_STR2UINT64(operation.operationid, row[0]);
 		operation.actionid	= action->actionid;
 		operation.operationtype	= atoi(row[1]);
 		operation.object	= atoi(row[2]);
-		operation.objectid	= zbx_atoui64(row[3]);
+		ZBX_STR2UINT64(operation.objectid, row[3]);
 		operation.default_msg	= atoi(row[4]);
 		operation.shortdata	= strdup(row[5]);
 		operation.longdata	= strdup(row[6]);
@@ -530,8 +548,8 @@ static void	execute_operations(DB_ESCALATION *escalation, DB_EVENT *event, DB_AC
 						shortdata = action->shortdata;
 						longdata = action->longdata;
 					}
-					
-					add_object_msg(event->objectid, &operation, &user_msg, shortdata, longdata);
+
+					add_object_msg(event->source, escalation->triggerid, &operation, &user_msg, shortdata, longdata);
 					break;
 				case	OPERATION_TYPE_COMMAND:
 					add_command_alert(escalation, event, action, operation.longdata);
@@ -554,7 +572,7 @@ static void	execute_operations(DB_ESCALATION *escalation, DB_EVENT *event, DB_AC
 		p = user_msg;
 		user_msg = user_msg->next;
 
-		add_message_alert(escalation, event, action, p->userid, p->subject, p->message);
+		add_message_alert(escalation, event, action, p->userid, p->mediatypeid, p->subject, p->message);
 
 		zbx_free(p->subject);
 		zbx_free(p->message);
@@ -587,22 +605,23 @@ static void	process_recovery_msg(DB_ESCALATION *escalation, DB_EVENT *r_event, D
 {
 	DB_RESULT	result;
 	DB_ROW		row;
-	zbx_uint64_t	userid;
+	zbx_uint64_t	userid, mediatypeid;
 
 	if (1 == action->recovery_msg)
 	{
-		result = DBselect("select distinct userid from alerts where actionid=" ZBX_FS_UI64
-				" and eventid=" ZBX_FS_UI64 " and alerttype=%d",
+		result = DBselect("select distinct userid,mediatypeid from alerts where actionid=" ZBX_FS_UI64
+				" and eventid=" ZBX_FS_UI64 " and mediatypeid<>0 and alerttype=%d",
 				action->actionid,
 				escalation->eventid,
 				ALERT_TYPE_MESSAGE);
 
 		while (NULL != (row = DBfetch(result)))
 		{
-			userid = zbx_atoui64(row[0]);
+			ZBX_STR2UINT64(userid, row[0]);
+			ZBX_STR2UINT64(mediatypeid, row[1]);
 
 			escalation->esc_step = 0;
-			add_message_alert(escalation, r_event, action, userid, action->shortdata, action->longdata);
+			add_message_alert(escalation, r_event, action, userid, mediatypeid, action->shortdata, action->longdata);
 		}
 
 		DBfree_result(result);
@@ -705,19 +724,32 @@ static void	execute_escalation(DB_ESCALATION *escalation)
 	DB_ACTION	action;
 	DB_EVENT	event;
 	char		*error = NULL;
+	int		source;
 
-	/* Trigger disabled? */
-	result = DBselect("select description,status from triggers where triggerid=" ZBX_FS_UI64,
-			escalation->triggerid);
+	result = DBselect("select source from events where eventid=" ZBX_FS_UI64,
+			escalation->eventid);
 	if (NULL == (row = DBfetch(result)))
-		error = zbx_dsprintf(error, "Trigger [" ZBX_FS_UI64 "] deleted.",
-				escalation->triggerid);
-	else if (TRIGGER_STATUS_DISABLED == atoi(row[1]))
-		error = zbx_dsprintf(error, "Trigger '%s' disabled.",
-				row[0]);
+		error = zbx_dsprintf(error, "Event [" ZBX_FS_UI64 "] deleted.",
+				escalation->eventid);
+	else
+		source = atoi(row[0]);
 	DBfree_result(result);
 
-	if (NULL == error)
+	if (NULL == error && EVENT_SOURCE_TRIGGERS == source)
+	{
+		/* Trigger disabled? */
+		result = DBselect("select description,status from triggers where triggerid=" ZBX_FS_UI64,
+				escalation->triggerid);
+		if (NULL == (row = DBfetch(result)))
+			error = zbx_dsprintf(error, "Trigger [" ZBX_FS_UI64 "] deleted.",
+					escalation->triggerid);
+		else if (TRIGGER_STATUS_DISABLED == atoi(row[1]))
+			error = zbx_dsprintf(error, "Trigger '%s' disabled.",
+					row[0]);
+		DBfree_result(result);
+	}
+
+	if (NULL == error && EVENT_SOURCE_TRIGGERS == source)
 	{
 		/* Item disabled? */
 		result = DBselect("select i.description from items i,functions f,triggers t"
@@ -731,7 +763,7 @@ static void	execute_escalation(DB_ESCALATION *escalation)
 		DBfree_result(result);
 	}
 
-	if (NULL == error)
+	if (NULL == error && EVENT_SOURCE_TRIGGERS == source)
 	{
 		/* Host disabled? */
 		result = DBselect("select h.host from hosts h,items i,functions f,triggers t"
@@ -764,7 +796,7 @@ static void	execute_escalation(DB_ESCALATION *escalation)
 	if (NULL != (row = DBfetch(result)))
 	{
 		memset(&action, 0, sizeof(action));
-		action.actionid		= zbx_atoui64(row[0]);
+		ZBX_STR2UINT64(action.actionid, row[0]);
 		action.eventsource	= atoi(row[1]);
 		action.esc_period	= atoi(row[2]);
 		action.shortdata	= strdup(row[3]);
@@ -816,7 +848,7 @@ static void	execute_escalation(DB_ESCALATION *escalation)
 	if (NULL != error)
 	{
 		escalation->status = ESCALATION_STATUS_COMPLETED;
-		zabbix_log(LOG_LEVEL_WARNING, "Escalation canceled: %s",
+		zabbix_log(LOG_LEVEL_WARNING, "Escalation cancelled: %s",
 				error);
 		zbx_free(error);
 	}
@@ -839,14 +871,14 @@ static void	process_escalations(int now)
 
 	while (NULL != (row = DBfetch(result))) {
 		memset(&escalation, 0, sizeof(escalation));
-		escalation.escalationid		= zbx_atoui64(row[0]);
-		escalation.actionid		= zbx_atoui64(row[1]);
-		escalation.triggerid		= zbx_atoui64(row[2]);
-		escalation.eventid		= zbx_atoui64(row[3]);
-		escalation.r_eventid		= zbx_atoui64(row[4]);
-		escalation.esc_step		= atoi(row[5]);
-		escalation.status		= atoi(row[6]);
-		escalation.nextcheck		= 0;
+		ZBX_STR2UINT64(escalation.escalationid, row[0]);
+		ZBX_STR2UINT64(escalation.actionid, row[1]);
+		ZBX_STR2UINT64(escalation.triggerid, row[2]);
+		ZBX_STR2UINT64(escalation.eventid, row[3]);
+		ZBX_STR2UINT64(escalation.r_eventid, row[4]);
+		escalation.esc_step	= atoi(row[5]);
+		escalation.status	= atoi(row[6]);
+		escalation.nextcheck	= 0;
 
 		DBbegin();
 
@@ -899,7 +931,7 @@ static void	process_escalations(int now)
 	if (NULL == (row = DBfetch(result)) || DBis_null(row[0]) == SUCCEED || DBis_null(row[1]) == SUCCEED)
 	{
 		zabbix_log(LOG_LEVEL_DEBUG, "No items to update for minnextcheck.");
-		res = FAIL; 
+		res = FAIL;
 	}
 	else
 	{
@@ -925,7 +957,7 @@ static void	process_escalations(int now)
  *                                                                            *
  * Parameters:                                                                *
  *                                                                            *
- * Return value:                                                              * 
+ * Return value:                                                              *
  *                                                                            *
  * Author: Aleksander Vladishev                                               *
  *                                                                            *
@@ -940,9 +972,10 @@ int main_escalator_loop()
 
 	zabbix_log(LOG_LEVEL_DEBUG, "In main_escalator_loop()");
 
-	phan.sa_handler = child_signal_handler;
+/*	phan.sa_handler = child_signal_handler;*/
+        phan.sa_sigaction = child_signal_handler;
 	sigemptyset(&phan.sa_mask);
-	phan.sa_flags = 0;
+	phan.sa_flags = SA_SIGINFO;
 	sigaction(SIGALRM, &phan, NULL);
 
 	zbx_setproctitle("escalator [connecting to the database]");
@@ -976,12 +1009,12 @@ int main_escalator_loop()
 				sec,
 				CONFIG_ESCALATOR_FREQUENCY);
 
-		zbx_setproctitle("escalator [sleeping for %d seconds]", 
+		zbx_setproctitle("escalator [sleeping for %d seconds]",
 				CONFIG_ESCALATOR_FREQUENCY);
 
 		sleep(CONFIG_ESCALATOR_FREQUENCY);
 /*		if (sleeptime > 0) {
-			zbx_setproctitle("escalator [sleeping for %d seconds]", 
+			zbx_setproctitle("escalator [sleeping for %d seconds]",
 					sleeptime);
 
 			sleep(sleeptime);
