@@ -1,4 +1,4 @@
-/* 
+/*
 ** ZABBIX
 ** Copyright (C) 2000-2005 SIA Zabbix
 **
@@ -32,7 +32,7 @@
  *                                                                            *
  * Parameters:                                                                *
  *                                                                            *
- * Return value: SUCCEED - information removed succesfully                    *
+ * Return value: SUCCEED - information removed successfully                   *
  *               FAIL - otherwise                                             *
  *                                                                            *
  * Author: Alexei Vladishev                                                   *
@@ -69,8 +69,8 @@ static int housekeeping_process_log()
 			housekeeper.value);
 #elif defined(HAVE_POSTGRESQL)
 		deleted = DBexecute("delete from %s where oid in (select oid from %s where %s=" ZBX_FS_UI64 " limit 500)",
-				housekeeper.tablename, 
-				housekeeper.tablename, 
+				housekeeper.tablename,
+				housekeeper.tablename,
 				housekeeper.field,
 				housekeeper.value);
 #else
@@ -105,7 +105,7 @@ static int housekeeping_sessions(int now)
 		now);
 
 	deleted = DBexecute("delete from sessions where lastaccess<%d",
-		now-24*3600);
+		now-365*86400);
 
 	zabbix_log( LOG_LEVEL_DEBUG, "Deleted [%ld] records from table [sessions]",
 		deleted);
@@ -163,7 +163,7 @@ static int housekeeping_events(int now)
 	result = DBselect("select event_history from config");
 
 	row1=DBfetch(result);
-	
+
 	if(!row1 || DBis_null(row1[0])==SUCCEED)
 	{
 		zabbix_log( LOG_LEVEL_ERR, "No records in table 'config'.");
@@ -178,17 +178,17 @@ static int housekeeping_events(int now)
 		while((row2=DBfetch(result2)))
 		{
 			ZBX_STR2UINT64(eventid,row2[0]);
-			
+
 			DBexecute("delete from acknowledges where eventid=" ZBX_FS_UI64,
 				eventid);
-			
+
 			DBexecute("delete from events where eventid=" ZBX_FS_UI64,
 				eventid);
 		}
 		DBfree_result(result2);
 
 	}
-	
+
 	DBfree_result(result);
 	return res;
 }
@@ -208,13 +208,13 @@ static int housekeeping_events(int now)
  * Comments:                                                                  *
  *                                                                            *
  ******************************************************************************/
-static int delete_history(char *table, zbx_uint64_t itemid, int keep_history, int now)
+static int	delete_history(const char *table, zbx_uint64_t itemid, int keep_history, int now)
 {
 	DB_RESULT       result;
 	DB_ROW          row;
 	int             min_clock;
 
-	zabbix_log( LOG_LEVEL_DEBUG, "In delete_history(%s," ZBX_FS_UI64 "," ZBX_FS_UI64 ",%d)",
+	zabbix_log( LOG_LEVEL_DEBUG, "In delete_history(%s," ZBX_FS_UI64 ",%d,%d)",
 		table,
 		itemid,
 		keep_history,
@@ -257,7 +257,7 @@ static int delete_history(char *table, zbx_uint64_t itemid, int keep_history, in
  *                                                                            *
  * Parameters: now - current timestamp                                        *
  *                                                                            *
- * Return value: SUCCEED - information removed succesfully                    *
+ * Return value: SUCCEED - information removed successfully                   *
  *               FAIL - otherwise                                             *
  *                                                                            *
  * Author: Alexei Vladishev                                                   *
@@ -291,6 +291,7 @@ static int housekeeping_history_and_trends(int now)
                 deleted += delete_history("history_text", item.itemid, item.history, now);
                 deleted += delete_history("history_log", item.itemid, item.history, now);
                 deleted += delete_history("trends", item.itemid, item.trends, now);
+		deleted += delete_history("trends_uint", item.itemid, item.trends, now);
         }
         DBfree_result(result);
         return deleted;
@@ -359,7 +360,7 @@ int main_housekeeper_loop()
 /* Transaction is not required here. It causes timeouts under MySQL */
 /*		DBcommit();*/
 
-		DBvacuum();
+/*		DBvacuum();*/
 
 		zabbix_log( LOG_LEVEL_DEBUG, "Sleeping for %d hours",
 			CONFIG_HOUSEKEEPING_FREQUENCY);
