@@ -1,4 +1,4 @@
-/* 
+/*
 ** ZABBIX
 ** Copyright (C) 2000-2005 SIA Zabbix
 **
@@ -20,19 +20,15 @@
 #include "common.h"
 
 #include "cfg.h"
-#include "pid.h"
 #include "db.h"
 #include "log.h"
-#include "zlog.h"
 
-#include "../functions.h"
-#include "../expression.h"
 #include "httptest.h"
 #include "httppoller.h"
 
 #include "daemon.h"
 
-int	httppoller_num;
+int httppoller_num;
 
 /******************************************************************************
  *                                                                            *
@@ -56,18 +52,18 @@ static int get_minnextcheck(int now)
 
 	int		res;
 
-	result = DBselect("select count(*),min(nextcheck) from httptest t where t.status=%d and " ZBX_SQL_MOD(t.httptestid,%d) "=%d and " ZBX_COND_NODEID,
+	result = DBselect("select count(*),min(nextcheck) from httptest t where t.status=%d and " ZBX_SQL_MOD(t.httptestid,%d) "=%d" DB_NODE,
 		HTTPTEST_STATUS_MONITORED,
 		CONFIG_HTTPPOLLER_FORKS,
 		httppoller_num-1,
-		LOCAL_NODE("t.httptestid"));
+		DBnode_local("t.httptestid"));
 
 	row=DBfetch(result);
 
 	if(!row || DBis_null(row[0])==SUCCEED || DBis_null(row[1])==SUCCEED)
 	{
 		zabbix_log(LOG_LEVEL_DEBUG, "No httptests to process in get_minnextcheck.");
-		res = FAIL; 
+		res = FAIL;
 	}
 	else
 	{
@@ -148,7 +144,7 @@ void main_httppoller_loop(int num)
 			zabbix_log( LOG_LEVEL_DEBUG, "Sleeping for %d seconds",
 					sleeptime );
 
-			zbx_setproctitle("http poller [sleeping for %d seconds]", 
+			zbx_setproctitle("http poller [sleeping for %d seconds]",
 					sleeptime);
 
 			sleep( sleeptime );
