@@ -1,4 +1,4 @@
-/* 
+/*
 ** ZABBIX
 ** Copyright (C) 2000-2005 SIA Zabbix
 **
@@ -31,7 +31,6 @@
 
 #ifdef	HAVE_LIBCURL
 
-static zbx_process_t	zbx_process;
 static S_ZBX_HTTPPAGE	page;
 
 /******************************************************************************
@@ -44,7 +43,7 @@ static S_ZBX_HTTPPAGE	page;
  *             host - host name                                               *
  *             value - new value of the item                                  *
  *                                                                            *
- * Return value: SUCCEED - new value sucesfully processed                     *
+ * Return value: SUCCEED - new value successfully processed                   *
  *               FAIL - otherwise                                             *
  *                                                                            *
  * Author: Alexei Vladishev                                                   *
@@ -56,20 +55,28 @@ static int process_value(zbx_uint64_t itemid, AGENT_RESULT *value)
 {
 	DB_RESULT	result;
 	DB_ROW		row;
-	DB_ITEM		item;
-	time_t		now;
+	unsigned char	value_type;
 
 	INIT_CHECK_MEMORY();
 
 	zabbix_log( LOG_LEVEL_DEBUG, "In process_value(itemid:" ZBX_FS_UI64 ")",
 			itemid);
 
-	result = DBselect("select %s where h.status=%d and h.hostid=i.hostid and i.status=%d and i.type=%d and i.itemid=" ZBX_FS_UI64 DB_NODE,
-			ZBX_SQL_ITEM_SELECT,
+	result = DBselect(
+			"select i.itemid,i.value_type"
+			" from items i,hosts h"
+			" where h.hostid=i.hostid"
+				" and h.status=%d"
+				" and i.status=%d"
+				" and i.type=%d"
+				" and i.itemid=" ZBX_FS_UI64
+				" and (h.maintenance_status=%d or h.maintenance_type=%d)"
+				DB_NODE,
 			HOST_STATUS_MONITORED,
 			ITEM_STATUS_ACTIVE,
 			ITEM_TYPE_HTTPTEST,
 			itemid,
+			HOST_MAINTENANCE_STATUS_OFF, MAINTENANCE_TYPE_NORMAL,
 			DBnode_local("h.hostid"));
 	row=DBfetch(result);
 
@@ -80,24 +87,9 @@ static int process_value(zbx_uint64_t itemid, AGENT_RESULT *value)
 		return  FAIL;
 	}
 
-	DBget_item_from_db(&item,row);
+	value_type = (unsigned char)atoi(row[1]);
 
-	now = time(NULL);
-
-	if (0 == CONFIG_DBSYNCER_FORKS)
-		DBbegin();
-
-	switch (zbx_process) {
-	case ZBX_PROCESS_SERVER:
-		process_new_value(&item, value, now);
-		break;
-	case ZBX_PROCESS_PROXY:
-		proxy_process_new_value(&item, value, now);
-		break;
-	}
-
-	if (0 == CONFIG_DBSYNCER_FORKS)
-		DBcommit();
+	dc_add_history(itemid, value_type, value, time(NULL), 0, NULL, 0, 0, 0, 0);
 
 	DBfree_result(result);
 
@@ -127,7 +119,7 @@ static size_t WRITEFUNCTION2( void *ptr, size_t size, size_t nmemb, void *stream
 
 static size_t HEADERFUNCTION2( void *ptr, size_t size, size_t nmemb, void *stream)
 {
-/*	
+/*
 	ZBX_LIM_PRINT("HEADERFUNCTION", size*nmemb, ptr, 300);
 	zabbix_log(LOG_LEVEL_WARNING, "In HEADERFUNCTION");
 */
@@ -181,7 +173,7 @@ static void	process_test_data(DB_HTTPTEST *httptest, S_ZBX_HTTPSTAT *stat)
 
 		free_result(&value);
 	}
-	
+
 	DBfree_result(result);
 	zabbix_log(LOG_LEVEL_DEBUG, "End process_test_data()");
 
@@ -237,7 +229,7 @@ static void	process_step_data(DB_HTTPTEST *httptest, DB_HTTPSTEP *httpstep, S_ZB
 
 		free_result(&value);
 	}
-	
+
 	DBfree_result(result);
 	zabbix_log(LOG_LEVEL_DEBUG, "End process_step_data()");
 
@@ -266,6 +258,7 @@ static void	process_httptest(DB_HTTPTEST *httptest)
 	DB_HTTPSTEP	httpstep;
 	int		err;
 	char		*err_str = NULL, *esc_err_str = NULL;
+	char		auth[HTTPTEST_HTTP_USER_LEN_MAX + HTTPTEST_HTTP_PASSWORD_LEN_MAX];
 	int		now;
 	int		lastfailedstep;
 
@@ -401,6 +394,32 @@ static void	process_httptest(DB_HTTPTEST *httptest)
 				lastfailedstep = httpstep.no;
 			}
 		}
+		/*if( !err_str )*/
+		if( !err_str && httptest->authentication == HTTPTEST_AUTH_BASIC )
+		{
+			zabbix_log(LOG_LEVEL_DEBUG, "WEBMonitor: Setting HTTPAUTH [%d]", httptest->authentication);
+			if(CURLE_OK != (err = curl_easy_setopt(easyhandle, CURLOPT_HTTPAUTH, CURLAUTH_BASIC)))
+			{
+				zabbix_log(LOG_LEVEL_ERR, "Cannot set HTTPAUTH [%s]",
+						curl_easy_strerror(err));
+				err_str = strdup(curl_easy_strerror(err));
+				lastfailedstep = httpstep.no;
+			}
+		}
+		if( !err_str && httptest->authentication == HTTPTEST_AUTH_BASIC)
+		{
+			zabbix_log(LOG_LEVEL_DEBUG, "WEBMonitor: Using basic authentication");
+
+			zbx_snprintf(auth, sizeof(auth), "%s:%s", httptest->http_user, httptest->http_password);
+
+			if(CURLE_OK != (err = curl_easy_setopt(easyhandle, CURLOPT_USERPWD, auth)))
+			{
+				zabbix_log(LOG_LEVEL_ERR, "Cannot set USERPWD [%s]",
+					curl_easy_strerror(err));
+				err_str = strdup(curl_easy_strerror(err));
+				lastfailedstep = httpstep.no;
+			}
+		}
 		if( !err_str )
 		{
 			if(CURLE_OK != (err = curl_easy_setopt(easyhandle, CURLOPT_TIMEOUT, httpstep.timeout)))
@@ -531,7 +550,7 @@ static void	process_httptest(DB_HTTPTEST *httptest)
  * Comments: always SUCCEED                                                   *
  *                                                                            *
  ******************************************************************************/
-void process_httptests(zbx_process_t p, int now)
+void process_httptests(int now)
 {
 	DB_RESULT	result;
 	DB_ROW		row;
@@ -542,25 +561,26 @@ void process_httptests(zbx_process_t p, int now)
 
 	zabbix_log(LOG_LEVEL_DEBUG, "In process_httptests()");
 
-	zbx_process	= p;
-
-	result = DBselect("select httptestid,name,applicationid,nextcheck,status,delay,macros,agent"
+	result = DBselect("select httptestid,name,applicationid,nextcheck,status,delay,macros,agent,authentication,http_user,http_password"
 			" from httptest where status=%d and nextcheck<=%d and " ZBX_SQL_MOD(httptestid,%d) "=%d" DB_NODE,
-			HTTPTEST_STATUS_MONITORED,
-			now,
-			CONFIG_HTTPPOLLER_FORKS,
-			httppoller_num-1,
-			DBnode_local("httptestid"));
+		HTTPTEST_STATUS_MONITORED,
+		now,
+		CONFIG_HTTPPOLLER_FORKS,
+		httppoller_num-1,
+		DBnode_local("httptestid"));
 	while((row=DBfetch(result)))
 	{
 		ZBX_STR2UINT64(httptest.httptestid, row[0]);
-		httptest.name=row[1];
+		httptest.name		= row[1];
 		ZBX_STR2UINT64(httptest.applicationid, row[2]);
-		httptest.nextcheck=atoi(row[3]);
-		httptest.status=atoi(row[4]);
-		httptest.delay=atoi(row[5]);
-		httptest.macros=row[6];
-		httptest.agent=row[7];
+		httptest.nextcheck	= atoi(row[3]);
+		httptest.status		= atoi(row[4]);
+		httptest.delay		= atoi(row[5]);
+		httptest.macros		= row[6];
+		httptest.agent		= row[7];
+		httptest.authentication	= atoi(row[8]);
+		httptest.http_user	= row[9];
+		httptest.http_password	= row[10];
 
 		process_httptest(&httptest);
 	}
