@@ -1,4 +1,4 @@
-/* 
+/*
 ** ZABBIX
 ** Copyright (C) 2000-2005 SIA Zabbix
 **
@@ -20,13 +20,11 @@
 #ifndef ZABBIX_CHECKS_AGENT_H
 #define ZABBIX_CHECKS_AGENT_H
 
-#include "common.h"
-#include "db.h"
-#include "log.h"
+#include "dbcache.h"
 #include "sysinfo.h"
 
-extern  int     CONFIG_NOTIMEWAIT;
+extern char	*CONFIG_SOURCE_IP;
 
-extern	int	get_value_agent(DB_ITEM *item, AGENT_RESULT *result);
+int	get_value_agent(DC_ITEM *item, AGENT_RESULT *result);
 
 #endif
