@@ -1,4 +1,4 @@
-/* 
+/*
 ** ZABBIX
 ** Copyright (C) 2000-2005 SIA Zabbix
 **
@@ -23,6 +23,7 @@
 
 #include "active.h"
 
+
 /******************************************************************************
  *                                                                            *
  * Function: get_hostid_by_host                                               *
@@ -32,14 +33,14 @@
  * Parameters: host - host name                                               *
  *                                                                            *
  * Return value:  SUCCEED - host is found                                     *
- *                FAIL - an error occured or host not found                   *
+ *                FAIL - an error occurred or host not found                  *
  *                                                                            *
  * Author: Aleksander Vladishev                                               *
  *                                                                            *
  * Comments:                                                                  *
  *                                                                            *
  ******************************************************************************/
-static int	get_hostid_by_host(const char *host, zbx_uint64_t *hostid, char *error)
+static int	get_hostid_by_host(const char *host, zbx_uint64_t *hostid, char *error, zbx_process_t zbx_process)
 {
 	char		*host_esc;
 	DB_RESULT	result;
@@ -50,7 +51,12 @@ static int	get_hostid_by_host(const char *host, zbx_uint64_t *hostid, char *erro
 
 	host_esc = DBdyn_escape_string(host);
 
-	result = DBselect("select hostid from hosts where host='%s'" DB_NODE,
+	result = DBselect(
+			"select hostid"
+			" from hosts"
+			" where host='%s'"
+		       		" and proxy_hostid=0"
+				DB_NODE,
 			host_esc,
 			DBnode_local("hostid"));
 
@@ -60,8 +66,24 @@ static int	get_hostid_by_host(const char *host, zbx_uint64_t *hostid, char *erro
 		res = SUCCEED;
 	}
 	else
+	{
 		zbx_snprintf(error, MAX_STRING_LEN, "host [%s] not found", host);
 
+		DBbegin();
+
+		switch (zbx_process)
+		{
+		case ZBX_PROCESS_SERVER:
+			DBregister_host(0, host, (int)time(NULL));
+			break;
+		case ZBX_PROCESS_PROXY:
+			DBproxy_register_host(host);
+			break;
+		}
+
+		DBcommit();
+	}
+
 	DBfree_result(result);
 
 	zbx_free(host_esc);
@@ -78,8 +100,8 @@ static int	get_hostid_by_host(const char *host, zbx_uint64_t *hostid, char *erro
  * Parameters: sock - open socket of server-agent connection                  *
  *             request - request buffer                                       *
  *                                                                            *
- * Return value:  SUCCEED - list of active checks sent succesfully            *
- *                FAIL - an error occured                                     *
+ * Return value:  SUCCEED - list of active checks sent successfully           *
+ *                FAIL - an error occurred                                    *
  *                                                                            *
  * Author: Alexei Vladishev                                                   *
  *                                                                            *
@@ -87,7 +109,7 @@ static int	get_hostid_by_host(const char *host, zbx_uint64_t *hostid, char *erro
  *           format of the list: key:delay:last_log_size                      *
  *                                                                            *
  ******************************************************************************/
-int	send_list_of_active_checks(zbx_sock_t *sock, char *request)
+int	send_list_of_active_checks(zbx_sock_t *sock, char *request, zbx_process_t zbx_process)
 {
 	char		*host = NULL, *p;
 	DB_RESULT	result;
@@ -114,7 +136,7 @@ int	send_list_of_active_checks(zbx_sock_t *sock, char *request)
 		goto out;
 	}
 
-	if (FAIL == get_hostid_by_host(host, &hostid, error))
+	if (FAIL == get_hostid_by_host(host, &hostid, error, zbx_process))
 		goto out;
 
 	buffer = zbx_malloc(buffer, buffer_alloc);
@@ -130,8 +152,9 @@ int	send_list_of_active_checks(zbx_sock_t *sock, char *request)
 
 	if (0 != CONFIG_REFRESH_UNSUPPORTED) {
 		zbx_snprintf_alloc(&buffer, &buffer_alloc, &buffer_offset, 256,
-				" and (i.status=%d or (i.status=%d and i.nextcheck<=%d))",
-				ITEM_STATUS_ACTIVE, ITEM_STATUS_NOTSUPPORTED, time(NULL));
+				" and (i.status=%d or (i.status=%d and i.lastclock+%d<=%d))",
+				ITEM_STATUS_ACTIVE, ITEM_STATUS_NOTSUPPORTED,
+				CONFIG_REFRESH_UNSUPPORTED, time(NULL));
 	} else {
 		zbx_snprintf_alloc(&buffer, &buffer_alloc, &buffer_offset, 256,
 				" and i.status=%d",
@@ -155,10 +178,12 @@ int	send_list_of_active_checks(zbx_sock_t *sock, char *request)
 	zabbix_log(LOG_LEVEL_DEBUG, "Sending [%s]",
 			buffer);
 
+	alarm(CONFIG_TIMEOUT);
 	if (SUCCEED != zbx_tcp_send_raw(sock, buffer))
 		zbx_snprintf(error, MAX_STRING_LEN, "%s", zbx_tcp_strerror());
 	else
 		res = SUCCEED;
+	alarm(0);
 
 	zbx_free(buffer);
 
@@ -170,6 +195,21 @@ out:
 	return res;
 }
 
+static	void	add_regexp_name(char ***regexp, int *regexp_alloc, int *regexp_num, const char *regexp_name)
+{
+	int i = 0;
+	for (; i < *regexp_num; i++)
+		if (0 == strcmp(*regexp[i], regexp_name))
+			return;
+	if (i == *regexp_num) {
+		if (*regexp_num == *regexp_alloc) {
+			*regexp_alloc += 32;
+			*regexp = zbx_realloc(*regexp, *regexp_alloc);
+		}
+		*regexp[*regexp_num++] = strdup(regexp_name);
+	}
+}
+
 /******************************************************************************
  *                                                                            *
  * Function: send_list_of_active_checks_json                                  *
@@ -179,17 +219,19 @@ out:
  * Parameters: sock - open socket of server-agent connection                  *
  *             json - request buffer                                          *
  *                                                                            *
- * Return value:  SUCCEED - list of active checks sent succesfully            *
- *                FAIL - an error occured                                     *
+ * Return value:  SUCCEED - list of active checks sent successfully           *
+ *                FAIL - an error occurred                                    *
  *                                                                            *
  * Author: Aleksander Vladishev                                               *
  *                                                                            *
  * Comments:                                                                  *
  *                                                                            *
  ******************************************************************************/
-int	send_list_of_active_checks_json(zbx_sock_t *sock, struct zbx_json_parse *jp)
+int	send_list_of_active_checks_json(zbx_sock_t *sock, struct zbx_json_parse *jp, zbx_process_t zbx_process)
 {
-	char		host[MAX_STRING_LEN], tmp[32];
+	char		host[HOST_HOST_LEN_MAX], *name_esc, params[MAX_STRING_LEN],
+			pattern[MAX_STRING_LEN], tmp[32],
+			key_severity[MAX_STRING_LEN], key_logeventid[MAX_STRING_LEN];
 	DB_RESULT	result;
 	DB_ROW		row;
 	DB_ITEM		item;
@@ -198,6 +240,14 @@ int	send_list_of_active_checks_json(zbx_sock_t *sock, struct zbx_json_parse *jp)
 	zbx_uint64_t	hostid;
 	char		error[MAX_STRING_LEN];
 
+	char		**regexp = NULL;
+	int		regexp_alloc = 32;
+	int		regexp_num = 0, n;
+
+	char		*sql = NULL;
+	int		sql_alloc = 2048;
+	int		sql_offset;
+
 	zabbix_log(LOG_LEVEL_DEBUG, "In send_list_of_active_checks_json()");
 
 	if (FAIL == zbx_json_value_by_name(jp, ZBX_PROTO_TAG_HOST, host, sizeof(host)))
@@ -206,31 +256,39 @@ int	send_list_of_active_checks_json(zbx_sock_t *sock, struct zbx_json_parse *jp)
 		goto error;
 	}
 
-	if (FAIL == get_hostid_by_host(host, &hostid, error))
+	if (FAIL == get_hostid_by_host(host, &hostid, error, zbx_process))
 		goto error;
 
-	if (0 != CONFIG_REFRESH_UNSUPPORTED) {
-		result = DBselect("select %s where i.hostid=h.hostid and h.status=%d and i.type=%d and h.hostid=" ZBX_FS_UI64
-			" and h.proxy_hostid=0 and (i.status=%d or (i.status=%d and i.nextcheck<=%d))",
+	regexp = zbx_malloc(regexp, regexp_alloc);
+	sql = zbx_malloc(sql, sql_alloc);
+
+	name_esc = DBdyn_escape_string(host);
+
+	sql_offset = 0;
+	zbx_snprintf_alloc(&sql, &sql_alloc, &sql_offset, 1024,
+			"select %s where i.hostid=h.hostid and h.status=%d and i.type=%d and h.hostid=" ZBX_FS_UI64
+			" and h.proxy_hostid=0",
 			ZBX_SQL_ITEM_SELECT,
 			HOST_STATUS_MONITORED,
 			ITEM_TYPE_ZABBIX_ACTIVE,
-			hostid,
-			ITEM_STATUS_ACTIVE, ITEM_STATUS_NOTSUPPORTED, time(NULL));
-	} else {
-		result = DBselect("select %s where i.hostid=h.hostid and h.status=%d and i.type=%d and h.hostid=" ZBX_FS_UI64
-			" and h.proxy_hostid=0 and i.status=%d",
-			ZBX_SQL_ITEM_SELECT,
-			HOST_STATUS_MONITORED,
-			ITEM_TYPE_ZABBIX_ACTIVE,
-			hostid,
-			ITEM_STATUS_ACTIVE);
-	}
+			hostid);
+
+	if (0 != CONFIG_REFRESH_UNSUPPORTED)
+		zbx_snprintf_alloc(&sql, &sql_alloc, &sql_offset, 256, " and (i.status=%d or (i.status=%d and i.lastclock+%d<=%d))",
+				ITEM_STATUS_ACTIVE, ITEM_STATUS_NOTSUPPORTED,
+				CONFIG_REFRESH_UNSUPPORTED, time(NULL));
+	else
+		zbx_snprintf_alloc(&sql, &sql_alloc, &sql_offset, 256, " and i.status=%d",
+				ITEM_STATUS_ACTIVE);
+
+	zbx_free(name_esc);
 
 	zbx_json_init(&json, ZBX_JSON_STAT_BUF_LEN);
 	zbx_json_addstring(&json, ZBX_PROTO_TAG_RESPONSE, ZBX_PROTO_VALUE_SUCCESS, ZBX_JSON_TYPE_STRING);
 	zbx_json_addarray(&json, ZBX_PROTO_TAG_DATA);
 
+	result = DBselect("%s", sql);
+
 	while (NULL != (row = DBfetch(result)))
 	{
 		DBget_item_from_db(&item, row);
@@ -243,23 +301,110 @@ int	send_list_of_active_checks_json(zbx_sock_t *sock, struct zbx_json_parse *jp)
 		zbx_json_addstring(&json, ZBX_PROTO_TAG_DELAY, tmp, ZBX_JSON_TYPE_STRING);
 		zbx_snprintf(tmp, sizeof(tmp), "%d", item.lastlogsize);
 		zbx_json_addstring(&json, ZBX_PROTO_TAG_LOGLASTSIZE, tmp, ZBX_JSON_TYPE_STRING);
+		zbx_snprintf(tmp, sizeof(tmp), "%d", item.mtime);
+		zbx_json_addstring(&json, ZBX_PROTO_TAG_MTIME, tmp, ZBX_JSON_TYPE_STRING);
 		zbx_json_close(&json);
+
+		/* Special processing for log[] and logrt[] items */
+		do {	/* simple try realization */
+
+			/* log[filename,pattern,encoding,maxlinespersec] */
+			/* logrt[filename_format,pattern,encoding,maxlinespersec] */
+
+			if (0 != strncmp(item.key, "log[", 4) && 0 != strncmp(item.key, "logrt[", 11))
+				break;
+
+			if (2 != parse_command(item.key, NULL, 0, params, MAX_STRING_LEN))
+				break;
+
+			/*dealing with `pattern' parameter*/
+			if (0 == get_param(params, 2, pattern, sizeof(pattern)) &&
+				*pattern == '@')
+					add_regexp_name(&regexp, &regexp_alloc, &regexp_num, pattern + 1);
+		} while (0);	/* simple try realization */
+
+		/* Special processing for eventlog[] items */
+		do {	/* simple try realization */
+
+			/* eventlog[filename,pattern,severity,source,logeventid,maxlinespersec] */
+
+			if (0 != strncmp(item.key, "eventlog[", 9))
+				break;
+
+			if (2 != parse_command(item.key, NULL, 0, params, MAX_STRING_LEN))
+				break;
+
+			/*dealing with `pattern' parameter*/
+			if (0 == get_param(params, 2, pattern, sizeof(pattern)) &&
+				*pattern == '@')
+					add_regexp_name(&regexp, &regexp_alloc, &regexp_num, pattern + 1);
+
+			/*dealing with `severity' parameter*/
+			if (0 == get_param(params, 3, key_severity, sizeof(key_severity)) &&
+				*key_severity == '@')
+					add_regexp_name(&regexp, &regexp_alloc, &regexp_num, key_severity + 1);
+
+			/*dealing with `logeventid' parameter*/
+			if (0 == get_param(params, 5, key_logeventid, sizeof(key_logeventid)) &&
+				*key_logeventid == '@')
+					add_regexp_name(&regexp, &regexp_alloc, &regexp_num, key_logeventid + 1);
+		} while (0);	/* simple try realization */
 	}
+	zbx_json_close(&json);
+
 	DBfree_result(result);
 
+	if (0 != regexp_num)
+	{
+		zbx_json_addarray(&json, ZBX_PROTO_TAG_REGEXP);
+
+		sql_offset = 0;
+		zbx_snprintf_alloc(&sql, &sql_alloc, &sql_offset, 512,
+				"select r.name,e.expression,e.expression_type,e.exp_delimiter,e.case_sensitive"
+				" from regexps r,expressions e where r.regexpid=e.regexpid and r.name in (");
+
+		for (n = 0; n < regexp_num; n++)
+		{
+			name_esc = DBdyn_escape_string(regexp[n]);
+			zbx_snprintf_alloc(&sql, &sql_alloc, &sql_offset, 512, "%s'%s'",
+					n == 0 ? "" : ",",
+					name_esc);
+			zbx_free(name_esc);
+			zbx_free(regexp[n]);
+		}
+		zbx_snprintf_alloc(&sql, &sql_alloc, &sql_offset, 8, ")");
+
+		result = DBselect("%s", sql);
+		while (NULL != (row = DBfetch(result)))
+		{
+			zbx_json_addobject(&json, NULL);
+			zbx_json_addstring(&json, "name", row[0], ZBX_JSON_TYPE_STRING);
+			zbx_json_addstring(&json, "expression", row[1], ZBX_JSON_TYPE_STRING);
+			zbx_json_addstring(&json, "expression_type", row[2], ZBX_JSON_TYPE_INT);
+			zbx_json_addstring(&json, "exp_delimiter", row[3], ZBX_JSON_TYPE_STRING);
+			zbx_json_addstring(&json, "case_sensitive", row[4], ZBX_JSON_TYPE_INT);
+			zbx_json_close(&json);
+		}
+		DBfree_result(result);
+	}
+	zbx_free(regexp);
+
 	zabbix_log(LOG_LEVEL_DEBUG, "Sending [%s]",
 			json.buffer);
 
-	if (SUCCEED != zbx_tcp_send_raw(sock, json.buffer))
+	alarm(CONFIG_TIMEOUT);
+	if (SUCCEED != zbx_tcp_send(sock, json.buffer))
 		zbx_snprintf(error, MAX_STRING_LEN, "%s", zbx_tcp_strerror());
 	else
 		res = SUCCEED;
+	alarm(0);
 
 	zbx_json_free(&json);
+	zbx_free(sql);
 
 	return res;
 error:
-	zabbix_log(LOG_LEVEL_WARNING, "Send list of active checks to [%s] failed: %s",
+	zabbix_log(LOG_LEVEL_WARNING, "Sending list of active checks to [%s] failed: %s",
 			get_ip_by_socket(sock), error);
 
 	zbx_json_init(&json, ZBX_JSON_STAT_BUF_LEN);
@@ -269,7 +414,7 @@ error:
 	zabbix_log(LOG_LEVEL_DEBUG, "Sending [%s]",
 			json.buffer);
 
-	res = zbx_tcp_send_raw(sock, json.buffer);
+	res = zbx_tcp_send(sock, json.buffer);
 
 	zbx_json_free(&json);
 
