@@ -1,4 +1,4 @@
-/* 
+/*
 ** ZABBIX
 ** Copyright (C) 2000-2005 SIA Zabbix
 **
@@ -18,29 +18,64 @@
 **/
 
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <unistd.h>
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <netinet/in.h>
-#include <netdb.h>
+//#include <stdio.h>
+//#include <stdlib.h>
+//#include <unistd.h>
+//#include <sys/types.h>
+//#include <sys/stat.h>
+//#include <netinet/in.h>
+//#include <netdb.h>
 
-#include <string.h>
+//#include <string.h>
 
-#include <time.h>
+//#include <time.h>
 
-#include <sys/socket.h>
-#include <errno.h>
+//#include <sys/socket.h>
+//#include <errno.h>
 
+#include "common.h"
 #include "nodecommand.h"
 #include "comms.h"
-#include "common.h"
+#include "zbxserver.h"
 #include "db.h"
 #include "log.h"
 #include "zlog.h"
 #include "../poller/checks_ipmi.h"
 
+/******************************************************************************
+ *                                                                            *
+ * Function: get_command_by_scriptid                                          *
+ *                                                                            *
+ * Purpose: get script by scriptid                                            *
+ *                                                                            *
+ * Parameters:                                                                *
+ *                                                                            *
+ * Return value: NULL if script not found                                     *
+ *                                                                            *
+ * Author: Aleksander Vladishev                                               *
+ *                                                                            *
+ * Comments:                                                                  *
+ *                                                                            *
+ ******************************************************************************/
+static char	*get_command_by_scriptid(zbx_uint64_t scriptid)
+{
+	DB_RESULT	db_result;
+	DB_ROW		db_row;
+	char		*command = NULL;
+
+	db_result = DBselect(
+			"select command"
+			" from scripts"
+			" where scriptid=" ZBX_FS_UI64,
+			scriptid);
+
+	if (NULL != (db_row = DBfetch(db_result)))
+		command = strdup(db_row[0]);
+	DBfree_result(db_result);
+
+	return command;
+}
+
 /******************************************************************************
  *                                                                            *
  * Function: execute_script                                                   *
@@ -50,26 +85,51 @@
  * Parameters:                                                                *
  *                                                                            *
  * Return value:  SUCCEED - processed successfully                            *
- *                FAIL - an error occured                                     *
+ *                FAIL - an error occurred                                    *
  *                                                                            *
  * Author: Aleksander Vladishev                                               *
  *                                                                            *
  * Comments:                                                                  *
  *                                                                            *
  ******************************************************************************/
-static void	execute_script(zbx_uint64_t hostid, char *command, char **result, int *result_allocated)
+static int	execute_script(zbx_uint64_t scriptid, zbx_uint64_t hostid, char **result)
 {
-	int		result_offset = 0;
-	char		*p, buffer[MAX_STRING_LEN];
+	char		*p, buffer[MAX_STRING_LEN],
+			*command;
+	int		result_alloc = 256, result_offset = 0,
+			ret = FAIL;
 	FILE		*f;
+	DC_HOST		host;
 #ifdef HAVE_OPENIPMI
 	DB_RESULT	db_result;
 	DB_ROW		db_row;
-	DB_ITEM		item;
-	int		ret, val;
+	DC_ITEM		item;
+	int		val;
+	char		error[MAX_STRING_LEN];
 #endif
 
-	zabbix_log(LOG_LEVEL_DEBUG, "In execute_script(command:%s)", command);
+	zabbix_log(LOG_LEVEL_DEBUG, "In execute_script() scriptid:" ZBX_FS_UI64
+			" hostid:" ZBX_FS_UI64, scriptid, hostid);
+
+	if (FAIL == DCget_host_by_hostid(&host, hostid))
+	{
+		*result = zbx_dsprintf(*result, "NODE %d: Unknown Host ID [" ZBX_FS_UI64 "]",
+				CONFIG_NODEID, hostid);
+		return ret;
+	}
+
+	if (NULL == (command = get_command_by_scriptid(scriptid)))
+	{
+		*result = zbx_dsprintf(*result, "NODE %d: Unknowh Script ID [" ZBX_FS_UI64 "]",
+				CONFIG_NODEID, scriptid);
+		return ret;
+	}
+
+	substitute_simple_macros(NULL, NULL, NULL, &host, NULL, NULL,
+			&command, MACRO_TYPE_SCRIPT, NULL, 0);
+
+	zabbix_log(LOG_LEVEL_WARNING, "NODE %d: Executing command: '%s'",
+			CONFIG_NODEID, command);
 
 	p = command;
 	while (*p == ' ' && *p != '\0')
@@ -78,94 +138,83 @@ static void	execute_script(zbx_uint64_t hostid, char *command, char **result, in
 #ifdef HAVE_OPENIPMI
 	if (0 == strncmp(p, "IPMI", 4))
 	{
-		db_result = DBselect("select distinct host,ip,useip,port,dns,useipmi,ipmi_port,ipmi_authtype,"
-				"ipmi_privilege,ipmi_username,ipmi_password from hosts where hostid=" ZBX_FS_UI64 DB_NODE,
+		db_result = DBselect(
+				"select hostid,host,useip,ip,dns,port,useipmi,ipmi_ip,ipmi_port,ipmi_authtype,"
+					"ipmi_privilege,ipmi_username,ipmi_password"
+				" from hosts"
+				" where hostid=" ZBX_FS_UI64
+					DB_NODE,
 				hostid,
 				DBnode_local("hostid"));
 
 		if (NULL != (db_row = DBfetch(db_result)))
 		{
-			item.host_name		= db_row[0];
-			item.host_ip		= db_row[1];
-			item.useip		= atoi(db_row[2]);
-			item.port		= atoi(db_row[3]);
-			item.host_dns		= db_row[4];
+			memset(&item, 0, sizeof(item));
 
-			item.useipmi		= atoi(db_row[5]);
-			item.ipmi_port		= atoi(db_row[6]);
-			item.ipmi_authtype	= atoi(db_row[7]);
-			item.ipmi_privilege	= atoi(db_row[8]);
-			item.ipmi_username	= db_row[9];
-			item.ipmi_password	= db_row[10];
+			ZBX_STR2UINT64(item.host.hostid, db_row[0]);
+			zbx_strlcpy(item.host.host, db_row[1], sizeof(item.host.host));
+			item.host.useip = (unsigned char)atoi(db_row[2]);
+			zbx_strlcpy(item.host.ip, db_row[3], sizeof(item.host.ip));
+			zbx_strlcpy(item.host.dns, db_row[4], sizeof(item.host.dns));
+			item.host.port = (unsigned short)atoi(db_row[5]);
 
-			if (SUCCEED == (ret = parse_ipmi_command(p, &item.ipmi_sensor, &val)))
+			if (1 == atoi(db_row[6]))
 			{
-				if (SUCCEED == (ret = set_ipmi_control_value(&item, val, buffer, sizeof(buffer))))
+				zbx_strlcpy(item.host.ipmi_ip_orig, db_row[7], sizeof(item.host.ipmi_ip));
+				item.host.ipmi_port = (unsigned short)atoi(db_row[8]);
+				item.host.ipmi_authtype = atoi(db_row[9]);
+				item.host.ipmi_privilege = atoi(db_row[10]);
+				zbx_strlcpy(item.host.ipmi_username, db_row[11], sizeof(item.host.ipmi_username));
+				zbx_strlcpy(item.host.ipmi_password, db_row[12], sizeof(item.host.ipmi_password));
+			}
+
+			if (SUCCEED == (ret = parse_ipmi_command(p, item.ipmi_sensor, &val)))
+			{
+				if (SUCCEED == (ret = set_ipmi_control_value(&item, val,
+						error, sizeof(error))))
 				{
-					zbx_snprintf_alloc(result, result_allocated, &result_offset, 128,
-							"%d%cNODE %d: IPMI command successfully executed",
-							ret,
-							ZBX_DM_DELIMITER,
+					*result = zbx_dsprintf(*result, "NODE %d: IPMI command successfully executed",
 							CONFIG_NODEID);
 				}
 				else
-				{
-					zbx_snprintf_alloc(result, result_allocated, &result_offset, 128,
-							"%d%cNODE %d: Cannot execute IPMI command [%s] error: %s",
-							FAIL,
-							ZBX_DM_DELIMITER,
-							CONFIG_NODEID,
-							command,
-							buffer);
-				}
+					*result = zbx_dsprintf(*result, "NODE %d: Cannot execute IPMI command: %s",
+							CONFIG_NODEID, error);
 			}
 			else
-				zbx_snprintf_alloc(result, result_allocated, &result_offset, 128,
-						"%d%cNODE %d: Cannot parse IPMI command [%s]",
-						FAIL,
-						ZBX_DM_DELIMITER,
-						CONFIG_NODEID,
-						command);
+				 *result = zbx_dsprintf(*result, "NODE %d: Cannot parse IPMI command",
+						CONFIG_NODEID);
 		}
 		else
-		{
-			zbx_snprintf_alloc(result, result_allocated, &result_offset, 128,
-					"%d%cNODE %d: Cannot execute [%s] error: Invalid hostid",
-					FAIL,
-					ZBX_DM_DELIMITER,
-					CONFIG_NODEID,
-					command);
-		}
+			*result = zbx_dsprintf(*result, "NODE %d: Unknown Host ID [" ZBX_FS_UI64 "]",
+					CONFIG_NODEID, hostid);
 		DBfree_result(db_result);
 	}
 	else
 	{
 #endif
-		if(0 != (f = popen(p, "r"))) {
-			zbx_snprintf_alloc(result, result_allocated, &result_offset, 8, "%d%c",
-				SUCCEED,
-				ZBX_DM_DELIMITER);
+		if(0 != (f = popen(p, "r")))
+		{
+			*result = zbx_malloc(*result, result_alloc);
+			**result = '\0';
 
-			while (NULL != fgets(buffer, sizeof(buffer)-1, f)) {
-				zbx_snprintf_alloc(result, result_allocated, &result_offset, sizeof(buffer),
-					"%s",
-					buffer);
-			}
-			(*result)[result_offset] = '\0';
+			while (NULL != fgets(buffer, sizeof(buffer), f))
+				zbx_snprintf_alloc(result, &result_alloc, &result_offset,
+						strlen(buffer) + 1, "%s", buffer);
 
 			pclose(f);
-		} else {
-			zbx_snprintf_alloc(result, result_allocated, &result_offset, 128,
-				"%d%cNODE %d: Cannot execute [%s] error:%s",
-				FAIL,
-				ZBX_DM_DELIMITER,
-				CONFIG_NODEID,
-				command,
-				strerror(errno));
+
+			ret = SUCCEED;
 		}
+		else
+			*result = zbx_dsprintf(*result, "NODE %d: Cannot execute command: %s",
+					CONFIG_NODEID, strerror(errno));
 #ifdef HAVE_OPENIPMI
 	}
 #endif
+
+	zbx_free(command);
+
+	return ret;
 }
 
 /******************************************************************************
@@ -177,73 +226,60 @@ static void	execute_script(zbx_uint64_t hostid, char *command, char **result, in
  * Parameters:                                                                *
  *                                                                            *
  * Return value:  SUCCEED - processed successfully                            *
- *                FAIL - an error occured                                     *
+ *                FAIL - an error occurred                                    *
  *                                                                            *
  * Author: Aleksander Vladishev                                               *
  *                                                                            *
  * Comments:                                                                  *
  *                                                                            *
  ******************************************************************************/
-void	send_script(int nodeid, const char *data, char **result, int *result_allocated)
+static int	send_script(int nodeid, const char *data, char **result)
 {
-	DB_RESULT	dbresult;
-	DB_ROW		dbrow;
-	int		result_offset = 0;
-	zbx_sock_t	sock;
-	char		*answer;
+	DB_RESULT		db_result;
+	DB_ROW			db_row;
+	int			ret = FAIL;
+	zbx_sock_t		sock;
+	char			*answer;
 
 	zabbix_log(LOG_LEVEL_DEBUG, "In send_script(nodeid:%d)", nodeid);
 
-	dbresult = DBselect("select ip,port from nodes where nodeid=%d",
-		nodeid);
+	db_result = DBselect(
+			"select ip,port"
+			" from nodes"
+			" where nodeid=%d",
+			nodeid);
 
-	if (NULL != (dbrow = DBfetch(dbresult))) {
-		if (SUCCEED == zbx_tcp_connect(&sock, CONFIG_SOURCE_IP, dbrow[0], atoi(dbrow[1]), 0)) {
-			if (FAIL == zbx_tcp_send(&sock, data)) {
-				zbx_snprintf_alloc(result, result_allocated, &result_offset, 128,
-					"%d%cNODE %d: Error while sending data to Node [%d] error: %s",
-					FAIL,
-					ZBX_DM_DELIMITER,
-					CONFIG_NODEID,
-					nodeid,
-					zbx_tcp_strerror());
+	if (NULL != (db_row = DBfetch(db_result)))
+	{
+		if (SUCCEED == (ret = zbx_tcp_connect(&sock, CONFIG_SOURCE_IP,
+				db_row[0], atoi(db_row[1]), CONFIG_TRAPPER_TIMEOUT)))
+		{
+			if (FAIL == (ret = zbx_tcp_send(&sock, data)))
+			{
+				*result = zbx_dsprintf(*result, "NODE %d: Error while sending data to Node [%d]: %s",
+						CONFIG_NODEID, nodeid, zbx_tcp_strerror());
 				goto exit_sock;
 			}
 
-			if (SUCCEED == zbx_tcp_recv(&sock, &answer/*, ZBX_TCP_READ_UNTIL_CLOSE*/)) {
-				zbx_snprintf_alloc(result, result_allocated, &result_offset, strlen(answer)+1,
-				"%s",
-				answer);
-			} else {
-				zbx_snprintf_alloc(result, result_allocated, &result_offset, 128,
-					"%d%cNODE %d: Error while receiving answer from Node [%d] error: %s",
-					FAIL,
-					ZBX_DM_DELIMITER,
-					CONFIG_NODEID,
-					nodeid,
-					zbx_tcp_strerror());
-				goto exit_sock;
-			}
+			if (SUCCEED == (ret = zbx_tcp_recv(&sock, &answer)))
+				*result = zbx_dsprintf(*result, "%s", answer);
+			else
+				*result = zbx_dsprintf(*result, "NODE %d: Error while receiving data from Node [%d]: %s",
+						CONFIG_NODEID, nodeid, zbx_tcp_strerror());
 exit_sock:
 			zbx_tcp_close(&sock);
-		} else {
-			zbx_snprintf_alloc(result, result_allocated, &result_offset, 128,
-				"%d%cNODE %d: Unable to connect to Node [%d] error: %s",
-				FAIL,
-				ZBX_DM_DELIMITER,
-				CONFIG_NODEID,
-				nodeid,
-				zbx_tcp_strerror());
 		}
-	} else {
-		zbx_snprintf_alloc(result, result_allocated, &result_offset, 128,
-			"%d%cNODE %d: Node [%d] is unknown",
-			FAIL,
-			ZBX_DM_DELIMITER,
-			CONFIG_NODEID,
-			nodeid);
+		else
+			*result = zbx_dsprintf(*result, "NODE %d: Unable to connect to Node [%d]: %s",
+					CONFIG_NODEID, nodeid, zbx_tcp_strerror());
 	}
-	DBfree_result(dbresult);
+	else
+		*result = zbx_dsprintf(*result, "NODE %d: Unknown Node ID [%d]",
+				CONFIG_NODEID, nodeid);
+
+	DBfree_result(db_result);
+
+	return ret;
 }
 
 /******************************************************************************
@@ -255,24 +291,24 @@ exit_sock:
  * Parameters:                                                                *
  *                                                                            *
  * Return value:  SUCCEED - processed successfully                            *
- *                FAIL - an error occured                                     *
+ *                FAIL - an error occurred                                    *
  *                                                                            *
  * Author: Aleksander Vladishev                                               *
  *                                                                            *
  * Comments:                                                                  *
  *                                                                            *
  ******************************************************************************/
-int	get_next_point_to_node(int current_nodeid, int slave_nodeid, int *nodeid)
+static int	get_next_point_to_node(int current_nodeid, int slave_nodeid, int *nodeid)
 {
-	DB_RESULT	dbresult;
-	DB_ROW		dbrow;
+	DB_RESULT	db_result;
+	DB_ROW		db_row;
 	int		id, res = FAIL;
 
-	dbresult = DBselect("select nodeid from nodes where masterid=%d",
+	db_result = DBselect("select nodeid from nodes where masterid=%d",
 		current_nodeid);
 
-	while (NULL != (dbrow = DBfetch(dbresult))) {
-		id = atoi(dbrow[0]);
+	while (NULL != (db_row = DBfetch(db_result))) {
+		id = atoi(db_row[0]);
 		if (id == slave_nodeid || SUCCEED == get_next_point_to_node(id, slave_nodeid, NULL)) {
 			if (NULL != nodeid)
 				*nodeid = id;
@@ -280,7 +316,7 @@ int	get_next_point_to_node(int current_nodeid, int slave_nodeid, int *nodeid)
 			break;
 		}
 	}
-	DBfree_result(dbresult);
+	DBfree_result(db_result);
 
 	return res;
 }
@@ -294,68 +330,81 @@ int	get_next_point_to_node(int current_nodeid, int slave_nodeid, int *nodeid)
  * Parameters:                                                                *
  *                                                                            *
  * Return value:  SUCCEED - processed successfully                            *
- *                FAIL - an error occured                                     *
+ *                FAIL - an error occurred                                    *
  *                                                                            *
  * Author: Aleksander Vladishev                                               *
  *                                                                            *
  * Comments:                                                                  *
  *                                                                            *
  ******************************************************************************/
-int	node_process_command(zbx_sock_t *sock, const char *data)
+int	node_process_command(zbx_sock_t *sock, const char *data, struct zbx_json_parse *jp)
 {
-	const char	*r;
-	char		*tmp = NULL, *result = NULL;
-	int		tmp_allocated = 64, result_allocated = 1024;
-	int		datalen;
-	int		nodeid, next_nodeid;
-	int		result_offset = 0;
-	zbx_uint64_t	hostid;
+	char		*result = NULL, *send, tmp[64];
+	const char	*response;
+	int		nodeid, next_nodeid, ret = FAIL;
+	zbx_uint64_t	scriptid, hostid;
+	struct zbx_json	j;
 
-	result = zbx_malloc(result, result_allocated);
-	tmp = zbx_malloc(tmp, tmp_allocated);
-	datalen = strlen(data);
+	zabbix_log(LOG_LEVEL_DEBUG, "In node_process_command()");
 
-	zabbix_log(LOG_LEVEL_DEBUG, "In node_process_command(datalen:%d)",
-		datalen);
-
-	r = data;
-	zbx_get_next_field(&r, &tmp, &tmp_allocated, ZBX_DM_DELIMITER); /* Constant 'Command' */
-	zbx_get_next_field(&r, &tmp, &tmp_allocated, ZBX_DM_DELIMITER); /* NodeID */
+	if (SUCCEED != zbx_json_value_by_name(jp, ZBX_PROTO_TAG_NODEID, tmp, sizeof(tmp)))
+		return FAIL;
 	nodeid = atoi(tmp);
-	zbx_get_next_field(&r, &tmp, &tmp_allocated, ZBX_DM_DELIMITER); /* hostid */
-	hostid = zbx_atoui64(tmp);
-	zbx_get_next_field(&r, &tmp, &tmp_allocated, ZBX_DM_DELIMITER);
 
-	if (nodeid == CONFIG_NODEID) {
-		zabbix_log(LOG_LEVEL_WARNING, "NODE %d: Received command \"%s\"",
-			CONFIG_NODEID,
-			tmp);
+	if (SUCCEED != zbx_json_value_by_name(jp, ZBX_PROTO_TAG_SCRIPTID, tmp, sizeof(tmp)))
+		return FAIL;
+	ZBX_STR2UINT64(scriptid, tmp);
 
-		execute_script(hostid, tmp, &result, &result_allocated);
-	} else if (SUCCEED == get_next_point_to_node(CONFIG_NODEID, nodeid, &next_nodeid)) {
-		zabbix_log(LOG_LEVEL_WARNING, "NODE %d: Sending command \"%s\" for nodeid %d"
-			"to node %d",
-			CONFIG_NODEID,
-			tmp,
-			nodeid,
-			next_nodeid);
+	if (SUCCEED != zbx_json_value_by_name(jp, ZBX_PROTO_TAG_HOSTID, tmp, sizeof(tmp)))
+		return FAIL;
+	ZBX_STR2UINT64(hostid, tmp);
 
-		send_script(next_nodeid, data, &result, &result_allocated);
-	} else {
-		zbx_snprintf_alloc(&result, &result_allocated, &result_offset, 128,
-			"%d%cNODE %d: Node [%d] is unknown",
-			FAIL,
-			ZBX_DM_DELIMITER,
-			CONFIG_NODEID,
-			nodeid);
+	zbx_json_init(&j, 256);
+
+	if (nodeid == CONFIG_NODEID)
+	{
+		ret = execute_script(scriptid, hostid, &result);
+
+		response = (FAIL == ret) ? ZBX_PROTO_VALUE_FAILED : ZBX_PROTO_VALUE_SUCCESS;
+
+		zbx_json_addstring(&j, ZBX_PROTO_TAG_RESPONSE, response, ZBX_JSON_TYPE_STRING);
+		zbx_json_addstring(&j, ZBX_PROTO_TAG_VALUE, result, ZBX_JSON_TYPE_STRING);
+		send = j.buffer;
+	}
+	else if (SUCCEED == get_next_point_to_node(CONFIG_NODEID, nodeid, &next_nodeid))
+	{
+		zabbix_log(LOG_LEVEL_WARNING, "NODE %d: Sending command for Node %d to Node %d",
+				CONFIG_NODEID, nodeid, next_nodeid);
+
+		if (FAIL == (ret = send_script(next_nodeid, data, &result)))
+		{
+			zbx_json_addstring(&j, ZBX_PROTO_TAG_RESPONSE, ZBX_PROTO_VALUE_FAILED, ZBX_JSON_TYPE_STRING);
+			zbx_json_addstring(&j, ZBX_PROTO_TAG_VALUE, result, ZBX_JSON_TYPE_STRING);
+			send = j.buffer;
+		}
+		else
+			send = result;
+	}
+	else
+	{
+		result = zbx_dsprintf(result, "NODE %d: Unknown Node ID [%d]",
+				CONFIG_NODEID, nodeid);
+
+		zbx_json_addstring(&j, ZBX_PROTO_TAG_RESPONSE, ZBX_PROTO_VALUE_FAILED, ZBX_JSON_TYPE_STRING);
+		zbx_json_addstring(&j, ZBX_PROTO_TAG_VALUE, result, ZBX_JSON_TYPE_STRING);
+		send = j.buffer;
 	}
 
-	if (zbx_tcp_send_raw(sock, result) != SUCCEED) {
+	alarm(CONFIG_TIMEOUT);
+	if (zbx_tcp_send_raw(sock, send) != SUCCEED)
+	{
 		zabbix_log(LOG_LEVEL_WARNING, "NODE %d: Error sending result of command to node %d",
 			CONFIG_NODEID,
 			nodeid);
 	}
-	zbx_free(tmp);
+	alarm(0);
+
+	zbx_json_free(&j);
 	zbx_free(result);
 
 	return SUCCEED;
