@@ -1,4 +1,4 @@
-/* 
+/*
 ** ZABBIX
 ** Copyright (C) 2000-2005 SIA Zabbix
 **
@@ -36,7 +36,7 @@
  * Parameters:                                                                *
  *                                                                            *
  * Return value:  SUCCEED - processed successfully                            *
- *                FAIL - an error occured                                     *
+ *                FAIL - an error occurred                                    *
  *                                                                            *
  * Author: Aleksander Vladishev                                               *
  *                                                                            *
@@ -45,46 +45,60 @@
  ******************************************************************************/
 int	process_discovery_data(zbx_sock_t *sock, struct zbx_json_parse *jp)
 {
+	const char		*__function_name = "process_discovery_data";
 	char			tmp[MAX_STRING_LEN];
+	zbx_uint64_t		last_druleid;
+	DB_DRULE		drule;
 	DB_DCHECK		dcheck;
 	DB_DHOST		dhost;
 	struct zbx_json_parse	jp_data, jp_row;
 	int			res = SUCCEED;
 
-	int			port;
+	int			port, status;
 	const char		*p;
-	char			ip[HOST_IP_LEN_MAX],
-				key_[ITEM_KEY_LEN_MAX];
+	char			last_ip[HOST_IP_LEN_MAX], ip[HOST_IP_LEN_MAX],
+				key_[ITEM_KEY_LEN_MAX],
+				value[DSERVICE_VALUE_LEN_MAX];
 	time_t			now, hosttime, itemtime;
 	zbx_uint64_t		proxy_hostid;
+	DB_RESULT		result;
+	DB_ROW			row;
 
-	zabbix_log(LOG_LEVEL_DEBUG, "In process_discovery_data()");
+	zabbix_log(LOG_LEVEL_DEBUG, "In %s()", __function_name);
 
-	if (FAIL == get_proxy_id(jp, &proxy_hostid)) {
+	if (FAIL == get_proxy_id(jp, &proxy_hostid))
+	{
 		res = FAIL;
 		goto exit;
 	}
 
-	update_proxy_lastaccess(proxy_hostid);
-
 	now = time(NULL);
-	
-	if (FAIL == zbx_json_value_by_name(jp, ZBX_PROTO_TAG_CLOCK, tmp, sizeof(tmp))) {
+
+	if (FAIL == zbx_json_value_by_name(jp, ZBX_PROTO_TAG_CLOCK, tmp, sizeof(tmp)))
+	{
 		res = FAIL;
 		goto exit;
 	}
 
 	hosttime = atoi(tmp);
+	memset(&drule, 0, sizeof(drule));
+	last_druleid = 0;
+	*last_ip = '\0';
 
-	if (SUCCEED == zbx_json_brackets_by_name(jp, ZBX_PROTO_TAG_DATA, &jp_data)) {
-		memset(&dhost, 0, sizeof(dhost));
-
+	if (SUCCEED == zbx_json_brackets_by_name(jp, ZBX_PROTO_TAG_DATA, &jp_data))
+	{
 		p = NULL;
-		while (NULL != (p = zbx_json_next(&jp_data, p)) && SUCCEED == res) {
+		while (NULL != (p = zbx_json_next(&jp_data, p)) && SUCCEED == res)
+		{
 			if (FAIL == (res = zbx_json_brackets_open(p, &jp_row)))
 				break;
 
 			memset(&dcheck, 0, sizeof(dcheck));
+			*key_ = '\0';
+			*value = '\0';
+			port = 0;
+			status = 0;
+			dcheck.key_ = key_;
 
 			if (FAIL == zbx_json_value_by_name(&jp_row, ZBX_PROTO_TAG_CLOCK, tmp, sizeof(tmp)))
 				goto json_parse_error;
@@ -92,7 +106,11 @@ int	process_discovery_data(zbx_sock_t *sock, struct zbx_json_parse *jp)
 
 			if (FAIL == zbx_json_value_by_name(&jp_row, ZBX_PROTO_TAG_DRULE, tmp, sizeof(tmp)))
 				goto json_parse_error;
-			dcheck.druleid = zbx_atoui64(tmp);
+			ZBX_STR2UINT64(drule.druleid, tmp);
+
+			if (FAIL == zbx_json_value_by_name(&jp_row, ZBX_PROTO_TAG_DCHECK, tmp, sizeof(tmp)))
+				goto json_parse_error;
+			ZBX_STR2UINT64(dcheck.dcheckid, tmp);
 
 			if (FAIL == zbx_json_value_by_name(&jp_row, ZBX_PROTO_TAG_TYPE, tmp, sizeof(tmp)))
 				goto json_parse_error;
@@ -101,34 +119,49 @@ int	process_discovery_data(zbx_sock_t *sock, struct zbx_json_parse *jp)
 			if (FAIL == zbx_json_value_by_name(&jp_row, ZBX_PROTO_TAG_IP, ip, sizeof(ip)))
 				goto json_parse_error;
 
-			if (FAIL == zbx_json_value_by_name(&jp_row, ZBX_PROTO_TAG_PORT, tmp, sizeof(tmp)))
-				goto json_parse_error;
-			port = atoi(tmp);
+			if (SUCCEED == zbx_json_value_by_name(&jp_row, ZBX_PROTO_TAG_PORT, tmp, sizeof(tmp)))
+				port = atoi(tmp);
 
-			if (FAIL == zbx_json_value_by_name(&jp_row, ZBX_PROTO_TAG_KEY, key_, sizeof(key_)))
-				goto json_parse_error;
-			dcheck.key_ = key_;
+			zbx_json_value_by_name(&jp_row, ZBX_PROTO_TAG_KEY, key_, sizeof(key_));
+			zbx_json_value_by_name(&jp_row, ZBX_PROTO_TAG_VALUE, value, sizeof(value));
 
-			if (FAIL == zbx_json_value_by_name(&jp_row, ZBX_PROTO_TAG_VALUE, dcheck.value, sizeof(dcheck.value)))
-				goto json_parse_error;
+			if (SUCCEED == zbx_json_value_by_name(&jp_row, ZBX_PROTO_TAG_STATUS, tmp, sizeof(tmp)))
+				status = atoi(tmp);
 
-			if (FAIL == zbx_json_value_by_name(&jp_row, ZBX_PROTO_TAG_STATUS, tmp, sizeof(tmp)))
-				goto json_parse_error;
-			dcheck.status = atoi(tmp);
+			if (0 == last_druleid || drule.druleid != last_druleid)
+			{
+				result = DBselect(
+						"select unique_dcheckid"
+						" from drules"
+						" where druleid=" ZBX_FS_UI64,
+						drule.druleid);
 
-			if (dcheck.type == -1) {
-				memset(&dhost, 0, sizeof(dhost));
-				dhost.druleid = dcheck.druleid;
+				if (NULL != (row = DBfetch(result)))
+					ZBX_STR2UINT64(drule.unique_dcheckid, row[0]);
+				DBfree_result(result);
 
-				register_host(&dhost, ip, dcheck.status);
-				update_host_status(&dhost, dcheck.status, itemtime);
-			} else {
-				memset(&dhost, 0, sizeof(dhost));
-				dhost.druleid = dcheck.druleid;
-
-				update_service(&dhost, &dcheck, ip, port, itemtime);
+				last_druleid = drule.druleid;
 			}
 
+			if ('\0' == *last_ip || 0 != strcmp(ip, last_ip))
+			{
+				memset(&dhost, 0, sizeof(dhost));
+				zbx_strlcpy(last_ip, ip, HOST_IP_LEN_MAX);
+			}
+
+			zabbix_log(LOG_LEVEL_DEBUG, "%s() druleid:" ZBX_FS_UI64 " dcheckid:" ZBX_FS_UI64  " unique_dcheckid:" ZBX_FS_UI64
+					" type:%d time:'%s %s' ip:'%s' port:%d key:'%s' value:'%s'",
+					__function_name, drule.druleid, dcheck.dcheckid, drule.unique_dcheckid, dcheck.type,
+					zbx_date2str(itemtime), zbx_time2str(itemtime),
+					ip, port, dcheck.key_, value);
+
+			DBbegin();
+			if (dcheck.type == -1)
+				update_host(&dhost, ip, status, itemtime);
+			else
+				update_service(&drule, &dcheck, &dhost, ip, port, status, value, itemtime);
+			DBcommit();
+
 			continue;
 json_parse_error:
 			zabbix_log(LOG_LEVEL_WARNING, "Invalid discovery data. %s",
@@ -136,21 +169,22 @@ json_parse_error:
 			zabbix_syslog("Invalid discovery data. %s",
 					zbx_json_strerror());
 		}
-	} else  {
+	}
+	else
+	{
 		zabbix_log(LOG_LEVEL_WARNING, "Invalid discovery data. %s",
 				zbx_json_strerror());
 		zabbix_syslog("Invalid discovery data. %s",
 				zbx_json_strerror());
 	}
 exit:
-	if (SUCCEED != send_result(sock, res, NULL)) {
+	if (SUCCEED != send_result(sock, res, NULL))
+	{
 		zabbix_log(LOG_LEVEL_WARNING, "Error sending result back");
 		zabbix_syslog("Trapper: error sending result back");
 	}
 
-	zabbix_log(LOG_LEVEL_DEBUG, "End of process_discovery_data():%s",
-			res == SUCCEED ? "SUCCEED" : "FAIL");
-	
+	zabbix_log(LOG_LEVEL_DEBUG, "End of %s():%s", __function_name, zbx_result_string(res));
+
 	return res;
 }
-
