@@ -1,4 +1,4 @@
-/* 
+/*
 ** ZABBIX
 ** Copyright (C) 2000-2005 SIA Zabbix
 **
@@ -22,7 +22,6 @@
 #include "cfg.h"
 #include "comms.h"
 #include "pid.h"
-#include "db.h"
 #include "log.h"
 #include "zlog.h"
 #include "zbxjson.h"
@@ -38,6 +37,8 @@
 #include "nodecommand.h"
 #include "proxyconfig.h"
 #include "proxydiscovery.h"
+#include "proxyautoreg.h"
+#include "proxyhosts.h"
 
 #include "daemon.h"
 
@@ -129,8 +130,14 @@ static void	calc_timestamp(char *line,int *timestamp, char *format)
  *             key - item's key                                               *
  *             value - new value of server:key                                *
  *             lastlogsize - if key=log[*], last size of log file             *
+ *                           if key=logrt[*], last size of log file           *
+ *                           if key=eventlog[*], last event id of the log     *
+ *             mtime - if key=logrt[*], last modification time                *
+ *                                                             of log file    *
+ *                     if key=log[*], is not used                             *
+ *                     if key=eventlog[*], is not used                        *
  *                                                                            *
- * Return value: SUCCEED - new value processed sucesfully                     *
+ * Return value: SUCCEED - new value processed successfully                   *
  *               FAIL - otherwise                                             *
  *                                                                            *
  * Author: Alexei Vladishev                                                   *
@@ -138,151 +145,82 @@ static void	calc_timestamp(char *line,int *timestamp, char *format)
  * Comments: for trapper server process                                       *
  *                                                                            *
  ******************************************************************************/
-static void	process_mass_data(zbx_sock_t *sock, zbx_uint64_t proxy_hostid, AGENT_VALUE *values, int value_num,
-		int *processed, time_t proxy_timediff)
+static void	process_mass_data(zbx_sock_t *sock, zbx_uint64_t proxy_hostid, AGENT_VALUE *values,
+		int value_num, int *processed, time_t proxy_timediff)
 {
 	AGENT_RESULT	agent;
-	DB_RESULT	result;
-	DB_ROW		row;
-	DB_ITEM		item;
-	char		host_esc[MAX_STRING_LEN], key_esc[MAX_STRING_LEN];
-	static char	*sql = NULL;
-	static int	sql_allocated = 65536;
-	int		sql_offset = 0, i;
+	DC_ITEM		item;
+	int		i;
 
 	zabbix_log(LOG_LEVEL_DEBUG, "In process_mass_data()");
 
-	if (NULL == sql)
-		sql = zbx_malloc(sql, sql_allocated);
-
-	zbx_snprintf_alloc(&sql, &sql_allocated, &sql_offset, 2048,
-			"select %s where h.hostid=i.hostid and h.proxy_hostid=" ZBX_FS_UI64
-			" and h.status=%d and i.status in (%d,%d)",
-			ZBX_SQL_ITEM_SELECT,
-			proxy_hostid,
-			HOST_STATUS_MONITORED,
-			ITEM_STATUS_ACTIVE, ITEM_STATUS_NOTSUPPORTED);
-
-	if (proxy_hostid == 0)
-	{
-		zbx_snprintf_alloc(&sql, &sql_allocated, &sql_offset, 64,
-				" and i.type in (%d,%d)",
-				ITEM_TYPE_TRAPPER,
-				ITEM_TYPE_ZABBIX_ACTIVE);
-	}
-	else
-	{
-		zbx_snprintf_alloc(&sql, &sql_allocated, &sql_offset, 64,
-				" and i.type in (%d,%d,%d,%d,%d,%d,%d,%d,%d,%d)",
-				ITEM_TYPE_ZABBIX,
-				ITEM_TYPE_SNMPv1,
-				ITEM_TYPE_TRAPPER,
-				ITEM_TYPE_SIMPLE,
-				ITEM_TYPE_SNMPv2c,
-				ITEM_TYPE_SNMPv3,
-				ITEM_TYPE_ZABBIX_ACTIVE,
-				ITEM_TYPE_HTTPTEST,
-				ITEM_TYPE_EXTERNAL,
-				ITEM_TYPE_IPMI);
-	}
-
-	zbx_snprintf_alloc(&sql, &sql_allocated, &sql_offset, 8, " and (");
+	DCinit_nextchecks();
 
 	for (i = 0; i < value_num; i++)
 	{
-		DBescape_string(values[i].host_name, host_esc, sizeof(host_esc));
-		DBescape_string(values[i].key, key_esc, sizeof(key_esc));
-		zbx_snprintf_alloc(&sql, &sql_allocated, &sql_offset, 512,
-				"(h.host='%s' and i.key_='%s') or ",
-				host_esc,
-				key_esc);
-	}
-
-	sql_offset -= 4;
-	zbx_snprintf_alloc(&sql, &sql_allocated, &sql_offset, 128, ")" DB_NODE,
-			DBnode_local("h.hostid"));
-
-	result = DBselect("%s", sql);
-
-	while (NULL != (row = DBfetch(result))) {
-		DBget_item_from_db(&item, row);
-
-		if (item.type == ITEM_TYPE_ZABBIX_ACTIVE && FAIL == zbx_tcp_check_security(sock, item.trapper_hosts, 1))
+		if (SUCCEED != DCconfig_get_item_by_key(&item, proxy_hostid, values[i].host_name, values[i].key))
 			continue;
 
-		for (i = 0; i < value_num; i++)
+		if (item.host.maintenance_status == HOST_MAINTENANCE_STATUS_ON &&
+				item.host.maintenance_type == MAINTENANCE_TYPE_NODATA &&
+				item.host.maintenance_from <= values[i].clock)
+			continue;
+
+		if (item.type != ITEM_TYPE_TRAPPER && item.type != ITEM_TYPE_ZABBIX_ACTIVE)
+			if (0 != proxy_hostid && (item.type == ITEM_TYPE_INTERNAL ||
+						item.type == ITEM_TYPE_AGGREGATE ||
+						item.type == ITEM_TYPE_DB_MONITOR))
+			continue;
+			
+		if (item.type == ITEM_TYPE_TRAPPER &&
+				FAIL == zbx_tcp_check_security(sock, item.trapper_hosts, 1))
 		{
-			if (0 == strcmp(item.host_name, values[i].host_name) && 0 == strcmp(item.key_orig, values[i].key)) {
-/*				zabbix_log(LOG_LEVEL_DEBUG, "Processing [%s@%s: \"%s\"]",
-						item.key,
-						item.host_name,
-						values[i].value);*/
-
-				if (0 == strcmp(values[i].value, "ZBX_NOTSUPPORTED"))
-				{
-					zabbix_log(LOG_LEVEL_WARNING, "Active parameter [%s] is not supported by agent on host [%s]",
-							item.key_orig,
-							item.host_name);
-					zabbix_syslog("Active parameter [%s] is not supported by agent on host [%s]",
-							item.key_orig,
-							item.host_name);
-
-					if (NULL != processed)
-						(*processed)++;
-				}
-				else
-				{
-					if (0 == strncmp(item.key, "log[", 4) || 0 == strncmp(item.key, "eventlog[", 9))
-					{
-						item.lastlogsize = values[i].lastlogsize;
-						item.timestamp = values[i].timestamp;
-
-						calc_timestamp(values[i].value, &item.timestamp, item.logtimefmt);
-
-						item.eventlog_severity = values[i].severity;
-						item.eventlog_source = values[i].source;
-
-/*						zabbix_log(LOG_LEVEL_DEBUG, "Value [%s] Lastlogsize [%s] Timestamp [%s]",
-								values[i].value,
-								item.lastlogsize,
-								item.timestamp);*/
-					}
-
-					init_result(&agent);
-
-					if (SUCCEED == set_result_type(&agent, item.value_type, values[i].value))
-					{
-						if (0 == CONFIG_DBSYNCER_FORKS)
-							DBbegin();
-
-						switch (zbx_process) {
-						case ZBX_PROCESS_SERVER:
-							process_new_value(&item, &agent, values[i].clock);
-							break;
-						case ZBX_PROCESS_PROXY:
-							proxy_process_new_value(&item, &agent, values[i].clock);
-							break;
-						}
-
-						if (0 == CONFIG_DBSYNCER_FORKS)
-							DBcommit();
-
-						if (NULL != processed)
-							(*processed)++;
-					}
-					else
-					{
-						if (GET_MSG_RESULT(&agent))
-							zabbix_log(LOG_LEVEL_WARNING, "Item [%s] error: %s",
-									zbx_host_key_string_by_item(&item),
-									agent.msg);
-					}
-					free_result(&agent);
-			 	}
-			}
+			zabbix_log(LOG_LEVEL_WARNING, "Process data failed: %s", zbx_tcp_strerror());
+			continue;
 		}
+
+		if (0 == strcmp(values[i].value, "ZBX_NOTSUPPORTED"))
+		{
+			DCadd_nextcheck(&item, (time_t)values[i].clock, values[i].value);
+
+			if (NULL != processed)
+				(*processed)++;
+		}
+		else
+		{
+			init_result(&agent);
+
+			if (SUCCEED == set_result_type(&agent, item.value_type, item.data_type, values[i].value))
+			{
+				if (ITEM_VALUE_TYPE_LOG == item.value_type)
+					calc_timestamp(values[i].value, &values[i].timestamp, item.logtimefmt);
+
+				dc_add_history(item.itemid, item.value_type, &agent, values[i].clock,
+						values[i].timestamp, values[i].source, values[i].severity,
+						values[i].logeventid, values[i].lastlogsize, values[i].mtime);
+
+				if (NULL != processed)
+					(*processed)++;
+			}
+			else if (GET_MSG_RESULT(&agent))
+			{
+				zabbix_log(LOG_LEVEL_WARNING, "Item [%s:%s] error: %s",
+						item.host.host, item.key_orig, agent.msg);
+				DCadd_nextcheck(&item, (time_t)values[i].clock, agent.msg);
+			}
+			else
+			{
+				/* this should never happen
+				 * set_result_type() always set MSG result if not SUCCEED
+				 */
+			}
+			free_result(&agent);
+	 	}
 	}
-	DBfree_result(result);
+
+	DCflush_nextchecks();
+
+	zabbix_log(LOG_LEVEL_DEBUG, "End process_mass_data()");
 }
 
 /******************************************************************************
@@ -294,7 +232,7 @@ static void	process_mass_data(zbx_sock_t *sock, zbx_uint64_t proxy_hostid, AGENT
  * Parameters: result SUCCEED or FAIL                                         *
  *                                                                            *
  * Return value:  SUCCEED - processed successfully                            *
- *                FAIL - an error occured                                     *
+ *                FAIL - an error occurred                                    *
  *                                                                            *
  * Author: Alexei Vladishev                                                   *
  *                                                                            *
@@ -313,7 +251,9 @@ int	send_result(zbx_sock_t *sock, int result, char *info)
 	{
 		zbx_json_addstring(&json, ZBX_PROTO_TAG_INFO, info, ZBX_JSON_TYPE_STRING);
 	}
+	alarm(CONFIG_TIMEOUT);
 	ret = zbx_tcp_send(sock, json.buffer);
+	alarm(0);
 
 	zbx_json_free(&json);
 
@@ -340,7 +280,7 @@ static void clean_agent_values(AGENT_VALUE *values, int value_num)
  * Parameters:                                                                *
  *                                                                            *
  * Return value:  SUCCEED - processed successfully                            *
- *                FAIL - an error occured                                     *
+ *                FAIL - an error occurred                                    *
  *                                                                            *
  * Author: Alexei Vladishev                                                   *
  *                                                                            *
@@ -359,7 +299,7 @@ static int	process_new_values(zbx_sock_t *sock, struct zbx_json_parse *jp, const
 
 #define VALUES_MAX	256
 	static AGENT_VALUE	*values = NULL, *av;
-	int			value_num = 0;
+	int			value_num = 0, total_num = 0;
 
 	zabbix_log(LOG_LEVEL_DEBUG, "In process_new_values()");
 
@@ -372,7 +312,7 @@ static int	process_new_values(zbx_sock_t *sock, struct zbx_json_parse *jp, const
 	if (SUCCEED == zbx_json_value_by_name(jp, ZBX_PROTO_TAG_CLOCK, tmp, sizeof(tmp)))
 		proxy_timediff = now - atoi(tmp);
 
-/* {"request":"ZBX_SENDER_DATA","data":[{"key":"system.cpu.num",...,...},{...},...]} 
+/* {"request":"ZBX_SENDER_DATA","data":[{"key":"system.cpu.num",...,...},{...},...]}
  *                                     ^
  */	if (NULL == (p = zbx_json_pair_by_name(jp, ZBX_PROTO_TAG_DATA)))
 	{
@@ -382,19 +322,19 @@ static int	process_new_values(zbx_sock_t *sock, struct zbx_json_parse *jp, const
 
 	if(SUCCEED == ret)
 	{
-/* {"request":"ZBX_SENDER_DATA","data":[{"key":"system.cpu.num",...,...},{...},...]} 
+/* {"request":"ZBX_SENDER_DATA","data":[{"key":"system.cpu.num",...,...},{...},...]}
  *                                     ^------------------------------------------^
  */		if (FAIL == (ret = zbx_json_brackets_open(p, &jp_data)))
 			zabbix_log(LOG_LEVEL_WARNING, "Can't proceed jason request. %s",
 					zbx_json_strerror());
 	}
 
-/* {"request":"ZBX_SENDER_DATA","data":[{"key":"system.cpu.num",...,...},{...},...]} 
+/* {"request":"ZBX_SENDER_DATA","data":[{"key":"system.cpu.num",...,...},{...},...]}
  *                                      ^
  */	p = NULL;
 	while (SUCCEED == ret && NULL != (p = zbx_json_next(&jp_data, p)))
 	{
-/* {"request":"ZBX_SENDER_DATA","data":[{"key":"system.cpu.num",...,...},{...},...]} 
+/* {"request":"ZBX_SENDER_DATA","data":[{"key":"system.cpu.num",...,...},{...},...]}
  *                                      ^------------------------------^
  */ 		if (FAIL == (ret = zbx_json_brackets_open(p, &jp_row)))
 			break;
@@ -423,9 +363,12 @@ static int	process_new_values(zbx_sock_t *sock, struct zbx_json_parse *jp, const
 
 		av->value = strdup(tmp);
 
-		if (SUCCEED == zbx_json_value_by_name(&jp_row, ZBX_PROTO_TAG_LOGLASTSIZE, tmp, sizeof(tmp))) 
+		if (SUCCEED == zbx_json_value_by_name(&jp_row, ZBX_PROTO_TAG_LOGLASTSIZE, tmp, sizeof(tmp)))
 			av->lastlogsize = atoi(tmp);
 
+		if (SUCCEED == zbx_json_value_by_name(&jp_row, ZBX_PROTO_TAG_MTIME, tmp, sizeof(tmp)))
+			av->mtime = atoi(tmp);
+
 		if (SUCCEED == zbx_json_value_by_name(&jp_row, ZBX_PROTO_TAG_LOGTIMESTAMP, tmp, sizeof(tmp)))
 			av->timestamp = atoi(tmp);
 
@@ -435,12 +378,16 @@ static int	process_new_values(zbx_sock_t *sock, struct zbx_json_parse *jp, const
 		if (SUCCEED == zbx_json_value_by_name(&jp_row, ZBX_PROTO_TAG_LOGSEVERITY, tmp, sizeof(tmp)))
 			av->severity = atoi(tmp);
 
-		value_num ++;
+		if (SUCCEED == zbx_json_value_by_name(&jp_row, ZBX_PROTO_TAG_LOGEVENTID, tmp, sizeof(tmp)))
+			av->logeventid = atoi(tmp);
+
+		value_num++;
 
 		if (value_num == VALUES_MAX) {
 			process_mass_data(sock, proxy_hostid, values, value_num, &processed, proxy_timediff);
 
 			clean_agent_values(values, value_num);
+			total_num += value_num;
 			value_num = 0;
 		}
 	}
@@ -449,18 +396,21 @@ static int	process_new_values(zbx_sock_t *sock, struct zbx_json_parse *jp, const
 		process_mass_data(sock, proxy_hostid, values, value_num, &processed, proxy_timediff);
 
 	clean_agent_values(values, value_num);
+	total_num += value_num;
 
 	zbx_snprintf(info, sizeof(info), "Processed %d Failed %d Total %d Seconds spent " ZBX_FS_DBL,
 			processed,
-			value_num - processed,
-			value_num,
+			total_num - processed,
+			total_num,
 			zbx_time() - sec);
 
+	alarm(CONFIG_TIMEOUT);
 	if (send_result(sock, ret, info) != SUCCEED)
 	{
 		zabbix_log( LOG_LEVEL_WARNING, "Error sending result back");
 		zabbix_syslog("Trapper: error sending result back");
 	}
+	alarm(0);
 
 	return ret;
 }
@@ -474,7 +424,7 @@ static int	process_new_values(zbx_sock_t *sock, struct zbx_json_parse *jp, const
  * Parameters:                                                                *
  *                                                                            *
  * Return value:  SUCCEED - processed successfully                            *
- *                FAIL - an error occured                                     *
+ *                FAIL - an error occurred                                    *
  *                                                                            *
  * Author: Aleksander Vladishev                                               *
  *                                                                            *
@@ -504,7 +454,7 @@ static int	process_proxy_values(zbx_sock_t *sock, struct zbx_json_parse *jp)
  * Parameters:                                                                *
  *                                                                            *
  * Return value:  SUCCEED - processed successfully                            *
- *                FAIL - an error occured                                     *
+ *                FAIL - an error occurred                                    *
  *                                                                            *
  * Author: Aleksander Vladishev                                               *
  *                                                                            *
@@ -532,9 +482,7 @@ static int	process_proxy_heartbeat(zbx_sock_t *sock, struct zbx_json_parse *jp)
 
 static int	process_trap(zbx_sock_t	*sock, char *s, int max_len)
 {
-	char	*server,*key,*value_string, *data;
-	char	copy[MAX_STRING_LEN];
-	char	host_dec[HOST_HOST_LEN_MAX], key_dec[ITEM_KEY_LEN_MAX], value_dec[MAX_BUF_LEN];
+	char	*pl, *pr, *data, value_dec[MAX_BUF_LEN];
 	char	lastlogsize[11], timestamp[11], source[HISTORY_LOG_SOURCE_LEN_MAX], severity[11];
 	int	sender_nodeid, nodeid;
 	char	*answer;
@@ -555,19 +503,13 @@ static int	process_trap(zbx_sock_t	*sock, char *s, int max_len)
 
 	if (0 == strncmp(s,"ZBX_GET_ACTIVE_CHECKS", 21))	/* Request for list of active checks */
 	{
-		ret = send_list_of_active_checks(sock, s);
+		ret = send_list_of_active_checks(sock, s, zbx_process);
 /* Request for last ids */
 	} else if (strncmp(s,"ZBX_GET_HISTORY_LAST_ID", 23) == 0) {
 		send_history_last_id(sock, s);
 		return ret;
 /* Process information sent by zabbix_sender */
 	} else {
-		/* Command? */
-		if(strncmp(s,"Command",7) == 0)
-		{
-			node_process_command(sock, s);
-			return ret;
-		}
 		/* Node data exchange? */
 		if(strncmp(s,"Data",4) == 0)
 		{
@@ -576,16 +518,22 @@ static int	process_trap(zbx_sock_t	*sock, char *s, int max_len)
 /*			zabbix_log( LOG_LEVEL_WARNING, "Node data received [len:%d]", strlen(s)); */
 			res = node_sync(s, &sender_nodeid, &nodeid);
 			if (FAIL == res)
+			{
+				alarm(CONFIG_TIMEOUT);
 				send_data_to_node(sender_nodeid, sock, "FAIL");
+				alarm(0);
+			}
 			else {
 				res = calculate_checksums(nodeid, NULL, 0);
 				if (SUCCEED == res && NULL != (data = get_config_data(nodeid, ZBX_NODE_SLAVE))) {
+					alarm(CONFIG_TRAPPER_TIMEOUT);
 					res = send_data_to_node(sender_nodeid, sock, data);
 					zbx_free(data);
 					if (SUCCEED == res)
 						res = recv_data_from_node(sender_nodeid, sock, &answer);
 					if (SUCCEED == res && 0 == strcmp(answer, "OK"))
 						res = update_checksums(nodeid, ZBX_NODE_SLAVE, SUCCEED, NULL, 0, NULL);
+					alarm(0);
 				}
 			}
 
@@ -598,10 +546,12 @@ static int	process_trap(zbx_sock_t	*sock, char *s, int max_len)
 		{
 /*			zabbix_log( LOG_LEVEL_WARNING, "Slave node history received [len:%d]", strlen(s)); */
 			if (node_history(s, datalen) == SUCCEED) {
+				alarm(CONFIG_TIMEOUT);
 				if (zbx_tcp_send_raw(sock,"OK") != SUCCEED) {
 					zabbix_log( LOG_LEVEL_WARNING, "Error sending confirmation to node");
 					zabbix_syslog("Trapper: error sending confirmation to node");
 				}
+				alarm(0);
 			}
 			return ret;
 		}
@@ -626,85 +576,80 @@ static int	process_trap(zbx_sock_t	*sock, char *s, int max_len)
 				{
 					ret = process_discovery_data(sock, &jp);
 				}
+				else if (0 == strcmp(value, ZBX_PROTO_VALUE_AUTO_REGISTRATION_DATA) && zbx_process == ZBX_PROCESS_SERVER)
+				{
+					ret = process_autoreg_data(sock, &jp);
+				}
 				else if (0 == strcmp(value, ZBX_PROTO_VALUE_PROXY_HEARTBEAT) && zbx_process == ZBX_PROCESS_SERVER)
 				{
 					ret = process_proxy_heartbeat(sock, &jp);
 				}
 				else if (0 == strcmp(value, ZBX_PROTO_VALUE_GET_ACTIVE_CHECKS))
 				{
-					ret = send_list_of_active_checks_json(sock, &jp);
+					ret = send_list_of_active_checks_json(sock, &jp, zbx_process);
+				}
+				else if (0 == strcmp(value, ZBX_PROTO_VALUE_HOST_AVAILABILITY))
+				{
+					ret = process_host_availability(sock, &jp);
+				}
+				else if (0 == strcmp(value, ZBX_PROTO_VALUE_COMMAND))
+				{
+					ret = node_process_command(sock, s, &jp);
 				}
 				else
 				{
-					zabbix_log( LOG_LEVEL_WARNING, "Unknown request received [%s]",
-						value);
+					zabbix_log(LOG_LEVEL_WARNING, "Unknown request received [%s]",
+							value);
 				}
 			}
 			return ret;
 		}
 		/* New XML protocol? */
-		else if(s[0]=='<')
+		else if (*s == '<')
 		{
-			zabbix_log( LOG_LEVEL_DEBUG, "XML received [%s]", s);
+			comms_parse_response(s, av.host_name, sizeof(av.host_name), av.key, sizeof(av.key), value_dec, sizeof(value_dec),
+					lastlogsize, sizeof(lastlogsize), timestamp, sizeof(timestamp),
+					source, sizeof(source),	severity, sizeof(severity));
 
-			comms_parse_response(s, host_dec, sizeof(host_dec), key_dec, sizeof(key_dec), value_dec, sizeof(value_dec),
-					lastlogsize, sizeof(lastlogsize), timestamp, sizeof(timestamp), source, sizeof(source),
-					severity, sizeof(severity));
-
-			server		= host_dec;
-			value_string	= value_dec;
-			key		= key_dec;
+			av.value	= value_dec;
+			av.lastlogsize	= atoi(lastlogsize);
+			av.timestamp	= atoi(timestamp);
+			av.source	= source;
+			av.severity	= atoi(severity);
 		}
 		else
 		{
-			strscpy(copy,s);
-
-			server=(char *)strtok(s,":");
-			if(NULL == server)
-			{
+			pl = s;
+			if (NULL == (pr = strchr(pl, ':')))
 				return FAIL;
-			}
 
-			key=(char *)strtok(NULL,":");
-			if(NULL == key)
-			{
-				return FAIL;
-			}
-	
-			value_string=strchr(copy,':');
-			value_string=strchr(value_string+1,':');
+			*pr = '\0';
+			zbx_strlcpy(av.host_name, pl, sizeof(av.host_name));
+			*pr = ':';
 
-			if(NULL == value_string)
-			{
+			pl = pr + 1;
+			if (NULL == (pr = strchr(pl, ':')))
 				return FAIL;
-			}
-			/* It points to ':', so have to increment */
-			value_string++;
-			*lastlogsize	= '\0';
-			*timestamp	= '\0';
-			*source		= '\0';
-			*severity	= '\0';
+
+			*pr = '\0';
+			zbx_strlcpy(av.key, pl, sizeof(av.key));
+			*pr = ':';
+
+			av.severity	= 0;
 		}
-		zabbix_log( LOG_LEVEL_DEBUG, "Value [%s]", value_string);
 
 		av.clock = time(NULL);
-		zbx_strlcpy(av.host_name, server, sizeof(av.host_name));
-		zbx_strlcpy(av.key, key, sizeof(av.key));
-		av.value = value_string;
-		av.lastlogsize = atoi(lastlogsize);
-		av.timestamp = atoi(timestamp);
-		av.source = source;
-		av.severity = atoi(severity);
 
 		process_mass_data(sock, 0, &av, 1, NULL, 0);
 
-		if( zbx_tcp_send_raw(sock, SUCCEED == ret ? "OK" : "NOT OK") != SUCCEED)
+		alarm(CONFIG_TIMEOUT);
+		if (SUCCEED != zbx_tcp_send_raw(sock, SUCCEED == ret ? "OK" : "NOT OK"))
 		{
-			zabbix_log( LOG_LEVEL_WARNING, "Error sending result back");
+			zabbix_log(LOG_LEVEL_WARNING, "Error sending result back");
 			zabbix_syslog("Trapper: error sending result back");
 		}
-		zabbix_log( LOG_LEVEL_DEBUG, "After write()");
-	}	
+		alarm(0);
+	}
 	return ret;
 }
 
@@ -712,26 +657,16 @@ void	process_trapper_child(zbx_sock_t *sock)
 {
 	char	*data;
 
-/* suseconds_t is not defined under HP-UX */
-/*	struct timeval tv;
-	suseconds_t    msec;
-	gettimeofday(&tv, NULL);
-	msec = tv.tv_usec;*/
+	alarm(CONFIG_TRAPPER_TIMEOUT);
 
-	alarm(ZABBIX_TRAPPER_TIMEOUT);
-
-	if(zbx_tcp_recv(sock, &data) != SUCCEED)
+	if (SUCCEED != zbx_tcp_recv(sock, &data))
 	{
 		alarm(0);
 		return;
 	}
-
-	process_trap(sock, data, sizeof(data));
 	alarm(0);
 
-/*	gettimeofday(&tv, NULL);
-	zabbix_log( LOG_LEVEL_DEBUG, "Trap processed in " ZBX_FS_DBL " seconds",
-		(double)(tv.tv_usec-msec)/1000000 );*/
+	process_trap(sock, data, sizeof(data));
 }
 
 void	child_trapper_main(zbx_process_t p, zbx_sock_t *s)
@@ -740,9 +675,10 @@ void	child_trapper_main(zbx_process_t p, zbx_sock_t *s)
 
 	zabbix_log( LOG_LEVEL_DEBUG, "In child_trapper_main()");
 
-	phan.sa_handler = child_signal_handler;
+/*	phan.sa_handler = child_signal_handler;*/
+	phan.sa_sigaction = child_signal_handler;
 	sigemptyset(&phan.sa_mask);
-	phan.sa_flags = 0;
+	phan.sa_flags = SA_SIGINFO;
 	sigaction(SIGALRM, &phan, NULL);
 
 	zbx_process = p;
