@@ -1,4 +1,4 @@
-/* 
+/*
 ** ZABBIX
 ** Copyright (C) 2000-2005 SIA Zabbix
 **
@@ -23,6 +23,9 @@
 #include "common.h"
 #include "comms.h"
 
+extern int	CONFIG_TIMEOUT;
+extern int	CONFIG_TRAPPER_TIMEOUT;
+
 #define AGENT_VALUE	struct zbx_agent_value_t
 
 AGENT_VALUE
@@ -32,9 +35,11 @@ AGENT_VALUE
 	char	key[ITEM_KEY_LEN_MAX];
 	char	*value;
 	int	lastlogsize;
+	int	mtime;
 	int	timestamp;
 	char	*source;
 	int	severity;
+	int	logeventid;
 };
 
 int	send_result(zbx_sock_t *sock, int result, char *info);
